# -*- coding: utf-8 -*-
# Copyright 2020 Paul Bailey
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        https://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

# Sourced from https://lw.microstrategy.com/msdz/MSDL/GARelease_Current/docs/ReferenceFiles/reference/com/microstrategy/utils/localization/WebAPIErrorCodes.html
iserver_error_codes = {
    -2147181482: "AE_DISABLEMERGEDE",
    -2147211493: "AE_E_ANASQL",
    -2147212251: "AE_E_APPLYFUNC",
    -2147212221: "AE_E_ATTR_ARITY_INCONSISTENT",
    -2147212258: "AE_E_ATTR_FORM",
    -2147212222: "AE_E_ATTR_FORM_MISSING",
    -2147212252: "AE_E_BREAKBY_LEVEL",
    -2147212260: "AE_E_BREAKBY_UNIT",
    -2147212241: "AE_E_CALCEVENTEVALUATOR",
    -2147212255: "AE_E_CALCPLAN_INTERNAL",
    -2147212257: "AE_E_CALPLAN_DEPENDENCYTABLE",
    -2147212271: "AE_E_CALPLAN_EVENT",
    -2147212240: "AE_E_CAL_METRIC",
    -2147212269: "AE_E_COMPMETRIC_EXPR",
    -2147212270: "AE_E_COMPMETRIC_FUNC",
    -2147212267: "AE_E_COMPMETRIC_TYPE",
    -2147212242: "AE_E_CONSOLIDATION",
    -2147212265: "AE_E_CONST_NODE",
    -2147212266: "AE_E_CONST_TYPE",
    -2147212286: "AE_E_CONVERSION",
    -2147212281: "AE_E_CURRENT_ELEMENT_NOTFOUND",
    -2147212227: "AE_E_DA_DEFINEONDE",
    -2147212226: "AE_E_DA_FORM_ROWCOUNT_MISMATCH",
    -2147212230: "AE_E_DE_DOUBLEDEFINITION",
    -2147212224: "AE_E_DE_INCUBE",
    -2147212225: "AE_E_DE_INEMMACUBE",
    -2147212273: "AE_E_DIMTY_UNIT_TYPE",
    -2147212283: "AE_E_ELEMENT_TYPE_MISMATCH",
    -2147212282: "AE_E_ELEMENT_TYPE_UNEXPECTED",
    -2147212231: "AE_E_FILTER_DE",
    -2147212262: "AE_E_FILTER_EXPR",
    -2147212261: "AE_E_FILTER_FORM",
    -2147212264: "AE_E_FILTER_FUNC",
    -2147212263: "AE_E_FILTER_LEAF",
    -2147212249: "AE_E_FUNCCAL",
    -2147212243: "AE_E_FUNC_NOTAVAILABLE",
    -2147081156: "AE_E_INCREFRESH_MISMATCH",
    -2147079418: "AE_E_INCREFRESH_ML",
    -2147212287: "AE_E_INTERNAL",
    -2147212280: "AE_E_INVALID_TEMPLATE",
    -2147212279: "AE_E_INVALID_UNIT",
    -2147206752: "AE_E_LOAD_OBJECTS",
    -2147474379: "AE_E_METRIC_LEVEL",
    -2147212223: "AE_E_METRIC_LEVEL_MISMATCH",
    -2147212274: "AE_E_METRIC_NOVAL",
    -2147212238: "AE_E_MSIFILETABLE_OPEN",
    -2147212237: "AE_E_MSIFILETABLE_REPORTID",
    -2147212256: "AE_E_NODE",
    -2147212253: "AE_E_NONNUMERIC_INPUT",
    -2147212259: "AE_E_NULLCHECKING",
    -2147474380: "AE_E_PLUGIN_FUNC",
    -2147081148: "AE_E_RA_RELATION_HAS_CIRCLE",
    -2147081147: "AE_E_RA_RELATION_MULTI_PARENTS",
    -2147212284: "AE_E_RB_ELEMENT_NOTFOUND",
    -2147212285: "AE_E_RB_OBJECT_UNEXPECTED",
    -2147212250: "AE_E_SUBSET",
    -2147212248: "AE_E_SUBSET_CONSOLIDATION",
    -2147474378: "AE_E_SUBSET_CSI",
    -2147474377: "AE_E_SUBSET_EXECUTION",
    -2147212247: "AE_E_SUBSET_FILTER",
    -2147212245: "AE_E_SUBSET_METRIC_BASEPLAN",
    -2147212244: "AE_E_SUBSET_METRIC_CMPOUNDLEAF",
    -2147212246: "AE_E_SUBSET_TEMPLATE",
    -2147212276: "AE_E_SUBTOTAL_EXPR",
    -2147212268: "AE_E_SUBTOTAL_INDEX",
    -2147212272: "AE_E_SUBTOTAL_LEVEL",
    -2147212278: "AE_E_SUBTOTAL_METRIC_TYPE",
    -2147212277: "AE_E_SUBTOTAL_METRIC_VAL",
    -2147212275: "AE_E_SUBTOTAL_OBJ",
    -2147212232: "AE_E_UNIT_NOTFOUND",
    -2147212288: "AE_E_UNSPECIFIED",
    -2147212239: "AE_E_VIEWFILTER_MISSINGOBJ",
    -2147212254: "AE_E_VIEW_CREATION",
    -2147212229: "AE_E_WRONGDATATYPE",
    -2147465636: "AE_INFO_AGGREGATION",
    -2147465639: "AE_INFO_CONSOLIDATION",
    -2147465647: "AE_INFO_CROSSTAB",
    -2147465607: "AE_INFO_DATASET_STEPS",
    -2147465635: "AE_INFO_DERIVED_ELEMENT",
    -2147465637: "AE_INFO_FILTER",
    -2147465641: "AE_INFO_INDATASET",
    -2147465640: "AE_INFO_INVIEW",
    -2147465644: "AE_INFO_METRIC",
    -2147465646: "AE_INFO_METRICLIMIT",
    -2147465643: "AE_INFO_ORIGINAL_LEVEL",
    -2147465648: "AE_INFO_STEPS",
    -2147465645: "AE_INFO_SUBTOTAL",
    -2147465642: "AE_INFO_SUBTOTAL_LEVEL",
    -2147465638: "AE_INFO_THRESHOLDS",
    -2147482622: "AE_STR_JOBCOMPLETE",
    -2147217012: "APPOBJ_E_CORRUPTED",
    -2147217019: "APPOBJ_E_DELETED",
    -2147217007: "APPOBJ_E_ELEMENT_ATTRNOTMATCH",
    -2147217006: "APPOBJ_E_ELEMENT_METRICNOTMATCH",
    -2147216934: "APPOBJ_E_FORMNOTFOUND",
    -2147217010: "APPOBJ_E_FORMNOTLOADED",
    -2147217014: "APPOBJ_E_INTERFACE",
    -2147217017: "APPOBJ_E_LASTAXIS",
    -2147217013: "APPOBJ_E_NOTEMPLATE",
    -2147217020: "APPOBJ_E_NOTFOUND",
    -2147216936: "APPOBJ_E_NOT_AVAILABLE_FOR_DISABLED_METRICS",
    -2147216935: "APPOBJ_E_NOT_AVAILABLE_FOR_DISABLED_UNITS",
    -2147217011: "APPOBJ_E_NOXTABVIEW",
    -2147217016: "APPOBJ_E_OBJECT",
    -2147217018: "APPOBJ_E_PARAMETER",
    -2147217015: "APPOBJ_E_POINTER",
    -2147217008: "APPOBJ_E_TEMPLATEFORMS_NOTMATCH",
    -2147217009: "APPOBJ_E_UNINITIALIZED",
    -2147216975: "AUTHEN_E_ADD_HOLDER_TO_MEMBER",
    -2147216977: "AUTHEN_E_ADD_SELF_TO_SELF",
    -2147216978: "AUTHEN_E_ADD_USER_TO_USER",
    -2147216976: "AUTHEN_E_COPY_MEMBERSHIP",
    -2147213317: "AUTHEN_E_DATE_OUT_OF_RANGE",
    -2147212191: "AUTHEN_E_DEPRECATED_PRIVILEGE",
    -2147212057: "AUTHEN_E_INVALID_ANT_COMMENT_EXPIRATION_DATE",
    -2147216957: "AUTHEN_E_INVALID_OPERATION",
    -2147216969: "AUTHEN_E_INVALID_PWD_EXPIRATION_DATE",
    -2147202280: "AUTHEN_E_LDAP_PLATFORM_NOT_FOUND",
    -2147213789: "AUTHEN_E_LOGIN_BAD_TOKEN_STRING",
    -2147202285: "AUTHEN_E_LOGIN_CANNOT_FIND_USER",
    -2147202288: "AUTHEN_E_LOGIN_EMPTY_USERNAME",
    -2147216959: "AUTHEN_E_LOGIN_FAIL",
    -2147216960: "AUTHEN_E_LOGIN_FAILED_NEW_PASSWORD_REQD",
    -2147216965: "AUTHEN_E_LOGIN_FAIL_ACCOUNT_DISABLED",
    -2147213785: "AUTHEN_E_LOGIN_FAIL_CHANGED_PASSWORD",
    -2147216963: "AUTHEN_E_LOGIN_FAIL_EXPIRED_PWD",
    -2147213791: "AUTHEN_E_LOGIN_FAIL_GET_CLIENT_NTSID",
    -2147212462: "AUTHEN_E_LOGIN_FAIL_INTEGRATED",
    -2147216964: "AUTHEN_E_LOGIN_FAIL_INVALID_PWD",
    -2147216962: "AUTHEN_E_LOGIN_FAIL_MUILTUSER",
    -2147213792: "AUTHEN_E_LOGIN_FAIL_NO_STANDARD_AUTH",
    -2147216953: "AUTHEN_E_LOGIN_FAIL_NTTRUST",
    -2147216966: "AUTHEN_E_LOGIN_FAIL_USERGROUP",
    -2147216951: "AUTHEN_E_LOGIN_FAIL_WHCREDENTIAL",
    -2147202286: "AUTHEN_E_LOGIN_PASSWORD_FAIL",
    -2147216961: "AUTHEN_E_LOGIN_USER_NO_PRIV",
    -2147202284: "AUTHEN_E_LOGIN_WITH_INFO",
    -2147216628: "AUTHEN_E_MD4_ALTOWNER_NOT_ENABLED",
    -2147216627: "AUTHEN_E_MD4_ALTOWNER_NO_IMPERSONATE_SYSTEM_USER",
    -2147213402: "AUTHEN_E_OPEN_TOO_MANY_PROJECTS",
    -2147216952: "AUTHEN_E_PASSWD_MODIFIABLE",
    -2147216973: "AUTHEN_E_PRIV_DES_NOTFOUND",
    -2147216974: "AUTHEN_E_PRIV_NAME_NOTFOUND",
    -2147213458: "AUTHEN_E_PUT_LDAPDN",
    -2147216954: "AUTHEN_E_PUT_LOGIN",
    -2147216955: "AUTHEN_E_PUT_NTSID",
    -2147216956: "AUTHEN_E_PUT_RDBMSLOGIN",
    -2147212486: "AUTHEN_E_PUT_UID",
    -2147216972: "AUTHEN_E_PWD_LOCKED",
    -2147202298: "AUTHEN_E_REMOVE_USER_FROM_USER",
    -2147216968: "AUTHEN_E_REQUIRE_NEW_PWD",
    -2147202292: "AUTHEN_E_SECOND_FACTOR_AUTH_FAIL",
    -2147213783: "AUTHEN_E_SYSTEM_PRIVILEGE",
    -2147216971: "AUTHEN_E_USER_ACCT_REQD",
    -2147202287: "AUTHEN_E_USER_LOCKED_EXCEED_FAIL_ATTEPTS",
    -2147216967: "AUTHEN_E_USER_NOT_FOUND",
    -2147213784: "AUTHEN_E_USER_NO_PRIV",
    -2147202277: "AUTHEN_E_USHER_NO_ADMIN_TOKEN",
    -2147202279: "AUTHEN_E_USHER_NO_ORGID",
    -2147202278: "AUTHEN_E_USHER_NO_URL",
    -2147202291: "AUTHEN_E_USHER_QR_CODE_LOGIN_FAIL",
    -2147216970: "AUTHEN_E_WRONG_PWD",
    -2147212488: "AUTHEN_NOT_ALLOW_LOGIN_FOR_NOT_LINKED",
    -2147212489: "AUTHEN_NOT_TRUSTED_WEB_SERVER",
    -2147483133: "AUTH_C_LOGIN_FAIL_ACCOUNT_DISABLED",
    -2147483131: "AUTH_C_LOGIN_FAIL_EXPIRED_PWD",
    -2147483132: "AUTH_C_LOGIN_FAIL_INVALID_PWD",
    -2147483130: "AUTH_C_LOGIN_FAIL_MUILTUSER",
    -2147483134: "AUTH_C_LOGIN_FAIL_USERGROUP",
    -2147483129: "AUTH_C_LOGIN_USER_NO_PRIV",
    -2147483137: "AUTH_C_MD_CONNECTION",
    -2147481382: "AUTH_C_NO_PROJECT_ACCESSIBLE",
    -2147483140: "AUTH_C_NULL_LOGIN",
    -2147483139: "AUTH_C_NULL_MDLOGIN",
    -2147483138: "AUTH_C_NULL_WHLOGIN",
    -2147483135: "AUTH_C_USER_NOT_FOUND",
    -2147483136: "AUTH_C_WH_CONNECTION",
    -2147216958: "AUTH_E_NO_CONFIGURATION",
    -2147213321: "BIGINT_E_FORMAT",
    -2147213322: "BIGINT_E_INVALID_BIG_DECIMAL",
    -2147216997: "BLOCK_TYPE_NOTFOUND",
    -2147211510: "CALC_E_BINDING_PARAM",
    -2147211513: "CALC_E_BUF_SIZE",
    -2147211511: "CALC_E_EXPR",
    -2147211520: "CALC_E_FUNC_NOT_FOUND",
    -2147211515: "CALC_E_INTERNAL",
    -2147211518: "CALC_E_INVALID_FUNCTYPE",
    -2147211519: "CALC_E_LEVEL_MISMATCH",
    -2147211517: "CALC_E_NON_NUMERIC",
    -2147211512: "CALC_E_UNIT",
    -2147211516: "CALC_E_UNSPECIFIED",
    -2147211514: "CALC_E_VARIANT_CONVERT",
    -2147211504: "CALE_E_ANASQL",
    -2147211506: "CALE_E_CONSOLIDATION_ELEM",
    -2147211509: "CALE_E_CONSOLIDATION_EXPR",
    -2147211508: "CALE_E_CONSOLIDATION_UNEXPECTED",
    -2147211507: "CALE_E_SORT_DEF",
    -2147211505: "CALE_E_SORT_METRIC",
    -2147212139: "CATSVR2_E_CATALOGINFOS_DUPLICATE_DBROLE",
    -2147212134: "CATSVR2_E_CATALOGINFOS_NO_DBROLE",
    -2147212124: "CATSVR2_E_COLUMNINFOS_DUPLICATE_ID",
    -2147212137: "CATSVR2_E_COLUMNINFOS_DUPLICATE_NAME",
    -2147212056: "CATSVR2_E_COLUMNINFOS_DUPLICATE_NAME_IN_WH",
    -2147212135: "CATSVR2_E_COLUMNINFOS_UNNAMED",
    -2147212113: "CATSVR2_E_COLUMNINFO_FRESH",
    -2147212115: "CATSVR2_E_COLUMNINFO_MISSING",
    -2147212116: "CATSVR2_E_COLUMNINFO_NOT_FRESH",
    -2147212114: "CATSVR2_E_COLUMNINFO_NO_ID",
    -2147212133: "CATSVR2_E_DBTABLEINFOS_DUPLICATE_ID",
    -2147212138: "CATSVR2_E_DBTABLEINFOS_DUPLICATE_NAME",
    -2147212132: "CATSVR2_E_DBTABLEINFOS_NO_COLUMNS",
    -2147212136: "CATSVR2_E_DBTABLEINFOS_UNNAMED",
    -2147212117: "CATSVR2_E_DBTABLEINFO_FRESH",
    -2147212119: "CATSVR2_E_DBTABLEINFO_MISSING",
    -2147212120: "CATSVR2_E_DBTABLEINFO_NOT_FRESH",
    -2147212118: "CATSVR2_E_DBTABLEINFO_NO_ID",
    -2147213824: "CATSVR_E_CATSQL_MISSING_COLUMN",
    -2147213491: "CATSVR_E_DBMS_DEFAULT_SQL",
    -2147213490: "CATSVR_E_EXPECT_COLUMN_RESTR",
    -2147213786: "CATSVR_E_INCOMPLETE_CATALOG_SQL",
    -2147212195: "CATSVR_E_NO_DBCONNECTION",
    -2147212194: "CATSVR_E_NO_DBLOGIN",
    -2147213796: "CATSVR_E_NO_DBMS",
    -2147213797: "CATSVR_E_NO_DBROLE",
    -2147212045: "CATSVR_E_SAPHANA_VARIABLES_SQL_NOTAVAIL",
    -2147213723: "CATSVR_E_SQL_MISSING_PATTERN",
    -2147213492: "CATSVR_E_TABLE_KEYS_ERROR",
    -2147213493: "CATSVR_E_TABLE_KEYS_NOTAVAIL",
    -2147213494: "CATSVR_E_UNSUPPORTED_FLAGS",
    -2147212004: "CATSVR_E_WHTABLE_MISSING_IN_DB",
    -2147483122: "CLISVC_C_ADMINISTRATOR",
    -2147483123: "CLISVC_C_EVERYONE",
    -2147483128: "CLISVC_C_LOGIN",
    -2147483127: "CLISVC_C_NTSID",
    -2147483125: "CLISVC_C_NULL_NAME",
    -2147483126: "CLISVC_C_RDBMSLOGIN",
    -2147483124: "CLISVC_C_WRONG_SOURCE",
    -2147212112: "CLISVC_E_ANALYSISQUOTA_PROJECT_LEVEL",
    -2147213472: "CLISVC_E_AUDITOR_HANDLE_EXPIRED",
    -2147213471: "CLISVC_E_AUDITOR_HANDLE_MISMATCH",
    -2147213473: "CLISVC_E_AUDITOR_HANDLE_TOO_MANY",
    -2147213778: "CLISVC_E_BAD_DELTA_VERSION",
    -2147212331: "CLISVC_E_CONFIG_2_PROJECT_FILE",
    -2147216948: "CLISVC_E_CREATE_GROUP",
    -2147216949: "CLISVC_E_CREATE_USER",
    -2147216946: "CLISVC_E_DELETE_GROUP",
    -2147213770: "CLISVC_E_DELETE_OBJECT_CONTEXT",
    -2147216947: "CLISVC_E_DELETE_USER",
    -2147213777: "CLISVC_E_DELTA_MD_VERSION_INCOMPATIBLE",
    -2147213775: "CLISVC_E_DELTA_REPEAT_OBJECT",
    -2147213776: "CLISVC_E_DELTA_SCHEMA_INCOMPATIBLE",
    -2147213794: "CLISVC_E_DUP_DBMSLOGIN",
    -2147213793: "CLISVC_E_DUP_NTSID",
    -2147213795: "CLISVC_E_DUP_USERLOGIN",
    -2147216944: "CLISVC_E_GROUP_EXISTED",
    -2147216950: "CLISVC_E_MD4",
    -2147212332: "CLISVC_E_MISSING_DEPENDENCY",
    -2147212146: "CLISVC_E_MULTILINGUAL_STRING_MANIPULATOR_MAX_ERRORS",
    -2147213779: "CLISVC_E_NOT_DELTA_FILE",
    -2147216634: "CLISVC_E_NO_GROUP_USER_PROFILE",
    -2147213479: "CLISVC_E_PREDEFINED_USER_OR_GROUP_NOT_EXISTED",
    -2147212330: "CLISVC_E_PROJECT_2_CONFIG_FILE",
    -2147213474: "CLISVC_E_PROMPT_UNKNOWN",
    -2147213773: "CLISVC_E_REPEATED_MAP_REFERENCE",
    -2147213774: "CLISVC_E_UNDO_KEEPBOTH",
    -2147213771: "CLISVC_E_UNEXPECTED_REPLACE_REFERENCE",
    -2147213772: "CLISVC_E_UNEXPECTED_SEARCH_OR_REPLACE_REFERENCE",
    -2147213798: "CLISVC_E_USERPROFILE_PROJECT_LEVEL",
    -2147213475: "CLISVC_E_USERPROFILE_ROOTFOLDER_NOT_EXIST",
    -2147216945: "CLISVC_E_USER_EXISTED",
    -2147216633: "CLISVC_E_USER_PROFILE_EXIST",
    -2147216632: "CLISVC_E_USER_PROFILE_NOT_EXIST",
    -2147483181: "CLNTCONN_CACHE_ELEMENT_CACHELIFETIME",
    -2147483183: "CLNTCONN_CACHE_ELEMENT_FILECACHEPATH",
    -2147483187: "CLNTCONN_CACHE_ELEMENT_MAXCACHECOUNT",
    -2147483186: "CLNTCONN_CACHE_ELEMENT_MAXMEMORYCONSUMPTION",
    -2147483182: "CLNTCONN_CACHE_ELEMENT_SWAPPOLICY",
    -2147483185: "CLNTCONN_CACHE_ELEMENT_TABLEBUCKETCOUNT",
    -2147483184: "CLNTCONN_CACHE_ELEMENT_TABLEBUCKETPERLOCK",
    -2147483188: "CLNTCONN_CACHE_OBJECT_CACHELIFETIME",
    -2147483190: "CLNTCONN_CACHE_OBJECT_FILECACHEPATH",
    -2147483194: "CLNTCONN_CACHE_OBJECT_MAXCACHECOUNT",
    -2147483193: "CLNTCONN_CACHE_OBJECT_MAXMEMORYCONSUMPTION",
    -2147483189: "CLNTCONN_CACHE_OBJECT_SWAPPOLICY",
    -2147483192: "CLNTCONN_CACHE_OBJECT_TABLEBUCKETCOUNT",
    -2147483191: "CLNTCONN_CACHE_OBJECT_TABLEBUCKETPERLOCK",
    -2147483174: "CLNTCONN_CACHE_REPORT_CACHELIFETIME",
    -2147483173: "CLNTCONN_CACHE_REPORT_DISABLECACHING",
    -2147483176: "CLNTCONN_CACHE_REPORT_FILECACHEPATH",
    -2147483180: "CLNTCONN_CACHE_REPORT_MAXCACHECOUNT",
    -2147483179: "CLNTCONN_CACHE_REPORT_MAXMEMORYCONSUMPTION",
    -2147483175: "CLNTCONN_CACHE_REPORT_SWAPPOLICY",
    -2147483178: "CLNTCONN_CACHE_REPORT_TABLEBUCKETCOUNT",
    -2147483177: "CLNTCONN_CACHE_REPORT_TABLEBUCKETPERLOCK",
    -2147483195: "CLNTCONN_CACHE_START",
    -2147214713: "CLNTCONN_E_1_2_TIER_NO_ADMIN",
    -2147214666: "CLNTCONN_E_3TIER_NO_CONFIG_TYPE",
    -2147214675: "CLNTCONN_E_3T_CREATE_NO_RESULT",
    -2147214674: "CLNTCONN_E_3T_CREATE_RESULT_CORRUPTED",
    -2147214673: "CLNTCONN_E_3T_PROJECT_NOT_ACTIVE",
    -2147214722: "CLNTCONN_E_3_TIER_PROJECT_CREATION_ONLY",
    -2147214723: "CLNTCONN_E_3_TIER_PROJECT_DELETION_CLOSE_PROJECT",
    -2147214693: "CLNTCONN_E_COMPONENT_2TIER",
    -2147214692: "CLNTCONN_E_COMPONENT_34TIER",
    -2147214690: "CLNTCONN_E_CREATE_SESSION_SERVER_LEVEL",
    -2147214683: "CLNTCONN_E_DATASOURCE_2TIER_NOPROJECT_SESSION",
    -2147214685: "CLNTCONN_E_DATASOURCE_CONFIGURATIONID_NOT_NULL",
    -2147214686: "CLNTCONN_E_DATASOURCE_CONFIGURATIONID_NULL",
    -2147214680: "CLNTCONN_E_DATASOURCE_CREATE_EXISTEDCONFIG",
    -2147214681: "CLNTCONN_E_DATASOURCE_CREATE_EXISTEDPROJECT",
    -2147214679: "CLNTCONN_E_DATASOURCE_CREATE_EXISTEDSERVERDEF",
    -2147214669: "CLNTCONN_E_DATASOURCE_DELETE_USER_NO_PRIV",
    -2147214720: "CLNTCONN_E_DATASOURCE_EXIST",
    -2147214705: "CLNTCONN_E_DATASOURCE_INITIALIZED",
    -2147214668: "CLNTCONN_E_DATASOURCE_INVALID_AUTH",
    -2147214719: "CLNTCONN_E_DATASOURCE_NONEXIST",
    -2147214684: "CLNTCONN_E_DATASOURCE_NOT_2TIER",
    -2147214689: "CLNTCONN_E_DATASOURCE_NOT_INDEPENDENT",
    -2147214672: "CLNTCONN_E_DATASOURCE_NOT_MD6_PROJECT",
    -2147214687: "CLNTCONN_E_DATASOURCE_PROJECTID_NOT_NULL",
    -2147214688: "CLNTCONN_E_DATASOURCE_SERVER_NOT_CONNECTED",
    -2147214664: "CLNTCONN_E_DATA_SOURCE_PORT_NO_NEGATIVE",
    -2147214718: "CLNTCONN_E_INCONSISTENT_DATASOURCE_EXIST",
    -2147214710: "CLNTCONN_E_INVALID_MDVERSION",
    -2147214712: "CLNTCONN_E_KEY_NOT_IN_REGISTRY",
    -2147214707: "CLNTCONN_E_KEY_WRITE_FAILURE",
    -2147213480: "CLNTCONN_E_LDAP_NO_2TIER_LDAP_AUTH",
    -2147214677: "CLNTCONN_E_MD4_AUTH_NOTSUPPORT",
    -2147214676: "CLNTCONN_E_MD6_AUTH_NOTSUPPORT",
    -2147212487: "CLNTCONN_E_NO_SIMPLE_SECURITY_PLUG_IN",
    -2147214667: "CLNTCONN_E_PASSWD_ENCRYPTION_FAILURE",
    -2147214663: "CLNTCONN_E_PROJECT_NOT_FOUND",
    -2147214699: "CLNTCONN_E_PROPERTY_GET_2TIER",
    -2147214697: "CLNTCONN_E_PROPERTY_GET_34TIER",
    -2147214695: "CLNTCONN_E_PROPERTY_GET_4TIER",
    -2147214703: "CLNTCONN_E_PROPERTY_GET_PROJECT_LEVEL",
    -2147214701: "CLNTCONN_E_PROPERTY_GET_SERVER_LEVEL",
    -2147214714: "CLNTCONN_E_PROPERTY_NOT_SET",
    -2147214698: "CLNTCONN_E_PROPERTY_PUT_2TIER",
    -2147214696: "CLNTCONN_E_PROPERTY_PUT_34TIER",
    -2147214694: "CLNTCONN_E_PROPERTY_PUT_4TIER",
    -2147214702: "CLNTCONN_E_PROPERTY_PUT_PROJECT_LEVEL",
    -2147214700: "CLNTCONN_E_PROPERTY_PUT_SERVER_LEVEL",
    -2147214706: "CLNTCONN_E_REGISTRY_DELETE_FAIL",
    -2147214709: "CLNTCONN_E_REGISTRY_READ_FAIL",
    -2147214671: "CLNTCONN_E_SCRIPT_NOT_FOUND",
    -2147214721: "CLNTCONN_E_SERVER_NO_PASSTHROUGH",
    -2147214704: "CLNTCONN_E_SERVER_UNINIT",
    -2147214682: "CLNTCONN_E_SESSION_CLOSED",
    -2147214678: "CLNTCONN_E_SESSION_MISMATCH_MDSRV",
    -2147214670: "CLNTCONN_E_SESSION_NO_USER",
    -2147214715: "CLNTCONN_E_TIER_MODE_NOT_SET",
    -2147214665: "CLNTCONN_E_TRUSTED_AUTH_WIN95",
    -2147214691: "CLNTCONN_E_UNDEFINED_ROLE",
    -2147214711: "CLNTCONN_E_VALUE_NOT_IN_REGISTRY",
    -2147214708: "CLNTCONN_E_VALUE_WRITE_FAILURE",
    -2147214717: "CLNTCONN_E_WRONG_PLACE_ADD_PROJECT",
    -2147214716: "CLNTCONN_E_WRONG_PLACE_ADD_SERVER",
    -2147483220: "CLNTCONN_KEY_DATASOURCE",
    -2147483221: "CLNTCONN_KEY_MICROSTRATEGY",
    -2147483203: "CLNTCONN_STR_CONFIGURATIONNAME",
    -2147483205: "CLNTCONN_STR_DATASOURCENAME",
    -2147483202: "CLNTCONN_STR_LOGIN",
    -2147483199: "CLNTCONN_STR_MDLOGIN",
    -2147483198: "CLNTCONN_STR_MDPWD",
    -2147483204: "CLNTCONN_STR_PROJECTNAME",
    -2147483201: "CLNTCONN_STR_PWD",
    -2147483200: "CLNTCONN_STR_TYPE",
    -2147483197: "CLNTCONN_STR_WHLOGIN",
    -2147483196: "CLNTCONN_STR_WHPWD",
    -2147483209: "CLNTCONN_VALUE_ID",
    -2147483219: "CLNTCONN_VALUE_LOCATION",
    -2147483217: "CLNTCONN_VALUE_MDODBCSTRING",
    -2147483215: "CLNTCONN_VALUE_MDVERSION",
    -2147483218: "CLNTCONN_VALUE_MODE",
    -2147483210: "CLNTCONN_VALUE_NAME",
    -2147483213: "CLNTCONN_VALUE_PORTNUMBER",
    -2147483212: "CLNTCONN_VALUE_PROTOCOLTYPE",
    -2147483207: "CLNTCONN_VALUE_REMOTEDSNAME",
    -2147483208: "CLNTCONN_VALUE_REMOTEMACHINE",
    -2147483206: "CLNTCONN_VALUE_SERVERDEFNAME",
    -2147483214: "CLNTCONN_VALUE_SERVERNAME",
    -2147483211: "CLNTCONN_VALUE_URL",
    -2147483216: "CLNTCONN_VALUE_WHODBCSTRING",
    -2147212044: "CLOUDPRO_E_INVALID_OBJECT_NAME",
    -2147212077: "CLOUDPRO_E_UNEXPECTED_REFERENCE_TO_PERSONALIZATION_ATTRIBUTE",
    -2147212054: "CLOUD_E_REPORT_OR_TABLE_DEPENDS_ON_THE_DBROLE",
    -2147212017: "CLOUD_E_UMWH_DBROLE_NOT_SET",
    -2147216931: "CNTSVR_E_COMMAND_UNALLOWED_AT_SERVER_SIDE",
    -2147216941: "CNTSVR_E_PROJECT_NOT_REGISTERED",
    -2147216940: "CNTSVR_E_WRONG_OBJECT_LEVEL",
    -2147213369: "CONTEXT_E_AMBIGUOUS_MEMBER",
    -2147213371: "CONTEXT_E_CHILD_READ_ONLY",
    -2147213372: "CONTEXT_E_CHILD_READ_WRITE",
    -2147213370: "CONTEXT_E_CYCLIC_DEPENDENCY",
    -2147213366: "CONTEXT_E_DIFFERENT_RUNTIME",
    -2147213335: "CONTEXT_E_EDIT_CONTEXT",
    -2147213375: "CONTEXT_E_INVALID_TYPE",
    -2147213377: "CONTEXT_E_OBJECT_MISSING",
    -2147213367: "CONTEXT_E_OVERRIDDEN_DEPENDENT",
    -2147213368: "CONTEXT_E_OVERRIDDEN_MEMBER",
    -2147213376: "CONTEXT_E_READ_ONLY",
    -2147213374: "CONTEXT_E_READ_ONLY_IN_CHILD",
    -2147213341: "CONTEXT_E_REPLACE_WITH_EXISTING",
    -2147213342: "CONTEXT_E_REPLACE_WITH_MISSING",
    -2147213333: "CONTEXT_E_SOLE_MERGED_CHILD",
    -2147213373: "CONTEXT_E_TEMPORARY_REFERENCE",
    -2147213823: "CTXSVR_E_PROJECT_NOT_REGISTERED",
    -2147072532: "CUBSVR_E_NO_EVENT_HANDLER",
    -2147479842: "C_PASSWORD_POLICY_EDIT_DISTANCE",
    -2147479839: "C_PASSWORD_POLICY_MINIMUM_CHARS",
    -2147479847: "C_PASSWORD_POLICY_MINIMUM_LENGTH",
    -2147479845: "C_PASSWORD_POLICY_MINIMUM_LOWERCASE",
    -2147479844: "C_PASSWORD_POLICY_MINIMUM_SPECIAL",
    -2147479846: "C_PASSWORD_POLICY_MINIMUM_UPPERCASE",
    -2147479841: "C_PASSWORD_POLICY_NO_ROTATING",
    -2147479840: "C_PASSWORD_POLICY_NO_USER_INFO",
    -2147479843: "C_PASSWORD_POLICY_NUMBER",
    -2147207143: "DATABASE_OPEN_ERROR",
    -2147207146: "DATABASE_OPEN_INFORMATION",
    -2147207147: "DATABASE_OPEN_SUCCESS",
    -2147212027: "DATA_E_ACCESS_INVALID_CELL",
    -2147212031: "DATA_E_ALREADY_INITIALIZED",
    -2147212020: "DATA_E_ALREADY_LOADED",
    -2147212018: "DATA_E_INTERNAL",
    -2147212030: "DATA_E_INTIALIZE_FAILED",
    -2147212021: "DATA_E_INVALID_DATATYPE",
    -2147212028: "DATA_E_LOAD",
    -2147212025: "DATA_E_METRIC_NOT_FOUND",
    -2147212032: "DATA_E_NOT_INITIALIZED",
    -2147212029: "DATA_E_SAVE",
    -2147212024: "DATA_E_SLICE_NOT_FOUND",
    -2147212026: "DATA_E_UNIT_NOT_FOUND",
    -2147212019: "DATA_E_UNSPECIFIED",
    -2147212022: "DATA_E_WRONG_DATASIZE",
    -2147212023: "DATA_E_WRONG_DATATYPE",
    -2147216982: "DBCAT_E_DIRTY_OBJECT_EXISTS",
    -2147216983: "DBCAT_NO_OBJECT",
    -2147215870: "DBELESVR_BAD_SQLRESULT",
    -2147215868: "DBELESVR_CANTCONNECT",
    -2147215872: "DBELESVR_FAILED_QUERY",
    -2147215871: "DBELESVR_LOADELEMENT_FAILED",
    -2147215869: "DBELESVR_NOELEMENTS",
    -2147206403: "DFC_APPOBJ_EMPTY",
    -2147206409: "DFC_APPOBJ_EXP_AGGMETRIC_NO_EXP",
    -2147206410: "DFC_APPOBJ_EXP_BASE_CALLED",
    -2147206404: "DFC_APPOBJ_EXP_DEF_ERR",
    -2147206412: "DFC_APPOBJ_EXP_LOADAPP",
    -2147206411: "DFC_APPOBJ_EXP_LOGIC",
    -2147206407: "DFC_APPOBJ_EXP_NO_FILTER",
    -2147206406: "DFC_APPOBJ_EXP_NULL_DISP",
    -2147206405: "DFC_APPOBJ_EXP_NULL_FUNC",
    -2147206408: "DFC_APPOBJ_EXP_NULL_TREE_NODE",
    -2147206402: "DFC_APPOBJ_LOGICER_BASE_CLASS",
    -2147206399: "DFC_APPOBJ_LOGICER_FILTER_MQ",
    -2147155971: "DFC_APPOBJ_LOGICER_MORE_PARTITION_ATTR_THAN_SUPPORT",
    -2147206401: "DFC_APPOBJ_LOGICER_NO_FILTER_PART",
    -2147206400: "DFC_APPOBJ_LOGICER_NO_INTERNAL_DATA",
    -2147206397: "DFC_APPOBJ_LOGICER_NO_SQL",
    -2147206398: "DFC_APPOBJ_LOGICER_WRONG_AGG",
    -2147206385: "DFC_APP_OBJ_LOAD_EXP",
    -2147071252: "DFC_BDE_CONNECTION_ERROR",
    -2147205449: "DFC_CONV_EMPTY_TABLE_NAME_DATAMART",
    -2147205451: "DFC_CONV_INVALID_REPORT_DATAMART",
    -2147205450: "DFC_CONV_NO_DATAMART_DEFINED",
    -2147204504: "DFC_CONV_SECURITY_FILTER_LEVEL_CONFLICT",
    -2147206356: "DFC_CONV_TOO_MANY_FORM",
    -2147206362: "DFC_ENGINEERR_GETMOD",
    -2147206358: "DFC_ENGINEERR_GETMSG",
    -2147206360: "DFC_ENGINEERR_ISTREAM",
    -2147206361: "DFC_ENGINEERR_NO_FORMAT_STR",
    -2147206363: "DFC_ENGINEERR_UNKN_MOD",
    -2147206359: "DFC_ENGINEERR_UNPACK",
    -2147206357: "DFC_ENGINEERR_UNPACK_MSG",
    -2147205463: "DFC_ENGSUBGRP_NULL_COMPUNIT",
    -2147206470: "DFC_ENG_AGGMETRIC_BRANCH_GETDT",
    -2147206472: "DFC_ENG_AGGMETRIC_BRANCH_GETMAXTREE",
    -2147206471: "DFC_ENG_AGGMETRIC_BRANCH_REMOVE",
    -2147206474: "DFC_ENG_AGGMETRIC_GENSTRINGRES",
    -2147206466: "DFC_ENG_AGGMETRIC_LEAF_DECOMP",
    -2147206465: "DFC_ENG_AGGMETRIC_LEAF_GETDT",
    -2147206469: "DFC_ENG_AGGMETRIC_LEAF_GETSTRING",
    -2147206468: "DFC_ENG_AGGMETRIC_LEAF_PREPROC",
    -2147206467: "DFC_ENG_AGGMETRIC_LEAF_REMOVE",
    -2147206473: "DFC_ENG_AGGMETRIC_REMOVE",
    -2147205481: "DFC_ENG_COMPUNIT_EMPTY_FROMUNIT",
    -2147206461: "DFC_ENG_COMPUNIT_EMPTY_REP",
    -2147205455: "DFC_ENG_COMPUNIT_GEN_CREATE",
    -2147205489: "DFC_ENG_COMPUNIT_SCHEMA_OLD",
    -2147205429: "DFC_ENG_COMPUNIT_VOID_BASE_CLASS_CALLED",
    -2147205290: "DFC_ENG_CROSSJOIN_ABORT",
    -2147204502: "DFC_ENG_CROSSJOIN_ABORT2",
    -2147206436: "DFC_ENG_CUSTGRP_BAND_BAD_OUTPUT",
    -2147205444: "DFC_ENG_DATAMART_ANA_PASS",
    -2147205485: "DFC_ENG_DATATYPE_NOT_SUPPORTED",
    -2147203490: "DFC_ENG_DDL_FREE_MODE",
    -2147206456: "DFC_ENG_DIMMETRIC_BRANCH_DECOMP",
    -2147206454: "DFC_ENG_DIMMETRIC_BRANCH_GENLEVEL",
    -2147206457: "DFC_ENG_DIMMETRIC_BRANCH_GENTREE",
    -2147206451: "DFC_ENG_DIMMETRIC_BRANCH_PROPALLCH",
    -2147206452: "DFC_ENG_DIMMETRIC_BRANCH_PROPOJ",
    -2147206453: "DFC_ENG_DIMMETRIC_BRANCH_SETDIMTY",
    -2147206455: "DFC_ENG_DIMMETRIC_BRANCH_SETSCHEMA",
    -2147206460: "DFC_ENG_DIMMETRIC_CLONE",
    -2147206459: "DFC_ENG_DIMMETRIC_MERGE",
    -2147206458: "DFC_ENG_DIMMETRIC_SET",
    -2147205440: "DFC_ENG_DIMTY_AV",
    -2147205428: "DFC_ENG_EMPTY_COMPUNIT_BRANCH",
    -2147206443: "DFC_ENG_EXPRFUNC_DECOMP4",
    -2147206440: "DFC_ENG_EXPRFUNC_GENATT",
    -2147206442: "DFC_ENG_EXPRFUNC_GENDBQ",
    -2147206445: "DFC_ENG_EXPRFUNC_GETAGG",
    -2147206439: "DFC_ENG_EXPRFUNC_GETAGGMET",
    -2147206438: "DFC_ENG_EXPRFUNC_GETDBROLE",
    -2147206441: "DFC_ENG_EXPRFUNC_GETDT",
    -2147206449: "DFC_ENG_EXPRFUNC_GETME",
    -2147206444: "DFC_ENG_EXPRFUNC_REMOV",
    -2147206447: "DFC_ENG_EXPRFUNC_UPD",
    -2147206446: "DFC_ENG_EXPRFUNC_UPD_DMDM",
    -2147206448: "DFC_ENG_EXPRFUNC_UPD_NODIM",
    -2147206437: "DFC_ENG_EXPRSCH_EXPR_GETAGG",
    -2147206396: "DFC_ENG_EXP_APPOBJ",
    -2147206395: "DFC_ENG_EXP_LOGIC",
    -2147206394: "DFC_ENG_EXP_NO_DATA",
    -2147206392: "DFC_ENG_EXP_NO_DATA_SAVE",
    -2147206391: "DFC_ENG_EXP_REPORT_EMP",
    -2147206393: "DFC_ENG_EXP_SMALL_BUF",
    -2147205434: "DFC_ENG_FACTSET_COMMON_ENTRYLEVEL",
    -2147205432: "DFC_ENG_FACTSET_DYNAMICFACT",
    -2147205431: "DFC_ENG_FACTSET_DYNAMICFACT_TABLETYPE",
    -2147205435: "DFC_ENG_FACTSET_FACTGROUP",
    -2147205430: "DFC_ENG_FACTSET_FACTLEVEL",
    -2147206463: "DFC_ENG_FACTSET_NOT_SUPPORT",
    -2147206464: "DFC_ENG_FACTSET_NO_TABLE",
    -2147205433: "DFC_ENG_FACTSET_NULL_ENTRYLEVEL",
    -2147205436: "DFC_ENG_FACTSET_RESOLVING_ANALEVEL",
    -2147075253: "DFC_ENG_FACT_TABLE_ASSOC_EMPTY",
    -2147205437: "DFC_ENG_FGTGA_NOTABLE",
    -2147206433: "DFC_ENG_FILTER_EMB_CG",
    -2147206434: "DFC_ENG_FILTER_EMB_GENATTR",
    -2147206435: "DFC_ENG_FILTER_EMB_GENSQL",
    -2147206425: "DFC_ENG_FILTER_ENT_GENATTR",
    -2147206424: "DFC_ENG_FILTER_ENT_SET",
    -2147206423: "DFC_ENG_FILTER_METR_CG",
    -2147206422: "DFC_ENG_FILTER_PRED_GEN",
    -2147206421: "DFC_ENG_FILTER_PRED_ISMG",
    -2147206428: "DFC_ENG_FILTER_UNIT_BR_PROCMQ",
    -2147206429: "DFC_ENG_FILTER_UNIT_BR_RES",
    -2147206427: "DFC_ENG_FILTER_UNIT_BR_UPDEXPR",
    -2147206426: "DFC_ENG_FILTER_UNIT_BR_UPDEXPRAM",
    -2147206432: "DFC_ENG_FILTER_UNIT_GENATTR",
    -2147206431: "DFC_ENG_FILTER_UNIT_GENSQL",
    -2147206430: "DFC_ENG_FILTER_UNIT_UPD",
    -2147206419: "DFC_ENG_FROMUNIT_CJ_GEN",
    -2147205494: "DFC_ENG_FROMUNIT_JOIN_COMPARE_STR_RES_PAIR",
    -2147206418: "DFC_ENG_FROMUNIT_JOIN_GEN",
    -2147205438: "DFC_ENG_FROMUNIT_JOIN_GEN_LEFT_RIGHT",
    -2147205493: "DFC_ENG_FROMUNIT_JOIN_NULL_CHILD",
    -2147206417: "DFC_ENG_FROMUNIT_LEAF_GEN",
    -2147206416: "DFC_ENG_FROMUNIT_LEAF_GEN_ATTR",
    -2147205492: "DFC_ENG_FROMUNIT_LEAF_NULL_TABLE",
    -2147205465: "DFC_ENG_FROMUNIT_NULL_JOINATTR_COLREF",
    -2147205491: "DFC_ENG_FROMUNIT_NULL_LEAF_IN_TREE",
    -2147205471: "DFC_ENG_FROMUNIT_TREE_SIZE",
    -2147205469: "DFC_ENG_FROM_CROSSJOIN_CHILD",
    -2147205464: "DFC_ENG_FROM_CROSSJOIN_FORM",
    -2147205470: "DFC_ENG_FROM_CROSSJOIN_PARENT",
    -2147205475: "DFC_ENG_FROM_DISALLOW_CROSSJOIN",
    -2147201767: "DFC_ENG_FROM_FACTEXTENSION_FAIL",
    -2147206420: "DFC_ENG_FROM_JOIN",
    -2147206329: "DFC_ENG_FROM_LHS_PDTABLE",
    -2147205495: "DFC_ENG_FROM_LINKATTRS_ERR",
    -2147466641: "DFC_ENG_GEN_METRIC_IN_SELECT",
    -2147203476: "DFC_ENG_HETERDB_DM_IN_RODB",
    -2147203482: "DFC_ENG_HETERDB_NO_PRIVILEGE",
    -2147203475: "DFC_ENG_HETERDB_NULL_COMP_DBROLE",
    -2147203474: "DFC_ENG_HETERDB_PROJ_MAIN_DBROLE_RO",
    -2147181279: "DFC_ENG_HETERDB_RWD_NO_PRIVILEGE",
    -2147203472: "DFC_ENG_HETERDB_SUBSET_NO_PRIVILEGE",
    -2147205425: "DFC_ENG_JOIN_FAILURE",
    -2147202281: "DFC_ENG_LESS_TRANS_ATTR_DEFUNITS",
    -2147205490: "DFC_ENG_LINK_ATTRS",
    -2147205472: "DFC_ENG_LOGIC_EMPTY_SELECT",
    -2147206388: "DFC_ENG_LOGIC_EXP_CRO_JOIN",
    -2147206389: "DFC_ENG_LOGIC_EXP_EMP_COMP",
    -2147206390: "DFC_ENG_LOGIC_EXP_NO_COMP",
    -2147206387: "DFC_ENG_LOGIC_EXP_OUT_LIMIT",
    -2147204500: "DFC_ENG_LOGIC_INVALID_ROLE",
    -2147181278: "DFC_ENG_METRIC_IN_SECURITYFILTER_NOT_ALLOWED",
    -2147075254: "DFC_ENG_NON_AGG_DIMTY_ERROR",
    -2147213299: "DFC_ENG_NO_FACT_IN_CALC",
    -2147205462: "DFC_ENG_NULL_COLREF",
    -2147179500: "DFC_ENG_NULL_COMPUNIT_REPORT",
    -2147075235: "DFC_ENG_NULL_POINTER",
    -2147206462: "DFC_ENG_OBJ_INCONS",
    -2147203473: "DFC_ENG_OLAP_INVALID_DFN",
    -2147206386: "DFC_ENG_PART_MULTI_TABLE",
    -2147206415: "DFC_ENG_REPBASE_GETKEY",
    -2147206414: "DFC_ENG_REPBASE_GETKEY_ECL",
    -2147206450: "DFC_ENG_REPENG_CONSTR",
    -2147206413: "DFC_ENG_TEMP_CG",
    -2147213300: "DFC_ENG_TOO_MANY_TEMP_TABLE",
    -2147211500: "DFC_ENG_XDA_ABOVE_TOP",
    -2147211492: "DFC_ENG_XDA_ABOVE_TOP_QB",
    -2147211503: "DFC_ENG_XDA_ATTR_ID_MISSING",
    -2147211499: "DFC_ENG_XDA_BELOW_BOTTOM",
    -2147211491: "DFC_ENG_XDA_BELOW_BOTTOM_QB",
    -2147211498: "DFC_ENG_XDA_HAS_TOP_BOTTOM",
    -2147211496: "DFC_ENG_XDA_QW_INVALID_FROM",
    -2147211494: "DFC_ENG_XDA_QW_INVALID_GROUP_BY",
    -2147211497: "DFC_ENG_XDA_QW_INVALID_SELECT",
    -2147211495: "DFC_ENG_XDA_QW_INVALID_WHERE",
    -2147211502: "DFC_ENG_XDA_UNSUPPORT_SF",
    -2147211501: "DFC_ENG_XDA_UNSUPPORT_SF_ATTR",
    -2147211253: "DFC_E_APPLY_FUNC_MISS_CONSTCHILD",
    -2147179492: "DFC_E_ATTR_NO_SOURCETABLE",
    -2147179491: "DFC_E_ATTR_NO_SOURCETABLE_FIX_IT",
    -2147206693: "DFC_E_BINDTABLE",
    -2147203480: "DFC_E_CANCELED_PROMPT",
    -2147205448: "DFC_E_COM_ATTRINFO_PARTIAL_IDFORM",
    -2147206841: "DFC_E_COM_INTERFACE",
    -2147206839: "DFC_E_COM_NULLPTR",
    -2147206840: "DFC_E_COM_QI",
    -2147203479: "DFC_E_CUBE_CS_CG",
    -2147202366: "DFC_E_CUBE_DR_TEMP",
    -2147202371: "DFC_E_CUBE_IR",
    -2147202372: "DFC_E_CUBE_IR_DEL_FILTER",
    -2147202365: "DFC_E_CUBE_IR_DR_TEMP",
    -2147202348: "DFC_E_CUBE_IR_FILTER_DELETE_MDX",
    -2147202370: "DFC_E_CUBE_IR_FILTER_QB_FFSQL",
    -2147202369: "DFC_E_CUBE_IR_REPORT_TEMP_ADD",
    -2147202368: "DFC_E_CUBE_IR_REPORT_TEMP_DELETE",
    -2147202367: "DFC_E_CUBE_IR_REPORT_TEMP_UPDATE",
    -2147048423: "DFC_E_DESCENDANTS",
    -2147204408: "DFC_E_DE_EXPR_TOO_DEEP",
    -2147072393: "DFC_E_DIMMETRIC_OBJ_UNSUPPORTED",
    -2147204473: "DFC_E_EMPTY_BINDINGTABLE",
    -2147206826: "DFC_E_EMPTY_TEMPLATE",
    -2147464037: "DFC_E_FACT_EXTENSION_EXPR_ERROR",
    -2147201763: "DFC_E_FILTERUNITREL_STACKOVERFLOW",
    -2147201765: "DFC_E_FILTER_ATTR_NOT_IN_SCHEMA",
    -2147464038: "DFC_E_FILTER_HAS_NO_FACT",
    -2147464039: "DFC_E_FILTER_HAS_RECURSIVE_METRIC",
    -2147464045: "DFC_E_GO_BROKEN_PARENT_CHILD_REL",
    -2147464046: "DFC_E_GO_COMPUNIT_IS_NULL",
    -2147464043: "DFC_E_GO_DW_GOT_EMPTY_FILTER",
    -2147464041: "DFC_E_GO_NON_RAF_PRIMARY_BRANCH_NOT_HANDLED",
    -2147464044: "DFC_E_GO_PARENTS_AND_FROMINFO_DIFF_SIZE",
    -2147464040: "DFC_E_GO_PARENT_SHOULD_BE_LEAF",
    -2147464048: "DFC_E_GO_PARTITION_WITHOUT_PARTITION_BASE_TABLE",
    -2147464042: "DFC_E_GO_PREPROCESSCASEWHEREHAVING_ERROR",
    -2147464047: "DFC_E_GO_WRONG_MFROMINFO_SIZE",
    -2147206837: "DFC_E_INVALIDCASE",
    -2147206305: "DFC_E_INVALID_PATTERN",
    -2147202357: "DFC_E_IRR_CS_CG",
    -2147441634: "DFC_E_JOB_IS_CANCELED",
    -2147206836: "DFC_E_MEMERR",
    -2147204407: "DFC_E_METRIC_EXPR_TOO_DEEP",
    -2147213298: "DFC_E_MISSING_TEMPLATE_OBJECT",
    -2147206796: "DFC_E_NOSUBOBJ",
    -2147202325: "DFC_E_NOT_PARAMS",
    -2147155970: "DFC_E_NULL_PARTITION_ATTR",
    -2147206800: "DFC_E_OBJ_ATTR",
    -2147206798: "DFC_E_OBJ_COL",
    -2147206749: "DFC_E_OBJ_CRT_ATTR",
    -2147206802: "DFC_E_OBJ_DIM",
    -2147206822: "DFC_E_OBJ_DIMMETRIC",
    -2147206797: "DFC_E_OBJ_DIMTY",
    -2147206805: "DFC_E_OBJ_FACT",
    -2147206801: "DFC_E_OBJ_FACTGRP",
    -2147206807: "DFC_E_OBJ_FILTER",
    -2147206804: "DFC_E_OBJ_FUNC",
    -2147206795: "DFC_E_OBJ_LINK",
    -2147211252: "DFC_E_OBJ_NULL_ELEMENT",
    -2147206799: "DFC_E_OBJ_REL",
    -2147206825: "DFC_E_OBJ_REPORT",
    -2147206806: "DFC_E_OBJ_ROLE",
    -2147206803: "DFC_E_OBJ_TABLE",
    -2147206823: "DFC_E_OBJ_TEMP",
    -2147206824: "DFC_E_OBJ_TEMPATTR",
    -2147206670: "DFC_E_PATH",
    -2147205293: "DFC_E_RAF_CG",
    -2147205292: "DFC_E_RAF_DATAMART",
    -2147205294: "DFC_E_RAF_LOOP",
    -2147205291: "DFC_E_RAF_SUBSET",
    -2147048424: "DFC_E_REC_ATTR",
    -2147070692: "DFC_E_REPORT_ENGINE",
    -2147211254: "DFC_E_RF_NO_OUTPUT_LEVEL",
    -2147206603: "DFC_E_SCHEMA",
    -2147206838: "DFC_E_SCHEMA_NOOBJ",
    -2147212795: "DFC_E_SEC_FILTER_MISSING",
    -2147203478: "DFC_E_SUBSET_CS_CG",
    -2147203471: "DFC_E_SUBSET_MQ_LEVEL",
    -2147206694: "DFC_E_TEMP_DUP_ATTR",
    -2147206751: "DFC_E_TYPE_MISMATCH",
    -2147202383: "DFC_E_USER_GROUP_LOOP_DEF",
    -2147179499: "DFC_METRIC_IN_SELF_REL_TABLE",
    -2147048425: "DFC_NULL_SELF_REL_TABLE",
    -2147206674: "DFC_N_AGG_METRIC",
    -2147206661: "DFC_N_AGG_METRIC_BRANCH",
    -2147206665: "DFC_N_AGG_METRIC_EXPR",
    -2147206660: "DFC_N_AGG_METRIC_LEAF",
    -2147206663: "DFC_N_AGG_METRIC_SHORTCUT",
    -2147206616: "DFC_N_ATTRIBUTES",
    -2147206687: "DFC_N_ATTR_FORM",
    -2147206669: "DFC_N_ATTR_FORMS",
    -2147206612: "DFC_N_ATTR_INFO",
    -2147206611: "DFC_N_ATTR_INFOS",
    -2147206613: "DFC_N_ATTR_REL",
    -2147206614: "DFC_N_ATTR_RELS",
    -2147206684: "DFC_N_AXES",
    -2147206683: "DFC_N_AXIS",
    -2147206667: "DFC_N_BASE_ATTR_FORM",
    -2147206668: "DFC_N_BASE_ATTR_FORMS",
    -2147206652: "DFC_N_CONDITION",
    -2147206650: "DFC_N_CONSOLID",
    -2147206656: "DFC_N_CONST",
    -2147206646: "DFC_N_CUSTOM_GROUP",
    -2147206631: "DFC_N_DBMS",
    -2147206630: "DFC_N_DB_ROLE",
    -2147206622: "DFC_N_DB_TABLE",
    -2147206629: "DFC_N_DB_VER",
    -2147206692: "DFC_N_DIMENSION",
    -2147206619: "DFC_N_DIMENSIONS",
    -2147206657: "DFC_N_DIMTY_UNIT",
    -2147206604: "DFC_N_DIR_ATTR",
    -2147206605: "DFC_N_DIR_ATTRS",
    -2147206648: "DFC_N_ELEMENTS",
    -2147206647: "DFC_N_ELM",
    -2147206649: "DFC_N_ELM_COLLECT",
    -2147206645: "DFC_N_ELM_OBJ",
    -2147206675: "DFC_N_EXPR",
    -2147206653: "DFC_N_EXPR_FUNC",
    -2147206608: "DFC_N_EXT",
    -2147206609: "DFC_N_EXTS",
    -2147206606: "DFC_N_EXT_UNIT",
    -2147206607: "DFC_N_EXT_UNITS",
    -2147206625: "DFC_N_FACTS",
    -2147206617: "DFC_N_FACT_GROUP",
    -2147206618: "DFC_N_FACT_GROUPS",
    -2147206610: "DFC_N_FACT_INFO",
    -2147206654: "DFC_N_FILTER_ENTITY",
    -2147206651: "DFC_N_FILTER_METRIC",
    -2147206655: "DFC_N_FILTER_UNIT",
    -2147206634: "DFC_N_FOLDER",
    -2147206641: "DFC_N_FORM",
    -2147206691: "DFC_N_FORMS",
    -2147206642: "DFC_N_FORM_SHORTCUT",
    -2147206624: "DFC_N_FUNCS",
    -2147206615: "DFC_N_GUIDE",
    -2147206635: "DFC_N_MD_SEC_FILTER",
    -2147206677: "DFC_N_METRIC",
    -2147206680: "DFC_N_METRIC_LIMIT",
    -2147206662: "DFC_N_NODE",
    -2147206686: "DFC_N_OBJ_INFO",
    -2147206639: "DFC_N_OLAP_SORTS",
    -2147206659: "DFC_N_OPERATOR",
    -2147206671: "DFC_N_PROJ",
    -2147206643: "DFC_N_REL",
    -2147206644: "DFC_N_REL_NODE",
    -2147206626: "DFC_N_ROLE",
    -2147206627: "DFC_N_ROLES",
    -2147206679: "DFC_N_ROOT",
    -2147206673: "DFC_N_RPT_DEF",
    -2147206633: "DFC_N_SEARCH",
    -2147206664: "DFC_N_SHORTCUT",
    -2147206637: "DFC_N_SORT",
    -2147206638: "DFC_N_SORTS",
    -2147206672: "DFC_N_SOURCE",
    -2147206623: "DFC_N_SQL_PATT",
    -2147206620: "DFC_N_TABLE",
    -2147206621: "DFC_N_TABLES",
    -2147206632: "DFC_N_TABLE_SOURCE",
    -2147206628: "DFC_N_TABLE_SPACE",
    -2147206685: "DFC_N_TEMP",
    -2147206690: "DFC_N_TEMP_ATTR",
    -2147206689: "DFC_N_TEMP_CONSOLID",
    -2147206688: "DFC_N_TEMP_DIMENSION",
    -2147206678: "DFC_N_TEMP_METRIC",
    -2147206681: "DFC_N_TEMP_METRICS",
    -2147206682: "DFC_N_TEMP_UNIT",
    -2147206676: "DFC_N_TEMP_UNIT_METRICS",
    -2147206640: "DFC_N_TIME_NODE",
    -2147206666: "DFC_N_TYPE",
    -2147206636: "DFC_N_USER_SEC_FILTERS",
    -2147206658: "DFC_N_VALUE",
    -2147206750: "DFC_OBJ_CUSTOM_GRP",
    -2147048422: "DFC_QB_SQLOPRTYPE_NOT_SUPPORTED",
    -2147206348: "DFC_QRYENGSVR_CANCEL",
    -2147206351: "DFC_QRYENGSVR_INVALID_ID",
    -2147206349: "DFC_QRYENGSVR_JOB_FAILED",
    -2147206350: "DFC_QRYENGSVR_JOB_FINISH",
    -2147206347: "DFC_QRYENGSVR_NO_DBROLE",
    -2147203466: "DFC_QRYENG_DBCOMMIT_FAIL",
    -2147206355: "DFC_QRYENG_NO_DBROLE",
    -2147206353: "DFC_QRYENG_NO_MEM",
    -2147466643: "DFC_QRYENG_NO_TABLE",
    -2147205439: "DFC_QRYENG_RES_ELM_TRUNC",
    -2147205488: "DFC_QRYENG_RES_TRUNC",
    -2147466645: "DFC_QRYENG_SET_REPORT",
    -2147204498: "DFC_QRYENG_STAT_ERROR_PASS",
    -2147206354: "DFC_QRYENG_TOO_MANY_JOBS",
    -2147179498: "DFC_REC_COLUMN_NOT_DEFINE",
    -2147206372: "DFC_SCHEMA_EXCP_ATTR",
    -2147206327: "DFC_SCHEMA_EXCP_ATTR_ROLE_LIMIT_EXCEED",
    -2147206371: "DFC_SCHEMA_EXCP_BASE",
    -2147206369: "DFC_SCHEMA_EXCP_DIMTY",
    -2147205480: "DFC_SCHEMA_EXCP_EXT_FACT_NO_JOIN",
    -2147206366: "DFC_SCHEMA_EXCP_FACT",
    -2147206375: "DFC_SCHEMA_EXCP_LOGIC",
    -2147206367: "DFC_SCHEMA_EXCP_NOT_EXTEND",
    -2147205487: "DFC_SCHEMA_EXCP_NOT_EXTEND_APPEND",
    -2147206373: "DFC_SCHEMA_EXCP_NOT_IMPL",
    -2147206370: "DFC_SCHEMA_EXCP_NO_FACT",
    -2147206328: "DFC_SCHEMA_EXCP_NO_FUNC",
    -2147206364: "DFC_SCHEMA_EXCP_NULL_FUNC",
    -2147206365: "DFC_SCHEMA_EXCP_NULL_NODE",
    -2147206368: "DFC_SCHEMA_EXCP_PARTITION",
    -2147206374: "DFC_SCHEMA_EXCP_POPU",
    -2147206304: "DFC_SCHEMA_EXCP_PTNHETERDB",
    -2147206306: "DFC_SCHEMA_INVALID_SAP_EXPR_PROMPT",
    -2147206381: "DFC_SCHM_ATTRDEFUNIT_EMP_LKUP",
    -2147206382: "DFC_SCHM_ATTRDEFUNIT_MAP",
    -2147206383: "DFC_SCHM_ATTRDEF_LINK",
    -2147204479: "DFC_SCHM_ATTRDEF_SORT_FORM",
    -2147206380: "DFC_SCHM_ATTRGRP_MARK",
    -2147206384: "DFC_SCHM_ATTR_ELIM",
    -2147205461: "DFC_SCHM_EXCP_NULL_TOTALFORM",
    -2147210861: "DFC_SCHM_EXCP_NULL_TOTALFORM_OBSOLETE",
    -2147206377: "DFC_SCHM_EXPRFUNC_GETDT",
    -2147203477: "DFC_SCHM_EXPRFUNC_NOT_SUPPORT",
    -2147206379: "DFC_SCHM_ROLE_PRINT",
    -2147206378: "DFC_SCHM_SCHEXP_LIST",
    -2147206376: "DFC_SCHM_TABLEI_GET",
    -2147206340: "DFC_SQLENG_CONV_AGGMETRIC_UNEXP",
    -2147206339: "DFC_SQLENG_CONV_EMP_CG",
    -2147206346: "DFC_SQLENG_CONV_ERR",
    -2147206341: "DFC_SQLENG_EMP_DEF",
    -2147206342: "DFC_SQLENG_HIER_NOT_REPLACABLE",
    -2147206345: "DFC_SQLENG_MSG",
    -2147206343: "DFC_SQLENG_NO_SQL",
    -2147206344: "DFC_SQLENG_RPT_CONV_ERR",
    -2147203484: "DFC_SQLENG_SR_ATTR_INVALID",
    -2147203485: "DFC_SQLENG_SR_FILTER_INVALID",
    -2147203483: "DFC_SQLENG_SR_METRIC_INVALID",
    -2147205486: "DFC_SQLSVR_BAD_CUSTGRP_WITH_BAND",
    -2147205466: "DFC_SQLSVR_HOLEINFO_ERR",
    -2147206337: "DFC_SQLSVR_SQLS_ITEM",
    -2147206336: "DFC_SQLSVR_SQLS_REMOV",
    -2147206338: "DFC_SQLSVR_SQL_TOO_LONG",
    -2147024897: "DFC_TUPLE_INDEX_INVALID",
    -2147206352: "DFC_UNKNOWN_EXCEP",
    -2147206475: "DFC_UTIL_BUF_OUT_MEM",
    -2147206485: "DFC_UTIL_BV_ASSIGN",
    -2147206476: "DFC_UTIL_EXP_NO_FACT",
    -2147206480: "DFC_UTIL_FLIP",
    -2147206479: "DFC_UTIL_INPUT_NOT_INI",
    -2147206486: "DFC_UTIL_NOT_ECL",
    -2147206478: "DFC_UTIL_NOT_INI",
    -2147206483: "DFC_UTIL_OPR_AND_ASG",
    -2147206491: "DFC_UTIL_OPR_EQ",
    -2147206484: "DFC_UTIL_OPR_INT",
    -2147206482: "DFC_UTIL_OPR_OR_ASG",
    -2147206481: "DFC_UTIL_OPR_XOR_ASG",
    -2147206489: "DFC_UTIL_OR_ECL",
    -2147206477: "DFC_UTIL_OUT_RANGE",
    -2147206487: "DFC_UTIL_RESET_INT",
    -2147206490: "DFC_UTIL_SET_INT",
    -2147206488: "DFC_UTIL_XOR_ECL",
    -2147206335: "DFC_VLDBSVR_DSSTYPE",
    -2147206334: "DFC_VLDBSVR_IDSSDATATYPE",
    -2147206333: "DFC_VLDBSVR_LONG_TYPE",
    -2147206332: "DFC_VLDBSVR_STRING_TYPE",
    -2147205454: "DMTSVR_E_CLOSED",
    -2147212289: "DOCIST_E_ADD_CUBE_DATASET",
    -2147212290: "DOCIST_E_CUBE_IN_DATASET",
    -2147213352: "DOCIST_E_DATASET_NOT_READY",
    -2147213363: "DOCIST_E_ELEMENT_LIST_NOT_READY",
    -2147212490: "DOCIST_E_MOD_LINKED_RPT_VIEW",
    -2147213364: "DOCIST_E_NODEFN",
    -2147213356: "DOCIST_E_NO_PARENT_GROUPBYPATH",
    -2147213355: "DOCIST_E_NO_RW_ELEMENT_OBJECT",
    -2147213324: "DOCIST_E_NULL_OBJECT_ELEMENT",
    -2147213354: "DOCIST_E_OBJECT_TYPE_NOT_SUPPORT",
    -2147213325: "DOCIST_E_REPORT_TYPE_NOT_SUPPORT",
    -2147213358: "DOCIST_E_RWNODE_TYPE_NOT_SUPPORT",
    -2147213330: "DOCIST_E_SAVEAS_FLAG_NOT_SUPPORT",
    -2147072495: "DOCSVR_CACHEMANANGER_NOT_INITIALIZED",
    -2147071824: "DOCSVR_CACHE_COMPRESSION_FAIL",
    -2147072502: "DOCSVR_CACHE_CREATE_FAILED",
    -2147072503: "DOCSVR_CACHE_EXCEED_MAX_COUNT",
    -2147072498: "DOCSVR_CACHE_EXCEED_MAX_MEMORY_USAGE",
    -2147072493: "DOCSVR_CACHE_FILE_CORRUPTED",
    -2147072500: "DOCSVR_CACHE_FILE_NOT_FOUND",
    -2147072499: "DOCSVR_CACHE_FILE_WRONG_VERSION",
    -2147072496: "DOCSVR_CACHE_NOT_FOUND",
    -2147072497: "DOCSVR_CACHE_PAGEIN_FAILED",
    -2147072501: "DOCSVR_CACHE_PAGEOUT_FAILED",
    -2147072494: "DOCSVR_CACHE_PERSIST_FAILED",
    -2147212468: "DOCSVR_E_CONTROLGROUPBYSECTION_NO_GROUPBYUNIT",
    -2147213361: "DOCSVR_E_DOC_EXEC_FLAG_NOT_SET",
    -2147213365: "DOCSVR_E_EXECUTION_IN_PROGRESS",
    -2147072458: "DOCSVR_E_INTERACTIVE_RPTCOUNT_ZERO",
    -2147212471: "DOCSVR_E_MANIPULATION_CANNOT_CANCEL",
    -2147213394: "DOCSVR_E_NO_EVENT_HANDLER",
    -2147213360: "DOCSVR_E_NO_GRAPH_DATA",
    -2147213359: "DOCSVR_E_NO_IMAGEPATH",
    -2147213357: "DOCSVR_E_RW_ELEMENT_TYPE_NOT_SUPPORT",
    -2147213362: "DOCSVR_E_WAIT_FOR_PROMPT",
    -2147213204: "DOCSVR_MANIPULATION_SKIP",
    -2147480646: "DSSCOM_ABBREVIATION_PATTERN",
    -2147483312: "DSSCOM_C_ANALYTICAL_ENGINE_SERVER",
    -2147483299: "DSSCOM_C_AND",
    -2147483309: "DSSCOM_C_AUTH_SERVER",
    -2147481639: "DSSCOM_C_BREAKBY",
    -2147482806: "DSSCOM_C_CACHE_FILE_SERVER",
    -2147443434: "DSSCOM_C_CATALOG_CONTENT_SOURCE",
    -2147443443: "DSSCOM_C_CATALOG_NET_CLIENT",
    -2147443442: "DSSCOM_C_CATALOG_NET_SERVER",
    -2147443445: "DSSCOM_C_CATALOG_SERVER2",
    -2147443446: "DSSCOM_C_CATALOG_SOURCE",
    -2147483285: "DSSCOM_C_CATALOG_UPDT",
    -2147483308: "DSSCOM_C_CLIENT_SERVICES",
    -2147072533: "DSSCOM_C_CLI_CUBE_SVR",
    -2147482655: "DSSCOM_C_CONTENT_SERVER",
    -2147482854: "DSSCOM_C_COPY",
    -2147483289: "DSSCOM_C_COPY_OBJECT",
    -2147482853: "DSSCOM_C_COPY_OF",
    -2147072536: "DSSCOM_C_CUBE_NETCLIENT",
    -2147072535: "DSSCOM_C_CUBE_NETSERVER",
    -2147072544: "DSSCOM_C_CUBE_SERVER",
    -2147482805: "DSSCOM_C_DATAMART_SERVER",
    -2147483320: "DSSCOM_C_DBELEMENT_SERVER",
    -2147483288: "DSSCOM_C_DELETE_OBJECT",
    -2147483304: "DSSCOM_C_DOCUMENT_NET_CLEINT",
    -2147483305: "DSSCOM_C_DOCUMENT_SERVER",
    -2147482654: "DSSCOM_C_DOCUMENT_SERVICES",
    -2147483303: "DSSCOM_C_DOCUMENT_SOURCE_SERVER",
    -2147481631: "DSSCOM_C_DRILL_DERIVED_ATTRIBUTES",
    -2147443135: "DSSCOM_C_DRILL_DERIVED_ELEMENTS",
    -2147482857: "DSSCOM_C_DRILL_FILTER",
    -2147482858: "DSSCOM_C_DRILL_METRICS",
    -2147483318: "DSSCOM_C_ELEMENT_NET_CLIENT",
    -2147483317: "DSSCOM_C_ELEMENT_NET_SERVER",
    -2147483319: "DSSCOM_C_ELEMENT_SERVER",
    -2147482837: "DSSCOM_C_ELEMENT_TYPE_BAND",
    -2147482847: "DSSCOM_C_ELEMENT_TYPE_CONCRETE",
    -2147482841: "DSSCOM_C_ELEMENT_TYPE_CONSOLIDATION",
    -2147482839: "DSSCOM_C_ELEMENT_TYPE_CUSTOM_GROUP",
    -2147482842: "DSSCOM_C_ELEMENT_TYPE_DIMENSION",
    -2147482840: "DSSCOM_C_ELEMENT_TYPE_FILTER",
    -2147482844: "DSSCOM_C_ELEMENT_TYPE_FIRST",
    -2147482838: "DSSCOM_C_ELEMENT_TYPE_JOINT",
    -2147482843: "DSSCOM_C_ELEMENT_TYPE_LAST",
    -2147482846: "DSSCOM_C_ELEMENT_TYPE_METRIC",
    -2147482834: "DSSCOM_C_ELEMENT_TYPE_RESERVED14",
    -2147482833: "DSSCOM_C_ELEMENT_TYPE_RESERVED15",
    -2147482832: "DSSCOM_C_ELEMENT_TYPE_RESERVED16",
    -2147482831: "DSSCOM_C_ELEMENT_TYPE_RESERVED17",
    -2147482830: "DSSCOM_C_ELEMENT_TYPE_RESERVED18",
    -2147482829: "DSSCOM_C_ELEMENT_TYPE_RESERVED19",
    -2147482828: "DSSCOM_C_ELEMENT_TYPE_RESERVED20",
    -2147482836: "DSSCOM_C_ELEMENT_TYPE_RESIDUE",
    -2147482848: "DSSCOM_C_ELEMENT_TYPE_START",
    -2147482835: "DSSCOM_C_ELEMENT_TYPE_SUBEXPRESSION",
    -2147482845: "DSSCOM_C_ELEMENT_TYPE_SUBTOTAL",
    -2147481844: "DSSCOM_C_EMPTY_FILTER",
    -2147483307: "DSSCOM_C_ENGINE_LITE",
    -2147482722: "DSSCOM_C_ETL_SERVER",
    -2147483284: "DSSCOM_C_EXECSEARCH",
    -2147483295: "DSSCOM_C_EXECUTE_FT",
    -2147483297: "DSSCOM_C_EXECUTE_REPORT",
    -2147483296: "DSSCOM_C_EXECUTE_REPORTDEFN",
    -2147482653: "DSSCOM_C_EXPORT_ENGINE_SERVER",
    -2147483282: "DSSCOM_C_FINDLINK",
    -2147483291: "DSSCOM_C_FIND_OBJECT",
    -2147483306: "DSSCOM_C_FUNCTION_SERVER",
    -2147481842: "DSSCOM_C_IMPORT_SERVICES",
    -2147483286: "DSSCOM_C_LOADOBJDEPN",
    -2147483287: "DSSCOM_C_LOADOBJSDEPN",
    -2147483089: "DSSCOM_C_LOADSCHEMAADV",
    -2147483294: "DSSCOM_C_LOAD_ELEMENT",
    -2147483293: "DSSCOM_C_LOAD_ELEMENTS",
    -2147482652: "DSSCOM_C_MANAGED_OBJECTS_FOLDER",
    -2147483327: "DSSCOM_C_METADATA_SERVER",
    -2147483301: "DSSCOM_C_NET_HTTP",
    -2147483302: "DSSCOM_C_NET_SOCKET",
    -2147482807: "DSSCOM_C_NEWPROJECT",
    -2147482656: "DSSCOM_C_OBJECT_CONTEXT_FACTORY",
    -2147482802: "DSSCOM_C_OBJECT_ID",
    -2147482804: "DSSCOM_C_OBJECT_NAME",
    -2147483328: "DSSCOM_C_OBJECT_SERVER",
    -2147482803: "DSSCOM_C_OBJECT_TYPE",
    -2147483298: "DSSCOM_C_OR",
    -2147481640: "DSSCOM_C_PAGE_BY",
    -2147460360: "DSSCOM_C_PDS_ACPALETTE",
    -2147460340: "DSSCOM_C_PDS_AE_DYNSOURCEORDER",
    -2147460339: "DSSCOM_C_PDS_AE_DYNSOURCEORDER_DESC",
    -2147474760: "DSSCOM_C_PDS_AE_EBGovern__FeatureFlag_BDHGoS",
    -2147474759: "DSSCOM_C_PDS_AE_EBGovern__FeatureFlag_BDHGoSDESC",
    -2147478627: "DSSCOM_C_PDS_AE_EBGovern__FeatureFlag_Description",
    -2147478628: "DSSCOM_C_PDS_AE_EBGovern__FeatureFlag_Name",
    -2147478581: "DSSCOM_C_PDS_AE_IKGovern__FeatureFlag_Description",
    -2147478582: "DSSCOM_C_PDS_AE_IKGovern__FeatureFlag_Name",
    -2147460362: "DSSCOM_C_PDS_AMPALETTE",
    -2147460345: "DSSCOM_C_PDS_ANALYST_DESC",
    -2147460346: "DSSCOM_C_PDS_ANALYST_NAME",
    -2147460323: "DSSCOM_C_PDS_ANALYTICSARCHITECT",
    -2147460322: "DSSCOM_C_PDS_ANALYTICSARCHITECT_DESC",
    -2147460361: "DSSCOM_C_PDS_ANMPALETTE",
    -2147460325: "DSSCOM_C_PDS_APPLICATIONARCHITECT",
    -2147460324: "DSSCOM_C_PDS_APPLICATIONARCHITECT_DESC",
    -2147460347: "DSSCOM_C_PDS_APPLICATION_ADMINISTRATOR_DESC",
    -2147460348: "DSSCOM_C_PDS_APPLICATION_ADMINISTRATOR_NAME",
    -2147477745: "DSSCOM_C_PDS_APPLYTRANS1TOM",
    -2147477739: "DSSCOM_C_PDS_APPLYTRANS_AGGFUNC",
    -2147477743: "DSSCOM_C_PDS_APPLYTRANS_ATTRFORM",
    -2147477740: "DSSCOM_C_PDS_APPLYTRANS_ENDEXPR",
    -2147477738: "DSSCOM_C_PDS_APPLYTRANS_LEVEL",
    -2147477744: "DSSCOM_C_PDS_APPLYTRANS_METRICEXPR",
    -2147477741: "DSSCOM_C_PDS_APPLYTRANS_STARTEXPR",
    -2147477742: "DSSCOM_C_PDS_APPLYTRANS_TRANSEXPR",
    -2147460363: "DSSCOM_C_PDS_AVPALETTE",
    -2147478594: "DSSCOM_C_PDS_AppSchema_FeatureFlag_Description",
    -2147478595: "DSSCOM_C_PDS_AppSchema_FeatureFlag_Name",
    -2147481408: "DSSCOM_C_PDS_BLANK_OLAP_REPORT_DESC",
    -2147481409: "DSSCOM_C_PDS_BLANK_OLAP_REPORT_NAME",
    -2147481443: "DSSCOM_C_PDS_BLANK_REPORT_DESC",
    -2147481444: "DSSCOM_C_PDS_BLANK_REPORT_NAME",
    -2147481412: "DSSCOM_C_PDS_BLANK_VIEW_REPORT_DESC",
    -2147481413: "DSSCOM_C_PDS_BLANK_VIEW_REPORT_NAME",
    -2147460389: "DSSCOM_C_PDS_BLUE",
    -2147478592: "DSSCOM_C_PDS_Bucketing_FeatureFlag_Description",
    -2147478593: "DSSCOM_C_PDS_Bucketing_FeatureFlag_Name",
    -2147460330: "DSSCOM_C_PDS_CBSPALETTE",
    -2147460343: "DSSCOM_C_PDS_CERTIFIER_DESC",
    -2147460344: "DSSCOM_C_PDS_CERTIFIER_NAME",
    -2147460329: "DSSCOM_C_PDS_COLLABORATOR",
    -2147460328: "DSSCOM_C_PDS_COLLABORATOR_DESC",
    -2147460341: "DSSCOM_C_PDS_CONSUMER_DESC",
    -2147460342: "DSSCOM_C_PDS_CONSUMER_NAME",
    -2147460384: "DSSCOM_C_PDS_DARKTHEME",
    -2147460383: "DSSCOM_C_PDS_DARKTHEME_DESC",
    -2147460317: "DSSCOM_C_PDS_DATABASEARCHITECT",
    -2147460316: "DSSCOM_C_PDS_DATABASEARCHITECT_DESC",
    -2147478621: "DSSCOM_C_PDS_DBE_DataBlendingForFR_FeatureFlag_Description",
    -2147478622: "DSSCOM_C_PDS_DBE_DataBlendingForFR_FeatureFlag_Name",
    -2147460365: "DSSCOM_C_PDS_DEV_DOSSIERANDROID",
    -2147460364: "DSSCOM_C_PDS_DEV_DOSSIERANDROID_DESC",
    -2147460367: "DSSCOM_C_PDS_DEV_DOSSIERIPADID",
    -2147460366: "DSSCOM_C_PDS_DEV_DOSSIERIPADID_DESC",
    -2147460327: "DSSCOM_C_PDS_DEV_DOSSIERIPHONEID",
    -2147460326: "DSSCOM_C_PDS_DEV_DOSSIERIPHONEID_DESC",
    -2147460967: "DSSCOM_C_PDS_DEV_FTP_LOC",
    -2147460966: "DSSCOM_C_PDS_DEV_FTP_LOC_DESC",
    -2147461148: "DSSCOM_C_PDS_DEV_GENERIC_EMAIL",
    -2147461147: "DSSCOM_C_PDS_DEV_GENERIC_EMAIL_DESC",
    -2147461058: "DSSCOM_C_PDS_DEV_MOBILEAPNSFORIPAD",
    -2147461057: "DSSCOM_C_PDS_DEV_MOBILEAPNSFORIPAD_DESC",
    -2147461056: "DSSCOM_C_PDS_DEV_MOBILEAPNSFORIPHONE",
    -2147461055: "DSSCOM_C_PDS_DEV_MOBILEAPNSFORIPHONE_DESC",
    -2147461084: "DSSCOM_C_PDS_DEV_MOBILEBES",
    -2147461083: "DSSCOM_C_PDS_DEV_MOBILEBES_DESC",
    -2147460369: "DSSCOM_C_PDS_DEV_MOBILEGCMFORANDROID",
    -2147460368: "DSSCOM_C_PDS_DEV_MOBILEGCMFORANDROID_DESC",
    -2147461143: "DSSCOM_C_PDS_DEV_MSFT_OUTLOOK_DESC",
    -2147461139: "DSSCOM_C_PDS_DEV_MSFT_OUTLOOK_EXP_DESC",
    -2147461141: "DSSCOM_C_PDS_DEV_MSFT_OUTLOOK_WEB_ACC_DESC",
    -2147461128: "DSSCOM_C_PDS_DEV_USER_SEL_LOC",
    -2147461127: "DSSCOM_C_PDS_DEV_USER_SEL_LOC_DESC",
    -2147461126: "DSSCOM_C_PDS_DEV_USER_SEL_PRINTER",
    -2147461125: "DSSCOM_C_PDS_DEV_USER_SEL_PRINTER_DESC",
    -2147461146: "DSSCOM_C_PDS_DEV_WEBMAIL",
    -2147461145: "DSSCOM_C_PDS_DEV_WEBMAIL_DESC",
    -2147478625: "DSSCOM_C_PDS_DM_FROnDB_FeatureFlag_Description",
    -2147478626: "DSSCOM_C_PDS_DM_FROnDB_FeatureFlag_Name",
    -2147460943: "DSSCOM_C_PDS_DTPALETTE",
    -2147460942: "DSSCOM_C_PDS_DTPALETTE_DESC",
    -2147478612: "DSSCOM_C_PDS_DeletedDossier_Shortcut_Description",
    -2147478613: "DSSCOM_C_PDS_DeletedDossier_Shortcut_Name",
    -2147478610: "DSSCOM_C_PDS_DocServices_GUIDAsNodeIdentifier_FeatureFlag_Description",
    -2147478611: "DSSCOM_C_PDS_DocServices_GUIDAsNodeIdentifier_FeatureFlag_Name",
    -2147478606: "DSSCOM_C_PDS_DocServices_OnDmdEval4GF_FeatureFlag_Description",
    -2147478607: "DSSCOM_C_PDS_DocServices_OnDmdEval4GF_FeatureFlag_Name",
    -2147478577: "DSSCOM_C_PDS_DocServices_SharedPageCache_FeatureFlag_Description",
    -2147478578: "DSSCOM_C_PDS_DocServices_SharedPageCache_FeatureFlag_Name",
    -2147478585: "DSSCOM_C_PDS_DocServices_ShortcutCache_FeatureFlag_Description",
    -2147478586: "DSSCOM_C_PDS_DocServices_ShortcutCache_FeatureFlag_Name",
    -2147478583: "DSSCOM_C_PDS_EE_NewEEExportOption_Encrypt_Description",
    -2147478584: "DSSCOM_C_PDS_EE_NewEEExportOption_Encrypt_Name",
    -2147478619: "DSSCOM_C_PDS_EE_NewEEExportOption_FeatureFlag_Description",
    -2147478620: "DSSCOM_C_PDS_EE_NewEEExportOption_FeatureFlag_Name",
    -2147478587: "DSSCOM_C_PDS_EE_NewEE_ExportFilterSummary_Description",
    -2147478588: "DSSCOM_C_PDS_EE_NewEE_ExportFilterSummary_Name",
    -2147478629: "DSSCOM_C_PDS_EE_NewEE__FeatureFlag_Description",
    -2147478630: "DSSCOM_C_PDS_EE_NewEE__FeatureFlag_Name",
    -2147460319: "DSSCOM_C_PDS_EMBEDDEDANALYTICSARCHITECT",
    -2147460318: "DSSCOM_C_PDS_EMBEDDEDANALYTICSARCHITECT_DESC",
    -2147460338: "DSSCOM_C_PDS_ENGINE_ADVANCEDPU",
    -2147460337: "DSSCOM_C_PDS_ENGINE_ADVANCEDPU_DESC",
    -2147460332: "DSSCOM_C_PDS_ENGINE_NONAGGRREGATION_MTC",
    -2147460331: "DSSCOM_C_PDS_ENGINE_NONAGGRREGATION_MTC_DESC",
    -2147460336: "DSSCOM_C_PDS_ENGINE_PARALLEL_AE",
    -2147460335: "DSSCOM_C_PDS_ENGINE_PARALLEL_AE_DESC",
    -2147478567: "DSSCOM_C_PDS_ESM_SYSPROMPT_Date1_Desc",
    -2147478568: "DSSCOM_C_PDS_ESM_SYSPROMPT_Date1_Name",
    -2147478569: "DSSCOM_C_PDS_ESM_SYSPROMPT_Double1_Desc",
    -2147478570: "DSSCOM_C_PDS_ESM_SYSPROMPT_Double1_Name",
    -2147478565: "DSSCOM_C_PDS_ESM_SYSPROMPT_Integer1_Desc",
    -2147478566: "DSSCOM_C_PDS_ESM_SYSPROMPT_Integer1_Name",
    -2147478573: "DSSCOM_C_PDS_ESM_SYSPROMPT_String1_Desc",
    -2147478574: "DSSCOM_C_PDS_ESM_SYSPROMPT_String1_Name",
    -2147478571: "DSSCOM_C_PDS_ESM_SYSPROMPT_String2_Desc",
    -2147478572: "DSSCOM_C_PDS_ESM_SYSPROMPT_String2_Name",
    -2147478598: "DSSCOM_C_PDS_EarlyTempRel_FeatureFlag_Description",
    -2147478599: "DSSCOM_C_PDS_EarlyTempRel_FeatureFlag_Name",
    -2147478623: "DSSCOM_C_PDS_Engine_AJFE_FeatureFlag_Description",
    -2147478624: "DSSCOM_C_PDS_Engine_AJFE_FeatureFlag_Name",
    -2147481441: "DSSCOM_C_PDS_FILTER_EMBEDDED_PROMPTED",
    -2147482329: "DSSCOM_C_PDS_FIN_ACCRINT",
    -2147482328: "DSSCOM_C_PDS_FIN_ACCRINTM",
    -2147482327: "DSSCOM_C_PDS_FIN_COUPDAYBS",
    -2147482326: "DSSCOM_C_PDS_FIN_COUPDAYS",
    -2147482325: "DSSCOM_C_PDS_FIN_COUPDAYSNC",
    -2147482323: "DSSCOM_C_PDS_FIN_COUPNCD",
    -2147482324: "DSSCOM_C_PDS_FIN_COUPNUM",
    -2147482322: "DSSCOM_C_PDS_FIN_COUPPCD",
    -2147482347: "DSSCOM_C_PDS_FIN_CUMIPMT",
    -2147482346: "DSSCOM_C_PDS_FIN_CUMPRINC",
    -2147482345: "DSSCOM_C_PDS_FIN_DB",
    -2147482344: "DSSCOM_C_PDS_FIN_DDB",
    -2147482321: "DSSCOM_C_PDS_FIN_DISC",
    -2147482343: "DSSCOM_C_PDS_FIN_DOLLARDE",
    -2147482342: "DSSCOM_C_PDS_FIN_DOLLARFR",
    -2147482320: "DSSCOM_C_PDS_FIN_DURATION",
    -2147482341: "DSSCOM_C_PDS_FIN_EFFECT",
    -2147482340: "DSSCOM_C_PDS_FIN_FV",
    -2147482302: "DSSCOM_C_PDS_FIN_FVSCHEDULE",
    -2147482318: "DSSCOM_C_PDS_FIN_INTRATE",
    -2147482339: "DSSCOM_C_PDS_FIN_IPMT",
    -2147482303: "DSSCOM_C_PDS_FIN_IRR",
    -2147482319: "DSSCOM_C_PDS_FIN_MDURATION",
    -2147482300: "DSSCOM_C_PDS_FIN_MIRR",
    -2147482338: "DSSCOM_C_PDS_FIN_NOMINAL",
    -2147482337: "DSSCOM_C_PDS_FIN_NPER",
    -2147482301: "DSSCOM_C_PDS_FIN_NPV",
    -2147482317: "DSSCOM_C_PDS_FIN_ODDFPRICE",
    -2147482316: "DSSCOM_C_PDS_FIN_ODDFYIELD",
    -2147482315: "DSSCOM_C_PDS_FIN_ODDLPRICE",
    -2147482314: "DSSCOM_C_PDS_FIN_ODDLYIELD",
    -2147482336: "DSSCOM_C_PDS_FIN_PMT",
    -2147482335: "DSSCOM_C_PDS_FIN_PPMT",
    -2147482313: "DSSCOM_C_PDS_FIN_PRICE",
    -2147482312: "DSSCOM_C_PDS_FIN_PRICEDISC",
    -2147482311: "DSSCOM_C_PDS_FIN_PRICEMAT",
    -2147482334: "DSSCOM_C_PDS_FIN_PV",
    -2147482333: "DSSCOM_C_PDS_FIN_RATE",
    -2147482309: "DSSCOM_C_PDS_FIN_RECEIVED",
    -2147482332: "DSSCOM_C_PDS_FIN_SLN",
    -2147482331: "DSSCOM_C_PDS_FIN_SYD",
    -2147482308: "DSSCOM_C_PDS_FIN_TBILLEQ",
    -2147482307: "DSSCOM_C_PDS_FIN_TBILLPRICE",
    -2147482306: "DSSCOM_C_PDS_FIN_TBILLYIELD",
    -2147482330: "DSSCOM_C_PDS_FIN_VDB",
    -2147460965: "DSSCOM_C_PDS_FIN_XIRR",
    -2147460960: "DSSCOM_C_PDS_FIN_XNPV",
    -2147482310: "DSSCOM_C_PDS_FIN_YIELD",
    -2147482305: "DSSCOM_C_PDS_FIN_YIELDDISC",
    -2147482304: "DSSCOM_C_PDS_FIN_YIELDMAT",
    -2147481416: "DSSCOM_C_PDS_FORM_DESC_NAME",
    -2147481417: "DSSCOM_C_PDS_FORM_ID_NAME",
    -2147478604: "DSSCOM_C_PDS_FR_Optimization__FeatureFlag_Description",
    -2147478605: "DSSCOM_C_PDS_FR_Optimization__FeatureFlag_Name",
    -2147462628: "DSSCOM_C_PDS_FUNCARG_ABS_NUMBER",
    -2147462622: "DSSCOM_C_PDS_FUNCARG_ACCRINTM_ISSUE",
    -2147462621: "DSSCOM_C_PDS_FUNCARG_ACCRINTM_MATURITY",
    -2147462620: "DSSCOM_C_PDS_FUNCARG_ACCRINTM_RATE",
    -2147462626: "DSSCOM_C_PDS_FUNCARG_ACCRINT_FIRSTINTEREST",
    -2147462623: "DSSCOM_C_PDS_FUNCARG_ACCRINT_FREQUENCY",
    -2147462627: "DSSCOM_C_PDS_FUNCARG_ACCRINT_ISSUE",
    -2147462624: "DSSCOM_C_PDS_FUNCARG_ACCRINT_RATE",
    -2147462625: "DSSCOM_C_PDS_FUNCARG_ACCRINT_SETTLEMENT",
    -2147462618: "DSSCOM_C_PDS_FUNCARG_ACOSH_NUMBER",
    -2147462619: "DSSCOM_C_PDS_FUNCARG_ACOS_NUMBER",
    -2147462143: "DSSCOM_C_PDS_FUNCARG_ADD2_VALUELIST",
    -2147462617: "DSSCOM_C_PDS_FUNCARG_ADDDAYS_DATETIME",
    -2147462616: "DSSCOM_C_PDS_FUNCARG_ADDDAYS_DAYS",
    -2147462615: "DSSCOM_C_PDS_FUNCARG_ADDMONTHS_DATETIME",
    -2147462614: "DSSCOM_C_PDS_FUNCARG_ADDMONTHS_INTEGER",
    -2147462642: "DSSCOM_C_PDS_FUNCARG_ADD_ARG1",
    -2147462641: "DSSCOM_C_PDS_FUNCARG_ADD_ARG2",
    -2147462613: "DSSCOM_C_PDS_FUNCARG_AND_ARG1",
    -2147462612: "DSSCOM_C_PDS_FUNCARG_AND_ARG2",
    -2147462610: "DSSCOM_C_PDS_FUNCARG_ASINH_NUMBER",
    -2147462611: "DSSCOM_C_PDS_FUNCARG_ASIN_NUMBER",
    -2147462608: "DSSCOM_C_PDS_FUNCARG_ATAN2_X_NUM",
    -2147462607: "DSSCOM_C_PDS_FUNCARG_ATAN2_Y_NUM",
    -2147462606: "DSSCOM_C_PDS_FUNCARG_ATANH_NUMBER",
    -2147462609: "DSSCOM_C_PDS_FUNCARG_ATAN_NUMBER",
    -2147462142: "DSSCOM_C_PDS_FUNCARG_AVERAGE_VALUELIST",
    -2147462604: "DSSCOM_C_PDS_FUNCARG_AVGDEV_VALUELIST",
    -2147462605: "DSSCOM_C_PDS_FUNCARG_AVG_VALUELIST",
    -2147462596: "DSSCOM_C_PDS_FUNCARG_BANDINGC_BANDCOUNT",
    -2147462598: "DSSCOM_C_PDS_FUNCARG_BANDINGC_STARTAT",
    -2147462597: "DSSCOM_C_PDS_FUNCARG_BANDINGC_STOPAT",
    -2147462599: "DSSCOM_C_PDS_FUNCARG_BANDINGC_VALUELIST",
    -2147461571: "DSSCOM_C_PDS_FUNCARG_BANDINGM_VALUELIST",
    -2147462594: "DSSCOM_C_PDS_FUNCARG_BANDINGP_BOUNDARY1",
    -2147462593: "DSSCOM_C_PDS_FUNCARG_BANDINGP_BOUNDARYLIST",
    -2147462595: "DSSCOM_C_PDS_FUNCARG_BANDINGP_VALUELIST",
    -2147462600: "DSSCOM_C_PDS_FUNCARG_BANDING_SIZE",
    -2147462602: "DSSCOM_C_PDS_FUNCARG_BANDING_STARTAT",
    -2147462601: "DSSCOM_C_PDS_FUNCARG_BANDING_STOPAT",
    -2147462603: "DSSCOM_C_PDS_FUNCARG_BANDING_VALUELIST",
    -2147462592: "DSSCOM_C_PDS_FUNCARG_BEGINSWITH_ARG1",
    -2147462591: "DSSCOM_C_PDS_FUNCARG_BEGINSWITH_ARG2",
    -2147462589: "DSSCOM_C_PDS_FUNCARG_BETADISTRIBUTION_ALPHA",
    -2147462588: "DSSCOM_C_PDS_FUNCARG_BETADISTRIBUTION_BETA",
    -2147462590: "DSSCOM_C_PDS_FUNCARG_BETADISTRIBUTION_X",
    -2147462586: "DSSCOM_C_PDS_FUNCARG_BETWEEN_BOUNDARY1",
    -2147462585: "DSSCOM_C_PDS_FUNCARG_BETWEEN_BOUNDARY2",
    -2147462587: "DSSCOM_C_PDS_FUNCARG_BETWEEN_VALUE",
    -2147462583: "DSSCOM_C_PDS_FUNCARG_BINOMIALDISTRIBUTION_N",
    -2147462582: "DSSCOM_C_PDS_FUNCARG_BINOMIALDISTRIBUTION_P",
    -2147462584: "DSSCOM_C_PDS_FUNCARG_BINOMIALDISTRIBUTION_X",
    -2147462578: "DSSCOM_C_PDS_FUNCARG_CASEV_EXPRESSION",
    -2147462576: "DSSCOM_C_PDS_FUNCARG_CASEV_RESULT1",
    -2147462577: "DSSCOM_C_PDS_FUNCARG_CASEV_VALUE1",
    -2147462575: "DSSCOM_C_PDS_FUNCARG_CASEV_VALUERESULTLIST",
    -2147462581: "DSSCOM_C_PDS_FUNCARG_CASE_CONDITION1",
    -2147462579: "DSSCOM_C_PDS_FUNCARG_CASE_CONDITIONRESULTLIST",
    -2147462580: "DSSCOM_C_PDS_FUNCARG_CASE_RESULT1",
    -2147462574: "DSSCOM_C_PDS_FUNCARG_CEILING_NUMBER",
    -2147462572: "DSSCOM_C_PDS_FUNCARG_CHISQUAREDISTRIBUTION_DF",
    -2147462573: "DSSCOM_C_PDS_FUNCARG_CHISQUAREDISTRIBUTION_X",
    -2147462571: "DSSCOM_C_PDS_FUNCARG_CHISQUARETEST_DATA_1",
    -2147462570: "DSSCOM_C_PDS_FUNCARG_CHISQUARETEST_DATA_2",
    -2147462569: "DSSCOM_C_PDS_FUNCARG_COMBINE_NUMBER",
    -2147462568: "DSSCOM_C_PDS_FUNCARG_COMBINE_NUMBER_CHOSEN",
    -2147462565: "DSSCOM_C_PDS_FUNCARG_CONCATBLANK_STRING1",
    -2147462564: "DSSCOM_C_PDS_FUNCARG_CONCATBLANK_STRINGLIST",
    -2147462567: "DSSCOM_C_PDS_FUNCARG_CONCAT_STRING1",
    -2147462566: "DSSCOM_C_PDS_FUNCARG_CONCAT_STRINGLIST",
    -2147462563: "DSSCOM_C_PDS_FUNCARG_CONFIDENCE_ALPHA",
    -2147462561: "DSSCOM_C_PDS_FUNCARG_CONFIDENCE_SIZE",
    -2147462562: "DSSCOM_C_PDS_FUNCARG_CONFIDENCE_STDEV",
    -2147462560: "DSSCOM_C_PDS_FUNCARG_CONTAINS_ARG1",
    -2147462559: "DSSCOM_C_PDS_FUNCARG_CONTAINS_ARG2",
    -2147462558: "DSSCOM_C_PDS_FUNCARG_CORRELATION_VALUELIST1",
    -2147462557: "DSSCOM_C_PDS_FUNCARG_CORRELATION_VALUELIST2",
    -2147462555: "DSSCOM_C_PDS_FUNCARG_COSH_NUMBER",
    -2147462556: "DSSCOM_C_PDS_FUNCARG_COS_NUMBER",
    -2147462554: "DSSCOM_C_PDS_FUNCARG_COUNT_VALUELIST",
    -2147462551: "DSSCOM_C_PDS_FUNCARG_COUPDAYBS_FREQUENCY",
    -2147462552: "DSSCOM_C_PDS_FUNCARG_COUPDAYBS_MATURITY",
    -2147462553: "DSSCOM_C_PDS_FUNCARG_COUPDAYBS_SETTLEMENT",
    -2147462545: "DSSCOM_C_PDS_FUNCARG_COUPDAYSNC_FREQUENCY",
    -2147462546: "DSSCOM_C_PDS_FUNCARG_COUPDAYSNC_MATURITY",
    -2147462547: "DSSCOM_C_PDS_FUNCARG_COUPDAYSNC_SETTLEMENT",
    -2147462548: "DSSCOM_C_PDS_FUNCARG_COUPDAYS_FREQUENCY",
    -2147462549: "DSSCOM_C_PDS_FUNCARG_COUPDAYS_MATURITY",
    -2147462550: "DSSCOM_C_PDS_FUNCARG_COUPDAYS_SETTLEMENT",
    -2147462542: "DSSCOM_C_PDS_FUNCARG_COUPNCD_FREQUENCY",
    -2147462543: "DSSCOM_C_PDS_FUNCARG_COUPNCD_MATURITY",
    -2147462544: "DSSCOM_C_PDS_FUNCARG_COUPNCD_SETTLEMENT",
    -2147462539: "DSSCOM_C_PDS_FUNCARG_COUPNUM_FREQUENCY",
    -2147462540: "DSSCOM_C_PDS_FUNCARG_COUPNUM_MATURITY",
    -2147462541: "DSSCOM_C_PDS_FUNCARG_COUPNUM_SETTLEMENT",
    -2147462536: "DSSCOM_C_PDS_FUNCARG_COUPPCD_FREQUENCY",
    -2147462537: "DSSCOM_C_PDS_FUNCARG_COUPPCD_MATURITY",
    -2147462538: "DSSCOM_C_PDS_FUNCARG_COUPPCD_SETTLEMENT",
    -2147462535: "DSSCOM_C_PDS_FUNCARG_COVARIANCE_VALUELIST1",
    -2147462534: "DSSCOM_C_PDS_FUNCARG_COVARIANCE_VALUELIST2",
    -2147462531: "DSSCOM_C_PDS_FUNCARG_CRITBINOMIAL_ALPHA",
    -2147462532: "DSSCOM_C_PDS_FUNCARG_CRITBINOMIAL_PROBABILITY_S",
    -2147462533: "DSSCOM_C_PDS_FUNCARG_CRITBINOMIAL_TRIALS",
    -2147462526: "DSSCOM_C_PDS_FUNCARG_CUMIPMT_END",
    -2147462529: "DSSCOM_C_PDS_FUNCARG_CUMIPMT_NPER",
    -2147462528: "DSSCOM_C_PDS_FUNCARG_CUMIPMT_PV",
    -2147462530: "DSSCOM_C_PDS_FUNCARG_CUMIPMT_RATE",
    -2147462527: "DSSCOM_C_PDS_FUNCARG_CUMIPMT_START",
    -2147462521: "DSSCOM_C_PDS_FUNCARG_CUMPRINC_END",
    -2147462524: "DSSCOM_C_PDS_FUNCARG_CUMPRINC_NPER",
    -2147462523: "DSSCOM_C_PDS_FUNCARG_CUMPRINC_PV",
    -2147462525: "DSSCOM_C_PDS_FUNCARG_CUMPRINC_RATE",
    -2147462522: "DSSCOM_C_PDS_FUNCARG_CUMPRINC_START",
    -2147460955: "DSSCOM_C_PDS_FUNCARG_DATETOSTRING_ARG2",
    -2147462520: "DSSCOM_C_PDS_FUNCARG_DATE_DATETIME",
    -2147462519: "DSSCOM_C_PDS_FUNCARG_DAYOFMONTH_INPUTDATE",
    -2147462518: "DSSCOM_C_PDS_FUNCARG_DAYOFWEEK_INPUTDATE",
    -2147462517: "DSSCOM_C_PDS_FUNCARG_DAYOFYEAR_INPUTDATE",
    -2147462516: "DSSCOM_C_PDS_FUNCARG_DAYSBETWEEN_DATE1",
    -2147462515: "DSSCOM_C_PDS_FUNCARG_DAYSBETWEEN_DATE2",
    -2147462514: "DSSCOM_C_PDS_FUNCARG_DB_COST",
    -2147462512: "DSSCOM_C_PDS_FUNCARG_DB_LIFE",
    -2147462511: "DSSCOM_C_PDS_FUNCARG_DB_PERIOD",
    -2147462513: "DSSCOM_C_PDS_FUNCARG_DB_SALVAGE",
    -2147462510: "DSSCOM_C_PDS_FUNCARG_DDB_COST",
    -2147462508: "DSSCOM_C_PDS_FUNCARG_DDB_LIFE",
    -2147462507: "DSSCOM_C_PDS_FUNCARG_DDB_PERIOD",
    -2147462509: "DSSCOM_C_PDS_FUNCARG_DDB_SALVAGE",
    -2147462506: "DSSCOM_C_PDS_FUNCARG_DEGREES_ANGLE",
    -2147462504: "DSSCOM_C_PDS_FUNCARG_DISC_MATURITY",
    -2147462503: "DSSCOM_C_PDS_FUNCARG_DISC_PRICE",
    -2147462502: "DSSCOM_C_PDS_FUNCARG_DISC_REDEMPTION",
    -2147462505: "DSSCOM_C_PDS_FUNCARG_DISC_SETTLEMENT",
    -2147462644: "DSSCOM_C_PDS_FUNCARG_DIVIDE_ARG1",
    -2147462643: "DSSCOM_C_PDS_FUNCARG_DIVIDE_ARG2",
    -2147462500: "DSSCOM_C_PDS_FUNCARG_DOLLARDE_FRACTION",
    -2147462501: "DSSCOM_C_PDS_FUNCARG_DOLLARDE_FRACTIONALDOLLAR",
    -2147462499: "DSSCOM_C_PDS_FUNCARG_DOLLARFR_DECIMALDOLLAR",
    -2147462498: "DSSCOM_C_PDS_FUNCARG_DOLLARFR_FRACTION",
    -2147462495: "DSSCOM_C_PDS_FUNCARG_DURATION_COUPONRATE",
    -2147462493: "DSSCOM_C_PDS_FUNCARG_DURATION_FREQUENCY",
    -2147462496: "DSSCOM_C_PDS_FUNCARG_DURATION_MATURITY",
    -2147462497: "DSSCOM_C_PDS_FUNCARG_DURATION_SETTLEMENT",
    -2147462494: "DSSCOM_C_PDS_FUNCARG_DURATION_YIELDRATE",
    -2147462492: "DSSCOM_C_PDS_FUNCARG_EFFECT_NOMINALRATE",
    -2147462491: "DSSCOM_C_PDS_FUNCARG_EFFECT_NPERY",
    -2147462490: "DSSCOM_C_PDS_FUNCARG_ENDSWITH_ARG1",
    -2147462489: "DSSCOM_C_PDS_FUNCARG_ENDSWITH_ARG2",
    -2147462634: "DSSCOM_C_PDS_FUNCARG_EQUAL_ARG1",
    -2147462633: "DSSCOM_C_PDS_FUNCARG_EQUAL_ARG2",
    -2147462486: "DSSCOM_C_PDS_FUNCARG_EXPONENTIALDISTRIBUTION_LAMBDA",
    -2147462487: "DSSCOM_C_PDS_FUNCARG_EXPONENTIALDISTRIBUTION_X",
    -2147462483: "DSSCOM_C_PDS_FUNCARG_EXPWGHMOVINGAVG_RATE",
    -2147462485: "DSSCOM_C_PDS_FUNCARG_EXPWGHMOVINGAVG_VALUELIST",
    -2147462484: "DSSCOM_C_PDS_FUNCARG_EXPWGHMOVINGAVG_WINDOWSIZE",
    -2147462481: "DSSCOM_C_PDS_FUNCARG_EXPWGHRUNNINGAVG_RATE",
    -2147462482: "DSSCOM_C_PDS_FUNCARG_EXPWGHRUNNINGAVG_VALUELIST",
    -2147462488: "DSSCOM_C_PDS_FUNCARG_EXP_NUMBER",
    -2147462480: "DSSCOM_C_PDS_FUNCARG_FACTORIAL_NUMBER",
    -2147462478: "DSSCOM_C_PDS_FUNCARG_FDISTRIBUTION_DF1",
    -2147462477: "DSSCOM_C_PDS_FUNCARG_FDISTRIBUTION_DF2",
    -2147462479: "DSSCOM_C_PDS_FUNCARG_FDISTRIBUTION_X",
    -2147462475: "DSSCOM_C_PDS_FUNCARG_FIRSTINRANGE_VALUELIST",
    -2147462476: "DSSCOM_C_PDS_FUNCARG_FIRST_VALUELIST",
    -2147462474: "DSSCOM_C_PDS_FUNCARG_FISHER_X",
    -2147462473: "DSSCOM_C_PDS_FUNCARG_FLOOR_NUMBER",
    -2147462138: "DSSCOM_C_PDS_FUNCARG_FORECASTV_KNOWNXVALUELIST",
    -2147462139: "DSSCOM_C_PDS_FUNCARG_FORECASTV_KNOWNYVALUELIST",
    -2147462140: "DSSCOM_C_PDS_FUNCARG_FORECASTV_X",
    -2147462141: "DSSCOM_C_PDS_FUNCARG_FORECAST_X",
    -2147462472: "DSSCOM_C_PDS_FUNCARG_FTEST_DATA_1",
    -2147462471: "DSSCOM_C_PDS_FUNCARG_FTEST_DATA_2",
    -2147462465: "DSSCOM_C_PDS_FUNCARG_FVSCHEDULE_PV",
    -2147462466: "DSSCOM_C_PDS_FUNCARG_FVSCHEDULE_VALUES",
    -2147462469: "DSSCOM_C_PDS_FUNCARG_FV_NPER",
    -2147462468: "DSSCOM_C_PDS_FUNCARG_FV_PMT",
    -2147462467: "DSSCOM_C_PDS_FUNCARG_FV_PV",
    -2147462470: "DSSCOM_C_PDS_FUNCARG_FV_RATE",
    -2147462463: "DSSCOM_C_PDS_FUNCARG_GAMMADISTRIBUTION_ALPHA",
    -2147462462: "DSSCOM_C_PDS_FUNCARG_GAMMADISTRIBUTION_BETA",
    -2147462464: "DSSCOM_C_PDS_FUNCARG_GAMMADISTRIBUTION_X",
    -2147462461: "DSSCOM_C_PDS_FUNCARG_GEOMEAN_VALUELIST",
    -2147462630: "DSSCOM_C_PDS_FUNCARG_GREATEREQUAL_ARG1",
    -2147462629: "DSSCOM_C_PDS_FUNCARG_GREATEREQUAL_ARG2",
    -2147462632: "DSSCOM_C_PDS_FUNCARG_GREATER_ARG1",
    -2147462631: "DSSCOM_C_PDS_FUNCARG_GREATER_ARG2",
    -2147462460: "DSSCOM_C_PDS_FUNCARG_GREATEST_VALUELIST",
    -2147462135: "DSSCOM_C_PDS_FUNCARG_GROWTHV_KNOWNYVALUELIST",
    -2147462136: "DSSCOM_C_PDS_FUNCARG_GROWTHV_X",
    -2147462137: "DSSCOM_C_PDS_FUNCARG_GROWTH_X",
    -2147462459: "DSSCOM_C_PDS_FUNCARG_HETEROSCEDASTICTTEST_DATA_1",
    -2147462458: "DSSCOM_C_PDS_FUNCARG_HETEROSCEDASTICTTEST_DATA_2",
    -2147477778: "DSSCOM_C_PDS_FUNCARG_HMEDIAN_NUM_HIST",
    -2147461008: "DSSCOM_C_PDS_FUNCARG_HMEDIAN_NUM_HIST1",
    -2147462457: "DSSCOM_C_PDS_FUNCARG_HOMOSCEDASTICTTEST_DATA_1",
    -2147462456: "DSSCOM_C_PDS_FUNCARG_HOMOSCEDASTICTTEST_DATA_2",
    -2147462455: "DSSCOM_C_PDS_FUNCARG_HOUR_DATETIME",
    -2147462452: "DSSCOM_C_PDS_FUNCARG_HYPERGEOMETRICDISTRIBUTION_M",
    -2147462453: "DSSCOM_C_PDS_FUNCARG_HYPERGEOMETRICDISTRIBUTION_N",
    -2147462451: "DSSCOM_C_PDS_FUNCARG_HYPERGEOMETRICDISTRIBUTION_N2",
    -2147462454: "DSSCOM_C_PDS_FUNCARG_HYPERGEOMETRICDISTRIBUTION_X",
    -2147460975: "DSSCOM_C_PDS_FUNCARG_IFBYDIMTY_DIMENSIONALITY",
    -2147460974: "DSSCOM_C_PDS_FUNCARG_IFBYDIMTY_HIGHEROREQUALBRANCH",
    -2147460973: "DSSCOM_C_PDS_FUNCARG_IFBYDIMTY_LOWERBRANCH",
    -2147462450: "DSSCOM_C_PDS_FUNCARG_IF_CONDITION",
    -2147462448: "DSSCOM_C_PDS_FUNCARG_IF_FALSEBRANCH",
    -2147462449: "DSSCOM_C_PDS_FUNCARG_IF_TRUEBRANCH",
    -2147462447: "DSSCOM_C_PDS_FUNCARG_INITCAP_STRING",
    -2147462134: "DSSCOM_C_PDS_FUNCARG_INT2_NUMBER",
    -2147462444: "DSSCOM_C_PDS_FUNCARG_INTERCEPT_X",
    -2147462445: "DSSCOM_C_PDS_FUNCARG_INTERCEPT_Y",
    -2147462443: "DSSCOM_C_PDS_FUNCARG_INTERSECT_ARG1",
    -2147462442: "DSSCOM_C_PDS_FUNCARG_INTERSECT_ARG2",
    -2147462439: "DSSCOM_C_PDS_FUNCARG_INTRATE_INVESTMENT",
    -2147462440: "DSSCOM_C_PDS_FUNCARG_INTRATE_MATURITY",
    -2147462438: "DSSCOM_C_PDS_FUNCARG_INTRATE_REDEMPTION",
    -2147462441: "DSSCOM_C_PDS_FUNCARG_INTRATE_SETTLEMENT",
    -2147462446: "DSSCOM_C_PDS_FUNCARG_INT_NUMBER",
    -2147462436: "DSSCOM_C_PDS_FUNCARG_INVERSEBETADISTRIBUTION_ALPHA",
    -2147462435: "DSSCOM_C_PDS_FUNCARG_INVERSEBETADISTRIBUTION_BETA",
    -2147462437: "DSSCOM_C_PDS_FUNCARG_INVERSEBETADISTRIBUTION_X",
    -2147462433: "DSSCOM_C_PDS_FUNCARG_INVERSECHIDISTRIBUTION_DF",
    -2147462434: "DSSCOM_C_PDS_FUNCARG_INVERSECHIDISTRIBUTION_X",
    -2147462431: "DSSCOM_C_PDS_FUNCARG_INVERSEFDISTRIBUTION_DF1",
    -2147462430: "DSSCOM_C_PDS_FUNCARG_INVERSEFDISTRIBUTION_DF2",
    -2147462432: "DSSCOM_C_PDS_FUNCARG_INVERSEFDISTRIBUTION_X",
    -2147462429: "DSSCOM_C_PDS_FUNCARG_INVERSEFISHER_X",
    -2147462427: "DSSCOM_C_PDS_FUNCARG_INVERSEGAMMADISTRIBUTION_ALPHA",
    -2147462426: "DSSCOM_C_PDS_FUNCARG_INVERSEGAMMADISTRIBUTION_BETA",
    -2147462428: "DSSCOM_C_PDS_FUNCARG_INVERSEGAMMADISTRIBUTION_X",
    -2147462424: "DSSCOM_C_PDS_FUNCARG_INVERSELOGNORMALDISTRIBUTION_MEAN",
    -2147462423: "DSSCOM_C_PDS_FUNCARG_INVERSELOGNORMALDISTRIBUTION_STDEV",
    -2147462425: "DSSCOM_C_PDS_FUNCARG_INVERSELOGNORMALDISTRIBUTION_X",
    -2147462421: "DSSCOM_C_PDS_FUNCARG_INVERSENORMDISTRIBUTION_MEAN",
    -2147462420: "DSSCOM_C_PDS_FUNCARG_INVERSENORMDISTRIBUTION_STDEV",
    -2147462422: "DSSCOM_C_PDS_FUNCARG_INVERSENORMDISTRIBUTION_X",
    -2147462419: "DSSCOM_C_PDS_FUNCARG_INVERSENORMSDISTRIBUTION_X",
    -2147462417: "DSSCOM_C_PDS_FUNCARG_INVERSETDISTRIBUTION_DF",
    -2147462418: "DSSCOM_C_PDS_FUNCARG_INVERSETDISTRIBUTION_PROBABILITY",
    -2147462414: "DSSCOM_C_PDS_FUNCARG_IPMT_NPERIOD",
    -2147462415: "DSSCOM_C_PDS_FUNCARG_IPMT_PERIOD",
    -2147462413: "DSSCOM_C_PDS_FUNCARG_IPMT_PV",
    -2147462416: "DSSCOM_C_PDS_FUNCARG_IPMT_RATE",
    -2147462412: "DSSCOM_C_PDS_FUNCARG_IRR_VALUES",
    -2147462411: "DSSCOM_C_PDS_FUNCARG_ISNOTNULL_VALUE",
    -2147462410: "DSSCOM_C_PDS_FUNCARG_ISNULL_VALUE",
    -2147462409: "DSSCOM_C_PDS_FUNCARG_KURTOSIS_VALUELIST",
    -2147461555: "DSSCOM_C_PDS_FUNCARG_LAG_DEFAULTVALUE",
    -2147461556: "DSSCOM_C_PDS_FUNCARG_LAG_OFFSET",
    -2147461557: "DSSCOM_C_PDS_FUNCARG_LAG_VALUELIST",
    -2147462407: "DSSCOM_C_PDS_FUNCARG_LASTINRANGE_VALUELIST",
    -2147462408: "DSSCOM_C_PDS_FUNCARG_LAST_VALUELIST",
    -2147461552: "DSSCOM_C_PDS_FUNCARG_LEAD_DEFAULTVALUE",
    -2147461553: "DSSCOM_C_PDS_FUNCARG_LEAD_OFFSET",
    -2147461554: "DSSCOM_C_PDS_FUNCARG_LEAD_VALUELIST",
    -2147462406: "DSSCOM_C_PDS_FUNCARG_LEAST_VALUELIST",
    -2147462404: "DSSCOM_C_PDS_FUNCARG_LEFTSTR_LENGTH",
    -2147462405: "DSSCOM_C_PDS_FUNCARG_LEFTSTR_STRING",
    -2147462403: "DSSCOM_C_PDS_FUNCARG_LENGTH_STRING",
    -2147462638: "DSSCOM_C_PDS_FUNCARG_LESSEQUAL_ARG1",
    -2147462637: "DSSCOM_C_PDS_FUNCARG_LESSEQUAL_ARG2",
    -2147462640: "DSSCOM_C_PDS_FUNCARG_LESS_ARG1",
    -2147462639: "DSSCOM_C_PDS_FUNCARG_LESS_ARG2",
    -2147462402: "DSSCOM_C_PDS_FUNCARG_LIKE_ARG1",
    -2147462401: "DSSCOM_C_PDS_FUNCARG_LIKE_ARG2",
    -2147462400: "DSSCOM_C_PDS_FUNCARG_LN_NUMBER",
    -2147462397: "DSSCOM_C_PDS_FUNCARG_LOG10_NUMBER",
    -2147462395: "DSSCOM_C_PDS_FUNCARG_LOGNORMALDISTRIBUTION_MEAN",
    -2147462394: "DSSCOM_C_PDS_FUNCARG_LOGNORMALDISTRIBUTION_STDEV",
    -2147462396: "DSSCOM_C_PDS_FUNCARG_LOGNORMALDISTRIBUTION_X",
    -2147462398: "DSSCOM_C_PDS_FUNCARG_LOG_BASE",
    -2147462399: "DSSCOM_C_PDS_FUNCARG_LOG_NUMBER",
    -2147462393: "DSSCOM_C_PDS_FUNCARG_LOWER_STRING",
    -2147462392: "DSSCOM_C_PDS_FUNCARG_LTRIM_STRING",
    -2147462391: "DSSCOM_C_PDS_FUNCARG_MAX_VALUELIST",
    -2147462388: "DSSCOM_C_PDS_FUNCARG_MDURATION_COUPONRATE",
    -2147462386: "DSSCOM_C_PDS_FUNCARG_MDURATION_FREQUENCY",
    -2147462389: "DSSCOM_C_PDS_FUNCARG_MDURATION_MATURITY",
    -2147462390: "DSSCOM_C_PDS_FUNCARG_MDURATION_SETTLEMENT",
    -2147462387: "DSSCOM_C_PDS_FUNCARG_MDURATION_YIELDRATE",
    -2147462385: "DSSCOM_C_PDS_FUNCARG_MEANTTEST_DATA",
    -2147462384: "DSSCOM_C_PDS_FUNCARG_MEANTTEST_HYPOTHESIS_MEAN",
    -2147462383: "DSSCOM_C_PDS_FUNCARG_MEDIAN_VALUELIST",
    -2147462382: "DSSCOM_C_PDS_FUNCARG_MILLISECOND_DATETIME",
    -2147462380: "DSSCOM_C_PDS_FUNCARG_MINUTE_DATETIME",
    -2147462381: "DSSCOM_C_PDS_FUNCARG_MIN_VALUELIST",
    -2147462378: "DSSCOM_C_PDS_FUNCARG_MIRR_FINANCIALRATE",
    -2147462377: "DSSCOM_C_PDS_FUNCARG_MIRR_REINVESTRATE",
    -2147462379: "DSSCOM_C_PDS_FUNCARG_MIRR_VALUES",
    -2147462374: "DSSCOM_C_PDS_FUNCARG_MODE_VALUELIST",
    -2147462375: "DSSCOM_C_PDS_FUNCARG_MOD_DIVISOR",
    -2147462376: "DSSCOM_C_PDS_FUNCARG_MOD_NUMBER",
    -2147462372: "DSSCOM_C_PDS_FUNCARG_MONTHENDDATE_DATETIME",
    -2147462371: "DSSCOM_C_PDS_FUNCARG_MONTHSBETWEEN_DATETIME1",
    -2147462370: "DSSCOM_C_PDS_FUNCARG_MONTHSBETWEEN_DATETIME2",
    -2147462369: "DSSCOM_C_PDS_FUNCARG_MONTHSTARTDATE_DATETIME",
    -2147462373: "DSSCOM_C_PDS_FUNCARG_MONTH_INPUTDATE",
    -2147462368: "DSSCOM_C_PDS_FUNCARG_MOVINGAVG_VALUELIST",
    -2147462367: "DSSCOM_C_PDS_FUNCARG_MOVINGAVG_WINDOWSIZE",
    -2147462366: "DSSCOM_C_PDS_FUNCARG_MOVINGCOUNT_VALUELIST",
    -2147462365: "DSSCOM_C_PDS_FUNCARG_MOVINGCOUNT_WINDOWSIZE",
    -2147462364: "DSSCOM_C_PDS_FUNCARG_MOVINGDIFFERENCE_VALUELIST",
    -2147462363: "DSSCOM_C_PDS_FUNCARG_MOVINGDIFFERENCE_WINDOWSIZE",
    -2147462362: "DSSCOM_C_PDS_FUNCARG_MOVINGMAX_VALUELIST",
    -2147462361: "DSSCOM_C_PDS_FUNCARG_MOVINGMAX_WINDOWSIZE",
    -2147462360: "DSSCOM_C_PDS_FUNCARG_MOVINGMIN_VALUELIST",
    -2147462359: "DSSCOM_C_PDS_FUNCARG_MOVINGMIN_WINDOWSIZE",
    -2147462356: "DSSCOM_C_PDS_FUNCARG_MOVINGSTDEVP_VALUELIST",
    -2147462355: "DSSCOM_C_PDS_FUNCARG_MOVINGSTDEVP_WINDOWSIZE",
    -2147462358: "DSSCOM_C_PDS_FUNCARG_MOVINGSTDEV_VALUELIST",
    -2147462357: "DSSCOM_C_PDS_FUNCARG_MOVINGSTDEV_WINDOWSIZE",
    -2147462354: "DSSCOM_C_PDS_FUNCARG_MOVINGSUM_VALUELIST",
    -2147462353: "DSSCOM_C_PDS_FUNCARG_MOVINGSUM_WINDOWSIZE",
    -2147462133: "DSSCOM_C_PDS_FUNCARG_MULTIPLY2_VALUELIST",
    -2147462646: "DSSCOM_C_PDS_FUNCARG_MULTIPLY_ARG1",
    -2147462645: "DSSCOM_C_PDS_FUNCARG_MULTIPLY_ARG2",
    -2147462352: "DSSCOM_C_PDS_FUNCARG_NEGATIVEBINOMIALDISTRIBUTION_F",
    -2147462350: "DSSCOM_C_PDS_FUNCARG_NEGATIVEBINOMIALDISTRIBUTION_P",
    -2147462351: "DSSCOM_C_PDS_FUNCARG_NEGATIVEBINOMIALDISTRIBUTION_S",
    -2147462349: "DSSCOM_C_PDS_FUNCARG_NOMINAL_EFFECTIVELRATE",
    -2147462348: "DSSCOM_C_PDS_FUNCARG_NOMINAL_NPERY",
    -2147462346: "DSSCOM_C_PDS_FUNCARG_NORMALDISTRIBUTION_MEAN",
    -2147462345: "DSSCOM_C_PDS_FUNCARG_NORMALDISTRIBUTION_STDEV",
    -2147462347: "DSSCOM_C_PDS_FUNCARG_NORMALDISTRIBUTION_X",
    -2147462343: "DSSCOM_C_PDS_FUNCARG_NOTBEGINSWITH_ARG1",
    -2147462342: "DSSCOM_C_PDS_FUNCARG_NOTBEGINSWITH_ARG2",
    -2147462340: "DSSCOM_C_PDS_FUNCARG_NOTBETWEEN_BOUNDARY1",
    -2147462339: "DSSCOM_C_PDS_FUNCARG_NOTBETWEEN_BOUNDARY2",
    -2147462341: "DSSCOM_C_PDS_FUNCARG_NOTBETWEEN_VALUE",
    -2147462338: "DSSCOM_C_PDS_FUNCARG_NOTCONTAINS_ARG1",
    -2147462337: "DSSCOM_C_PDS_FUNCARG_NOTCONTAINS_ARG2",
    -2147462336: "DSSCOM_C_PDS_FUNCARG_NOTENDSWITH_ARG1",
    -2147462335: "DSSCOM_C_PDS_FUNCARG_NOTENDSWITH_ARG2",
    -2147462636: "DSSCOM_C_PDS_FUNCARG_NOTEQUAL_ARG1",
    -2147462635: "DSSCOM_C_PDS_FUNCARG_NOTEQUAL_ARG2",
    -2147462334: "DSSCOM_C_PDS_FUNCARG_NOTLIKE_ARG1",
    -2147462333: "DSSCOM_C_PDS_FUNCARG_NOTLIKE_ARG2",
    -2147462344: "DSSCOM_C_PDS_FUNCARG_NOT_ARG1",
    -2147462329: "DSSCOM_C_PDS_FUNCARG_NPER_FV",
    -2147462331: "DSSCOM_C_PDS_FUNCARG_NPER_PAYMENT",
    -2147462330: "DSSCOM_C_PDS_FUNCARG_NPER_PV",
    -2147462332: "DSSCOM_C_PDS_FUNCARG_NPER_RATE",
    -2147462327: "DSSCOM_C_PDS_FUNCARG_NPV_RATE",
    -2147462328: "DSSCOM_C_PDS_FUNCARG_NPV_VALUES",
    -2147462324: "DSSCOM_C_PDS_FUNCARG_NTILESIZE_SIZE",
    -2147462325: "DSSCOM_C_PDS_FUNCARG_NTILESIZE_VALUELIST",
    -2147462321: "DSSCOM_C_PDS_FUNCARG_NTILEVALUESIZE_SIZE",
    -2147462322: "DSSCOM_C_PDS_FUNCARG_NTILEVALUESIZE_VALUELIST",
    -2147462323: "DSSCOM_C_PDS_FUNCARG_NTILEVALUE_VALUELIST",
    -2147462326: "DSSCOM_C_PDS_FUNCARG_NTILE_VALUELIST",
    -2147462320: "DSSCOM_C_PDS_FUNCARG_NULLTOZERO_VALUE",
    -2147462315: "DSSCOM_C_PDS_FUNCARG_ODDFPRICE_COUPONRATE",
    -2147462316: "DSSCOM_C_PDS_FUNCARG_ODDFPRICE_FIRSTCOUPON",
    -2147462312: "DSSCOM_C_PDS_FUNCARG_ODDFPRICE_FREQUENCY",
    -2147462317: "DSSCOM_C_PDS_FUNCARG_ODDFPRICE_ISSUE",
    -2147462318: "DSSCOM_C_PDS_FUNCARG_ODDFPRICE_MATURITY",
    -2147462313: "DSSCOM_C_PDS_FUNCARG_ODDFPRICE_REDEMPTION",
    -2147462319: "DSSCOM_C_PDS_FUNCARG_ODDFPRICE_SETTLEMENT",
    -2147462314: "DSSCOM_C_PDS_FUNCARG_ODDFPRICE_YIELDRATE",
    -2147462307: "DSSCOM_C_PDS_FUNCARG_ODDFYIELD_COUPONRATE",
    -2147462308: "DSSCOM_C_PDS_FUNCARG_ODDFYIELD_FIRSTCOUPON",
    -2147462304: "DSSCOM_C_PDS_FUNCARG_ODDFYIELD_FREQUENCY",
    -2147462309: "DSSCOM_C_PDS_FUNCARG_ODDFYIELD_ISSUE",
    -2147462310: "DSSCOM_C_PDS_FUNCARG_ODDFYIELD_MATURITY",
    -2147462306: "DSSCOM_C_PDS_FUNCARG_ODDFYIELD_PRICE",
    -2147462305: "DSSCOM_C_PDS_FUNCARG_ODDFYIELD_REDEMPTION",
    -2147462311: "DSSCOM_C_PDS_FUNCARG_ODDFYIELD_SETTLEMENT",
    -2147462300: "DSSCOM_C_PDS_FUNCARG_ODDLPRICE_COUPONRATE",
    -2147462297: "DSSCOM_C_PDS_FUNCARG_ODDLPRICE_FREQUENCY",
    -2147462301: "DSSCOM_C_PDS_FUNCARG_ODDLPRICE_LASTINTEREST",
    -2147462302: "DSSCOM_C_PDS_FUNCARG_ODDLPRICE_MATURITY",
    -2147462298: "DSSCOM_C_PDS_FUNCARG_ODDLPRICE_REDEMPTION",
    -2147462303: "DSSCOM_C_PDS_FUNCARG_ODDLPRICE_SETTLEMENT",
    -2147462299: "DSSCOM_C_PDS_FUNCARG_ODDLPRICE_YIELDRATE",
    -2147462293: "DSSCOM_C_PDS_FUNCARG_ODDLYIELD_COUPONRATE",
    -2147462290: "DSSCOM_C_PDS_FUNCARG_ODDLYIELD_FREQUENCY",
    -2147462294: "DSSCOM_C_PDS_FUNCARG_ODDLYIELD_LASTINTEREST",
    -2147462295: "DSSCOM_C_PDS_FUNCARG_ODDLYIELD_MATURITY",
    -2147462292: "DSSCOM_C_PDS_FUNCARG_ODDLYIELD_PRICE",
    -2147462291: "DSSCOM_C_PDS_FUNCARG_ODDLYIELD_REDEMPTION",
    -2147462296: "DSSCOM_C_PDS_FUNCARG_ODDLYIELD_SETTLEMENT",
    -2147461561: "DSSCOM_C_PDS_FUNCARG_OLAPAVG_VALUELIST",
    -2147461560: "DSSCOM_C_PDS_FUNCARG_OLAPCOUNT_VALUELIST",
    -2147461559: "DSSCOM_C_PDS_FUNCARG_OLAPMAX_VALUELIST",
    -2147461558: "DSSCOM_C_PDS_FUNCARG_OLAPMIN_VALUELIST",
    -2147461562: "DSSCOM_C_PDS_FUNCARG_OLAPSUM_VALUELIST",
    -2147462289: "DSSCOM_C_PDS_FUNCARG_OR_ARG1",
    -2147462288: "DSSCOM_C_PDS_FUNCARG_OR_ARG2",
    -2147462287: "DSSCOM_C_PDS_FUNCARG_PAIREDTTEST_DATA_1",
    -2147462286: "DSSCOM_C_PDS_FUNCARG_PAIREDTTEST_DATA_2",
    -2147462285: "DSSCOM_C_PDS_FUNCARG_PEARSON_DATA_1",
    -2147462284: "DSSCOM_C_PDS_FUNCARG_PEARSON_DATA_2",
    -2147462282: "DSSCOM_C_PDS_FUNCARG_PERCENTILE_K",
    -2147462283: "DSSCOM_C_PDS_FUNCARG_PERCENTILE_VALUELIST",
    -2147462281: "DSSCOM_C_PDS_FUNCARG_PERMUT_NUMBER",
    -2147462280: "DSSCOM_C_PDS_FUNCARG_PERMUT_NUMBER_CHOSEN",
    -2147462278: "DSSCOM_C_PDS_FUNCARG_PMT_NPER",
    -2147462277: "DSSCOM_C_PDS_FUNCARG_PMT_PV",
    -2147462279: "DSSCOM_C_PDS_FUNCARG_PMT_RATE",
    -2147462275: "DSSCOM_C_PDS_FUNCARG_POISSONDISTRIBUTION_LAMBDA",
    -2147462276: "DSSCOM_C_PDS_FUNCARG_POISSONDISTRIBUTION_X",
    -2147462274: "DSSCOM_C_PDS_FUNCARG_POSITION_FINDSTRING",
    -2147462273: "DSSCOM_C_PDS_FUNCARG_POSITION_WITHINSTRING",
    -2147462272: "DSSCOM_C_PDS_FUNCARG_POWER_NUMBER",
    -2147462271: "DSSCOM_C_PDS_FUNCARG_POWER_POWER",
    -2147462268: "DSSCOM_C_PDS_FUNCARG_PPMT_NPERIOD",
    -2147462269: "DSSCOM_C_PDS_FUNCARG_PPMT_PERIOD",
    -2147462267: "DSSCOM_C_PDS_FUNCARG_PPMT_PV",
    -2147462270: "DSSCOM_C_PDS_FUNCARG_PPMT_RATE",
    -2147462258: "DSSCOM_C_PDS_FUNCARG_PRICEDISC_DISCRATE",
    -2147462259: "DSSCOM_C_PDS_FUNCARG_PRICEDISC_MATURITY",
    -2147462257: "DSSCOM_C_PDS_FUNCARG_PRICEDISC_REDEMPTION",
    -2147462260: "DSSCOM_C_PDS_FUNCARG_PRICEDISC_SETTLEMENT",
    -2147462253: "DSSCOM_C_PDS_FUNCARG_PRICEMAT_COUPONRATE",
    -2147462254: "DSSCOM_C_PDS_FUNCARG_PRICEMAT_ISSUE",
    -2147462255: "DSSCOM_C_PDS_FUNCARG_PRICEMAT_MATURITY",
    -2147462256: "DSSCOM_C_PDS_FUNCARG_PRICEMAT_SETTLEMENT",
    -2147462252: "DSSCOM_C_PDS_FUNCARG_PRICEMAT_YIELDRATE",
    -2147462264: "DSSCOM_C_PDS_FUNCARG_PRICE_COUPONRATE",
    -2147462261: "DSSCOM_C_PDS_FUNCARG_PRICE_FREQUENCY",
    -2147462265: "DSSCOM_C_PDS_FUNCARG_PRICE_MATURITY",
    -2147462262: "DSSCOM_C_PDS_FUNCARG_PRICE_REDEMPTION",
    -2147462266: "DSSCOM_C_PDS_FUNCARG_PRICE_SETTLEMENT",
    -2147462263: "DSSCOM_C_PDS_FUNCARG_PRICE_YIELDRATE",
    -2147462251: "DSSCOM_C_PDS_FUNCARG_PRODUCT_VALUELIST",
    -2147462247: "DSSCOM_C_PDS_FUNCARG_PV_FV",
    -2147462249: "DSSCOM_C_PDS_FUNCARG_PV_NPERIOD",
    -2147462248: "DSSCOM_C_PDS_FUNCARG_PV_PAYMENT",
    -2147462250: "DSSCOM_C_PDS_FUNCARG_PV_RATE",
    -2147462246: "DSSCOM_C_PDS_FUNCARG_QUARTER_INPUTDATE",
    -2147462244: "DSSCOM_C_PDS_FUNCARG_QUOTIENT_DENOMINATOR",
    -2147462245: "DSSCOM_C_PDS_FUNCARG_QUOTIENT_NUMERATOR",
    -2147462243: "DSSCOM_C_PDS_FUNCARG_RADIANS_ANGLE",
    -2147462242: "DSSCOM_C_PDS_FUNCARG_RANDBETWEEN_BOTTOM",
    -2147462241: "DSSCOM_C_PDS_FUNCARG_RANDBETWEEN_TOP",
    -2147462240: "DSSCOM_C_PDS_FUNCARG_RANK_VALUELIST",
    -2147462239: "DSSCOM_C_PDS_FUNCARG_RATE_NPERIOD",
    -2147462238: "DSSCOM_C_PDS_FUNCARG_RATE_PAYMENT",
    -2147462237: "DSSCOM_C_PDS_FUNCARG_RATE_PV",
    -2147462233: "DSSCOM_C_PDS_FUNCARG_RECEIVED_DISCOUNT",
    -2147462234: "DSSCOM_C_PDS_FUNCARG_RECEIVED_INVESTMENT",
    -2147462235: "DSSCOM_C_PDS_FUNCARG_RECEIVED_MATURITY",
    -2147462236: "DSSCOM_C_PDS_FUNCARG_RECEIVED_SETTLEMENT",
    -2147462231: "DSSCOM_C_PDS_FUNCARG_RIGHTSTR_LENGTH",
    -2147462232: "DSSCOM_C_PDS_FUNCARG_RIGHTSTR_STRING",
    -2147462229: "DSSCOM_C_PDS_FUNCARG_ROUND2_NUMBER",
    -2147462228: "DSSCOM_C_PDS_FUNCARG_ROUND2_PRECISION",
    -2147462230: "DSSCOM_C_PDS_FUNCARG_ROUND_NUMBER",
    -2147462227: "DSSCOM_C_PDS_FUNCARG_RSQUARE_DATA_1",
    -2147462226: "DSSCOM_C_PDS_FUNCARG_RSQUARE_DATA_2",
    -2147462225: "DSSCOM_C_PDS_FUNCARG_RTRIM_STRING",
    -2147462224: "DSSCOM_C_PDS_FUNCARG_RUNNINGAVG_VALUELIST",
    -2147462223: "DSSCOM_C_PDS_FUNCARG_RUNNINGCOUNT_VALUELIST",
    -2147462222: "DSSCOM_C_PDS_FUNCARG_RUNNINGMAX_VALUELIST",
    -2147462221: "DSSCOM_C_PDS_FUNCARG_RUNNINGMIN_VALUELIST",
    -2147462219: "DSSCOM_C_PDS_FUNCARG_RUNNINGSTDEVP_VALUELIST",
    -2147462220: "DSSCOM_C_PDS_FUNCARG_RUNNINGSTDEV_VALUELIST",
    -2147462218: "DSSCOM_C_PDS_FUNCARG_RUNNINGSUM_VALUELIST",
    -2147462217: "DSSCOM_C_PDS_FUNCARG_SECOND_DATETIME",
    -2147462215: "DSSCOM_C_PDS_FUNCARG_SINH_NUMBER",
    -2147462216: "DSSCOM_C_PDS_FUNCARG_SIN_NUMBER",
    -2147462214: "DSSCOM_C_PDS_FUNCARG_SKEW_VALUELIST",
    -2147462213: "DSSCOM_C_PDS_FUNCARG_SLN_COST",
    -2147462211: "DSSCOM_C_PDS_FUNCARG_SLN_LIFE",
    -2147462212: "DSSCOM_C_PDS_FUNCARG_SLN_SALVAGE",
    -2147462209: "DSSCOM_C_PDS_FUNCARG_SLOPE_X",
    -2147462210: "DSSCOM_C_PDS_FUNCARG_SLOPE_Y",
    -2147462208: "DSSCOM_C_PDS_FUNCARG_SQRT_NUMBER",
    -2147462206: "DSSCOM_C_PDS_FUNCARG_STANDARDIZE_MEAN",
    -2147462205: "DSSCOM_C_PDS_FUNCARG_STANDARDIZE_STDEV",
    -2147462207: "DSSCOM_C_PDS_FUNCARG_STANDARDIZE_X",
    -2147462204: "DSSCOM_C_PDS_FUNCARG_STANDARDNORMALDISTRIBUTION_X",
    -2147462202: "DSSCOM_C_PDS_FUNCARG_STDEVP_VALUELIST",
    -2147462203: "DSSCOM_C_PDS_FUNCARG_STDEV_VALUELIST",
    -2147462200: "DSSCOM_C_PDS_FUNCARG_STEYX_X",
    -2147462201: "DSSCOM_C_PDS_FUNCARG_STEYX_Y",
    -2147462648: "DSSCOM_C_PDS_FUNCARG_SUBSTRACT_ARG1",
    -2147462647: "DSSCOM_C_PDS_FUNCARG_SUBSTRACT_ARG2",
    -2147462197: "DSSCOM_C_PDS_FUNCARG_SUBSTR_LENGTH",
    -2147462198: "DSSCOM_C_PDS_FUNCARG_SUBSTR_POSITION",
    -2147462199: "DSSCOM_C_PDS_FUNCARG_SUBSTR_STRING",
    -2147462196: "DSSCOM_C_PDS_FUNCARG_SUM_VALUELIST",
    -2147462195: "DSSCOM_C_PDS_FUNCARG_SYD_COST",
    -2147462193: "DSSCOM_C_PDS_FUNCARG_SYD_LIFE",
    -2147462192: "DSSCOM_C_PDS_FUNCARG_SYD_PERIOD",
    -2147462194: "DSSCOM_C_PDS_FUNCARG_SYD_SALVAGE",
    -2147462190: "DSSCOM_C_PDS_FUNCARG_TANH_NUMBER",
    -2147462191: "DSSCOM_C_PDS_FUNCARG_TAN_NUMBER",
    -2147462187: "DSSCOM_C_PDS_FUNCARG_TBILLEQ_DISCOUNT",
    -2147462188: "DSSCOM_C_PDS_FUNCARG_TBILLEQ_MATURITY",
    -2147462189: "DSSCOM_C_PDS_FUNCARG_TBILLEQ_SETTLEMENT",
    -2147462184: "DSSCOM_C_PDS_FUNCARG_TBILLPRICE_DISCOUNT",
    -2147462185: "DSSCOM_C_PDS_FUNCARG_TBILLPRICE_MATURITY",
    -2147462186: "DSSCOM_C_PDS_FUNCARG_TBILLPRICE_SETTLEMENT",
    -2147462182: "DSSCOM_C_PDS_FUNCARG_TBILLYIELD_MATURITY",
    -2147462181: "DSSCOM_C_PDS_FUNCARG_TBILLYIELD_PRICE",
    -2147462183: "DSSCOM_C_PDS_FUNCARG_TBILLYIELD_SETTLEMENT",
    -2147462179: "DSSCOM_C_PDS_FUNCARG_TDISTRIBUTION_DF",
    -2147462180: "DSSCOM_C_PDS_FUNCARG_TDISTRIBUTION_X",
    -2147462130: "DSSCOM_C_PDS_FUNCARG_TRENDV_KNOWNYVALUELIST",
    -2147462131: "DSSCOM_C_PDS_FUNCARG_TRENDV_X",
    -2147462132: "DSSCOM_C_PDS_FUNCARG_TREND_X",
    -2147462178: "DSSCOM_C_PDS_FUNCARG_TRIM_STRING",
    -2147462177: "DSSCOM_C_PDS_FUNCARG_TRUNC_NUMBER",
    -2147462176: "DSSCOM_C_PDS_FUNCARG_UMINUS_ARG",
    -2147462175: "DSSCOM_C_PDS_FUNCARG_UPPER_STRING",
    -2147462173: "DSSCOM_C_PDS_FUNCARG_VARP_VALUELIST",
    -2147462172: "DSSCOM_C_PDS_FUNCARG_VARTEST_DATA",
    -2147462171: "DSSCOM_C_PDS_FUNCARG_VARTEST_HYPOTHESIS_VARIANCE",
    -2147462174: "DSSCOM_C_PDS_FUNCARG_VAR_VALUELIST",
    -2147462170: "DSSCOM_C_PDS_FUNCARG_VDB_COST",
    -2147462168: "DSSCOM_C_PDS_FUNCARG_VDB_LIFE",
    -2147462167: "DSSCOM_C_PDS_FUNCARG_VDB_PERIOD",
    -2147462169: "DSSCOM_C_PDS_FUNCARG_VDB_SALVAGE",
    -2147462166: "DSSCOM_C_PDS_FUNCARG_WEEK_INPUTDATE",
    -2147462164: "DSSCOM_C_PDS_FUNCARG_WEIBULLDISTRIBUTION_ALPHA",
    -2147462163: "DSSCOM_C_PDS_FUNCARG_WEIBULLDISTRIBUTION_BETA",
    -2147462165: "DSSCOM_C_PDS_FUNCARG_WEIBULLDISTRIBUTION_X",
    -2147460963: "DSSCOM_C_PDS_FUNCARG_XIRR_DATES",
    -2147460961: "DSSCOM_C_PDS_FUNCARG_XIRR_GUESS",
    -2147460964: "DSSCOM_C_PDS_FUNCARG_XIRR_PAYMENTS",
    -2147460962: "DSSCOM_C_PDS_FUNCARG_XIRR_RATE",
    -2147460958: "DSSCOM_C_PDS_FUNCARG_XNPV_DATES",
    -2147460959: "DSSCOM_C_PDS_FUNCARG_XNPV_PAYMENTS",
    -2147460957: "DSSCOM_C_PDS_FUNCARG_XNPV_RATE",
    -2147460956: "DSSCOM_C_PDS_FUNCARG_XNPV_VALUE",
    -2147462161: "DSSCOM_C_PDS_FUNCARG_YEARENDDATE_DATETIME",
    -2147462160: "DSSCOM_C_PDS_FUNCARG_YEARSTARTDATE_DATETIME",
    -2147462162: "DSSCOM_C_PDS_FUNCARG_YEAR_INPUTDATE",
    -2147462152: "DSSCOM_C_PDS_FUNCARG_YIELDDISC_MATURITY",
    -2147462151: "DSSCOM_C_PDS_FUNCARG_YIELDDISC_PRICE",
    -2147462150: "DSSCOM_C_PDS_FUNCARG_YIELDDISC_REDEMPTION",
    -2147462153: "DSSCOM_C_PDS_FUNCARG_YIELDDISC_SETTLEMENT",
    -2147462147: "DSSCOM_C_PDS_FUNCARG_YIELDMAT_ISSUE",
    -2147462148: "DSSCOM_C_PDS_FUNCARG_YIELDMAT_MATURITY",
    -2147462145: "DSSCOM_C_PDS_FUNCARG_YIELDMAT_PRICE",
    -2147462146: "DSSCOM_C_PDS_FUNCARG_YIELDMAT_RATE",
    -2147462149: "DSSCOM_C_PDS_FUNCARG_YIELDMAT_SETTLEMENT",
    -2147462157: "DSSCOM_C_PDS_FUNCARG_YIELD_COUPONRATE",
    -2147462154: "DSSCOM_C_PDS_FUNCARG_YIELD_FREQUENCY",
    -2147462158: "DSSCOM_C_PDS_FUNCARG_YIELD_MATURITY",
    -2147462156: "DSSCOM_C_PDS_FUNCARG_YIELD_PRICE",
    -2147462155: "DSSCOM_C_PDS_FUNCARG_YIELD_REDEMPTION",
    -2147462159: "DSSCOM_C_PDS_FUNCARG_YIELD_SETTLEMENT",
    -2147462144: "DSSCOM_C_PDS_FUNCARG_ZEROTONULL_VALUE",
    -2147461645: "DSSCOM_C_PDS_FUNCPROP_ACCRINTM_BASIS",
    -2147461646: "DSSCOM_C_PDS_FUNCPROP_ACCRINTM_PAR",
    -2147461647: "DSSCOM_C_PDS_FUNCPROP_ACCRINT_BASIS",
    -2147461648: "DSSCOM_C_PDS_FUNCPROP_ACCRINT_PAR",
    -2147460982: "DSSCOM_C_PDS_FUNCPROP_AGGFUNC_ISREMOVABLE",
    -2147461548: "DSSCOM_C_PDS_FUNCPROP_AGGFUNC_USELOOKUPFORATTRIBUTE",
    -2147461643: "DSSCOM_C_PDS_FUNCPROP_BANDINGC_HASRESIDUE",
    -2147461570: "DSSCOM_C_PDS_FUNCPROP_BANDINGM_HASRESIDUE",
    -2147461642: "DSSCOM_C_PDS_FUNCPROP_BANDINGP_HASRESIDUE",
    -2147461644: "DSSCOM_C_PDS_FUNCPROP_BANDING_HASRESIDUE",
    -2147461641: "DSSCOM_C_PDS_FUNCPROP_BETADISTRIBUTION_LOWER_BOUND",
    -2147461640: "DSSCOM_C_PDS_FUNCPROP_BETADISTRIBUTION_UPPER_BOUND",
    -2147461639: "DSSCOM_C_PDS_FUNCPROP_BINOMIALDISTRIBUTION_CUMULATIVE",
    -2147461638: "DSSCOM_C_PDS_FUNCPROP_COUPDAYBS_BASIS",
    -2147461636: "DSSCOM_C_PDS_FUNCPROP_COUPDAYSNC_BASIS",
    -2147461637: "DSSCOM_C_PDS_FUNCPROP_COUPDAYS_BASIS",
    -2147461635: "DSSCOM_C_PDS_FUNCPROP_COUPNCD_BASIS",
    -2147461634: "DSSCOM_C_PDS_FUNCPROP_COUPNUM_BASIS",
    -2147461633: "DSSCOM_C_PDS_FUNCPROP_COUPPCD_BASIS",
    -2147461632: "DSSCOM_C_PDS_FUNCPROP_CUMIPMT_TYPE",
    -2147461631: "DSSCOM_C_PDS_FUNCPROP_CUMPRINC_TYPE",
    -2147461630: "DSSCOM_C_PDS_FUNCPROP_DB_MONTH",
    -2147461629: "DSSCOM_C_PDS_FUNCPROP_DDB_FACTOR",
    -2147461628: "DSSCOM_C_PDS_FUNCPROP_DISC_BASIS",
    -2147461627: "DSSCOM_C_PDS_FUNCPROP_DURATION_BASIS",
    -2147461626: "DSSCOM_C_PDS_FUNCPROP_EXPONENTIALDISTRIBUTION_CUMULATIVE",
    -2147461625: "DSSCOM_C_PDS_FUNCPROP_FTEST_HYPOTHESIS_TYPE",
    -2147461624: "DSSCOM_C_PDS_FUNCPROP_FTEST_RATIO",
    -2147461622: "DSSCOM_C_PDS_FUNCPROP_FVSCHEDULE_BASIS",
    -2147461623: "DSSCOM_C_PDS_FUNCPROP_FV_TYPE",
    -2147461621: "DSSCOM_C_PDS_FUNCPROP_GAMMADISTRIBUTION_CUMULATIVE",
    -2147461620: "DSSCOM_C_PDS_FUNCPROP_HETEROSCEDASTICTTEST_HYPOTHESIS_TYPE",
    -2147461619: "DSSCOM_C_PDS_FUNCPROP_HETEROSCEDASTICTTEST_OFFSET",
    -2147461618: "DSSCOM_C_PDS_FUNCPROP_HOMOSCEDASTICTTEST_HYPOTHESIS_TYPE",
    -2147461617: "DSSCOM_C_PDS_FUNCPROP_HOMOSCEDASTICTTEST_OFFSET",
    -2147461616: "DSSCOM_C_PDS_FUNCPROP_INTRATE_BASIS",
    -2147461615: "DSSCOM_C_PDS_FUNCPROP_INVERSEBETADISTRIBUTION_LOWER_BOUND",
    -2147461614: "DSSCOM_C_PDS_FUNCPROP_INVERSEBETADISTRIBUTION_UPPER_BOUND",
    -2147461613: "DSSCOM_C_PDS_FUNCPROP_IPMT_FV",
    -2147461612: "DSSCOM_C_PDS_FUNCPROP_IPMT_TYPE",
    -2147461611: "DSSCOM_C_PDS_FUNCPROP_IRR_GUESS",
    -2147461610: "DSSCOM_C_PDS_FUNCPROP_MDURATION_BASIS",
    -2147461609: "DSSCOM_C_PDS_FUNCPROP_MEANTTEST_HYPOTHESIS_TYPE",
    -2147461608: "DSSCOM_C_PDS_FUNCPROP_NORMALDISTRIBUTION_CUMULATIVE",
    -2147461607: "DSSCOM_C_PDS_FUNCPROP_NPER_TYPE",
    -2147461604: "DSSCOM_C_PDS_FUNCPROP_NTILESIZE_ASCENDING",
    -2147461601: "DSSCOM_C_PDS_FUNCPROP_NTILEVALUESIZE_ASCENDING",
    -2147461602: "DSSCOM_C_PDS_FUNCPROP_NTILEVALUE_ASCENDING",
    -2147461603: "DSSCOM_C_PDS_FUNCPROP_NTILEVALUE_SEGMENTS",
    -2147461605: "DSSCOM_C_PDS_FUNCPROP_NTILE_ASCENDING",
    -2147461606: "DSSCOM_C_PDS_FUNCPROP_NTILE_TILES",
    -2147461600: "DSSCOM_C_PDS_FUNCPROP_ODDFPRICE_BASIS",
    -2147461599: "DSSCOM_C_PDS_FUNCPROP_ODDFYIELD_BASIS",
    -2147461598: "DSSCOM_C_PDS_FUNCPROP_ODDLPRICE_BASIS",
    -2147461597: "DSSCOM_C_PDS_FUNCPROP_ODDLYIELD_BASIS",
    -2147461551: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_ISNEWOLAP",
    -2147461549: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPDBPATTERN",
    -2147461348: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPHASWINDOW",
    -2147461550: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPPATTERN",
    -2147461346: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPWINBDNUM",
    -2147461342: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPWINENDOFFSET",
    -2147461343: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPWINENDTYPE",
    -2147461344: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPWINSTOFFSET",
    -2147461345: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPWINSTTYPE",
    -2147461347: "DSSCOM_C_PDS_FUNCPROP_OLAPFUNC_OLAPWINTYPE",
    -2147461596: "DSSCOM_C_PDS_FUNCPROP_PAIREDTTEST_HYPOTHESIS_TYPE",
    -2147461595: "DSSCOM_C_PDS_FUNCPROP_PAIREDTTEST_OFFSET",
    -2147461594: "DSSCOM_C_PDS_FUNCPROP_PERCENTILE_ASCENDING",
    -2147461593: "DSSCOM_C_PDS_FUNCPROP_PMT_FV",
    -2147461592: "DSSCOM_C_PDS_FUNCPROP_PMT_TYPE",
    -2147461591: "DSSCOM_C_PDS_FUNCPROP_POISSONDISTRIBUTION_CUMULATIVE",
    -2147461590: "DSSCOM_C_PDS_FUNCPROP_PPMT_FV",
    -2147461589: "DSSCOM_C_PDS_FUNCPROP_PPMT_TYPE",
    -2147461587: "DSSCOM_C_PDS_FUNCPROP_PRICEDISC_BASIS",
    -2147461586: "DSSCOM_C_PDS_FUNCPROP_PRICEMAT_BASIS",
    -2147461588: "DSSCOM_C_PDS_FUNCPROP_PRICE_BASIS",
    -2147461585: "DSSCOM_C_PDS_FUNCPROP_PV_TYPE",
    -2147461584: "DSSCOM_C_PDS_FUNCPROP_RANK_ASC",
    -2147461583: "DSSCOM_C_PDS_FUNCPROP_RANK_BYVALUE",
    -2147461043: "DSSCOM_C_PDS_FUNCPROP_RANK_NULLINCLUDE",
    -2147461582: "DSSCOM_C_PDS_FUNCPROP_RATE_FV",
    -2147461580: "DSSCOM_C_PDS_FUNCPROP_RATE_GUESS",
    -2147461581: "DSSCOM_C_PDS_FUNCPROP_RATE_TYPE",
    -2147461579: "DSSCOM_C_PDS_FUNCPROP_RECEIVED_BASIS",
    -2147461578: "DSSCOM_C_PDS_FUNCPROP_VARTEST_HYPOTHESIS_TYPE",
    -2147461577: "DSSCOM_C_PDS_FUNCPROP_VDB_FACTOR",
    -2147461576: "DSSCOM_C_PDS_FUNCPROP_WEIBULLDISTRIBUTION_CUMULATIVE",
    -2147461574: "DSSCOM_C_PDS_FUNCPROP_YIELDDISC_BASIS",
    -2147461573: "DSSCOM_C_PDS_FUNCPROP_YIELDMAT_BASIS",
    -2147461575: "DSSCOM_C_PDS_FUNCPROP_YIELD_BASIS",
    -2147481990: "DSSCOM_C_PDS_FUNC_ADD",
    -2147481958: "DSSCOM_C_PDS_FUNC_ADD2",
    -2147481865: "DSSCOM_C_PDS_FUNC_ADDDAYS",
    -2147481864: "DSSCOM_C_PDS_FUNC_ADDMONTHS",
    -2147460376: "DSSCOM_C_PDS_FUNC_ANCESTORS",
    -2147481961: "DSSCOM_C_PDS_FUNC_AND",
    -2147482025: "DSSCOM_C_PDS_FUNC_APPLYAGG",
    -2147482023: "DSSCOM_C_PDS_FUNC_APPLYCOMPARISON",
    -2147481856: "DSSCOM_C_PDS_FUNC_APPLYCSSECURITYFILTER",
    -2147482024: "DSSCOM_C_PDS_FUNC_APPLYLOGIC",
    -2147481857: "DSSCOM_C_PDS_FUNC_APPLYOPTIONAL",
    -2147482022: "DSSCOM_C_PDS_FUNC_APPLYRELATIVE",
    -2147482026: "DSSCOM_C_PDS_FUNC_APPLYSIMPLE",
    -2147477746: "DSSCOM_C_PDS_FUNC_APPLYTRANS1TO1",
    -2147482505: "DSSCOM_C_PDS_FUNC_ARITHM_N",
    -2147482458: "DSSCOM_C_PDS_FUNC_ASSOCMODEL",
    -2147482457: "DSSCOM_C_PDS_FUNC_ASSOCMODELV",
    -2147481957: "DSSCOM_C_PDS_FUNC_AVERAGE",
    -2147482043: "DSSCOM_C_PDS_FUNC_AVG",
    -2147482034: "DSSCOM_C_PDS_FUNC_BANDING",
    -2147482033: "DSSCOM_C_PDS_FUNC_BANDINGC",
    -2147461572: "DSSCOM_C_PDS_FUNC_BANDINGM",
    -2147482032: "DSSCOM_C_PDS_FUNC_BANDINGP",
    -2147460981: "DSSCOM_C_PDS_FUNC_BANDNAMES",
    -2147482512: "DSSCOM_C_PDS_FUNC_BASIC_N",
    -2147481972: "DSSCOM_C_PDS_FUNC_BEGINSWITH",
    -2147481979: "DSSCOM_C_PDS_FUNC_BETWEEN",
    -2147481963: "DSSCOM_C_PDS_FUNC_BETWEENENHC",
    -2147461042: "DSSCOM_C_PDS_FUNC_BITAND",
    -2147461038: "DSSCOM_C_PDS_FUNC_BITLEFTSHIFT",
    -2147461039: "DSSCOM_C_PDS_FUNC_BITNOT",
    -2147461041: "DSSCOM_C_PDS_FUNC_BITOR",
    -2147461037: "DSSCOM_C_PDS_FUNC_BITRIGHTSHIFT",
    -2147461040: "DSSCOM_C_PDS_FUNC_BITXOR",
    -2147482514: "DSSCOM_C_PDS_FUNC_BUILTINPKG_N",
    -2147482031: "DSSCOM_C_PDS_FUNC_CASE",
    -2147482030: "DSSCOM_C_PDS_FUNC_CASEV",
    -2147460374: "DSSCOM_C_PDS_FUNC_CHILDREN",
    -2147482487: "DSSCOM_C_PDS_FUNC_CLUSTERINGMODEL",
    -2147482486: "DSSCOM_C_PDS_FUNC_CLUSTERINGMODELV",
    -2147481410: "DSSCOM_C_PDS_FUNC_COALESCE",
    -2147482504: "DSSCOM_C_PDS_FUNC_COMPOP_N",
    -2147482503: "DSSCOM_C_PDS_FUNC_COMPRANK_N",
    -2147481909: "DSSCOM_C_PDS_FUNC_CONCAT",
    -2147460406: "DSSCOM_C_PDS_FUNC_CONCATAGG",
    -2147460388: "DSSCOM_C_PDS_FUNC_CONCATAGG2",
    -2147481991: "DSSCOM_C_PDS_FUNC_CONCATBLANK",
    -2147481973: "DSSCOM_C_PDS_FUNC_CONTAINS",
    -2147482044: "DSSCOM_C_PDS_FUNC_COUNT",
    -2147481923: "DSSCOM_C_PDS_FUNC_CURRENTDATE",
    -2147481915: "DSSCOM_C_PDS_FUNC_CURRENTDATETIME",
    -2147481914: "DSSCOM_C_PDS_FUNC_CURRENTTIME",
    -2147482492: "DSSCOM_C_PDS_FUNC_DATA_MINING",
    -2147482481: "DSSCOM_C_PDS_FUNC_DATA_MINING2",
    -2147482493: "DSSCOM_C_PDS_FUNC_DATA_MINING_N",
    -2147481868: "DSSCOM_C_PDS_FUNC_DATE",
    -2147460946: "DSSCOM_C_PDS_FUNC_DATETIME_DATEDIFF",
    -2147481924: "DSSCOM_C_PDS_FUNC_DATE_N",
    -2147481922: "DSSCOM_C_PDS_FUNC_DAYOFMONTH",
    -2147481921: "DSSCOM_C_PDS_FUNC_DAYOFWEEK",
    -2147481920: "DSSCOM_C_PDS_FUNC_DAYOFYEAR",
    -2147481867: "DSSCOM_C_PDS_FUNC_DAYSBETWEEN",
    -2147460377: "DSSCOM_C_PDS_FUNC_DESCENDANTS",
    -2147481987: "DSSCOM_C_PDS_FUNC_DIVIDE",
    -2147481971: "DSSCOM_C_PDS_FUNC_ENDSWITH",
    -2147481985: "DSSCOM_C_PDS_FUNC_EQUAL",
    -2147481967: "DSSCOM_C_PDS_FUNC_EQUALENHC",
    -2147481414: "DSSCOM_C_PDS_FUNC_EXCEPT",
    -2147482000: "DSSCOM_C_PDS_FUNC_EXPWGHMOVINGAVG",
    -2147481993: "DSSCOM_C_PDS_FUNC_EXPWGHRUNNINGAVG",
    -2147481893: "DSSCOM_C_PDS_FUNC_FIRST",
    -2147482006: "DSSCOM_C_PDS_FUNC_FIRSTINRANGE",
    -2147460381: "DSSCOM_C_PDS_FUNC_FISCALMONTH",
    -2147460380: "DSSCOM_C_PDS_FUNC_FISCALQUARTER",
    -2147460382: "DSSCOM_C_PDS_FUNC_FISCALWEEK",
    -2147460379: "DSSCOM_C_PDS_FUNC_FISCALYEAR",
    -2147482513: "DSSCOM_C_PDS_FUNC_FUNCS_N",
    -2147482483: "DSSCOM_C_PDS_FUNC_GENERALREGRESSIONMODEL",
    -2147482482: "DSSCOM_C_PDS_FUNC_GENERALREGRESSIONMODELV",
    -2147482035: "DSSCOM_C_PDS_FUNC_GEOMEAN",
    -2147481983: "DSSCOM_C_PDS_FUNC_GREATER",
    -2147481981: "DSSCOM_C_PDS_FUNC_GREATEREQUAL",
    -2147481965: "DSSCOM_C_PDS_FUNC_GREATEREQUALENHC",
    -2147477777: "DSSCOM_C_PDS_FUNC_HMEDIAN",
    -2147481913: "DSSCOM_C_PDS_FUNC_HOUR",
    -2147481860: "DSSCOM_C_PDS_FUNC_IF",
    -2147460976: "DSSCOM_C_PDS_FUNC_IFBYDIMTY",
    -2147481977: "DSSCOM_C_PDS_FUNC_IN",
    -2147481901: "DSSCOM_C_PDS_FUNC_INITCAP",
    -2147482511: "DSSCOM_C_PDS_FUNC_INTERNAL_N",
    -2147482029: "DSSCOM_C_PDS_FUNC_INTERSECT",
    -2147482028: "DSSCOM_C_PDS_FUNC_INTERSECTIN",
    -2147482020: "DSSCOM_C_PDS_FUNC_ISNOTNULL",
    -2147482021: "DSSCOM_C_PDS_FUNC_ISNULL",
    -2147461564: "DSSCOM_C_PDS_FUNC_LAG",
    -2147481892: "DSSCOM_C_PDS_FUNC_LAST",
    -2147482005: "DSSCOM_C_PDS_FUNC_LASTINRANGE",
    -2147461563: "DSSCOM_C_PDS_FUNC_LEAD",
    -2147481898: "DSSCOM_C_PDS_FUNC_LEFTSTR",
    -2147481908: "DSSCOM_C_PDS_FUNC_LENGTH",
    -2147481982: "DSSCOM_C_PDS_FUNC_LESS",
    -2147481980: "DSSCOM_C_PDS_FUNC_LESSEQUAL",
    -2147481964: "DSSCOM_C_PDS_FUNC_LESSEQUALENHC",
    -2147481978: "DSSCOM_C_PDS_FUNC_LIKE",
    -2147482502: "DSSCOM_C_PDS_FUNC_LOGICOP_N",
    -2147481907: "DSSCOM_C_PDS_FUNC_LOWER",
    -2147481906: "DSSCOM_C_PDS_FUNC_LTRIM",
    -2147482041: "DSSCOM_C_PDS_FUNC_MAX",
    -2147481895: "DSSCOM_C_PDS_FUNC_MAX2",
    -2147482047: "DSSCOM_C_PDS_FUNC_MEDIAN",
    -2147481910: "DSSCOM_C_PDS_FUNC_MILLISECOND",
    -2147482042: "DSSCOM_C_PDS_FUNC_MIN",
    -2147481894: "DSSCOM_C_PDS_FUNC_MIN2",
    -2147482468: "DSSCOM_C_PDS_FUNC_MININGMODEL",
    -2147482467: "DSSCOM_C_PDS_FUNC_MININGMODELV",
    -2147481912: "DSSCOM_C_PDS_FUNC_MINUTE",
    -2147482046: "DSSCOM_C_PDS_FUNC_MODE",
    -2147481918: "DSSCOM_C_PDS_FUNC_MONTH",
    -2147481862: "DSSCOM_C_PDS_FUNC_MONTHENDDATE",
    -2147481866: "DSSCOM_C_PDS_FUNC_MONTHSBETWEEN",
    -2147481863: "DSSCOM_C_PDS_FUNC_MONTHSTARTDATE",
    -2147482008: "DSSCOM_C_PDS_FUNC_MOVINGAVG",
    -2147481999: "DSSCOM_C_PDS_FUNC_MOVINGCOUNT",
    -2147482003: "DSSCOM_C_PDS_FUNC_MOVINGDIFFERENCE",
    -2147482007: "DSSCOM_C_PDS_FUNC_MOVINGMAX",
    -2147482004: "DSSCOM_C_PDS_FUNC_MOVINGMIN",
    -2147482002: "DSSCOM_C_PDS_FUNC_MOVINGSTDEV",
    -2147482001: "DSSCOM_C_PDS_FUNC_MOVINGSTDEVP",
    -2147482009: "DSSCOM_C_PDS_FUNC_MOVINGSUM",
    -2147481988: "DSSCOM_C_PDS_FUNC_MULTIPLY",
    -2147481956: "DSSCOM_C_PDS_FUNC_MULTIPLY2",
    -2147482491: "DSSCOM_C_PDS_FUNC_NEURALNETWORK",
    -2147482490: "DSSCOM_C_PDS_FUNC_NEURALNETWORKV",
    -2147481959: "DSSCOM_C_PDS_FUNC_NOT",
    -2147481969: "DSSCOM_C_PDS_FUNC_NOTBEGINSWITH",
    -2147481974: "DSSCOM_C_PDS_FUNC_NOTBETWEEN",
    -2147481962: "DSSCOM_C_PDS_FUNC_NOTBETWEENENHC",
    -2147481970: "DSSCOM_C_PDS_FUNC_NOTCONTAINS",
    -2147481968: "DSSCOM_C_PDS_FUNC_NOTENDSWITH",
    -2147481984: "DSSCOM_C_PDS_FUNC_NOTEQUAL",
    -2147481966: "DSSCOM_C_PDS_FUNC_NOTEQUALENHC",
    -2147481976: "DSSCOM_C_PDS_FUNC_NOTIN",
    -2147481975: "DSSCOM_C_PDS_FUNC_NOTLIKE",
    -2147482015: "DSSCOM_C_PDS_FUNC_NTILE",
    -2147482013: "DSSCOM_C_PDS_FUNC_NTILE_S",
    -2147482014: "DSSCOM_C_PDS_FUNC_NTILE_V",
    -2147482012: "DSSCOM_C_PDS_FUNC_NTILE_VS",
    -2147460378: "DSSCOM_C_PDS_FUNC_NULLTOEMPTY",
    -2147482019: "DSSCOM_C_PDS_FUNC_NULLTOZERO",
    -2147482510: "DSSCOM_C_PDS_FUNC_NULLZERO_N",
    -2147461568: "DSSCOM_C_PDS_FUNC_OLAPAVG",
    -2147461567: "DSSCOM_C_PDS_FUNC_OLAPCOUNT",
    -2147461566: "DSSCOM_C_PDS_FUNC_OLAPMAX",
    -2147461565: "DSSCOM_C_PDS_FUNC_OLAPMIN",
    -2147461341: "DSSCOM_C_PDS_FUNC_OLAPRANK",
    -2147461569: "DSSCOM_C_PDS_FUNC_OLAPSUM",
    -2147482508: "DSSCOM_C_PDS_FUNC_OLAP_N",
    -2147482506: "DSSCOM_C_PDS_FUNC_OPERATOR_N",
    -2147481960: "DSSCOM_C_PDS_FUNC_OR",
    -2147460375: "DSSCOM_C_PDS_FUNC_PARENTS",
    -2147460405: "DSSCOM_C_PDS_FUNC_PA_PM",
    -2147460404: "DSSCOM_C_PDS_FUNC_PA_PMA",
    -2147460403: "DSSCOM_C_PDS_FUNC_PA_PMC",
    -2147482016: "DSSCOM_C_PDS_FUNC_PERCENTILE",
    -2147460972: "DSSCOM_C_PDS_FUNC_PERCENTRANKRELATIVE",
    -2147460971: "DSSCOM_C_PDS_FUNC_PERCENTRANKRELATIVE_INCLUSIVE",
    -2147460970: "DSSCOM_C_PDS_FUNC_PERCENTRANKRELATIVE_RANKOUTLIERS",
    -2147460969: "DSSCOM_C_PDS_FUNC_PERCENTRANKRELATIVE_SIGNIFICANCE",
    -2147460968: "DSSCOM_C_PDS_FUNC_PERCENTRANKRELATIVE_TRANCATE",
    -2147481905: "DSSCOM_C_PDS_FUNC_POSITION",
    -2147482040: "DSSCOM_C_PDS_FUNC_PRODUCT",
    -2147481917: "DSSCOM_C_PDS_FUNC_QUARTER",
    -2147460373: "DSSCOM_C_PDS_FUNC_QUARTERSTARTDATE",
    -2147482017: "DSSCOM_C_PDS_FUNC_RANK",
    -2147482509: "DSSCOM_C_PDS_FUNC_RANKNTILE_N",
    -2147482485: "DSSCOM_C_PDS_FUNC_REGRESSIONMODEL",
    -2147482484: "DSSCOM_C_PDS_FUNC_REGRESSIONMODELV",
    -2147481899: "DSSCOM_C_PDS_FUNC_RIGHTSTR",
    -2147481904: "DSSCOM_C_PDS_FUNC_RTRIM",
    -2147482464: "DSSCOM_C_PDS_FUNC_RULESETMODEL",
    -2147482463: "DSSCOM_C_PDS_FUNC_RULESETMODELV",
    -2147482010: "DSSCOM_C_PDS_FUNC_RUNNINGAVG",
    -2147481994: "DSSCOM_C_PDS_FUNC_RUNNINGCOUNT",
    -2147481998: "DSSCOM_C_PDS_FUNC_RUNNINGMAX",
    -2147481997: "DSSCOM_C_PDS_FUNC_RUNNINGMIN",
    -2147481996: "DSSCOM_C_PDS_FUNC_RUNNINGSTDEV",
    -2147481995: "DSSCOM_C_PDS_FUNC_RUNNINGSTDEVP",
    -2147482011: "DSSCOM_C_PDS_FUNC_RUNNINGSUM",
    -2147481911: "DSSCOM_C_PDS_FUNC_SECOND",
    -2147482039: "DSSCOM_C_PDS_FUNC_STDEV",
    -2147482038: "DSSCOM_C_PDS_FUNC_STDEVP",
    -2147460954: "DSSCOM_C_PDS_FUNC_STRING_BEGINSWITH",
    -2147460948: "DSSCOM_C_PDS_FUNC_STRING_CHAR",
    -2147460952: "DSSCOM_C_PDS_FUNC_STRING_CONTAINS",
    -2147460953: "DSSCOM_C_PDS_FUNC_STRING_ENDSWITH",
    -2147460395: "DSSCOM_C_PDS_FUNC_STRING_LASTPOSITION",
    -2147460950: "DSSCOM_C_PDS_FUNC_STRING_MATCH",
    -2147482507: "DSSCOM_C_PDS_FUNC_STRING_N",
    -2147460947: "DSSCOM_C_PDS_FUNC_STRING_REPEAT",
    -2147460951: "DSSCOM_C_PDS_FUNC_STRING_REPLACE",
    -2147460949: "DSSCOM_C_PDS_FUNC_STRING_SPLIT",
    -2147460394: "DSSCOM_C_PDS_FUNC_STRING_TITLECAP",
    -2147481903: "DSSCOM_C_PDS_FUNC_SUBSTR",
    -2147481989: "DSSCOM_C_PDS_FUNC_SUBTRACT",
    -2147482045: "DSSCOM_C_PDS_FUNC_SUM",
    -2147482466: "DSSCOM_C_PDS_FUNC_SVMMODEL",
    -2147482465: "DSSCOM_C_PDS_FUNC_SVMMODELV",
    -2147482455: "DSSCOM_C_PDS_FUNC_TIMESERIES",
    -2147460978: "DSSCOM_C_PDS_FUNC_TODATE",
    -2147460396: "DSSCOM_C_PDS_FUNC_TONUMBER",
    -2147460977: "DSSCOM_C_PDS_FUNC_TOSTRING",
    -2147482459: "DSSCOM_C_PDS_FUNC_TRAINASSOC",
    -2147482461: "DSSCOM_C_PDS_FUNC_TRAINCLUSTER",
    -2147482460: "DSSCOM_C_PDS_FUNC_TRAINDTREE",
    -2147482462: "DSSCOM_C_PDS_FUNC_TRAINREGRESSV2",
    -2147482456: "DSSCOM_C_PDS_FUNC_TRAINTIMESERIES",
    -2147482489: "DSSCOM_C_PDS_FUNC_TREEMODEL",
    -2147482488: "DSSCOM_C_PDS_FUNC_TREEMODELV",
    -2147481900: "DSSCOM_C_PDS_FUNC_TRIM",
    -2147482027: "DSSCOM_C_PDS_FUNC_TUPLE",
    -2147481992: "DSSCOM_C_PDS_FUNC_UCASE",
    -2147481986: "DSSCOM_C_PDS_FUNC_UMINUS",
    -2147481415: "DSSCOM_C_PDS_FUNC_UNION",
    -2147481902: "DSSCOM_C_PDS_FUNC_UPPER",
    -2147482037: "DSSCOM_C_PDS_FUNC_VAR",
    -2147482036: "DSSCOM_C_PDS_FUNC_VARP",
    -2147460399: "DSSCOM_C_PDS_FUNC_WCORR_DESC",
    -2147460402: "DSSCOM_C_PDS_FUNC_WCOV_DESC",
    -2147460401: "DSSCOM_C_PDS_FUNC_WCOV_XVALUE",
    -2147460400: "DSSCOM_C_PDS_FUNC_WCOV_YVALUE",
    -2147481919: "DSSCOM_C_PDS_FUNC_WEEK",
    -2147460372: "DSSCOM_C_PDS_FUNC_WEEKSTARTDATE",
    -2147460941: "DSSCOM_C_PDS_FUNC_WeighStdevP",
    -2147481916: "DSSCOM_C_PDS_FUNC_YEAR",
    -2147481859: "DSSCOM_C_PDS_FUNC_YEARENDDATE",
    -2147481861: "DSSCOM_C_PDS_FUNC_YEARSTARTDATE",
    -2147482018: "DSSCOM_C_PDS_FUNC_ZEROTONULL",
    -2147461007: "DSSCOM_C_PDS_FUNDESC_HMEDIAN",
    -2147478639: "DSSCOM_C_PDS_FeatureFlagSample_Description",
    -2147478638: "DSSCOM_C_PDS_FeatureFlagSample_Disclaimer",
    -2147478636: "DSSCOM_C_PDS_FinancialReportingFeatureFlag_DESCIPTION",
    -2147478637: "DSSCOM_C_PDS_FinancialReportingFeatureFlag_NAME",
    -2147478602: "DSSCOM_C_PDS_FixAmbiguousMetricSourceByFindBBT_FeatureFlag_Description",
    -2147478603: "DSSCOM_C_PDS_FixAmbiguousMetricSourceByFindBBT_FeatureFlag_Name",
    -2147461088: "DSSCOM_C_PDS_GRAPHSTYLES",
    -2147461097: "DSSCOM_C_PDS_GRAPHSTYLE_3DCONNECTGROUP",
    -2147461067: "DSSCOM_C_PDS_GRAPHSTYLE_3DCONNECTGROUP_902",
    -2147461021: "DSSCOM_C_PDS_GRAPHSTYLE_3DCONNECTGROUP_921",
    -2147460991: "DSSCOM_C_PDS_GRAPHSTYLE_3DCONNECTGROUP_932",
    -2147461096: "DSSCOM_C_PDS_GRAPHSTYLE_3DCONNECTSERIES",
    -2147461066: "DSSCOM_C_PDS_GRAPHSTYLE_3DCONNECTSERIES_902",
    -2147461020: "DSSCOM_C_PDS_GRAPHSTYLE_3DCONNECTSERIES_921",
    -2147460990: "DSSCOM_C_PDS_GRAPHSTYLE_3DCONNECTSERIES_932",
    -2147461098: "DSSCOM_C_PDS_GRAPHSTYLE_3DFLOATING",
    -2147461068: "DSSCOM_C_PDS_GRAPHSTYLE_3DFLOATING_902",
    -2147461022: "DSSCOM_C_PDS_GRAPHSTYLE_3DFLOATING_921",
    -2147460992: "DSSCOM_C_PDS_GRAPHSTYLE_3DFLOATING_932",
    -2147461099: "DSSCOM_C_PDS_GRAPHSTYLE_3DRISERS",
    -2147461069: "DSSCOM_C_PDS_GRAPHSTYLE_3DRISERS_902",
    -2147461023: "DSSCOM_C_PDS_GRAPHSTYLE_3DRISERS_921",
    -2147460993: "DSSCOM_C_PDS_GRAPHSTYLE_3DRISERS_932",
    -2147461094: "DSSCOM_C_PDS_GRAPHSTYLE_3DSCATTER",
    -2147461064: "DSSCOM_C_PDS_GRAPHSTYLE_3DSCATTER_902",
    -2147461018: "DSSCOM_C_PDS_GRAPHSTYLE_3DSCATTER_921",
    -2147460988: "DSSCOM_C_PDS_GRAPHSTYLE_3DSCATTER_932",
    -2147461095: "DSSCOM_C_PDS_GRAPHSTYLE_3DSURFACE",
    -2147461065: "DSSCOM_C_PDS_GRAPHSTYLE_3DSURFACE_902",
    -2147461019: "DSSCOM_C_PDS_GRAPHSTYLE_3DSURFACE_921",
    -2147460989: "DSSCOM_C_PDS_GRAPHSTYLE_3DSURFACE_932",
    -2147461090: "DSSCOM_C_PDS_GRAPHSTYLE_BOXPLOT",
    -2147461060: "DSSCOM_C_PDS_GRAPHSTYLE_BOXPLOT_902",
    -2147461014: "DSSCOM_C_PDS_GRAPHSTYLE_BOXPLOT_921",
    -2147460984: "DSSCOM_C_PDS_GRAPHSTYLE_BOXPLOT_932",
    -2147461102: "DSSCOM_C_PDS_GRAPHSTYLE_BUBBLE",
    -2147461072: "DSSCOM_C_PDS_GRAPHSTYLE_BUBBLE_902",
    -2147461035: "DSSCOM_C_PDS_GRAPHSTYLE_BUBBLE_921",
    -2147460996: "DSSCOM_C_PDS_GRAPHSTYLE_BUBBLE_932",
    -2147461092: "DSSCOM_C_PDS_GRAPHSTYLE_FUNNEL",
    -2147461062: "DSSCOM_C_PDS_GRAPHSTYLE_FUNNEL_902",
    -2147461016: "DSSCOM_C_PDS_GRAPHSTYLE_FUNNEL_921",
    -2147460986: "DSSCOM_C_PDS_GRAPHSTYLE_FUNNEL_932",
    -2147461089: "DSSCOM_C_PDS_GRAPHSTYLE_GANTT",
    -2147461059: "DSSCOM_C_PDS_GRAPHSTYLE_GANTT_902",
    -2147461013: "DSSCOM_C_PDS_GRAPHSTYLE_GANTT_921",
    -2147460983: "DSSCOM_C_PDS_GRAPHSTYLE_GANTT_932",
    -2147461093: "DSSCOM_C_PDS_GRAPHSTYLE_GAUGE",
    -2147461063: "DSSCOM_C_PDS_GRAPHSTYLE_GAUGE_902",
    -2147461017: "DSSCOM_C_PDS_GRAPHSTYLE_GAUGE_921",
    -2147460987: "DSSCOM_C_PDS_GRAPHSTYLE_GAUGE_932",
    -2147461101: "DSSCOM_C_PDS_GRAPHSTYLE_HILO",
    -2147461071: "DSSCOM_C_PDS_GRAPHSTYLE_HILO_902",
    -2147461025: "DSSCOM_C_PDS_GRAPHSTYLE_HILO_921",
    -2147460995: "DSSCOM_C_PDS_GRAPHSTYLE_HILO_932",
    -2147461100: "DSSCOM_C_PDS_GRAPHSTYLE_HISTOGRAM",
    -2147461070: "DSSCOM_C_PDS_GRAPHSTYLE_HISTOGRAM_902",
    -2147461024: "DSSCOM_C_PDS_GRAPHSTYLE_HISTOGRAM_921",
    -2147460994: "DSSCOM_C_PDS_GRAPHSTYLE_HISTOGRAM_932",
    -2147461111: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALAREA",
    -2147461005: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALAREA_932",
    -2147461109: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALBAR",
    -2147461079: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALBAR_902",
    -2147461031: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALBAR_921",
    -2147461003: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALBAR_932",
    -2147461107: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALLINE",
    -2147461077: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALLINE_902",
    -2147461029: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALLINE_921",
    -2147461001: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTALLINE_932",
    -2147461081: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTAL_AREA_902",
    -2147461033: "DSSCOM_C_PDS_GRAPHSTYLE_HORIZONTAL_AREA_921",
    -2147461091: "DSSCOM_C_PDS_GRAPHSTYLE_PARETO",
    -2147461061: "DSSCOM_C_PDS_GRAPHSTYLE_PARETO_902",
    -2147461015: "DSSCOM_C_PDS_GRAPHSTYLE_PARETO_921",
    -2147460985: "DSSCOM_C_PDS_GRAPHSTYLE_PARETO_932",
    -2147461106: "DSSCOM_C_PDS_GRAPHSTYLE_PIE",
    -2147461076: "DSSCOM_C_PDS_GRAPHSTYLE_PIE_902",
    -2147461028: "DSSCOM_C_PDS_GRAPHSTYLE_PIE_921",
    -2147461000: "DSSCOM_C_PDS_GRAPHSTYLE_PIE_932",
    -2147461104: "DSSCOM_C_PDS_GRAPHSTYLE_POLAR",
    -2147461074: "DSSCOM_C_PDS_GRAPHSTYLE_POLAR_902",
    -2147461027: "DSSCOM_C_PDS_GRAPHSTYLE_POLAR_921",
    -2147460998: "DSSCOM_C_PDS_GRAPHSTYLE_POLAR_932",
    -2147461103: "DSSCOM_C_PDS_GRAPHSTYLE_RADAR",
    -2147461073: "DSSCOM_C_PDS_GRAPHSTYLE_RADAR_902",
    -2147461026: "DSSCOM_C_PDS_GRAPHSTYLE_RADAR_921",
    -2147460997: "DSSCOM_C_PDS_GRAPHSTYLE_RADAR_932",
    -2147461105: "DSSCOM_C_PDS_GRAPHSTYLE_SCATTER",
    -2147461075: "DSSCOM_C_PDS_GRAPHSTYLE_SCATTER_902",
    -2147461036: "DSSCOM_C_PDS_GRAPHSTYLE_SCATTER_921",
    -2147460999: "DSSCOM_C_PDS_GRAPHSTYLE_SCATTER_932",
    -2147461112: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALAREA",
    -2147461082: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALAREA_902",
    -2147461034: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALAREA_921",
    -2147461006: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALAREA_932",
    -2147461110: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALBAR",
    -2147461080: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALBAR_902",
    -2147461032: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALBAR_921",
    -2147461004: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALBAR_932",
    -2147461108: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALLINE",
    -2147461078: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALLINE_902",
    -2147461030: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALLINE_921",
    -2147461002: "DSSCOM_C_PDS_GRAPHSTYLE_VERTICALLINE_932",
    -2147460390: "DSSCOM_C_PDS_GREEN",
    -2147482442: "DSSCOM_C_PDS_GUI_CART11D",
    -2147482443: "DSSCOM_C_PDS_GUI_CART11T",
    -2147482406: "DSSCOM_C_PDS_GUI_CART12D",
    -2147482407: "DSSCOM_C_PDS_GUI_CART12T",
    -2147482428: "DSSCOM_C_PDS_GUI_CART1D",
    -2147482429: "DSSCOM_C_PDS_GUI_CART1T",
    -2147482440: "DSSCOM_C_PDS_GUI_CART21D",
    -2147482441: "DSSCOM_C_PDS_GUI_CART21T",
    -2147482404: "DSSCOM_C_PDS_GUI_CART22D",
    -2147482405: "DSSCOM_C_PDS_GUI_CART22T",
    -2147482416: "DSSCOM_C_PDS_GUI_CART2D",
    -2147482417: "DSSCOM_C_PDS_GUI_CART2T",
    -2147482402: "DSSCOM_C_PDS_GUI_CART31D",
    -2147482403: "DSSCOM_C_PDS_GUI_CART31T",
    -2147482400: "DSSCOM_C_PDS_GUI_CART41D",
    -2147482401: "DSSCOM_C_PDS_GUI_CART41T",
    -2147482438: "DSSCOM_C_PDS_GUI_CHECK1D",
    -2147482439: "DSSCOM_C_PDS_GUI_CHECK1T",
    -2147482426: "DSSCOM_C_PDS_GUI_CHECK2D",
    -2147482427: "DSSCOM_C_PDS_GUI_CHECK2T",
    -2147482447: "DSSCOM_C_PDS_GUI_CURRENCY",
    -2147482446: "DSSCOM_C_PDS_GUI_CURRENCYPOSITION",
    -2147481887: "DSSCOM_C_PDS_GUI_DOCSTYLE_ACCOUNTING",
    -2147481886: "DSSCOM_C_PDS_GUI_DOCSTYLE_AGENT",
    -2147481885: "DSSCOM_C_PDS_GUI_DOCSTYLE_BLUE_AND_GREY",
    -2147481884: "DSSCOM_C_PDS_GUI_DOCSTYLE_CLASSIC",
    -2147481883: "DSSCOM_C_PDS_GUI_DOCSTYLE_COLORFUL",
    -2147481882: "DSSCOM_C_PDS_GUI_DOCSTYLE_COLUMNS",
    -2147481881: "DSSCOM_C_PDS_GUI_DOCSTYLE_FINANCE",
    -2147481880: "DSSCOM_C_PDS_GUI_DOCSTYLE_GREY_BANDS",
    -2147481879: "DSSCOM_C_PDS_GUI_DOCSTYLE_MONOCHROME",
    -2147481878: "DSSCOM_C_PDS_GUI_DOCSTYLE_PASTELS",
    -2147481877: "DSSCOM_C_PDS_GUI_DOCSTYLE_RED_AND_BLACK",
    -2147481872: "DSSCOM_C_PDS_GUI_DOCSTYLE_ROMANTIC",
    -2147481888: "DSSCOM_C_PDS_GUI_DOCSTYLE_SAMPLE",
    -2147481876: "DSSCOM_C_PDS_GUI_DOCSTYLE_SMALL_TYPE",
    -2147481875: "DSSCOM_C_PDS_GUI_DOCSTYLE_SQUARES",
    -2147481874: "DSSCOM_C_PDS_GUI_DOCSTYLE_SUNSET",
    -2147481873: "DSSCOM_C_PDS_GUI_DOCSTYLE_TABLE",
    -2147482399: "DSSCOM_C_PDS_GUI_FRMTFONTNAME",
    -2147482394: "DSSCOM_C_PDS_GUI_FRMTFONTSTYLE",
    -2147482398: "DSSCOM_C_PDS_GUI_MESSAGE_NEEDS_MORE_PARSING",
    -2147482432: "DSSCOM_C_PDS_GUI_MLIST1D",
    -2147482433: "DSSCOM_C_PDS_GUI_MLIST1T",
    -2147482420: "DSSCOM_C_PDS_GUI_MLIST2D",
    -2147482421: "DSSCOM_C_PDS_GUI_MLIST2T",
    -2147481896: "DSSCOM_C_PDS_GUI_NEWCURRENCYPOSITION",
    -2147482430: "DSSCOM_C_PDS_GUI_PULLDOWN1D",
    -2147482431: "DSSCOM_C_PDS_GUI_PULLDOWN1T",
    -2147482418: "DSSCOM_C_PDS_GUI_PULLDOWN2D",
    -2147482419: "DSSCOM_C_PDS_GUI_PULLDOWN2T",
    -2147482414: "DSSCOM_C_PDS_GUI_PULLDOWN3D",
    -2147482415: "DSSCOM_C_PDS_GUI_PULLDOWN3T",
    -2147482436: "DSSCOM_C_PDS_GUI_RADIO1D",
    -2147482437: "DSSCOM_C_PDS_GUI_RADIO1T",
    -2147482424: "DSSCOM_C_PDS_GUI_RADIO2D",
    -2147482425: "DSSCOM_C_PDS_GUI_RADIO2T",
    -2147482412: "DSSCOM_C_PDS_GUI_RADIO3D",
    -2147482413: "DSSCOM_C_PDS_GUI_RADIO3T",
    -2147482434: "DSSCOM_C_PDS_GUI_SLIST1D",
    -2147482435: "DSSCOM_C_PDS_GUI_SLIST1T",
    -2147482422: "DSSCOM_C_PDS_GUI_SLIST2D",
    -2147482423: "DSSCOM_C_PDS_GUI_SLIST2T",
    -2147482410: "DSSCOM_C_PDS_GUI_SLIST3D",
    -2147482411: "DSSCOM_C_PDS_GUI_SLIST3T",
    -2147482395: "DSSCOM_C_PDS_GUI_TAHOMA",
    -2147482397: "DSSCOM_C_PDS_GUI_TIMES_NEW_ROMAN",
    -2147482408: "DSSCOM_C_PDS_GUI_TST2D",
    -2147482444: "DSSCOM_C_PDS_GUI_TXT1D",
    -2147482445: "DSSCOM_C_PDS_GUI_TXT1T",
    -2147482409: "DSSCOM_C_PDS_GUI_TXT2T",
    -2147482396: "DSSCOM_C_PDS_GUI_VERDANA",
    -2147460358: "DSSCOM_C_PDS_HMPALETTE",
    -2147460359: "DSSCOM_C_PDS_HVPALETTE",
    -2147460386: "DSSCOM_C_PDS_LIGHTTHEME",
    -2147460385: "DSSCOM_C_PDS_LIGHTTHEME_DESC",
    -2147460945: "DSSCOM_C_PDS_LTPALETTE",
    -2147460944: "DSSCOM_C_PDS_LTPALETTE_DESC",
    -2147482247: "DSSCOM_C_PDS_MATH_ABS",
    -2147482246: "DSSCOM_C_PDS_MATH_ACOS",
    -2147482245: "DSSCOM_C_PDS_MATH_ACOSH",
    -2147482244: "DSSCOM_C_PDS_MATH_ASIN",
    -2147482217: "DSSCOM_C_PDS_MATH_ASINH",
    -2147482243: "DSSCOM_C_PDS_MATH_ATAN",
    -2147482242: "DSSCOM_C_PDS_MATH_ATAN2",
    -2147482241: "DSSCOM_C_PDS_MATH_ATANH",
    -2147482240: "DSSCOM_C_PDS_MATH_CEILING",
    -2147482239: "DSSCOM_C_PDS_MATH_COMBINE",
    -2147482238: "DSSCOM_C_PDS_MATH_COS",
    -2147482237: "DSSCOM_C_PDS_MATH_COSH",
    -2147482236: "DSSCOM_C_PDS_MATH_DEGREES",
    -2147482235: "DSSCOM_C_PDS_MATH_EXP",
    -2147482234: "DSSCOM_C_PDS_MATH_FACTORIAL",
    -2147482233: "DSSCOM_C_PDS_MATH_FLOOR",
    -2147482232: "DSSCOM_C_PDS_MATH_INT",
    -2147481858: "DSSCOM_C_PDS_MATH_INT2",
    -2147482231: "DSSCOM_C_PDS_MATH_LN",
    -2147482230: "DSSCOM_C_PDS_MATH_LOG",
    -2147482229: "DSSCOM_C_PDS_MATH_LOG10",
    -2147482216: "DSSCOM_C_PDS_MATH_MOD",
    -2147482228: "DSSCOM_C_PDS_MATH_POWER",
    -2147482227: "DSSCOM_C_PDS_MATH_QUOTIENT",
    -2147482226: "DSSCOM_C_PDS_MATH_RADIANS",
    -2147482225: "DSSCOM_C_PDS_MATH_RANDBETWEEN",
    -2147482224: "DSSCOM_C_PDS_MATH_ROUND",
    -2147482215: "DSSCOM_C_PDS_MATH_ROUND2",
    -2147482223: "DSSCOM_C_PDS_MATH_SIN",
    -2147482222: "DSSCOM_C_PDS_MATH_SINH",
    -2147482221: "DSSCOM_C_PDS_MATH_SQRT",
    -2147482220: "DSSCOM_C_PDS_MATH_TAN",
    -2147482219: "DSSCOM_C_PDS_MATH_TANH",
    -2147482218: "DSSCOM_C_PDS_MATH_TRUNC",
    -2147460357: "DSSCOM_C_PDS_MMPALETTE",
    -2147460321: "DSSCOM_C_PDS_MOBILEARCHITECT",
    -2147460320: "DSSCOM_C_PDS_MOBILEARCHITECT_DESC",
    -2147478608: "DSSCOM_C_PDS_MessagingServiceForStatistics_FeatureFlag_Description",
    -2147478609: "DSSCOM_C_PDS_MessagingServiceForStatistics_FeatureFlag_Name",
    -2147482633: "DSSCOM_C_PDS_NEWCNFG_3RDPARTYUSERS",
    -2147482639: "DSSCOM_C_PDS_NEWCNFG_CONNMAP",
    -2147460935: "DSSCOM_C_PDS_NEWCNFG_DAILYAT0",
    -2147460911: "DSSCOM_C_PDS_NEWCNFG_DAILYAT0_DESC",
    -2147460934: "DSSCOM_C_PDS_NEWCNFG_DAILYAT1",
    -2147460925: "DSSCOM_C_PDS_NEWCNFG_DAILYAT10",
    -2147460901: "DSSCOM_C_PDS_NEWCNFG_DAILYAT10_DESC",
    -2147460924: "DSSCOM_C_PDS_NEWCNFG_DAILYAT11",
    -2147460900: "DSSCOM_C_PDS_NEWCNFG_DAILYAT11_DESC",
    -2147460923: "DSSCOM_C_PDS_NEWCNFG_DAILYAT12",
    -2147460899: "DSSCOM_C_PDS_NEWCNFG_DAILYAT12_DESC",
    -2147460922: "DSSCOM_C_PDS_NEWCNFG_DAILYAT13",
    -2147460898: "DSSCOM_C_PDS_NEWCNFG_DAILYAT13_DESC",
    -2147460921: "DSSCOM_C_PDS_NEWCNFG_DAILYAT14",
    -2147460897: "DSSCOM_C_PDS_NEWCNFG_DAILYAT14_DESC",
    -2147460920: "DSSCOM_C_PDS_NEWCNFG_DAILYAT15",
    -2147460896: "DSSCOM_C_PDS_NEWCNFG_DAILYAT15_DESC",
    -2147460919: "DSSCOM_C_PDS_NEWCNFG_DAILYAT16",
    -2147460895: "DSSCOM_C_PDS_NEWCNFG_DAILYAT16_DESC",
    -2147460918: "DSSCOM_C_PDS_NEWCNFG_DAILYAT17",
    -2147460894: "DSSCOM_C_PDS_NEWCNFG_DAILYAT17_DESC",
    -2147460917: "DSSCOM_C_PDS_NEWCNFG_DAILYAT18",
    -2147460893: "DSSCOM_C_PDS_NEWCNFG_DAILYAT18_DESC",
    -2147460916: "DSSCOM_C_PDS_NEWCNFG_DAILYAT19",
    -2147460892: "DSSCOM_C_PDS_NEWCNFG_DAILYAT19_DESC",
    -2147460910: "DSSCOM_C_PDS_NEWCNFG_DAILYAT1_DESC",
    -2147460933: "DSSCOM_C_PDS_NEWCNFG_DAILYAT2",
    -2147460915: "DSSCOM_C_PDS_NEWCNFG_DAILYAT20",
    -2147460891: "DSSCOM_C_PDS_NEWCNFG_DAILYAT20_DESC",
    -2147460914: "DSSCOM_C_PDS_NEWCNFG_DAILYAT21",
    -2147460890: "DSSCOM_C_PDS_NEWCNFG_DAILYAT21_DESC",
    -2147460913: "DSSCOM_C_PDS_NEWCNFG_DAILYAT22",
    -2147460889: "DSSCOM_C_PDS_NEWCNFG_DAILYAT22_DESC",
    -2147460912: "DSSCOM_C_PDS_NEWCNFG_DAILYAT23",
    -2147460888: "DSSCOM_C_PDS_NEWCNFG_DAILYAT23_DESC",
    -2147460909: "DSSCOM_C_PDS_NEWCNFG_DAILYAT2_DESC",
    -2147460932: "DSSCOM_C_PDS_NEWCNFG_DAILYAT3",
    -2147460908: "DSSCOM_C_PDS_NEWCNFG_DAILYAT3_DESC",
    -2147460931: "DSSCOM_C_PDS_NEWCNFG_DAILYAT4",
    -2147460907: "DSSCOM_C_PDS_NEWCNFG_DAILYAT4_DESC",
    -2147460930: "DSSCOM_C_PDS_NEWCNFG_DAILYAT5",
    -2147460906: "DSSCOM_C_PDS_NEWCNFG_DAILYAT5_DESC",
    -2147460929: "DSSCOM_C_PDS_NEWCNFG_DAILYAT6",
    -2147460905: "DSSCOM_C_PDS_NEWCNFG_DAILYAT6_DESC",
    -2147460928: "DSSCOM_C_PDS_NEWCNFG_DAILYAT7",
    -2147460904: "DSSCOM_C_PDS_NEWCNFG_DAILYAT7_DESC",
    -2147460927: "DSSCOM_C_PDS_NEWCNFG_DAILYAT8",
    -2147460903: "DSSCOM_C_PDS_NEWCNFG_DAILYAT8_DESC",
    -2147460926: "DSSCOM_C_PDS_NEWCNFG_DAILYAT9",
    -2147460902: "DSSCOM_C_PDS_NEWCNFG_DAILYAT9_DESC",
    -2147482647: "DSSCOM_C_PDS_NEWCNFG_EVERYONE",
    -2147460552: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT0",
    -2147460528: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT0_DESC",
    -2147460551: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT1",
    -2147460542: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT10",
    -2147460518: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT10_DESC",
    -2147460541: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT11",
    -2147460517: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT11_DESC",
    -2147460540: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT12",
    -2147460516: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT12_DESC",
    -2147460539: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT13",
    -2147460515: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT13_DESC",
    -2147460538: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT14",
    -2147460514: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT14_DESC",
    -2147460537: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT15",
    -2147460513: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT15_DESC",
    -2147460536: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT16",
    -2147460512: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT16_DESC",
    -2147460535: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT17",
    -2147460511: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT17_DESC",
    -2147460534: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT18",
    -2147460510: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT18_DESC",
    -2147460533: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT19",
    -2147460509: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT19_DESC",
    -2147460527: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT1_DESC",
    -2147460550: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT2",
    -2147460532: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT20",
    -2147460508: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT20_DESC",
    -2147460531: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT21",
    -2147460507: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT21_DESC",
    -2147460530: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT22",
    -2147460506: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT22_DESC",
    -2147460529: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT23",
    -2147460505: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT23_DESC",
    -2147460526: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT2_DESC",
    -2147460549: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT3",
    -2147460525: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT3_DESC",
    -2147460548: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT4",
    -2147460524: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT4_DESC",
    -2147460547: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT5",
    -2147460523: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT5_DESC",
    -2147460546: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT6",
    -2147460522: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT6_DESC",
    -2147460545: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT7",
    -2147460521: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT7_DESC",
    -2147460544: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT8",
    -2147460520: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT8_DESC",
    -2147460543: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT9",
    -2147460519: "DSSCOM_C_PDS_NEWCNFG_FRIDAYAT9_DESC",
    -2147482637: "DSSCOM_C_PDS_NEWCNFG_LDAPPUBLIC",
    -2147482638: "DSSCOM_C_PDS_NEWCNFG_LDAPUSERS",
    -2147482612: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1028",
    -2147482605: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1030",
    -2147482632: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1031",
    -2147482631: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1033",
    -2147482630: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1036",
    -2147482629: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1040",
    -2147482628: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1041",
    -2147482627: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1042",
    -2147482607: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1043",
    -2147482606: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1045",
    -2147482626: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1046",
    -2147482601: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1049",
    -2147482625: "DSSCOM_C_PDS_NEWCNFG_LOCALE_1053",
    -2147482611: "DSSCOM_C_PDS_NEWCNFG_LOCALE_2052",
    -2147482610: "DSSCOM_C_PDS_NEWCNFG_LOCALE_2055",
    -2147482603: "DSSCOM_C_PDS_NEWCNFG_LOCALE_2057",
    -2147482600: "DSSCOM_C_PDS_NEWCNFG_LOCALE_2060",
    -2147482608: "DSSCOM_C_PDS_NEWCNFG_LOCALE_2064",
    -2147482613: "DSSCOM_C_PDS_NEWCNFG_LOCALE_3082",
    -2147482609: "DSSCOM_C_PDS_NEWCNFG_LOCALE_4108",
    -2147460791: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT0",
    -2147460768: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT0_DESC",
    -2147460790: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT1",
    -2147460781: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT10",
    -2147460758: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT10_DESC",
    -2147460780: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT11",
    -2147460757: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT11_DESC",
    -2147460779: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT12",
    -2147460756: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT12_DESC",
    -2147460778: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT13",
    -2147460755: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT13_DESC",
    -2147460777: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT14",
    -2147460754: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT14_DESC",
    -2147460776: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT15",
    -2147460753: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT15_DESC",
    -2147460775: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT16",
    -2147460752: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT16_DESC",
    -2147460774: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT17",
    -2147460751: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT17_DESC",
    -2147460773: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT18",
    -2147460750: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT18_DESC",
    -2147460772: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT19",
    -2147460749: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT19_DESC",
    -2147460767: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT1_DESC",
    -2147460789: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT2",
    -2147460771: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT20",
    -2147460748: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT20_DESC",
    -2147460408: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT21",
    -2147460747: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT21_DESC",
    -2147460770: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT22",
    -2147460746: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT22_DESC",
    -2147460769: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT23",
    -2147460745: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT23_DESC",
    -2147460766: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT2_DESC",
    -2147460788: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT3",
    -2147460765: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT3_DESC",
    -2147460787: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT4",
    -2147460764: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT4_DESC",
    -2147460786: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT5",
    -2147460763: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT5_DESC",
    -2147460785: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT6",
    -2147460762: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT6_DESC",
    -2147460784: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT7",
    -2147460761: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT7_DESC",
    -2147460783: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT8",
    -2147460760: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT8_DESC",
    -2147460782: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT9",
    -2147460759: "DSSCOM_C_PDS_NEWCNFG_MIDDLEOFMONTHAT9_DESC",
    -2147460744: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT0",
    -2147460720: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT0_DESC",
    -2147460743: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT1",
    -2147460734: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT10",
    -2147460710: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT10_DESC",
    -2147460733: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT11",
    -2147460709: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT11_DESC",
    -2147460732: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT12",
    -2147460708: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT12_DESC",
    -2147460731: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT13",
    -2147460707: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT13_DESC",
    -2147460730: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT14",
    -2147460706: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT14_DESC",
    -2147460729: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT15",
    -2147460705: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT15_DESC",
    -2147460728: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT16",
    -2147460704: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT16_DESC",
    -2147460727: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT17",
    -2147460703: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT17_DESC",
    -2147460726: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT18",
    -2147460702: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT18_DESC",
    -2147460725: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT19",
    -2147460701: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT19_DESC",
    -2147460719: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT1_DESC",
    -2147460742: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT2",
    -2147460724: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT20",
    -2147460700: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT20_DESC",
    -2147460723: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT21",
    -2147460699: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT21_DESC",
    -2147460722: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT22",
    -2147460698: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT22_DESC",
    -2147460721: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT23",
    -2147460697: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT23_DESC",
    -2147460718: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT2_DESC",
    -2147460741: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT3",
    -2147460717: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT3_DESC",
    -2147460740: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT4",
    -2147460716: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT4_DESC",
    -2147460739: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT5",
    -2147460715: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT5_DESC",
    -2147460738: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT6",
    -2147460714: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT6_DESC",
    -2147460737: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT7",
    -2147460713: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT7_DESC",
    -2147460736: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT8",
    -2147460712: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT8_DESC",
    -2147460735: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT9",
    -2147460711: "DSSCOM_C_PDS_NEWCNFG_MONDAYAT9_DESC",
    -2147482634: "DSSCOM_C_PDS_NEWCNFG_NCSADMIN",
    -2147482636: "DSSCOM_C_PDS_NEWCNFG_NORMALUSERS",
    -2147460407: "DSSCOM_C_PDS_NEWCNFG_PMFUNC",
    -2147460387: "DSSCOM_C_PDS_NEWCNFG_PMFUNC2",
    -2147482635: "DSSCOM_C_PDS_NEWCNFG_POWERUSERS",
    -2147482644: "DSSCOM_C_PDS_NEWCNFG_PUBLIC",
    -2147460504: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT0",
    -2147460480: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT0_DESC",
    -2147460503: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT1",
    -2147460494: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT10",
    -2147460470: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT10_DESC",
    -2147460493: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT11",
    -2147460469: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT11_DESC",
    -2147460492: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT12",
    -2147460468: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT12_DESC",
    -2147460491: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT13",
    -2147460467: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT13_DESC",
    -2147460490: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT14",
    -2147460466: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT14_DESC",
    -2147460489: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT15",
    -2147460465: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT15_DESC",
    -2147460488: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT16",
    -2147460464: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT16_DESC",
    -2147460487: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT17",
    -2147460463: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT17_DESC",
    -2147460486: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT18",
    -2147460462: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT18_DESC",
    -2147460485: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT19",
    -2147460461: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT19_DESC",
    -2147460479: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT1_DESC",
    -2147460502: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT2",
    -2147460484: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT20",
    -2147460460: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT20_DESC",
    -2147460483: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT21",
    -2147460459: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT21_DESC",
    -2147460482: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT22",
    -2147460458: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT22_DESC",
    -2147460481: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT23",
    -2147460457: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT23_DESC",
    -2147460478: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT2_DESC",
    -2147460501: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT3",
    -2147460477: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT3_DESC",
    -2147460500: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT4",
    -2147460476: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT4_DESC",
    -2147460499: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT5",
    -2147460475: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT5_DESC",
    -2147460498: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT6",
    -2147460474: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT6_DESC",
    -2147460497: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT7",
    -2147460473: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT7_DESC",
    -2147460496: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT8",
    -2147460472: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT8_DESC",
    -2147460495: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT9",
    -2147460471: "DSSCOM_C_PDS_NEWCNFG_SATURDAYAT9_DESC",
    -2147482640: "DSSCOM_C_PDS_NEWCNFG_SECURITYROLE",
    -2147460839: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT0",
    -2147460815: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT0_DESC",
    -2147460838: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT1",
    -2147460829: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT10",
    -2147460805: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT10_DESC",
    -2147460828: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT11",
    -2147460804: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT11_DESC",
    -2147460827: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT12",
    -2147460803: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT12_DESC",
    -2147460826: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT13",
    -2147460802: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT13_DESC",
    -2147460825: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT14",
    -2147460801: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT14_DESC",
    -2147460824: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT15",
    -2147460800: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT15_DESC",
    -2147460823: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT16",
    -2147460799: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT16_DESC",
    -2147460822: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT17",
    -2147460798: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT17_DESC",
    -2147460821: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT18",
    -2147460797: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT18_DESC",
    -2147460820: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT19",
    -2147460796: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT19_DESC",
    -2147460814: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT1_DESC",
    -2147460837: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT2",
    -2147460819: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT20",
    -2147460795: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT20_DESC",
    -2147460818: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT21",
    -2147460794: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT21_DESC",
    -2147460817: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT22",
    -2147460793: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT22_DESC",
    -2147460816: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT23",
    -2147460792: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT23_DESC",
    -2147460813: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT2_DESC",
    -2147460836: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT3",
    -2147460812: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT3_DESC",
    -2147460835: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT4",
    -2147460811: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT4_DESC",
    -2147460834: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT5",
    -2147460810: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT5_DESC",
    -2147460833: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT6",
    -2147460809: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT6_DESC",
    -2147460832: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT7",
    -2147460808: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT7_DESC",
    -2147460831: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT8",
    -2147460807: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT8_DESC",
    -2147460830: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT9",
    -2147460806: "DSSCOM_C_PDS_NEWCNFG_STARTOFMONTHAT9_DESC",
    -2147460456: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT0",
    -2147460432: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT0_DESC",
    -2147460455: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT1",
    -2147460446: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT10",
    -2147460422: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT10_DESC",
    -2147460445: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT11",
    -2147460421: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT11_DESC",
    -2147460444: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT12",
    -2147460420: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT12_DESC",
    -2147460443: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT13",
    -2147460419: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT13_DESC",
    -2147460442: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT14",
    -2147460418: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT14_DESC",
    -2147460441: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT15",
    -2147460417: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT15_DESC",
    -2147460440: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT16",
    -2147460416: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT16_DESC",
    -2147460439: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT17",
    -2147460415: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT17_DESC",
    -2147460438: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT18",
    -2147460414: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT18_DESC",
    -2147460437: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT19",
    -2147460413: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT19_DESC",
    -2147460431: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT1_DESC",
    -2147460454: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT2",
    -2147460436: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT20",
    -2147460412: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT20_DESC",
    -2147460435: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT21",
    -2147460411: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT21_DESC",
    -2147460434: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT22",
    -2147460410: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT22_DESC",
    -2147460433: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT23",
    -2147460409: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT23_DESC",
    -2147460430: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT2_DESC",
    -2147460453: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT3",
    -2147460429: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT3_DESC",
    -2147460452: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT4",
    -2147460428: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT4_DESC",
    -2147460451: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT5",
    -2147460427: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT5_DESC",
    -2147460450: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT6",
    -2147460426: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT6_DESC",
    -2147460449: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT7",
    -2147460425: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT7_DESC",
    -2147460448: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT8",
    -2147460424: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT8_DESC",
    -2147460447: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT9",
    -2147460423: "DSSCOM_C_PDS_NEWCNFG_SUNDAYAT9_DESC",
    -2147482645: "DSSCOM_C_PDS_NEWCNFG_SYSADMIN",
    -2147482646: "DSSCOM_C_PDS_NEWCNFG_SYSMONITOR",
    -2147460600: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT0",
    -2147460576: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT0_DESC",
    -2147460599: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT1",
    -2147460590: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT10",
    -2147460566: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT10_DESC",
    -2147460589: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT11",
    -2147460565: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT11_DESC",
    -2147460588: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT12",
    -2147460564: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT12_DESC",
    -2147460587: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT13",
    -2147460563: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT13_DESC",
    -2147460586: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT14",
    -2147460562: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT14_DESC",
    -2147460585: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT15",
    -2147460561: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT15_DESC",
    -2147460584: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT16",
    -2147460560: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT16_DESC",
    -2147460583: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT17",
    -2147460559: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT17_DESC",
    -2147460582: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT18",
    -2147460558: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT18_DESC",
    -2147460581: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT19",
    -2147460557: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT19_DESC",
    -2147460575: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT1_DESC",
    -2147460598: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT2",
    -2147460580: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT20",
    -2147460556: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT20_DESC",
    -2147460579: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT21",
    -2147460555: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT21_DESC",
    -2147460578: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT22",
    -2147460554: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT22_DESC",
    -2147460577: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT23",
    -2147198409: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT23_DESC",
    -2147460574: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT2_DESC",
    -2147460597: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT3",
    -2147460573: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT3_DESC",
    -2147460596: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT4",
    -2147460572: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT4_DESC",
    -2147460595: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT5",
    -2147460571: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT5_DESC",
    -2147460594: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT6",
    -2147460570: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT6_DESC",
    -2147460593: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT7",
    -2147460569: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT7_DESC",
    -2147460592: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT8",
    -2147460568: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT8_DESC",
    -2147460591: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT9",
    -2147460567: "DSSCOM_C_PDS_NEWCNFG_THURSDAYAT9_DESC",
    -2147460696: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT0",
    -2147460672: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT0_DESC",
    -2147460695: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT1",
    -2147460686: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT10",
    -2147460662: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT10_DESC",
    -2147460685: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT11",
    -2147460661: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT11_DESC",
    -2147460684: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT12",
    -2147460660: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT12_DESC",
    -2147460683: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT13",
    -2147460659: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT13_DESC",
    -2147460682: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT14",
    -2147460658: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT14_DESC",
    -2147460681: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT15",
    -2147460657: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT15_DESC",
    -2147460680: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT16",
    -2147460656: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT16_DESC",
    -2147460679: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT17",
    -2147460655: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT17_DESC",
    -2147460678: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT18",
    -2147460654: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT18_DESC",
    -2147460677: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT19",
    -2147460653: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT19_DESC",
    -2147460671: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT1_DESC",
    -2147460694: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT2",
    -2147460676: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT20",
    -2147460652: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT20_DESC",
    -2147460675: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT21",
    -2147460651: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT21_DESC",
    -2147460674: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT22",
    -2147460650: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT22_DESC",
    -2147460673: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT23",
    -2147460649: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT23_DESC",
    -2147460670: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT2_DESC",
    -2147460693: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT3",
    -2147460669: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT3_DESC",
    -2147460692: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT4",
    -2147460668: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT4_DESC",
    -2147460691: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT5",
    -2147460667: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT5_DESC",
    -2147460690: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT6",
    -2147460666: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT6_DESC",
    -2147460689: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT7",
    -2147460665: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT7_DESC",
    -2147460688: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT8",
    -2147460664: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT8_DESC",
    -2147460687: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT9",
    -2147460663: "DSSCOM_C_PDS_NEWCNFG_TUESDAYAT9_DESC",
    -2147482641: "DSSCOM_C_PDS_NEWCNFG_WEBANALYST",
    -2147482642: "DSSCOM_C_PDS_NEWCNFG_WEBREPORTER",
    -2147482643: "DSSCOM_C_PDS_NEWCNFG_WEBVIEWER",
    -2147460648: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT0",
    -2147460624: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT0_DESC",
    -2147460647: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT1",
    -2147460638: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT10",
    -2147460614: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT10_DESC",
    -2147460637: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT11",
    -2147460613: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT11_DESC",
    -2147460636: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT12",
    -2147460612: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT12_DESC",
    -2147460635: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT13",
    -2147460611: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT13_DESC",
    -2147460634: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT14",
    -2147460610: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT14_DESC",
    -2147460633: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT15",
    -2147460609: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT15_DESC",
    -2147460632: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT16",
    -2147460608: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT16_DESC",
    -2147460631: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT17",
    -2147460607: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT17_DESC",
    -2147460630: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT18",
    -2147460606: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT18_DESC",
    -2147460629: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT19",
    -2147460605: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT19_DESC",
    -2147460623: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT1_DESC",
    -2147460646: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT2",
    -2147460628: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT20",
    -2147460604: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT20_DESC",
    -2147460627: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT21",
    -2147460603: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT21_DESC",
    -2147460626: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT22",
    -2147460602: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT22_DESC",
    -2147460625: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT23",
    -2147460601: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT23_DESC",
    -2147460622: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT2_DESC",
    -2147460645: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT3",
    -2147460621: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT3_DESC",
    -2147460644: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT4",
    -2147460620: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT4_DESC",
    -2147460643: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT5",
    -2147460619: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT5_DESC",
    -2147460642: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT6",
    -2147460618: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT6_DESC",
    -2147460641: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT7",
    -2147460617: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT7_DESC",
    -2147460640: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT8",
    -2147460616: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT8_DESC",
    -2147460639: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT9",
    -2147460615: "DSSCOM_C_PDS_NEWCNFG_WEDNESDAYAT9_DESC",
    -2147460887: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT0",
    -2147460863: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT0_DESC",
    -2147460886: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT1",
    -2147460877: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT10",
    -2147460853: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT10_DESC",
    -2147460876: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT11",
    -2147460852: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT11_DESC",
    -2147460875: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT12",
    -2147460851: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT12_DESC",
    -2147460874: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT13",
    -2147460850: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT13_DESC",
    -2147460873: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT14",
    -2147460849: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT14_DESC",
    -2147460872: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT15",
    -2147460848: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT15_DESC",
    -2147460871: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT16",
    -2147460847: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT16_DESC",
    -2147460870: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT17",
    -2147460846: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT17_DESC",
    -2147460869: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT18",
    -2147460845: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT18_DESC",
    -2147460868: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT19",
    -2147460844: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT19_DESC",
    -2147460862: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT1_DESC",
    -2147460885: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT2",
    -2147460867: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT20",
    -2147460843: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT20_DESC",
    -2147460866: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT21",
    -2147460842: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT21_DESC",
    -2147460865: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT22",
    -2147460841: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT22_DESC",
    -2147460864: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT23",
    -2147460840: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT23_DESC",
    -2147460861: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT2_DESC",
    -2147460884: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT3",
    -2147460860: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT3_DESC",
    -2147460883: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT4",
    -2147460859: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT4_DESC",
    -2147460882: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT5",
    -2147460858: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT5_DESC",
    -2147460881: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT6",
    -2147460857: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT6_DESC",
    -2147460880: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT7",
    -2147460856: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT7_DESC",
    -2147460879: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT8",
    -2147460855: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT8_DESC",
    -2147460878: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT9",
    -2147460854: "DSSCOM_C_PDS_NEWCNFG_WEEKDAYAT9_DESC",
    -2147461050: "DSSCOM_C_PDS_NEWCONF_DIDATABASEINSTANCE",
    -2147461049: "DSSCOM_C_PDS_NEWCONF_DIDATABASEINSTANCE_DESC",
    -2147477772: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEDROPBOX",
    -2147477771: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEDROPBOX_DESC",
    -2147477727: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEELASTICSEARCH",
    -2147477726: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEELASTICSEARCH_DESC",
    -2147477762: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEFACEBOOK",
    -2147477761: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEFACEBOOK_DESC",
    -2147477776: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEGDRIVE",
    -2147477775: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEGDRIVE_DESC",
    -2147477770: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEGOOGLEANALYTICS",
    -2147477769: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEGOOGLEANALYTICS_DESC",
    -2147477768: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEGOOGLEBIGQUERY",
    -2147477766: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEGOOGLEBIGQUERYFFSQLMODEL",
    -2147477765: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEGOOGLEBIGQUERYFFSQLMODEL_DESC",
    -2147477767: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEGOOGLEBIGQUERY_DESC",
    -2147477723: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEHADOOPGATEWAY",
    -2147477722: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEHADOOPGATEWAY_DESC",
    -2147477774: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCESFDC",
    -2147477773: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCESFDC_DESC",
    -2147477748: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCESOLR",
    -2147477747: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCESOLR_DESC",
    -2147477764: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCETWITTER",
    -2147477763: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCETWITTER_DESC",
    -2147477735: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHANONYMOUS",
    -2147477734: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHANONYMOUS_DESC",
    -2147477729: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHINTEGRATED",
    -2147477728: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHINTEGRATED_DESC",
    -2147477733: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHKERBEROS",
    -2147477732: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHKERBEROS_DESC",
    -2147477731: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHSHAREDKERBEROS",
    -2147477730: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHSHAREDKERBEROS_DESC",
    -2147477737: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHWINDOWS",
    -2147477736: "DSSCOM_C_PDS_NEWCONF_DIEXTERNALSOURCEURLAUTHWINDOWS_DESC",
    -2147477725: "DSSCOM_C_PDS_NEWCONF_DISERVER",
    -2147477724: "DSSCOM_C_PDS_NEWCONF_DISERVER_DESC",
    -2147461011: "DSSCOM_C_PDS_NEWCONF_STATISTICSINSTANCE",
    -2147461010: "DSSCOM_C_PDS_NEWCONF_STATISTICSINSTANCE_DESC",
    -2147418128: "DSSCOM_C_PDS_NEWPRJ_ANALYSIS_N",
    -2147482531: "DSSCOM_C_PDS_NEWPRJ_ATTRS_N",
    -2147482499: "DSSCOM_C_PDS_NEWPRJ_AUTOSTYLES",
    -2147482500: "DSSCOM_C_PDS_NEWPRJ_AUTOSTYLES_N",
    -2147482517: "DSSCOM_C_PDS_NEWPRJ_BASEFML_N",
    -2147481407: "DSSCOM_C_PDS_NEWPRJ_BLANKDASHBOARD",
    -2147481405: "DSSCOM_C_PDS_NEWPRJ_BLANKDASHBOARD_DESC",
    -2147481889: "DSSCOM_C_PDS_NEWPRJ_BLANKDOCUMENT",
    -2147481404: "DSSCOM_C_PDS_NEWPRJ_BLANKDOCUMENT_DESC",
    -2147482498: "DSSCOM_C_PDS_NEWPRJ_BLANKREPORT",
    -2147482526: "DSSCOM_C_PDS_NEWPRJ_CONS_N",
    -2147482525: "DSSCOM_C_PDS_NEWPRJ_CUSTGRP_N",
    -2147461048: "DSSCOM_C_PDS_NEWPRJ_DASHBOARDS_N",
    -2147482546: "DSSCOM_C_PDS_NEWPRJ_DATAEXPLORER",
    -2147482501: "DSSCOM_C_PDS_NEWPRJ_DATAEXPL_N",
    -2147481890: "DSSCOM_C_PDS_NEWPRJ_DOCUMENTS",
    -2147481891: "DSSCOM_C_PDS_NEWPRJ_DOCUMENTS_N",
    -2147481384: "DSSCOM_C_PDS_NEWPRJ_DOSSIERS_N",
    -2147482497: "DSSCOM_C_PDS_NEWPRJ_DRILLMAPS_N",
    -2147482532: "DSSCOM_C_PDS_NEWPRJ_FACTS_N",
    -2147482535: "DSSCOM_C_PDS_NEWPRJ_FIFUNC_N",
    -2147482524: "DSSCOM_C_PDS_NEWPRJ_FILTERS_N",
    -2147482539: "DSSCOM_C_PDS_NEWPRJ_FUNCOP_N",
    -2147482534: "DSSCOM_C_PDS_NEWPRJ_HIER_N",
    -2147461009: "DSSCOM_C_PDS_NEWPRJ_LAYERS_N",
    -2147482536: "DSSCOM_C_PDS_NEWPRJ_MATHFUNC_N",
    -2147482496: "DSSCOM_C_PDS_NEWPRJ_MDSECURITYFILTERS_N",
    -2147482523: "DSSCOM_C_PDS_NEWPRJ_METRICS_N",
    -2147481383: "DSSCOM_C_PDS_NEWPRJ_NEWDOSSIER",
    -2147481385: "DSSCOM_C_PDS_NEWPRJ_NEWDOSSIERS_DESC",
    -2147481381: "DSSCOM_C_PDS_NEWPRJ_NEWDOSSIER_DESC",
    -2147482543: "DSSCOM_C_PDS_NEWPRJ_OBJTEMP",
    -2147482516: "DSSCOM_C_PDS_NEWPRJ_OBJTEMPL_N",
    -2147482530: "DSSCOM_C_PDS_NEWPRJ_PARTMAP_N",
    -2147482541: "DSSCOM_C_PDS_NEWPRJ_PBUILDER",
    -2147482538: "DSSCOM_C_PDS_NEWPRJ_PLUGIN_N",
    -2147461046: "DSSCOM_C_PDS_NEWPRJ_PORTABLE_DASHBOARDS_IPAD_N",
    -2147461045: "DSSCOM_C_PDS_NEWPRJ_PORTABLE_DASHBOARDS_IPHONE_N",
    -2147461047: "DSSCOM_C_PDS_NEWPRJ_PORTABLE_DASHBOARDS_N",
    -2147461044: "DSSCOM_C_PDS_NEWPRJ_PORTABLE_DASHBOARDS_WEB_N",
    -2147482518: "DSSCOM_C_PDS_NEWPRJ_PRJBLDR_N",
    -2147482542: "DSSCOM_C_PDS_NEWPRJ_PROFILE",
    -2147482515: "DSSCOM_C_PDS_NEWPRJ_PROFILES_C",
    -2147482495: "DSSCOM_C_PDS_NEWPRJ_PROJECTOBJECTS_N",
    -2147482522: "DSSCOM_C_PDS_NEWPRJ_PROMPTS_N",
    -2147482545: "DSSCOM_C_PDS_NEWPRJ_PROPSET",
    -2147482544: "DSSCOM_C_PDS_NEWPRJ_PUBLIC",
    -2147482527: "DSSCOM_C_PDS_NEWPRJ_PUBLIC_N",
    -2147482521: "DSSCOM_C_PDS_NEWPRJ_REPORTS_N",
    -2147461012: "DSSCOM_C_PDS_NEWPRJ_SAMPLE_DASHBOARDS_N",
    -2147482547: "DSSCOM_C_PDS_NEWPRJ_SCHEMA",
    -2147482540: "DSSCOM_C_PDS_NEWPRJ_SCHEMA_N",
    -2147482520: "DSSCOM_C_PDS_NEWPRJ_SEARCHES_C",
    -2147482537: "DSSCOM_C_PDS_NEWPRJ_STATFUNC_N",
    -2147482528: "DSSCOM_C_PDS_NEWPRJ_SUBTOT_N",
    -2147481869: "DSSCOM_C_PDS_NEWPRJ_SYSTEM_PROMPTS_N",
    -2147482533: "DSSCOM_C_PDS_NEWPRJ_TABLES_N",
    -2147460397: "DSSCOM_C_PDS_NEWPRJ_TAGS",
    -2147482519: "DSSCOM_C_PDS_NEWPRJ_TEMPLATES_N",
    -2147482529: "DSSCOM_C_PDS_NEWPRJ_TRANS_N",
    -2147482494: "DSSCOM_C_PDS_NEWPRJ_VERSION_HISTORY",
    -2147460392: "DSSCOM_C_PDS_ORANGE",
    -2147460315: "DSSCOM_C_PDS_PLATFORMADMINISTRATOR",
    -2147460314: "DSSCOM_C_PDS_PLATFORMADMINISTRATOR_DESC",
    -2147481359: "DSSCOM_C_PDS_PRIVATE_SEGMENTS_FOLDER",
    -2147481395: "DSSCOM_C_PDS_PROJECT_BULK_ADMINS_DESC",
    -2147481396: "DSSCOM_C_PDS_PROJECT_BULK_ADMINS_NAME",
    -2147481393: "DSSCOM_C_PDS_PROJECT_OPERATIONS_ADMINS_DESC",
    -2147481394: "DSSCOM_C_PDS_PROJECT_OPERATIONS_ADMINS_NAME",
    -2147481391: "DSSCOM_C_PDS_PROJECT_OPERATIONS_MONITORS_DESC",
    -2147481392: "DSSCOM_C_PDS_PROJECT_OPERATIONS_MONITORS_NAME",
    -2147481389: "DSSCOM_C_PDS_PROJECT_RESOURCE_SETTINGS_ADMINS_DESC",
    -2147481390: "DSSCOM_C_PDS_PROJECT_RESOURCE_SETTINGS_ADMINS_NAME",
    -2147481387: "DSSCOM_C_PDS_PROJECT_SECURITY_ADMINS_DESC",
    -2147481388: "DSSCOM_C_PDS_PROJECT_SECURITY_ADMINS_NAME",
    -2147481426: "DSSCOM_C_PDS_PROMPT_ALL_ATTRIBUTES_MEANING",
    -2147481428: "DSSCOM_C_PDS_PROMPT_ALL_ATTRIBUTES_NAME",
    -2147481427: "DSSCOM_C_PDS_PROMPT_ALL_ATTRIBUTES_TITLE",
    -2147481438: "DSSCOM_C_PDS_PROMPT_ALL_FILTERS_MEANING",
    -2147481440: "DSSCOM_C_PDS_PROMPT_ALL_FILTERS_NAME",
    -2147481439: "DSSCOM_C_PDS_PROMPT_ALL_FILTERS_TITLE",
    -2147481422: "DSSCOM_C_PDS_PROMPT_ALL_HIERARCHIES_MEANING",
    -2147481424: "DSSCOM_C_PDS_PROMPT_ALL_HIERARCHIES_NAME",
    -2147481423: "DSSCOM_C_PDS_PROMPT_ALL_HIERARCHIES_TITLE",
    -2147481430: "DSSCOM_C_PDS_PROMPT_ALL_METRICS_MEANING",
    -2147481432: "DSSCOM_C_PDS_PROMPT_ALL_METRICS_NAME",
    -2147481431: "DSSCOM_C_PDS_PROMPT_ALL_METRICS_TITLE",
    -2147481434: "DSSCOM_C_PDS_PROMPT_ALL_TEMPLATES_MEANING",
    -2147481436: "DSSCOM_C_PDS_PROMPT_ALL_TEMPLATES_NAME",
    -2147481435: "DSSCOM_C_PDS_PROMPT_ALL_TEMPLATES_TITLE",
    -2147479554: "DSSCOM_C_PDS_PROMPT_DESC_APPLICATUION_ID",
    -2147479646: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR1",
    -2147479628: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR10",
    -2147479626: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR11",
    -2147479624: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR12",
    -2147479622: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR13",
    -2147479620: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR14",
    -2147479618: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR15",
    -2147479616: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR16",
    -2147479614: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR17",
    -2147479612: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR18",
    -2147479610: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR19",
    -2147479644: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR2",
    -2147479608: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR20",
    -2147479606: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR21",
    -2147479604: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR22",
    -2147479602: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR23",
    -2147479600: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR24",
    -2147479598: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR25",
    -2147479596: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR26",
    -2147479594: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR27",
    -2147479592: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR28",
    -2147479590: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR29",
    -2147479642: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR3",
    -2147479588: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR30",
    -2147479586: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR31",
    -2147479584: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR32",
    -2147479582: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR33",
    -2147479580: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR34",
    -2147479578: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR35",
    -2147479576: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR36",
    -2147479574: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR37",
    -2147479572: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR38",
    -2147479570: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR39",
    -2147479640: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR4",
    -2147479568: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR40",
    -2147479638: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR5",
    -2147479636: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR6",
    -2147479634: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR7",
    -2147479632: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR8",
    -2147479630: "DSSCOM_C_PDS_PROMPT_DESC_LDAP_ATTR9",
    -2147478644: "DSSCOM_C_PDS_PROMPT_DESC_MEMBERID",
    -2147479566: "DSSCOM_C_PDS_PROMPT_DESC_MOBILE_ID",
    -2147478642: "DSSCOM_C_PDS_PROMPT_DESC_PAGEID",
    -2147478640: "DSSCOM_C_PDS_PROMPT_DESC_PAGEID_LIST",
    -2147478648: "DSSCOM_C_PDS_PROMPT_DESC_PRIVILEGES",
    -2147479556: "DSSCOM_C_PDS_PROMPT_DESC_PROFILE_ID",
    -2147479564: "DSSCOM_C_PDS_PROMPT_DESC_TOKEN_1",
    -2147479562: "DSSCOM_C_PDS_PROMPT_DESC_TOKEN_2",
    -2147479560: "DSSCOM_C_PDS_PROMPT_DESC_TOKEN_3",
    -2147479558: "DSSCOM_C_PDS_PROMPT_DESC_TOKEN_4",
    -2147478646: "DSSCOM_C_PDS_PROMPT_DESC_UID",
    -2147481871: "DSSCOM_C_PDS_PROMPT_LOGIN",
    -2147481870: "DSSCOM_C_PDS_PROMPT_LOGIN_DESC",
    -2147479555: "DSSCOM_C_PDS_PROMPT_NAME_APPLICATUION_ID",
    -2147479647: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR1",
    -2147479629: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR10",
    -2147479627: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR11",
    -2147479625: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR12",
    -2147479623: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR13",
    -2147479621: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR14",
    -2147479619: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR15",
    -2147479617: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR16",
    -2147479615: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR17",
    -2147479613: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR18",
    -2147479611: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR19",
    -2147479645: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR2",
    -2147479609: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR20",
    -2147479607: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR21",
    -2147479605: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR22",
    -2147479603: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR23",
    -2147479601: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR24",
    -2147479599: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR25",
    -2147479597: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR26",
    -2147479595: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR27",
    -2147479593: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR28",
    -2147479591: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR29",
    -2147479643: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR3",
    -2147479589: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR30",
    -2147479587: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR31",
    -2147479585: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR32",
    -2147479583: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR33",
    -2147479581: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR34",
    -2147479579: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR35",
    -2147479577: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR36",
    -2147479575: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR37",
    -2147479573: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR38",
    -2147479571: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR39",
    -2147479641: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR4",
    -2147479569: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR40",
    -2147479639: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR5",
    -2147479637: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR6",
    -2147479635: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR7",
    -2147479633: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR8",
    -2147479631: "DSSCOM_C_PDS_PROMPT_NAME_LDAP_ATTR9",
    -2147478645: "DSSCOM_C_PDS_PROMPT_NAME_MEMBERID",
    -2147479567: "DSSCOM_C_PDS_PROMPT_NAME_MOBILE_ID",
    -2147478643: "DSSCOM_C_PDS_PROMPT_NAME_PAGEID",
    -2147478641: "DSSCOM_C_PDS_PROMPT_NAME_PAGEID_LIST",
    -2147479553: "DSSCOM_C_PDS_PROMPT_NAME_PRIVILEGES",
    -2147479557: "DSSCOM_C_PDS_PROMPT_NAME_PROFILE_ID",
    -2147479565: "DSSCOM_C_PDS_PROMPT_NAME_TOKEN_1",
    -2147479563: "DSSCOM_C_PDS_PROMPT_NAME_TOKEN_2",
    -2147479561: "DSSCOM_C_PDS_PROMPT_NAME_TOKEN_3",
    -2147479559: "DSSCOM_C_PDS_PROMPT_NAME_TOKEN_4",
    -2147478647: "DSSCOM_C_PDS_PROMPT_NAME_UID",
    -2147482393: "DSSCOM_C_PDS_PUBLISHED_DOSSIERS_FOLDER",
    -2147478600: "DSSCOM_C_PDS_ParCSIExec_FeatureFlag_Description",
    -2147478601: "DSSCOM_C_PDS_ParCSIExec_FeatureFlag_Name",
    -2147478634: "DSSCOM_C_PDS_ParallelDataFetchPlusNormalizationFeatureFlag_Description",
    -2147478635: "DSSCOM_C_PDS_ParallelDataFetchPlusNormalizationFeatureFlag_Name",
    -2147478617: "DSSCOM_C_PDS_PublishedDossier_Shortcut_Description",
    -2147478618: "DSSCOM_C_PDS_PublishedDossier_Shortcut_Name",
    -2147481419: "DSSCOM_C_PDS_QUALIFY_ALL_METRICS_MEANING",
    -2147481421: "DSSCOM_C_PDS_QUALIFY_ALL_METRICS_NAME",
    -2147481420: "DSSCOM_C_PDS_QUALIFY_ALL_METRICS_TITLE",
    -2147460393: "DSSCOM_C_PDS_RED",
    -2147481445: "DSSCOM_C_PDS_REPORT_BUILDER_DESC",
    -2147481446: "DSSCOM_C_PDS_REPORT_BUILDER_NAME",
    -2147481447: "DSSCOM_C_PDS_REPORT_WIZARD_DESC",
    -2147481448: "DSSCOM_C_PDS_REPORT_WIZARD_NAME",
    -2147460356: "DSSCOM_C_PDS_RFPALETTE",
    -2147478633: "DSSCOM_C_PDS_RQE_FFSQLTextPromptSecurityFeatureFlag_Name",
    -2147460354: "DSSCOM_C_PDS_RSTPALETTE",
    -2147460355: "DSSCOM_C_PDS_RTPALETTE",
    -2147481425: "DSSCOM_C_PDS_SEARCH_ALL_ATTRIBUTES_NAME",
    -2147481437: "DSSCOM_C_PDS_SEARCH_ALL_FILTERS_NAME",
    -2147481429: "DSSCOM_C_PDS_SEARCH_ALL_METRICS_NAME",
    -2147481433: "DSSCOM_C_PDS_SEARCH_ALL_TEMPLATES_NAME",
    -2147481855: "DSSCOM_C_PDS_SEARCH_ATTRIBUTE",
    -2147482478: "DSSCOM_C_PDS_SEARCH_CONSOLIDATION",
    -2147482480: "DSSCOM_C_PDS_SEARCH_CUSTOM_GROUP",
    -2147482475: "DSSCOM_C_PDS_SEARCH_DOCUMENT_DEFN",
    -2147481854: "DSSCOM_C_PDS_SEARCH_FACT",
    -2147481849: "DSSCOM_C_PDS_SEARCH_FILTER",
    -2147481850: "DSSCOM_C_PDS_SEARCH_FUNCTION",
    -2147481853: "DSSCOM_C_PDS_SEARCH_HIERARCHY",
    -2147482469: "DSSCOM_C_PDS_SEARCH_MANAGED_OBJECTS",
    -2147482479: "DSSCOM_C_PDS_SEARCH_METRIC",
    -2147482472: "DSSCOM_C_PDS_SEARCH_PROMPT_ELEMENTS",
    -2147482471: "DSSCOM_C_PDS_SEARCH_PROMPT_EXPRESSION",
    -2147482473: "DSSCOM_C_PDS_SEARCH_PROMPT_OBJECT",
    -2147482470: "DSSCOM_C_PDS_SEARCH_PROMPT_TEXT",
    -2147482476: "DSSCOM_C_PDS_SEARCH_REPORT_DEFN",
    -2147482474: "DSSCOM_C_PDS_SEARCH_SEARCH",
    -2147481851: "DSSCOM_C_PDS_SEARCH_TABLE",
    -2147482477: "DSSCOM_C_PDS_SEARCH_TEMPLATE",
    -2147481852: "DSSCOM_C_PDS_SEARCH_TRANSFORMATION",
    -2147481360: "DSSCOM_C_PDS_SEGMENT_OBJECTS",
    -2147460333: "DSSCOM_C_PDS_SERVER_INTEGRITYIMPACT_DESC",
    -2147460334: "DSSCOM_C_PDS_SERVER_INTEGRITYMGRIMPACT",
    -2147460353: "DSSCOM_C_PDS_SSPALETTE",
    -2147482147: "DSSCOM_C_PDS_STAT_AVGDEV",
    -2147482144: "DSSCOM_C_PDS_STAT_BDIST",
    -2147482143: "DSSCOM_C_PDS_STAT_BIDIST",
    -2147482118: "DSSCOM_C_PDS_STAT_CONFIDENCE",
    -2147482111: "DSSCOM_C_PDS_STAT_CORRELATION",
    -2147482112: "DSSCOM_C_PDS_STAT_COVARIANCE",
    -2147482122: "DSSCOM_C_PDS_STAT_CRITBINOMIAL",
    -2147482108: "DSSCOM_C_PDS_STAT_CSQRTEST",
    -2147482141: "DSSCOM_C_PDS_STAT_CSQR_C168DIST",
    -2147482115: "DSSCOM_C_PDS_STAT_DATA1",
    -2147482113: "DSSCOM_C_PDS_STAT_DATA2",
    -2147482138: "DSSCOM_C_PDS_STAT_EXPONENTIALDIST",
    -2147482142: "DSSCOM_C_PDS_STAT_FDIST",
    -2147482121: "DSSCOM_C_PDS_STAT_FISHER",
    -2147482094: "DSSCOM_C_PDS_STAT_FORECAST_S",
    -2147482093: "DSSCOM_C_PDS_STAT_FORECAST_V",
    -2147482101: "DSSCOM_C_PDS_STAT_FTEST",
    -2147482137: "DSSCOM_C_PDS_STAT_GDIST",
    -2147482097: "DSSCOM_C_PDS_STAT_GROWTH_S",
    -2147482096: "DSSCOM_C_PDS_STAT_GROWTH_V",
    -2147482102: "DSSCOM_C_PDS_STAT_HETEROTTEST",
    -2147482103: "DSSCOM_C_PDS_STAT_HOMOTTEST",
    -2147482136: "DSSCOM_C_PDS_STAT_HYPERGEOMETRICDIST",
    -2147482106: "DSSCOM_C_PDS_STAT_INTERCEPT",
    -2147482130: "DSSCOM_C_PDS_STAT_INVERSEBDIST",
    -2147482128: "DSSCOM_C_PDS_STAT_INVERSECDIST",
    -2147482129: "DSSCOM_C_PDS_STAT_INVERSEFDIST",
    -2147482120: "DSSCOM_C_PDS_STAT_INVERSEFISHER",
    -2147482125: "DSSCOM_C_PDS_STAT_INVERSEGDIST",
    -2147482124: "DSSCOM_C_PDS_STAT_INVERSELOGNORMALDIST",
    -2147482127: "DSSCOM_C_PDS_STAT_INVERSENORMDIST",
    -2147482126: "DSSCOM_C_PDS_STAT_INVERSENORMSDIST",
    -2147482123: "DSSCOM_C_PDS_STAT_INVERSETDIST",
    -2147482146: "DSSCOM_C_PDS_STAT_KURTOSIS",
    -2147482100: "DSSCOM_C_PDS_STAT_LINEARTREND_S",
    -2147482099: "DSSCOM_C_PDS_STAT_LINEARTREND_V",
    -2147482135: "DSSCOM_C_PDS_STAT_LOGNORMALDIST",
    -2147482116: "DSSCOM_C_PDS_STAT_MEANTTEST",
    -2147482134: "DSSCOM_C_PDS_STAT_NEGATIVEBINOMINALDIST",
    -2147482139: "DSSCOM_C_PDS_STAT_NORMALDIST",
    -2147482104: "DSSCOM_C_PDS_STAT_PAIREDTTEST",
    -2147482110: "DSSCOM_C_PDS_STAT_PEARSON",
    -2147482119: "DSSCOM_C_PDS_STAT_PERMUT",
    -2147482133: "DSSCOM_C_PDS_STAT_POISSONDIST",
    -2147482109: "DSSCOM_C_PDS_STAT_RSQR",
    -2147482145: "DSSCOM_C_PDS_STAT_SKEW",
    -2147482107: "DSSCOM_C_PDS_STAT_SLOPE",
    -2147482117: "DSSCOM_C_PDS_STAT_STANDARDIZE",
    -2147482140: "DSSCOM_C_PDS_STAT_STDNORMALDIST",
    -2147482105: "DSSCOM_C_PDS_STAT_STEYX",
    -2147482132: "DSSCOM_C_PDS_STAT_TDIST",
    -2147482114: "DSSCOM_C_PDS_STAT_VARTEST",
    -2147482131: "DSSCOM_C_PDS_STAT_WEIBULLDIST",
    -2147481399: "DSSCOM_C_PDS_SVR_BULK_ADMINS_DESC",
    -2147481397: "DSSCOM_C_PDS_SVR_CONF_ADMINS_DESC",
    -2147481400: "DSSCOM_C_PDS_SVR_OPERATIONS_ADMINS_DESC",
    -2147481401: "DSSCOM_C_PDS_SVR_OPERATIONS_MONITORS_DESC",
    -2147481402: "DSSCOM_C_PDS_SVR_RESOURCE_SETTING_ADMINS_DESC",
    -2147481403: "DSSCOM_C_PDS_SVR_SEC_ADMINS_DESC",
    -2147460313: "DSSCOM_C_PDS_SYSTEMADMINISTRATOR",
    -2147460312: "DSSCOM_C_PDS_SYSTEMADMINISTRATOR_DESC",
    -2147460349: "DSSCOM_C_PDS_SYSTEM_ADMINISTRATOR_DESC",
    -2147460350: "DSSCOM_C_PDS_SYSTEM_ADMINISTRATOR_NAME",
    -2147461087: "DSSCOM_C_PDS_SYSTEM_HIERARCHY",
    -2147478575: "DSSCOM_C_PDS_SendingLogtoMessagingServices_FeatureFlag_Description",
    -2147478576: "DSSCOM_C_PDS_SendingLogtoMessagingServices_FeatureFlag_Name",
    -2147481442: "DSSCOM_C_PDS_TEMPLATE_EMBEDDED_PROMPTED",
    -2147481411: "DSSCOM_C_PDS_TEMPLATE_EMBEDDED_VIEW",
    -2147481418: "DSSCOM_C_PDS_TOT_AGG",
    -2147481945: "DSSCOM_C_PDS_TOT_AVERAGE",
    -2147481946: "DSSCOM_C_PDS_TOT_COUNT",
    -2147481936: "DSSCOM_C_PDS_TOT_GEOMEAN",
    -2147481943: "DSSCOM_C_PDS_TOT_MAXIMUM",
    -2147481941: "DSSCOM_C_PDS_TOT_MEDIAN",
    -2147481944: "DSSCOM_C_PDS_TOT_MINIMUM",
    -2147481940: "DSSCOM_C_PDS_TOT_MODE",
    -2147481897: "DSSCOM_C_PDS_TOT_NAME_AGG",
    -2147481933: "DSSCOM_C_PDS_TOT_NAME_AVERAGE",
    -2147481934: "DSSCOM_C_PDS_TOT_NAME_COUNT",
    -2147481925: "DSSCOM_C_PDS_TOT_NAME_GEOMEAN",
    -2147481931: "DSSCOM_C_PDS_TOT_NAME_MAXIMUM",
    -2147481929: "DSSCOM_C_PDS_TOT_NAME_MEDIAN",
    -2147481932: "DSSCOM_C_PDS_TOT_NAME_MINIMUM",
    -2147481928: "DSSCOM_C_PDS_TOT_NAME_MODE",
    -2147481930: "DSSCOM_C_PDS_TOT_NAME_PRODUCT",
    -2147481927: "DSSCOM_C_PDS_TOT_NAME_STDDEV",
    -2147481935: "DSSCOM_C_PDS_TOT_NAME_TOTAL",
    -2147481926: "DSSCOM_C_PDS_TOT_NAME_VARIANCE",
    -2147481942: "DSSCOM_C_PDS_TOT_PRODUCT",
    -2147481939: "DSSCOM_C_PDS_TOT_STDDEV",
    -2147481947: "DSSCOM_C_PDS_TOT_TOTAL",
    -2147481937: "DSSCOM_C_PDS_TOT_VARIANCE",
    -2147460352: "DSSCOM_C_PDS_TPPALETTE",
    -2147461118: "DSSCOM_C_PDS_TRANS_EMAIL",
    -2147461117: "DSSCOM_C_PDS_TRANS_EMAIL_DESC",
    -2147461116: "DSSCOM_C_PDS_TRANS_FILE",
    -2147461115: "DSSCOM_C_PDS_TRANS_FILE_DESC",
    -2147460980: "DSSCOM_C_PDS_TRANS_FTP",
    -2147460979: "DSSCOM_C_PDS_TRANS_FTP_DESC",
    -2147461086: "DSSCOM_C_PDS_TRANS_MOBILECLIENT",
    -2147460371: "DSSCOM_C_PDS_TRANS_MOBILECLIENTANDROID",
    -2147460370: "DSSCOM_C_PDS_TRANS_MOBILECLIENTANDROID_DESC",
    -2147461054: "DSSCOM_C_PDS_TRANS_MOBILECLIENTIPAD",
    -2147461053: "DSSCOM_C_PDS_TRANS_MOBILECLIENTIPAD_DESC",
    -2147461052: "DSSCOM_C_PDS_TRANS_MOBILECLIENTIPHONE",
    -2147461051: "DSSCOM_C_PDS_TRANS_MOBILECLIENTIPHONE_DESC",
    -2147461085: "DSSCOM_C_PDS_TRANS_MOBILECLIENT_DESC",
    -2147461114: "DSSCOM_C_PDS_TRANS_PRINT",
    -2147461113: "DSSCOM_C_PDS_TRANS_PRINT_DESC",
    -2147478596: "DSSCOM_C_PDS_ThreadControl_FeatureFlag_Description",
    -2147478597: "DSSCOM_C_PDS_ThreadControl_FeatureFlag_Name",
    -2147460299: "DSSCOM_C_PDS_USERGROUP_ANALYTICSSERVER",
    -2147460298: "DSSCOM_C_PDS_USERGROUP_ANALYTICSSERVER_DESC",
    -2147460303: "DSSCOM_C_PDS_USERGROUP_API",
    -2147460302: "DSSCOM_C_PDS_USERGROUP_API_DESC",
    -2147460305: "DSSCOM_C_PDS_USERGROUP_ARCHITECT",
    -2147460304: "DSSCOM_C_PDS_USERGROUP_ARCHITECT_DESC",
    -2147460295: "DSSCOM_C_PDS_USERGROUP_COLLABORATIONSERVER",
    -2147460294: "DSSCOM_C_PDS_USERGROUP_COLLABORATIONSERVER_DESC",
    -2147460307: "DSSCOM_C_PDS_USERGROUP_DESKTOP",
    -2147460306: "DSSCOM_C_PDS_USERGROUP_DESKTOP_DESC",
    -2147460293: "DSSCOM_C_PDS_USERGROUP_DISTRIBUTIONSERVER",
    -2147460292: "DSSCOM_C_PDS_USERGROUP_DISTRIBUTIONSERVER_DESC",
    -2147460301: "DSSCOM_C_PDS_USERGROUP_MOBILE",
    -2147460300: "DSSCOM_C_PDS_USERGROUP_MOBILE_DESC",
    -2147460311: "DSSCOM_C_PDS_USERGROUP_REPORTER",
    -2147460310: "DSSCOM_C_PDS_USERGROUP_REPORTER_DESC",
    -2147460297: "DSSCOM_C_PDS_USERGROUP_TRANSACTIONSERVER",
    -2147460296: "DSSCOM_C_PDS_USERGROUP_TRANSACTIONSERVER_DESC",
    -2147460309: "DSSCOM_C_PDS_USERGROUP_WEB",
    -2147460308: "DSSCOM_C_PDS_USERGROUP_WEB_DESC",
    -2147481398: "DSSCOM_C_PDS_USER_ADMINS_DESC",
    -2147481386: "DSSCOM_C_PDS_USER_SECOND_FACTOR_EXEMPT_DESC",
    -2147460351: "DSSCOM_C_PDS_VNPALETTE",
    -2147481406: "DSSCOM_C_PDS_XDA_CELLFORMAT_MIX",
    -2147460391: "DSSCOM_C_PDS_YELLOW",
    -2147478632: "DSSCOM_C_PDS__RQE_FFSQLTextPromptSecurityFeatureFlag_Description",
    -2147483310: "DSSCOM_C_PROJECT_CREATOR",
    -2147482763: "DSSCOM_C_PROMPT_ALL_QUALITIES",
    -2147482760: "DSSCOM_C_PROMPT_ATTRIBUTE_DESC",
    -2147482761: "DSSCOM_C_PROMPT_ATTRIBUTE_ID",
    -2147482765: "DSSCOM_C_PROMPT_CHOOSE_ALLMETRICS",
    -2147482766: "DSSCOM_C_PROMPT_CHOOSE_METRIC",
    -2147482759: "DSSCOM_C_PROMPT_ELEMENTS",
    -2147482768: "DSSCOM_C_PROMPT_HIERARCHY_ELEMENTS",
    -2147482769: "DSSCOM_C_PROMPT_HIERARCHY_QUAL",
    -2147482767: "DSSCOM_C_PROMPT_METRIC_QUAL",
    -2147482762: "DSSCOM_C_PROMPT_QUALITY_ELEMENTS",
    -2147482764: "DSSCOM_C_PROMPT_QUALITY_QUAL",
    -2147482770: "DSSCOM_C_PROMPT_REQ",
    -2147482856: "DSSCOM_C_PROPERTY",
    -2147483313: "DSSCOM_C_QUERY_ENGINE_SERVER",
    -2147483322: "DSSCOM_C_REPORT_EXECUTOR",
    -2147481648: "DSSCOM_C_REPORT_FILTER",
    -2147483324: "DSSCOM_C_REPORT_NET_CLIENT",
    -2147483323: "DSSCOM_C_REPORT_NET_SERVER",
    -2147481641: "DSSCOM_C_REPORT_OUT_SOURCE",
    -2147483321: "DSSCOM_C_REPORT_SERVER",
    -2147482771: "DSSCOM_C_REPORT_SERVICES",
    -2147483316: "DSSCOM_C_RESOLUTION_SERVER",
    -2147482855: "DSSCOM_C_ROOT",
    -2147483283: "DSSCOM_C_SAVELINK",
    -2147483290: "DSSCOM_C_SAVENMOVE",
    -2147443435: "DSSCOM_C_SCHEMA_MANIPULATOR",
    -2147482825: "DSSCOM_C_SCRIPT_ENGINE",
    -2147482826: "DSSCOM_C_SCRIPT_SERVER",
    -2147443448: "DSSCOM_C_SEARCH_SERVICES_CLIENT",
    -2147443447: "DSSCOM_C_SEARCH_SERVICES_SERVER",
    -2147481847: "DSSCOM_C_SECTION_BODY_FOOTER",
    -2147482648: "DSSCOM_C_SECTION_BODY_HEADER",
    -2147481848: "DSSCOM_C_SECTION_DETAILS",
    -2147481846: "DSSCOM_C_SECTION_DOCUMENT_FOOTER",
    -2147482649: "DSSCOM_C_SECTION_DOCUMENT_HEADER",
    -2147481644: "DSSCOM_C_SECTION_GROUPBY_FOOTER",
    -2147481645: "DSSCOM_C_SECTION_GROUPBY_HEADER",
    -2147479719: "DSSCOM_C_SECTION_OTHER_FOOTER",
    -2147479720: "DSSCOM_C_SECTION_OTHER_HEADER",
    -2147481845: "DSSCOM_C_SECTION_PAGE_FOOTER",
    -2147482650: "DSSCOM_C_SECTION_PAGE_HEADER",
    -2147483300: "DSSCOM_C_SERVER_ADMIN",
    -2147483326: "DSSCOM_C_SOURCE_NET_CLIENT",
    -2147483325: "DSSCOM_C_SOURCE_NET_SERVER",
    -2147483315: "DSSCOM_C_SQLS_SERVER",
    -2147483314: "DSSCOM_C_SQL_ENGINE_SERVER",
    -2147479721: "DSSCOM_C_TA_CHATTER",
    -2147479727: "DSSCOM_C_TA_ENTITY",
    -2147479725: "DSSCOM_C_TA_ENTITY_SENT_SCORE",
    -2147479726: "DSSCOM_C_TA_ENTITY_TYPE",
    -2147479734: "DSSCOM_C_TA_PHRASE",
    -2147479732: "DSSCOM_C_TA_PHRASE_SENT_SCORE",
    -2147479733: "DSSCOM_C_TA_PHRASE_TYPE",
    -2147479737: "DSSCOM_C_TA_TERM",
    -2147479735: "DSSCOM_C_TA_TERM_POS_TAG",
    -2147479736: "DSSCOM_C_TA_TERM_STERM",
    -2147479738: "DSSCOM_C_TA_TEXT_SENT_SCORE",
    -2147479731: "DSSCOM_C_TA_THEME_NAME",
    -2147479730: "DSSCOM_C_TA_THEME_NORM_NAME",
    -2147479728: "DSSCOM_C_TA_THEME_SENT_SCORE",
    -2147479729: "DSSCOM_C_TA_THEME_STEM_NAME",
    -2147479722: "DSSCOM_C_TA_TOKEN_SENT_SCORE",
    -2147479723: "DSSCOM_C_TA_TOPIC",
    -2147479724: "DSSCOM_C_TA_TOPIC_TYPE",
    -2147481647: "DSSCOM_C_VIEW_FILTER",
    -2147460398: "DSSCOM_C_WCOV_WEIGHTS",
    -2147460940: "DSSCOM_C_WeghtStdevP_Value",
    -2147460938: "DSSCOM_C_WeightMeanAve",
    -2147460937: "DSSCOM_C_WeightMeanAve_Values",
    -2147460936: "DSSCOM_C_WeightMeanAve_Weights",
    -2147460939: "DSSCOM_C_WeightStdevP_Weights",
    -2147483292: "DSSCOM_C_XML_ELEMENTS",
    -2147483311: "DSSCOM_C_XTAB_FACTORY",
    -2147480645: "DSSCOM_DESCRIPTION_PATTERN",
    -2147440620: "DSSCOM_EDITOR_EDITED",
    -2147212329: "DSSCOM_E_9_ALPHA_OR_BETA_PROJECT",
    -2147156942: "DSSCOM_E_ACCESSIBLEPROJECT_NOT_CALCULATED",
    -2147217393: "DSSCOM_E_AMBIGUOUSID",
    -2147217394: "DSSCOM_E_AMBIGUOUSNAME",
    -2147202299: "DSSCOM_E_APPLY_OPERATIONS_FAILED",
    -2147478758: "DSSCOM_E_APPSCHEMA",
    -2147212040: "DSSCOM_E_ATTRIBUTE_ALREADY_MAPPED_IN_TABLE",
    -2147217303: "DSSCOM_E_ATTRIBUTE_DEFN_FORM_NOT_FOUND",
    -2147212039: "DSSCOM_E_ATTRIBUTE_NOT_MAPPED_IN_TABLE",
    -2147217382: "DSSCOM_E_BAD_ITEM_SPEC",
    -2147217351: "DSSCOM_E_BAD_REPORT_TYPE",
    -2147212476: "DSSCOM_E_BASEFORM_DATATYPE_NOT_AVAILABLE",
    -2147217304: "DSSCOM_E_BASEFORM_WITH_UNDEFINED_COLUMN",
    -2147212130: "DSSCOM_E_BLOB_NOT_IN_RIGHT_TABLE",
    -2147156952: "DSSCOM_E_BOOKMARK_ID_NOT_PROVIDED",
    -2147156951: "DSSCOM_E_BOOKMARK_NAME_NOT_PROVIDED",
    -2147156950: "DSSCOM_E_BOOKMARK_NOT_FOUND",
    -2147217378: "DSSCOM_E_BUFFER_TOOSMALL",
    -2147217369: "DSSCOM_E_CACHE_IN_PROCESSING",
    -2147212033: "DSSCOM_E_CALLS_ON_READ_ONLY_OBJECT",
    -2147202303: "DSSCOM_E_CANNOT_COPY_DUE_TO_CUBE_QUOTA_EXCEEDED",
    -2147202290: "DSSCOM_E_CANNOT_EXPORT_DUE_TO_DSN_CONVERSION_FAILURE",
    -2147211976: "DSSCOM_E_CANNOT_EXPORT_DUE_TO_MSTR_SIZE_EXCEEDED",
    -2147180960: "DSSCOM_E_CANNOT_IMPORT_DUE_TO_INCOMPATIBLE_MSTR_VERSION",
    -2147202266: "DSSCOM_E_CANNOT_IMPORT_DUE_TO_LACK_PRIVILEGE",
    -2147202289: "DSSCOM_E_CANNOT_IMPORT_DUE_TO_MISSING_CUBE",
    -2147211955: "DSSCOM_E_CANNOT_IMPORT_MSTR_DUE_TO_MD_OBJECT_MISSING",
    -2147212502: "DSSCOM_E_CANNOT_MERGE_USER_AND_GROUP",
    -2147156949: "DSSCOM_E_CANNOT_PARSE_INCOMMING_STRING_TO_JSON",
    -2147212083: "DSSCOM_E_CANNOT_POPULATE_EXTERNAL_SHORTCUT_TARGET",
    -2147202283: "DSSCOM_E_CANNOT_SAVE_DUE_TO_BROKEN_SUBSCRIPTION_DEPENDENCY",
    -2147464407: "DSSCOM_E_CANNOT_SAVE_DUE_TO_CUBE_QUOTA_EXCEEDED",
    -2147212473: "DSSCOM_E_CHANGE_JOURNALING_NOT_DISABLED",
    -2147212474: "DSSCOM_E_CHANGE_JOURNALING_NOT_ENABLED",
    -2147212481: "DSSCOM_E_CHANGE_JOURNALING_NOT_SUPPORTED",
    -2147202311: "DSSCOM_E_CHANGE_OBJECT_ID",
    -2147202294: "DSSCOM_E_CLIENTID_SECRET_NOFOUND",
    -2147212005: "DSSCOM_E_COLUMN_REUSE",
    -2147213465: "DSSCOM_E_COPY_EMBEDDED_OBJECT",
    -2147212126: "DSSCOM_E_CREATE_CONFIGURATION_WITH_ID_UNSUPPORTED",
    -2147202313: "DSSCOM_E_CUBE_DEFN_CHANGED",
    -2147202307: "DSSCOM_E_CUBE_INSTANCE_LINKED",
    -2147212065: "DSSCOM_E_CUSTOM_GROUP_OVERWRITE_FILTER",
    -2147217349: "DSSCOM_E_DATAELEMENT_EXISTS",
    -2147212095: "DSSCOM_E_DBCONNECTION_HAS_NO_DBLOGIN",
    -2147212096: "DSSCOM_E_DBROLE_HAS_NO_DEFAULT_DBCONNECTION",
    -2147212010: "DSSCOM_E_DBROLE_NOTSET",
    -2147212012: "DSSCOM_E_DBROLE_NOT_SAME",
    -2147217363: "DSSCOM_E_DB_LOGIN",
    -2147216626: "DSSCOM_E_DELETEUSER_OWNER",
    -2147217387: "DSSCOM_E_DELETE_DEPOBJ",
    -2147212305: "DSSCOM_E_DELETE_DEPOBJ_EX",
    -2147216619: "DSSCOM_E_DELETE_DEP_PROJ_OBJ_ON_CONFIG_OBJ",
    -2147212008: "DSSCOM_E_DELETE_FIRSTFORM",
    -2147211999: "DSSCOM_E_DELETE_SYSDIM",
    -2147212478: "DSSCOM_E_DELETE_SYSTEM_USER_OR_GROUP",
    -2147212304: "DSSCOM_E_DELETE_USER_HAS_LOCK",
    -2147212041: "DSSCOM_E_DIRECT_MAPPING_VALIDATION_FAILED_BUT_REVERSE_OK",
    -2147217376: "DSSCOM_E_DSSFILE_SETTING",
    -2147212007: "DSSCOM_E_DUPLICATE_COLUMNNAME",
    -2147213318: "DSSCOM_E_DUPLICATE_LOCALE",
    -2147211995: "DSSCOM_E_DUP_BASE_ATTRIBUTE",
    -2147217373: "DSSCOM_E_DUP_NAME_TYPE",
    -2147211958: "DSSCOM_E_EKM_INTEGRITY_NOT_FOUND",
    -2147211963: "DSSCOM_E_EKM_INVALID",
    -2147211962: "DSSCOM_E_EKM_NOT_MATCH",
    -2147212143: "DSSCOM_E_EMBEDDED_NO_ID",
    -2147213334: "DSSCOM_E_EMPTY_PROPERTY_TYPE",
    -2147217365: "DSSCOM_E_ERROR_DSSID2BSTR",
    -2147080974: "DSSCOM_E_EXISTCOMPATIBLE_TABLE",
    -2147211986: "DSSCOM_E_EXIST_FORMCATEGORY",
    -2147212003: "DSSCOM_E_EXIST_RELATIONSHIP",
    -2147217298: "DSSCOM_E_EXPORT_MSTR_NOT_AVALIABLE",
    -2147217300: "DSSCOM_E_EXPORT_MSTR_NOT_AVALIABLE_FOR_FINANCIAL_REPORT",
    -2147217299: "DSSCOM_E_EXPORT_MSTR_NOT_AVALIABLE_FOR_MDX_FINANCIAL_REPORT",
    -2147216617: "DSSCOM_E_EXPRESSION_TOO_DEEP",
    -2147212097: "DSSCOM_E_EXTERNAL_SHORTCUT_NO_DBROLE",
    -2147202264: "DSSCOM_E_FAILED_TO_IMPORT_DUMMY_DATASET",
    -2147217388: "DSSCOM_E_FAIL_COCREATEINSTANCE",
    -2147180956: "DSSCOM_E_FAIL_TO_EXPORT_MSTR_AS_OFFLINE_MODE",
    -2147180958: "DSSCOM_E_FAIL_TO_EXPORT_MSTR_DUE_TO_MISSING_CUBE_INSTANCE",
    -2147171500: "DSSCOM_E_FAIL_TO_IMPORT_MSTR_FILE",
    -2147213457: "DSSCOM_E_FEATURE_NOT_SUPPORTED",
    -2147211956: "DSSCOM_E_FENCE_NOT_FOUND",
    -2147202295: "DSSCOM_E_FFSQL_ERROR_OBTAIN_DATA",
    -2147211966: "DSSCOM_E_FILE_DECRYPTION_FAILED",
    -2147211960: "DSSCOM_E_FILE_ENCRYPTION_FAILED",
    -2147217359: "DSSCOM_E_FOLDER_INCONSISTENCY",
    -2147217386: "DSSCOM_E_FOLDER_NOT_EMPTY",
    -2147212128: "DSSCOM_E_FOLDER_TREE_BOTH_PROJECT_AND_CONFIGURATION",
    -2147212129: "DSSCOM_E_FOLDER_TREE_MULTI_SEARCHROOTS",
    -2147212127: "DSSCOM_E_FOLDER_TREE_UNROOTED_MANAGED_OBJECTS",
    -2147213327: "DSSCOM_E_FOLDER_TYPES_COLLECTION_NOT_SUPPORTED",
    -2147214208: "DSSCOM_E_FTN_CANNOTSET",
    -2147213338: "DSSCOM_E_GENERICS_READONLY",
    -2147213339: "DSSCOM_E_GENERICS_UNCHECKED",
    -2147213336: "DSSCOM_E_GENERICS_UNKNOWN",
    -2147213337: "DSSCOM_E_HOLDER_INCONSISTENT",
    -2147212447: "DSSCOM_E_ICONPATH_TOO_LONG",
    -2147212199: "DSSCOM_E_ID_DUPLICATE_EMBEDDED_PROMPT",
    -2147080964: "DSSCOM_E_INCOMPATIBLE_TOTAL_TABLE_COUNT",
    -2147217403: "DSSCOM_E_INDEX_OUTOFRANGE",
    -2147217384: "DSSCOM_E_INDEX_OUT_OF_RANGE",
    -2147217348: "DSSCOM_E_INSUFFICIENT_VERSION_FOR_ACCESS",
    -2147217407: "DSSCOM_E_INTERNAL_ERROR",
    -2147211994: "DSSCOM_E_INVALID_BASE_ATTRIBUTE",
    -2147156948: "DSSCOM_E_INVALID_BOOKMARK_NAME",
    -2147212300: "DSSCOM_E_INVALID_BULK_REQUEST_FOLDER",
    -2147212299: "DSSCOM_E_INVALID_BULK_REQUEST_PROJECT",
    -2147217392: "DSSCOM_E_INVALID_COOKIE",
    -2147217375: "DSSCOM_E_INVALID_DSSFILE",
    -2147217366: "DSSCOM_E_INVALID_DSSID",
    -2147212203: "DSSCOM_E_INVALID_FORMAT_PROPERTY_ID",
    -2147212202: "DSSCOM_E_INVALID_FORMAT_PROPERTY_SET",
    -2147212204: "DSSCOM_E_INVALID_FORMAT_PROPERTY_VT",
    -2147217402: "DSSCOM_E_INVALID_INDEX",
    -2147213313: "DSSCOM_E_INVALID_LOCALE",
    -2147212034: "DSSCOM_E_INVALID_MAKEOWNED_OBJECT",
    -2147213351: "DSSCOM_E_INVALID_MANAGED_OBJECTS_FOLDER_OPERATION",
    -2147213353: "DSSCOM_E_INVALID_MANAGED_OBJECT_TYPE",
    -2147213714: "DSSCOM_E_INVALID_MULTILINGUAL_STRING_KEY",
    -2147212503: "DSSCOM_E_INVALID_NUMERIC_ELEMENT_VALUE",
    -2147212480: "DSSCOM_E_INVALID_REPORT_AS_FILTER",
    -2147212109: "DSSCOM_E_INVALID_SCHEMA_INSTANCE_ID",
    -2147212334: "DSSCOM_E_INVALID_STRING",
    -2147212302: "DSSCOM_E_INVALID_TARGET",
    -2147212131: "DSSCOM_E_INVALID_THUMBNAIL_STRING",
    -2147217379: "DSSCOM_E_ITEM_EXISTED",
    -2147217368: "DSSCOM_E_JOB_ID_NOT_FOUND",
    -2147217367: "DSSCOM_E_JOB_IN_WAITING_LIST",
    -2147211968: "DSSCOM_E_KEYSTORE_DECRYPTION_FAILED",
    -2147211970: "DSSCOM_E_KEYSTORE_NOT_FOUND",
    -2147217380: "DSSCOM_E_KEY_EXISTS",
    -2147217383: "DSSCOM_E_KEY_NOT_FOUND",
    -2147213387: "DSSCOM_E_LANGUAGE_MISMATCH",
    -2147213386: "DSSCOM_E_LANGUAGE_MISMATCH_CLIENT_SERVER",
    -2147211993: "DSSCOM_E_LAST_MEM_IN_TRANS",
    -2147156943: "DSSCOM_E_LIBRARY_NOT_CALCULATED",
    -2147212125: "DSSCOM_E_LOAD_PREDEFINED_PACKAGE_ERROR",
    -2147216616: "DSSCOM_E_LOCALE_ID_MISMATCH",
    -2147213406: "DSSCOM_E_LOCALE_NOT_SUPPORTED_BY_CONFIGURATION",
    -2147212200: "DSSCOM_E_LOCKED_CONFIG",
    -2147212453: "DSSCOM_E_LOCK_FOLDER",
    -2147212042: "DSSCOM_E_MAPPING_VALIDATION_FAILED_IN_BOTH_DIRECTIONS",
    -2147211969: "DSSCOM_E_MASTERKEY_NOT_FOUND",
    -2147202326: "DSSCOM_E_MESSAGE_CURRUPTED",
    -2147156953: "DSSCOM_E_MESSAGE_ID_NOT_PROVIDED",
    -2147217352: "DSSCOM_E_MESSAGE_NOT_FOUND",
    -2147213315: "DSSCOM_E_METADATA_INTERNATIONALIZATION_NOT_SUPPORTED",
    -2147217404: "DSSCOM_E_METHOD_NOTSUPPORT",
    -2147080976: "DSSCOM_E_METRIC_DISPLAY_PATH_INVALID",
    -2147212000: "DSSCOM_E_MISSING_ATTRIBUTE_DIM",
    -2147216613: "DSSCOM_E_MISSING_BASEFORM_ID",
    -2147217360: "DSSCOM_E_MODIFIED_LINKED_OBJECTS",
    -2147213721: "DSSCOM_E_MULTILINGUAL_STRING_TOO_LONG",
    -2147212454: "DSSCOM_E_MULTI_ERRS",
    -2147217397: "DSSCOM_E_NAMECLASH",
    -2147216985: "DSSCOM_E_NAME_BAD_FIRST_CHAR",
    -2147212001: "DSSCOM_E_NAME_COLLISION",
    -2147216986: "DSSCOM_E_NAME_INVALID_CHAR",
    -2147216984: "DSSCOM_E_NAME_REQUIRED",
    -2147216987: "DSSCOM_E_NAME_TOO_LONG",
    -2147212475: "DSSCOM_E_NESTED_PROMPT_TO_PROMPT",
    -2147211964: "DSSCOM_E_NEW_KM_INITALIZE_FAILED",
    -2147217045: "DSSCOM_E_NODE_SHORTCUT_TARGET",
    -2147080975: "DSSCOM_E_NOTCOMPATIBLE_TABLE",
    -2147217401: "DSSCOM_E_NOTFOUND",
    -2147217398: "DSSCOM_E_NOTINITIALIZED",
    -2147202293: "DSSCOM_E_NOTSUPPORT_ODBC",
    -2147211988: "DSSCOM_E_NOTSUPPORT_PERNAMESPACE",
    -2147211991: "DSSCOM_E_NOT_COMMON_TABLE",
    -2147212014: "DSSCOM_E_NOT_FFSQL",
    -2147212079: "DSSCOM_E_NOT_QUERY_BUILDER_REPORT",
    -2147217358: "DSSCOM_E_NOT_SEARCH_FOLDER",
    -2147212052: "DSSCOM_E_NOT_WEBFFSQL",
    -2147212053: "DSSCOM_E_NOT_WEBQB_OR_WEBFFSQL",
    -2147217391: "DSSCOM_E_NO_ASYNCHRONOUS",
    -2147212466: "DSSCOM_E_NO_BASE_GRAPHSTYLE",
    -2147211992: "DSSCOM_E_NO_COMMEN_TABLE",
    -2147212198: "DSSCOM_E_NO_LOCALE_ID",
    -2147212467: "DSSCOM_E_NO_LOCALE_OBJECT",
    -2147212444: "DSSCOM_E_NO_MYANSWERS",
    -2147217362: "DSSCOM_E_NO_PARENT_FOLDER",
    -2147212094: "DSSCOM_E_NO_REFERENCE_TO_DBROLE",
    -2147202301: "DSSCOM_E_NO_RELATED_TABLE",
    -2147217396: "DSSCOM_E_NULLSTRING",
    -2147211967: "DSSCOM_E_OBJECT_DECRYPTION_FAILED",
    -2147217400: "DSSCOM_E_OBJECT_DELETED",
    -2147212303: "DSSCOM_E_OBJECT_DOES_NOT_SUPPORT_ACTIVE_PROMPT",
    -2147211959: "DSSCOM_E_OBJECT_ENCRYPTION_FAILED",
    -2147217364: "DSSCOM_E_OBJECT_INVISIBLE",
    -2147213398: "DSSCOM_E_OBJECT_INVISIBLE_EX",
    -2147211957: "DSSCOM_E_OBJECT_LOCK_CONFLICT",
    -2147217361: "DSSCOM_E_OBJECT_NOTINITIALIZED",
    -2147217381: "DSSCOM_E_OBJECT_NOT_FOUND",
    -2147217123: "DSSCOM_E_OBJECT_NOT_FOUND_P",
    -2147217377: "DSSCOM_E_OBJECT_OUT_OF_DATE",
    -2147212058: "DSSCOM_E_OBJECT_SERVER_DISCONNECTED",
    -2147211971: "DSSCOM_E_OBSOLETE_CLIENT_VERSION",
    -2147211965: "DSSCOM_E_OLD_KM_INITALIZE_FAILED",
    -2147217374: "DSSCOM_E_OPEN_FILE",
    -2147202302: "DSSCOM_E_OVERWRITE_REPORT_IN_DOCUMENT",
    -2147212197: "DSSCOM_E_PRE_ORION_AUTOSTYLE_XML_ERROR",
    -2147211987: "DSSCOM_E_PRIMARY_KEY_NOT_SET",
    -2147213319: "DSSCOM_E_PRIMARY_LOCALE_CHANGE",
    -2147213320: "DSSCOM_E_PRIMARY_LOCALE_NOT_SET",
    -2147217371: "DSSCOM_E_PROCESS_CANCELED",
    -2147217370: "DSSCOM_E_PROCESS_NOT_FOUND_IN_CACHE",
    -2147217357: "DSSCOM_E_PROHIBITED_WRITE",
    -2147212038: "DSSCOM_E_PROJECT_DBROLE_NOT_SET",
    -2147212464: "DSSCOM_E_PROJECT_LOCKED",
    -2147212013: "DSSCOM_E_PROMPT_MISMATCH",
    -2147217405: "DSSCOM_E_PROPERTY_NOTSUPPORT",
    -2147212472: "DSSCOM_E_QCOLUMNSHORTCUT_TARGET_NOT_RETRIEVABLE",
    -2147217395: "DSSCOM_E_READONLY",
    -2147217399: "DSSCOM_E_REINITIALIZATION",
    -2147211961: "DSSCOM_E_REKEY_IN_PROGRESS",
    -2147202316: "DSSCOM_E_RELATIONSHIP_NOTEXIST",
    -2147217350: "DSSCOM_E_REPORT_ELEMENT_BROWSE",
    -2147217385: "DSSCOM_E_RESERVED_VALUE",
    -2147212011: "DSSCOM_E_RESULTS_NOT_FETCHED",
    -2147213349: "DSSCOM_E_RWDFIXISSUE",
    -2147213344: "DSSCOM_E_RWDTEMPLATENODE",
    -2147213350: "DSSCOM_E_RWDVALIDATION",
    -2147213345: "DSSCOM_E_RWRESOLVE_ATTRIBUTEFORM",
    -2147213348: "DSSCOM_E_RWRESOLVE_DATA_SOURCE",
    -2147213346: "DSSCOM_E_RWRESOLVE_METRIC",
    -2147213347: "DSSCOM_E_RWRESOLVE_METRIC_IN_MORE_DATA_SOURCE",
    -2147212006: "DSSCOM_E_SAME_COLUMNNAME",
    -2147211981: "DSSCOM_E_SCHEMA_MANI_LOCKED",
    -2147156941: "DSSCOM_E_SECURITY_CHECK_FAILED",
    -2147156954: "DSSCOM_E_SESSION_ID_NOT_PROVIDED",
    -2147464419: "DSSCOM_E_SHAREDPERSONALVIEWLINK_CANNOT_BE_FIND",
    -2147156945: "DSSCOM_E_SHORTCUT_ID_NOT_PROVIDED",
    -2147156947: "DSSCOM_E_SHORTCUT_NOT_FOUND",
    -2147217390: "DSSCOM_E_STRINGLEN",
    -2147213715: "DSSCOM_E_STRING_INVALID_CHARS",
    -2147213716: "DSSCOM_E_STRING_REQUIRED",
    -2147213718: "DSSCOM_E_STRING_TOO_LONG",
    -2147213717: "DSSCOM_E_STRING_TRUNCATED",
    -2147213314: "DSSCOM_E_STYLE_NOTFOUND",
    -2147213454: "DSSCOM_E_STYLE_ON_REPORT",
    -2147212002: "DSSCOM_E_TABLE_NOT_EXIST_IN_WH",
    -2147213312: "DSSCOM_E_TEXT_TO_DOUBLE",
    -2147212504: "DSSCOM_E_TEXT_TO_LONG",
    -2147212531: "DSSCOM_E_TEXT_TO_LONGLONG",
    -2147202276: "DSSCOM_E_THUMBNAIL_EXCEED_SIZELIMIT",
    -2147213328: "DSSCOM_E_TOO_MANY_PROJECTS",
    -2147212060: "DSSCOM_E_TRANSACTIONSUMBIT_NOCHANGE",
    -2147217408: "DSSCOM_E_UNEXPECTED_CASE",
    -2147217406: "DSSCOM_E_UNKNOWN_EXCEPTION",
    -2147212078: "DSSCOM_E_UNKNOWN_QUERY_BUILDER_EXPRESSION_PART",
    -2147202300: "DSSCOM_E_UNRECOGNIZED_XDATYPE",
    -2147213332: "DSSCOM_E_UNSUPPORTED_ASYNCH_BULK_OPERATION",
    -2147216615: "DSSCOM_E_UNSUPPORTED_CREATION",
    -2147217302: "DSSCOM_E_UNSUPPORTED_EXTENDEDTYPE",
    -2147202296: "DSSCOM_E_UNSUPPORTED_FILETYPE",
    -2147217372: "DSSCOM_E_UNSUPPORTED_FLAG",
    -2147213331: "DSSCOM_E_UNSUPPORTED_FLAGS",
    -2147213316: "DSSCOM_E_UNSUPPORTED_LOCALE",
    -2147217389: "DSSCOM_E_UNSUPPORTED_ROLE",
    -2147212465: "DSSCOM_E_UNSUPPORTED_SERIALIZATION_VERSION",
    -2147213452: "DSSCOM_E_UNSUPPORTED_TYPE",
    -2147211249: "DSSCOM_E_UNSUPPORTED_URL",
    -2147202297: "DSSCOM_E_UNSUPPORTED_XDATYPE",
    -2147212009: "DSSCOM_E_UPDATE_COLUMNDEP",
    -2147071210: "DSSCOM_E_URL_IMPORT_NOTALLOWED",
    -2147212061: "DSSCOM_E_VALIDATEINPUT_FAIL",
    -2147217347: "DSSCOM_E_VERSION_CHECK_NOT_SUPPORTED",
    -2147212051: "DSSCOM_E_WEBQB_CANCEL_CONVERT",
    -2147212049: "DSSCOM_E_WEBQB_EMPTY_SQLS",
    -2147212037: "DSSCOM_E_WEBQB_ERROR_OBTAIN_DATA",
    -2147212035: "DSSCOM_E_WEBQB_MAP_ATTRIBUTE_WITHOUT_MAPPING_ID",
    -2147212050: "DSSCOM_E_WEBQB_NO_DBROLE",
    -2147156946: "DSSCOM_E_WORKINGSET_NOT_FOUND",
    -2147213787: "DSSCOM_E_WRITE_FILE",
    -2147212043: "DSSCOM_E_WRITE_READ_ONLY_OBJECT",
    -2147217354: "DSSCOM_E_XML_ATTRIBUTE_NOT_FOUND",
    -2147217353: "DSSCOM_E_XML_ATTRIBUTE_NOT_FOUND_ONEOF",
    -2147211996: "DSSCOM_E_XML_BASE_GRAPHSTYLE_NEEDS_PROPERTY_UPDATE",
    -2147213326: "DSSCOM_E_XML_BUFFER_EXCEPTION",
    -2147217305: "DSSCOM_E_XML_CHILD_COUNT",
    -2147213388: "DSSCOM_E_XML_INVALID_REQUEST_ROOT_NODE",
    -2147217355: "DSSCOM_E_XML_NODE_NOT_FOUND",
    -2147216315: "DSSCOM_E_XML_PROPERTY_TYPE_MISMATCH",
    -2147217306: "DSSCOM_E_XML_SECOND_CLASS_COLLECTION_SKIP_ITEM",
    -2147212108: "DSSCOM_E_XML_WRONG_DOCUMENT",
    -2147480629: "DSSCOM_FILTERDETAILS_AND",
    -2147480631: "DSSCOM_FILTERDETAILS_BETWEEN",
    -2147480642: "DSSCOM_FILTERDETAILS_EQUALS",
    -2147480613: "DSSCOM_FILTERDETAILS_EQUAL_ENHANCED",
    -2147480640: "DSSCOM_FILTERDETAILS_GREATER",
    -2147480638: "DSSCOM_FILTERDETAILS_GREATER_EQUAL",
    -2147480639: "DSSCOM_FILTERDETAILS_LESS",
    -2147480637: "DSSCOM_FILTERDETAILS_LESS_EQUAL",
    -2147480630: "DSSCOM_FILTERDETAILS_LIKE",
    -2147480627: "DSSCOM_FILTERDETAILS_NOT",
    -2147480604: "DSSCOM_FILTERDETAILS_NOT_BETWEEN",
    -2147480641: "DSSCOM_FILTERDETAILS_NOT_EQUAL",
    -2147480612: "DSSCOM_FILTERDETAILS_NOT_EQUAL_ENHANCED",
    -2147480628: "DSSCOM_FILTERDETAILS_OR",
    -2147480648: "DSSCOM_FILTERDETAILS_RESERVED",
    -2147480448: "DSSCOM_FILTERDETAILS_RESERVED_LAST",
    -2147479648: "DSSCOM_INSERT_SHEET",
    -2147480647: "DSSCOM_NAME_PATTERN",
    -2147443084: "DSSCOM_ONETIER_ABOUT_ALLRIGHTRESERVED",
    -2147443085: "DSSCOM_ONETIER_ABOUT_COPYRIGHT",
    -2147443083: "DSSCOM_ONETIER_ABOUT_VERSION",
    -2147442717: "DSSCOM_ONETIER_AEVERSION_OUTDATED",
    -2147440621: "DSSCOM_ONETIER_CERTIFY",
    -2147440624: "DSSCOM_ONETIER_CERTIFYBY",
    -2147440617: "DSSCOM_ONETIER_CERTIFY_SAVEAS",
    -2147440622: "DSSCOM_ONETIER_CERTIFY_SAVEAS_INFO",
    -2147440613: "DSSCOM_ONETIER_CERTIFY_SAVE_DESC",
    -2147440612: "DSSCOM_ONETIER_CERTIFY_SAVE_INFO",
    -2147440623: "DSSCOM_ONETIER_CERTIFY_TIP",
    -2147440614: "DSSCOM_ONETIER_CERTIFY_TIP_2",
    -2147443183: "DSSCOM_ONETIER_COMPRESSION_ERROR",
    -2147442752: "DSSCOM_ONETIER_CONNECTION_STRING_RESPONSE",
    -2147443178: "DSSCOM_ONETIER_CONTROLLER_INITIALIZED",
    -2147443184: "DSSCOM_ONETIER_CREATE_FOLDER_ERROR",
    -2147442748: "DSSCOM_ONETIER_DATASETS_CONNECTION_RESPONSE",
    -2147442543: "DSSCOM_ONETIER_DATASETS_CONNECTION_RESPONSE_FOR_CONNECTION_STRING",
    -2147440615: "DSSCOM_ONETIER_DDA_NOT_SUPPORTED",
    -2147440618: "DSSCOM_ONETIER_DECERTIFY_IT",
    -2147443182: "DSSCOM_ONETIER_DECOMPRESSION_ERROR",
    -2147443047: "DSSCOM_ONETIER_DELETE",
    -2147443049: "DSSCOM_ONETIER_DELETE_SERVERCONNECTION_WARNING",
    -2147443149: "DSSCOM_ONETIER_DIALOG_LABEL_LANGUAGE",
    -2147443148: "DSSCOM_ONETIER_DIALOG_LABEL_NUMBER",
    -2147443147: "DSSCOM_ONETIER_DIALOG_PREFERENCES",
    -2147443136: "DSSCOM_ONETIER_DIALOG_WELCOME",
    -2147443053: "DSSCOM_ONETIER_DI_FILENOTSUPPORTED",
    -2147442544: "DSSCOM_ONETIER_DONOT_SAVE",
    -2147442750: "DSSCOM_ONETIER_DOWNLOAD_SCHEMA_ERROR",
    -2147443176: "DSSCOM_ONETIER_DSSCONTROLLER_INITIALIZE_ERROR",
    -2147443177: "DSSCOM_ONETIER_DSSDATAIMPORT_INITIALIZE_ERROR",
    -2147442541: "DSSCOM_ONETIER_ERROR_NAME_EXISTS",
    -2147028992: "DSSCOM_ONETIER_ERROR_WEBCOMMUNICATION_FAILURE",
    -2147443046: "DSSCOM_ONETIER_EXPORT_CUST_VIZ",
    -2147440639: "DSSCOM_ONETIER_E_BYPASS_SECURITY_FILTER",
    -2147440647: "DSSCOM_ONETIER_FEEDBACK_TITLE",
    -2147440619: "DSSCOM_ONETIER_GOTIT",
    -2147442760: "DSSCOM_ONETIER_INSUFFICIENT_MEMORY",
    -2147443111: "DSSCOM_ONETIER_INVALID_FILE",
    -2147443175: "DSSCOM_ONETIER_INVALID_JSON_PARAMETER_ERROR",
    -2147442743: "DSSCOM_ONETIER_LOCALE_CONFLICT",
    -2147443048: "DSSCOM_ONETIER_LOGOUT",
    -2147443185: "DSSCOM_ONETIER_MANIPULATION_ERROR",
    -2147442540: "DSSCOM_ONETIER_MANIPULATION_UNREVERSIBLE",
    -2147443194: "DSSCOM_ONETIER_MENU1",
    -2147443173: "DSSCOM_ONETIER_MENU10",
    -2147443172: "DSSCOM_ONETIER_MENU11",
    -2147443160: "DSSCOM_ONETIER_MENU12",
    -2147443193: "DSSCOM_ONETIER_MENU2",
    -2147443192: "DSSCOM_ONETIER_MENU3",
    -2147443191: "DSSCOM_ONETIER_MENU4",
    -2147443190: "DSSCOM_ONETIER_MENU5",
    -2147443189: "DSSCOM_ONETIER_MENU6",
    -2147443188: "DSSCOM_ONETIER_MENU7",
    -2147443187: "DSSCOM_ONETIER_MENU8",
    -2147443186: "DSSCOM_ONETIER_MENU9",
    -2147440637: "DSSCOM_ONETIER_MENU_ADDVIZFROMFILE",
    -2147440636: "DSSCOM_ONETIER_MENU_ADDVIZFROMGALLERY",
    -2147440633: "DSSCOM_ONETIER_MENU_COMMUNITYFORUM",
    -2147440631: "DSSCOM_ONETIER_MENU_CONTACTUS",
    -2147440634: "DSSCOM_ONETIER_MENU_DESKTOPHELP",
    -2147442951: "DSSCOM_ONETIER_MENU_DEVELOPER",
    -2147442952: "DSSCOM_ONETIER_MENU_DEVELOPER_VISBUILDER",
    -2147443045: "DSSCOM_ONETIER_MENU_ENTERFULLSCREEN",
    -2147443134: "DSSCOM_ONETIER_MENU_FILE_CLOSE",
    -2147443078: "DSSCOM_ONETIER_MENU_FILE_DASHBOARD_PROPERTIES",
    -2147443068: "DSSCOM_ONETIER_MENU_FILE_DOWNLOAD_FROM_SERVER",
    -2147443155: "DSSCOM_ONETIER_MENU_FILE_EXPORT",
    -2147443153: "DSSCOM_ONETIER_MENU_FILE_EXPORT_IMAGE",
    -2147443154: "DSSCOM_ONETIER_MENU_FILE_EXPORT_PDF",
    -2147443151: "DSSCOM_ONETIER_MENU_FILE_IMPORT_DATA",
    -2147443056: "DSSCOM_ONETIER_MENU_FILE_IMPORT_VIZ",
    -2147440648: "DSSCOM_ONETIER_MENU_FILE_IMPORT_VIZ_EXIST_NOTIFICATION",
    -2147440644: "DSSCOM_ONETIER_MENU_FILE_IMPORT_VIZ_FAIL_ERROR",
    -2147440645: "DSSCOM_ONETIER_MENU_FILE_IMPORT_VIZ_SUCCESS_NOTIFICATION",
    -2147442581: "DSSCOM_ONETIER_MENU_FILE_LOGOUT",
    -2147442578: "DSSCOM_ONETIER_MENU_FILE_LOGOUTFROM",
    -2147443133: "DSSCOM_ONETIER_MENU_FILE_OPENMSTR",
    -2147443075: "DSSCOM_ONETIER_MENU_FILE_PAGE_SETUP",
    -2147443152: "DSSCOM_ONETIER_MENU_FILE_PREFERENCES",
    -2147443076: "DSSCOM_ONETIER_MENU_FILE_PRINT",
    -2147443077: "DSSCOM_ONETIER_MENU_FILE_REFRESH_VIEW",
    -2147443150: "DSSCOM_ONETIER_MENU_FILE_SAVEAS",
    -2147443132: "DSSCOM_ONETIER_MENU_FILE_SAVEASMSTR",
    -2147443067: "DSSCOM_ONETIER_MENU_FILE_SAVE_TO_SERVER",
    -2147443074: "DSSCOM_ONETIER_MENU_FILE_SHARE_DASHBOARD",
    -2147442758: "DSSCOM_ONETIER_MENU_FILE_SHARE_FACEBOOK",
    -2147442756: "DSSCOM_ONETIER_MENU_FILE_SHARE_PUBLICCLOUD",
    -2147442757: "DSSCOM_ONETIER_MENU_FILE_SHARE_TWITTER",
    -2147443158: "DSSCOM_ONETIER_MENU_FULL_SCREEN",
    -2147443139: "DSSCOM_ONETIER_MENU_HELP_FEEDBACK",
    -2147443140: "DSSCOM_ONETIER_MENU_HELP_FORUM",
    -2147443143: "DSSCOM_ONETIER_MENU_HELP_ONLINE",
    -2147443138: "DSSCOM_ONETIER_MENU_HELP_START_GUIDE",
    -2147443141: "DSSCOM_ONETIER_MENU_HELP_TIPS",
    -2147443137: "DSSCOM_ONETIER_MENU_HELP_USER_GUIDE",
    -2147443142: "DSSCOM_ONETIER_MENU_HELP_WELCOME",
    -2147443117: "DSSCOM_ONETIER_MENU_MICROSTRATEGY",
    -2147443116: "DSSCOM_ONETIER_MENU_MICROSTRATEGY_ABOUT",
    -2147443115: "DSSCOM_ONETIER_MENU_MICROSTRATEGY_HIDE",
    -2147443114: "DSSCOM_ONETIER_MENU_MICROSTRATEGY_HIDE_OTHERS",
    -2147443112: "DSSCOM_ONETIER_MENU_MICROSTRATEGY_QUIT",
    -2147443065: "DSSCOM_ONETIER_MENU_MICROSTRATEGY_SERVICES",
    -2147443113: "DSSCOM_ONETIER_MENU_MICROSTRATEGY_SHOW_ALL",
    -2147440638: "DSSCOM_ONETIER_MENU_OPENFROMGALLERY",
    -2147443159: "DSSCOM_ONETIER_MENU_PRESENTATION_MODE",
    -2147443157: "DSSCOM_ONETIER_MENU_PRESENTATION_MODE_EXIT",
    -2147443060: "DSSCOM_ONETIER_MENU_SERVER",
    -2147443064: "DSSCOM_ONETIER_MENU_SERVER_ADDDATASETS",
    -2147443063: "DSSCOM_ONETIER_MENU_SERVER_BROWSEALLOBJECTS",
    -2147443062: "DSSCOM_ONETIER_MENU_SERVER_DOWNLOADDASHBOARD",
    -2147443057: "DSSCOM_ONETIER_MENU_SERVER_DOWNLOADREPORT",
    -2147443055: "DSSCOM_ONETIER_MENU_SERVER_IMPORT_DASHBOARD",
    -2147443061: "DSSCOM_ONETIER_MENU_SERVER_UPLOADDASHBOARD",
    -2147443168: "DSSCOM_ONETIER_MENU_STYLE",
    -2147443089: "DSSCOM_ONETIER_MENU_STYLE_CLASSIC_THEME",
    -2147443079: "DSSCOM_ONETIER_MENU_STYLE_CUSTOM_COLOR_PALETTE_PROPERTIES",
    -2147443088: "DSSCOM_ONETIER_MENU_STYLE_DARK_THEME",
    -2147443087: "DSSCOM_ONETIER_MENU_STYLE_DASHBOARD_FORMATTING_PROPERTIES",
    -2147443090: "DSSCOM_ONETIER_MENU_STYLE_DEFAULT_THEME",
    -2147443080: "DSSCOM_ONETIER_MENU_STYLE_FORMAT_OBJECT_PROPERTIES",
    -2147443086: "DSSCOM_ONETIER_MENU_STYLE_LIGHT_THEME",
    -2147443066: "DSSCOM_ONETIER_MENU_STYLE_PALETTES",
    -2147440635: "DSSCOM_ONETIER_MENU_SUBMITGALLERY",
    -2147440632: "DSSCOM_ONETIER_MENU_TRAININGOFFERING",
    -2147443169: "DSSCOM_ONETIER_MENU_VIEW",
    -2147443167: "DSSCOM_ONETIER_MENU_VIEW_DATASET_PANEL",
    -2147443166: "DSSCOM_ONETIER_MENU_VIEW_EDITOR_PANEL",
    -2147443164: "DSSCOM_ONETIER_MENU_VIEW_FILTER_PANEL",
    -2147442948: "DSSCOM_ONETIER_MENU_VIEW_FORMAT_PANEL",
    -2147443162: "DSSCOM_ONETIER_MENU_VIEW_PAGEBY_PANEL",
    -2147443165: "DSSCOM_ONETIER_MENU_VIEW_PROPERTIES_PANEL",
    -2147440625: "DSSCOM_ONETIER_MENU_VIEW_TOC_PANEL",
    -2147443163: "DSSCOM_ONETIER_MENU_VIEW_VIZ_GALLERY_PANEL",
    -2147443071: "DSSCOM_ONETIER_MENU_WINDOW",
    -2147443070: "DSSCOM_ONETIER_MENU_WINDOW_MINIMIZE",
    -2147443069: "DSSCOM_ONETIER_MENU_WINDOW_ZOOM",
    -2147442747: "DSSCOM_ONETIER_NO_USE_MSTR_DESKTOP_PRIVILEGE",
    -2147442742: "DSSCOM_ONETIER_NO_WRITE_WARNING",
    -2147442583: "DSSCOM_ONETIER_OLD_WS",
    -2147442558: "DSSCOM_ONETIER_PREFS_ASK",
    -2147442547: "DSSCOM_ONETIER_PREFS_AUTHREQUIRED",
    -2147442569: "DSSCOM_ONETIER_PREFS_CANCEL",
    -2147442566: "DSSCOM_ONETIER_PREFS_CHANGEAPPLY",
    -2147442570: "DSSCOM_ONETIER_PREFS_CHANGE_PROXY",
    -2147442572: "DSSCOM_ONETIER_PREFS_CHECKNOW",
    -2147442573: "DSSCOM_ONETIER_PREFS_CHECKUPDATES",
    -2147442567: "DSSCOM_ONETIER_PREFS_CHECKUPDATESAUTO",
    -2147442545: "DSSCOM_ONETIER_PREFS_CONNNAME",
    -2147442560: "DSSCOM_ONETIER_PREFS_CONNTYPE",
    -2147442546: "DSSCOM_ONETIER_PREFS_CREATE",
    -2147442551: "DSSCOM_ONETIER_PREFS_ENTERNEWNAME",
    -2147442577: "DSSCOM_ONETIER_PREFS_GENERAL",
    -2147442575: "DSSCOM_ONETIER_PREFS_LANGUAGE",
    -2147442554: "DSSCOM_ONETIER_PREFS_LOGIN",
    -2147442571: "DSSCOM_ONETIER_PREFS_NETWORK",
    -2147442552: "DSSCOM_ONETIER_PREFS_NEWNAME",
    -2147442574: "DSSCOM_ONETIER_PREFS_NUMFMT",
    -2147442568: "DSSCOM_ONETIER_PREFS_OK",
    -2147442555: "DSSCOM_ONETIER_PREFS_PWD",
    -2147442553: "DSSCOM_ONETIER_PREFS_RENAME",
    -2147442557: "DSSCOM_ONETIER_PREFS_SAVEDSUCCESS",
    -2147442548: "DSSCOM_ONETIER_PREFS_SAVEDWITHOUTTEST",
    -2147442576: "DSSCOM_ONETIER_PREFS_SERVER",
    -2147442565: "DSSCOM_ONETIER_PREFS_SERVERURL",
    -2147442559: "DSSCOM_ONETIER_PREFS_TESTSAVE",
    -2147442556: "DSSCOM_ONETIER_PREFS_UN",
    -2147442549: "DSSCOM_ONETIER_PREFS_UNABLECONNECT",
    -2147442550: "DSSCOM_ONETIER_PREFS_UNABLEVERIFY",
    -2147442564: "DSSCOM_ONETIER_PREFS_WSN",
    -2147442563: "DSSCOM_ONETIER_PREFS_WSP",
    -2147442562: "DSSCOM_ONETIER_PREFS_WSPATH",
    -2147442561: "DSSCOM_ONETIER_PREFS_WST",
    -2147440616: "DSSCOM_ONETIER_PROJECT_NOT_FOUND",
    -2147442749: "DSSCOM_ONETIER_PROXY_AUTH_REQUIRED",
    -2147440627: "DSSCOM_ONETIER_RECOVER_DASHBOARDNAME",
    -2147440626: "DSSCOM_ONETIER_RECOVER_LASTMODIFIED",
    -2147440630: "DSSCOM_ONETIER_RECOVER_MESSAGE",
    -2147440628: "DSSCOM_ONETIER_RECOVER_RECOVER",
    -2147440629: "DSSCOM_ONETIER_RECOVER_TITLE",
    -2147442580: "DSSCOM_ONETIER_REMOTE_DATASOURCE",
    -2147443144: "DSSCOM_ONETIER_REQUEST_SIZE_TOO_BIG",
    -2147443058: "DSSCOM_ONETIER_RESTORE_MSG",
    -2147443059: "DSSCOM_ONETIER_RESTORE_TITILE",
    -2147443179: "DSSCOM_ONETIER_RUN_MANIPULATION_ERROR",
    -2147442741: "DSSCOM_ONETIER_SAVE_CHANGES",
    -2147440611: "DSSCOM_ONETIER_SAVE_RECERTIFY",
    -2147442753: "DSSCOM_ONETIER_SERVER_PROJECT_ERROR",
    -2147443054: "DSSCOM_ONETIER_STR_RECOVERY",
    -2147443109: "DSSCOM_ONETIER_STR_VILOADFAILURE",
    -2147442754: "DSSCOM_ONETIER_SYSDEFAULT_FORMAT_ERROR",
    -2147442755: "DSSCOM_ONETIER_SYSDEFAULT_INIT_ERROR",
    -2147443156: "DSSCOM_ONETIER_TEXT_UNTITLED",
    -2147443174: "DSSCOM_ONETIER_UNIMPLETED_SERVICE_ERROR",
    -2147440610: "DSSCOM_ONETIER_VISUALIZATION_BUILDER",
    -2147440642: "DSSCOM_ONETIER_VIZ_DELETE_FAIL_ERROR",
    -2147440643: "DSSCOM_ONETIER_VIZ_DELETE_FAIL_NOTIFICATION",
    -2147443050: "DSSCOM_ONETIER_VIZ_DELETE_WARNING",
    -2147443072: "DSSCOM_ONETIER_WARING_DESC",
    -2147442751: "DSSCOM_ONETIER_WEBSERVER_AUTH_REQUIRED",
    -2147440646: "DSSCOM_ONETIER_WINDOW_ERROR",
    -2147443073: "DSSCOM_ONETIER_WINDOW_WARNING",
    -2147443180: "DSSCOM_ONETIER_XML_FORMAT_ERROR",
    -2147443181: "DSSCOM_ONETITER_JSON_REQUEST_ERROR",
    -2147440640: "DSSCOM_ONTTIER_UPDATE_TITLE",
    -2147440641: "DSSCOM_ONTTIER_VIZ_DELETE_EMPTYNAME_ERROR",
    -2147483331: "DSSCOM_STR_ADD",
    -2147481623: "DSSCOM_STR_ADD_DATA",
    -2147481622: "DSSCOM_STR_ADD_EXISTING_DATASET",
    -2147481621: "DSSCOM_STR_ADD_EXISTING_SCHEMA",
    -2147482712: "DSSCOM_STR_AGENT",
    -2147442538: "DSSCOM_STR_ALL_OTHERS",
    -2147481633: "DSSCOM_STR_AMOUNT",
    -2147481632: "DSSCOM_STR_AMOUNT_DESC",
    -2147468447: "DSSCOM_STR_BOOKMARK_ADDED",
    -2147468444: "DSSCOM_STR_BOOKMARK_DELETED",
    -2147468445: "DSSCOM_STR_BOOKMARK_RENAMED",
    -2147468446: "DSSCOM_STR_BOOKMARK_UPDATED",
    -2147441648: "DSSCOM_STR_BUILD_QUERY",
    -2147482677: "DSSCOM_STR_CHANGEJOURNALSEARCH",
    -2147482672: "DSSCOM_STR_CHANGE_JOURNAL",
    -2147483329: "DSSCOM_STR_COLLECTION",
    -2147481626: "DSSCOM_STR_COLUMNS",
    -2147441646: "DSSCOM_STR_CUSTOM_DATA",
    -2147441647: "DSSCOM_STR_CUSTOM_QUERY",
    -2147481624: "DSSCOM_STR_EDITOR",
    -2147481642: "DSSCOM_STR_EXCLUDING",
    -2147482671: "DSSCOM_STR_EXTERNAL_SHORTCUT",
    -2147482670: "DSSCOM_STR_EXTERNAL_SHORTCUT_TARGET",
    -2147481635: "DSSCOM_STR_FILTERDETAILS",
    -2147482673: "DSSCOM_STR_FLAG",
    -2147446781: "DSSCOM_STR_GOVERNING_MAX_ACTIVE_JOB_PER_USER",
    -2147446013: "DSSCOM_STR_GOVERNING_MAX_ACTIVE_JOB_PER_USER_DESC",
    -2147446780: "DSSCOM_STR_GOVERNING_MAX_ACTIVE_WH_JOB_PER_USER",
    -2147446012: "DSSCOM_STR_GOVERNING_MAX_ACTIVE_WH_JOB_PER_USER_DESC",
    -2147446784: "DSSCOM_STR_GOVERNING_MAX_ELAPSE_TIME",
    -2147446016: "DSSCOM_STR_GOVERNING_MAX_ELAPSE_TIME_DESC",
    -2147446778: "DSSCOM_STR_GOVERNING_MAX_FILE_SIZE_DATA_IMPORT",
    -2147446010: "DSSCOM_STR_GOVERNING_MAX_FILE_SIZE_DATA_IMPORT_DESC",
    -2147446782: "DSSCOM_STR_GOVERNING_MAX_MEMORY_RESULT_SETS",
    -2147446014: "DSSCOM_STR_GOVERNING_MAX_MEMORY_RESULT_SETS_DESC",
    -2147446774: "DSSCOM_STR_GOVERNING_MAX_NUMBER_HL_MSGS",
    -2147446006: "DSSCOM_STR_GOVERNING_MAX_NUMBER_HL_MSGS_DESC",
    -2147446779: "DSSCOM_STR_GOVERNING_MAX_QUOTA_FOR_DATA_IMPORT",
    -2147446011: "DSSCOM_STR_GOVERNING_MAX_QUOTA_FOR_DATA_IMPORT_DESC",
    -2147446775: "DSSCOM_STR_GOVERNING_MAX_RETENTION_TIME_HL",
    -2147446007: "DSSCOM_STR_GOVERNING_MAX_RETENTION_TIME_HL_DESC",
    -2147446776: "DSSCOM_STR_GOVERNING_MAX_SUB_PER_SCHEDULE",
    -2147446008: "DSSCOM_STR_GOVERNING_MAX_SUB_PER_SCHEDULE_DESC",
    -2147446777: "DSSCOM_STR_GOVERNING_MAX_SUB_PER_USER",
    -2147446009: "DSSCOM_STR_GOVERNING_MAX_SUB_PER_USER_DESC",
    -2147446783: "DSSCOM_STR_GOVERNING_MAX_WH_EXECUTE_TIME",
    -2147446015: "DSSCOM_STR_GOVERNING_MAX_WH_EXECUTE_TIME_DESC",
    -2147442542: "DSSCOM_STR_GROUP",
    -2147481634: "DSSCOM_STR_GROUPING",
    -2147481643: "DSSCOM_STR_INCLUDING",
    -2147481619: "DSSCOM_STR_INSERT_PANEL",
    -2147482668: "DSSCOM_STR_LAYER",
    -2147443201: "DSSCOM_STR_LINK_ATTRIBUTE_GEO_ROLES_NOT_SAME_FORM",
    -2147443198: "DSSCOM_STR_LINK_ATTRIBUTE_INCOMPATIBLE_DATA_TYPES",
    -2147443199: "DSSCOM_STR_LINK_ATTRIBUTE_INCOMPATIBLE_FORMS",
    -2147443197: "DSSCOM_STR_LINK_ATTRIBUTE_INCOMPATIBLE_GEO_ROLES",
    -2147443200: "DSSCOM_STR_LINK_ATTRIBUTE_MISSING_FORMS",
    -2147483346: "DSSCOM_STR_LOCALE",
    -2147481625: "DSSCOM_STR_METRICS",
    -2147477648: "DSSCOM_STR_MOVE_SHEET_TABS_TO_TOP",
    -2147482669: "DSSCOM_STR_MPPPROFILE",
    -2147482667: "DSSCOM_STR_PALETTE",
    -2147481620: "DSSCOM_STR_PANEL",
    -2147481638: "DSSCOM_STR_PROMPT_ALL",
    -2147481636: "DSSCOM_STR_PROMPT_NONE",
    -2147481646: "DSSCOM_STR_PROMPT_NOT_ANSWERED",
    -2147481637: "DSSCOM_STR_PROMPT_NO_SELECTION",
    -2147483330: "DSSCOM_STR_REMOVE",
    -2147481627: "DSSCOM_STR_ROWS",
    -2147443429: "DSSCOM_STR_SE_STOPWORDS",
    -2147450852: "DSSCOM_STR_SUBTYPEATTRIBUTEABSTRACT",
    -2147450854: "DSSCOM_STR_SUBTYPEATTRIBUTEROLE",
    -2147450853: "DSSCOM_STR_SUBTYPEATTRIBUTETRANSFORMATION",
    -2147450843: "DSSCOM_STR_SUBTYPECOLUMNCUSTOM",
    -2147450844: "DSSCOM_STR_SUBTYPECOLUMNNORMAL",
    -2147450880: "DSSCOM_STR_SUBTYPECUSTOMGROUP",
    -2147450840: "DSSCOM_STR_SUBTYPEDBTABLEPMT",
    -2147450850: "DSSCOM_STR_SUBTYPEDIMENSIONORDERED",
    -2147450851: "DSSCOM_STR_SUBTYPEDIMENSIONUSER",
    -2147450849: "DSSCOM_STR_SUBTYPEDIMENSIONUSERHIERARCHY",
    -2147450826: "DSSCOM_STR_SUBTYPEDOCUMENTTHEME",
    -2147450827: "DSSCOM_STR_SUBTYPEEXTERNALSHORTCUTSNAPSHOT",
    -2147450828: "DSSCOM_STR_SUBTYPEEXTERNALSHORTCUTURL",
    -2147450879: "DSSCOM_STR_SUBTYPEFILTERPARTITION",
    -2147450867: "DSSCOM_STR_SUBTYPEFOLDERSYSTEM",
    -2147450845: "DSSCOM_STR_SUBTYPEFORMNORMAL",
    -2147450846: "DSSCOM_STR_SUBTYPEFORMSYSTEM",
    -2147450855: "DSSCOM_STR_SUBTYPEFUNCTIONTHIRDPARTY",
    -2147450868: "DSSCOM_STR_SUBTYPEMETRICDMX",
    -2147450832: "DSSCOM_STR_SUBTYPEMETRICTRAINING",
    -2147450835: "DSSCOM_STR_SUBTYPEMONITORDBCONNECTIONS",
    -2147450837: "DSSCOM_STR_SUBTYPEMONITORJOBS",
    -2147450838: "DSSCOM_STR_SUBTYPEMONITORPERFORMANCE",
    -2147450836: "DSSCOM_STR_SUBTYPEMONITORUSERCONNECTIONS",
    -2147450834: "DSSCOM_STR_SUBTYPEPROMPTANSWER",
    -2147450833: "DSSCOM_STR_SUBTYPEPROMPTANSWERBOOLEAN",
    -2147450856: "DSSCOM_STR_SUBTYPEPROMPTBIGDECIMAL",
    -2147450866: "DSSCOM_STR_SUBTYPEPROMPTBOOLEAN",
    -2147450862: "DSSCOM_STR_SUBTYPEPROMPTDATE",
    -2147450857: "DSSCOM_STR_SUBTYPEPROMPTDIMTY",
    -2147450863: "DSSCOM_STR_SUBTYPEPROMPTDOUBLE",
    -2147450860: "DSSCOM_STR_SUBTYPEPROMPTELEMENTS",
    -2147450859: "DSSCOM_STR_SUBTYPEPROMPTEXPRESSION",
    -2147450858: "DSSCOM_STR_SUBTYPEPROMPTEXPRESSIONDRAFT",
    -2147450865: "DSSCOM_STR_SUBTYPEPROMPTLONG",
    -2147450861: "DSSCOM_STR_SUBTYPEPROMPTOBJECTS",
    -2147450864: "DSSCOM_STR_SUBTYPEPROMPTSTRING",
    -2147450874: "DSSCOM_STR_SUBTYPEREPORTBASE",
    -2147450871: "DSSCOM_STR_SUBTYPEREPORTCUBE",
    -2147450875: "DSSCOM_STR_SUBTYPEREPORTDATAMART",
    -2147450877: "DSSCOM_STR_SUBTYPEREPORTENGINE",
    -2147450878: "DSSCOM_STR_SUBTYPEREPORTGRAPH",
    -2147450873: "DSSCOM_STR_SUBTYPEREPORTGRIDANDGRAPH",
    -2147450831: "DSSCOM_STR_SUBTYPEREPORTINCREMENTALREFRESH",
    -2147450872: "DSSCOM_STR_SUBTYPEREPORTNONINTERACTIVE",
    -2147450876: "DSSCOM_STR_SUBTYPEREPORTTEXT",
    -2147450830: "DSSCOM_STR_SUBTYPEREPORTTRANSACTION",
    -2147450839: "DSSCOM_STR_SUBTYPEREPORTWRITINGDOCUMENT",
    -2147450841: "DSSCOM_STR_SUBTYPEROLETRANSFORMATION",
    -2147450829: "DSSCOM_STR_SUBTYPESEGMENTOBJECT",
    -2147450870: "DSSCOM_STR_SUBTYPESUBTOTALDEFINITION",
    -2147450869: "DSSCOM_STR_SUBTYPESYSTEMSUBTOTAL",
    -2147450848: "DSSCOM_STR_SUBTYPETABLEPARTITIONMD",
    -2147450847: "DSSCOM_STR_SUBTYPETABLEPARTITIONWH",
    -2147450842: "DSSCOM_STR_SUBTYPEUSERGROUP",
    -2147483384: "DSSCOM_STR_TYPEAGGMETRIC",
    -2147483379: "DSSCOM_STR_TYPEATTRIBUTE",
    -2147483370: "DSSCOM_STR_TYPEATTRIBUTEFORM",
    -2147482675: "DSSCOM_STR_TYPEBLOB",
    -2147483367: "DSSCOM_STR_TYPECATALOG",
    -2147483366: "DSSCOM_STR_TYPECATALOGDEFN",
    -2147483365: "DSSCOM_STR_TYPECOLUMN",
    -2147483355: "DSSCOM_STR_TYPECONFIGURATION",
    -2147483344: "DSSCOM_STR_TYPECONSOLIDATION",
    -2147483343: "DSSCOM_STR_TYPECONSOLIDATIONELEMENT",
    -2147482674: "DSSCOM_STR_TYPEDASHBOARDTEMPLATE",
    -2147483350: "DSSCOM_STR_TYPEDATAMART",
    -2147483375: "DSSCOM_STR_TYPEDATAMARTREPORT",
    -2147483360: "DSSCOM_STR_TYPEDBCONNECTION",
    -2147483361: "DSSCOM_STR_TYPEDBLOGIN",
    -2147483334: "DSSCOM_STR_TYPEDBMS",
    -2147483362: "DSSCOM_STR_TYPEDBROLE",
    -2147483338: "DSSCOM_STR_TYPEDBTABLE",
    -2147483382: "DSSCOM_STR_TYPEDEVICE",
    -2147483377: "DSSCOM_STR_TYPEDIMENSION",
    -2147443110: "DSSCOM_STR_TYPEDISTANCE",
    -2147483336: "DSSCOM_STR_TYPEDOCUMENTDEFINITION",
    -2147483335: "DSSCOM_STR_TYPEDRILLMAP",
    -2147483378: "DSSCOM_STR_TYPEFACT",
    -2147483374: "DSSCOM_STR_TYPEFACTGROUP",
    -2147482664: "DSSCOM_STR_TYPEFEATUREFLAG",
    -2147483390: "DSSCOM_STR_TYPEFILTER",
    -2147483383: "DSSCOM_STR_TYPEFOLDER",
    -2147483368: "DSSCOM_STR_TYPEFORMAT",
    -2147483345: "DSSCOM_STR_TYPEFORMATBAD",
    -2147483380: "DSSCOM_STR_TYPEFUNCTION",
    -2147483349: "DSSCOM_STR_TYPEFUNCTIONPACKAGEDEFINITION",
    -2147483357: "DSSCOM_STR_TYPEFUSER",
    -2147482678: "DSSCOM_STR_TYPEGRAPHSTYLE",
    -2147483339: "DSSCOM_STR_TYPELINK",
    -2147483333: "DSSCOM_STR_TYPEMDSECURITYFILTER",
    -2147483387: "DSSCOM_STR_TYPEMETRIC",
    -2147483371: "DSSCOM_STR_TYPEMONITOR",
    -2147482665: "DSSCOM_STR_TYPEPERSONALVIEW",
    -2147483359: "DSSCOM_STR_TYPEPROJECT",
    -2147483381: "DSSCOM_STR_TYPEPROMPT",
    -2147482680: "DSSCOM_STR_TYPEPROMPTANSWER",
    -2147482679: "DSSCOM_STR_TYPEPROMPTANSWERS",
    -2147483364: "DSSCOM_STR_TYPEPROPERTYGROUP",
    -2147483363: "DSSCOM_STR_TYPEPROPERTYSET",
    -2147483332: "DSSCOM_STR_TYPEQUALITY",
    -2147483388: "DSSCOM_STR_TYPEREPORTDEFN",
    -2147483354: "DSSCOM_STR_TYPEREQUEST",
    -2147482663: "DSSCOM_STR_TYPERESERVED18",
    -2147482662: "DSSCOM_STR_TYPERESERVED19",
    -2147483386: "DSSCOM_STR_TYPERESERVED2",
    -2147482661: "DSSCOM_STR_TYPERESERVED20",
    -2147482660: "DSSCOM_STR_TYPERESERVED21",
    -2147482659: "DSSCOM_STR_TYPERESERVED22",
    -2147482658: "DSSCOM_STR_TYPERESERVED23",
    -2147482657: "DSSCOM_STR_TYPERESERVED24",
    -2147483372: "DSSCOM_STR_TYPERESOLUTION",
    -2147483348: "DSSCOM_STR_TYPEROLE",
    -2147483342: "DSSCOM_STR_TYPESCHEDULEEVENT",
    -2147483341: "DSSCOM_STR_TYPESCHEDULEOBJECT",
    -2147483340: "DSSCOM_STR_TYPESCHEDULETRIGGER",
    -2147483369: "DSSCOM_STR_TYPESCHEMA",
    -2147483353: "DSSCOM_STR_TYPESCRIPT",
    -2147483352: "DSSCOM_STR_TYPESEARCH",
    -2147483351: "DSSCOM_STR_TYPESEARCHFOLDER",
    -2147483347: "DSSCOM_STR_TYPESECURITYROLE",
    -2147483358: "DSSCOM_STR_TYPESERVERDEF",
    -2147483373: "DSSCOM_STR_TYPESHORTCUT",
    -2147483385: "DSSCOM_STR_TYPESTYLE",
    -2147483376: "DSSCOM_STR_TYPETABLE",
    -2147483337: "DSSCOM_STR_TYPETABLESOURCE",
    -2147483389: "DSSCOM_STR_TYPETEMPLATE",
    -2147482666: "DSSCOM_STR_TYPETHRESHOLDS",
    -2147483356: "DSSCOM_STR_TYPETRANSMITTER",
    -2147483392: "DSSCOM_STR_TYPEUNKNOWN",
    -2147483391: "DSSCOM_STR_TYPE_START",
    -2147482822: "DSSCOM_STR_USER_OR_USERGROUP",
    -2147482651: "DSSCOM_STR_XSLNOSUPPORTED",
    -2147217356: "DSSCOM_UNSUPPORTED_ENCRYPTION_LEVEL",
    -2147442598: "DSSCOM_VERIFICATION_ATTR_BLOCKEND",
    -2147442640: "DSSCOM_VERIFICATION_ATTR_BLOCKI_RESERVED",
    -2147442641: "DSSCOM_VERIFICATION_ATTR_USERDBLOGIN",
    -2147442648: "DSSCOM_VERIFICATION_ATTR_USERGUID",
    -2147442644: "DSSCOM_VERIFICATION_ATTR_USERLDAPDN",
    -2147442642: "DSSCOM_VERIFICATION_ATTR_USERLDAPLogin",
    -2147442646: "DSSCOM_VERIFICATION_ATTR_USERLOGIN",
    -2147442647: "DSSCOM_VERIFICATION_ATTR_USERNAME",
    -2147442643: "DSSCOM_VERIFICATION_ATTR_USERSID",
    -2147442645: "DSSCOM_VERIFICATION_ATTR_USERUID",
    -2147442719: "DSSCOM_WSDESKTOP_BYPASS_SECURITY_FILTER",
    -2147442720: "DSSCOM_WSDESKTOP_LOCALE_CONFLICT",
    -2147442718: "DSSCOM_WSDESKTOP_PROMPT_NOT_SUPPOTED",
    -2147442721: "DSSCOM_WSDESKTOP_VIZ_DELETE_WARNING",
    -2147215102: "DSSRPTNET_E_NOINSTANCEPTR",
    -2147215100: "DSSRPTNET_E_NOMSGPTR",
    -2147215101: "DSSRPTNET_E_NOTCACHED",
    -2147215099: "DSSRPTNET_E_PENDING",
    -2147215098: "DSSRPTNET_E_PROMPTS",
    -2147209091: "DSSTIME_NOT_INITIALIZED",
    -2147468889: "DSS_REPORTCOMERROR2",
    -2147210361: "EE_CURL_ERROR",
    -2147210360: "EE_CURL_NOT_CONNECT",
    -2147210359: "EE_CURL_TIME_OUT",
    -2147210365: "EE_E_EXPORTJSONLENGTH",
    -2147210366: "EE_E_EXPORTOPTIONS",
    -2147472508: "EE_E_EXPORT_FAIL",
    -2147482615: "EE_INFO_PDF_COVERPAGE_COLUMNNUMBERNOTE",
    -2147482616: "EE_INFO_PDF_COVERPAGE_ROWNUMBERNOTE",
    -2147482618: "EE_INFO_PDF_INCREMENTALLYGENERATED",
    -2147482617: "EE_INFO_PDF_INCREMENTALLYGENERATEDANDPARTIALRESULT",
    -2147482619: "EE_INFO_PDF_PARTIALRESULT",
    -2147465472: "EE_MSG_EMPTYGRID",
    -2147210358: "EE_NEE_EXPORT_FAIL",
    -2147210363: "EE_NEWEE_EXPORT_FAIL",
    -2147210362: "EE_NEWEE_EXPORT_UNEXPECTED_ERROR",
    -2147482602: "EE_STR_EXCEL_OF",
    -2147482614: "EE_STR_EXCEL_PARTIAL_RESULT",
    -2147482604: "EE_STR_FLASH_WIDGETS_NOT_RENDERED",
    -2147482598: "EE_STR_HTML_PARTIAL_RESULT",
    -2147482620: "EE_STR_PDF_PARTIALRESULT_FONT",
    -2147482621: "EE_STR_PDF_PARTIALRESULT_NOTE",
    -2147482599: "EE_STR_PDF_TABLE_OF_CONTENTS",
    -2147214973: "ELENETSVR_E_COMMAND",
    -2147214976: "ELENETSVR_E_CORRUPT_HEADER",
    -2147214975: "ELENETSVR_E_LOAD_ELEMENT",
    -2147214974: "ELENETSVR_E_LOAD_ELEMENTS",
    -2147216639: "ELESVR_ERR_CACHEINSERT",
    -2147216636: "ELESVR_ERR_DIFFSOURCE",
    -2147216641: "ELESVR_ERR_HIRARCHY_NOT_SUPPORT",
    -2147216640: "ELESVR_ERR_NOATTRIBUTE",
    -2147216638: "ELESVR_ERR_REMOVEATTR",
    -2147216637: "ELESVR_ERR_RMVCOLLECTION",
    -2147213788: "ELESVR_E_PROMPT_FILTER",
    -2147216635: "ELESVR_E_SERVERSIDE",
    -2147213397: "ELESVR_E_UNSUPPORTED_SUBTYPE",
    -2147212446: "ELESVR_E_WRONG_SOURCETABLE_OR_SCHEMA",
    -2147479739: "ELES_C_COMPLETE",
    -2147479741: "ELES_C_FINDMATCHED_OBJECT",
    -2147479740: "ELES_C_LOG_HEADER",
    -2147217143: "ELES_E_FAILED",
    -2147211005: "ENGINE_ERROR_CANNOT_FIND_TABLE_IN_THE_OLD_CUBE",
    -2147211007: "ENGINE_ERROR_TOO_MANY_TABLE",
    -2147211006: "ENGINE_E_MULTITHREAD_ENTRY",
    -2147213303: "ENGINE_E_OBSOLETE_FUNC",
    -2147213301: "ENGINE_E_OUT_OF_MEMORY",
    -2147213302: "ENGINE_E_TERMINATED",
    -2147211008: "ENGINE_WARING_CROSS_JOIN",
    -2147206718: "ENGINE_WARNING_RESULT_TRUNC",
    -2147180907: "EXCEED_DOCINTERMDIATE_MAXIMUMROWS",
    -2147180900: "EXCEED_DOCINTERMDIATE_MAXIMUMROWS_DESKTOP_LOCAL",
    -2147180908: "EXCEED_DOCRESULT_MAXIMUMROWS",
    -2147217050: "EXP_ERR_BOTHNULL",
    -2147217051: "EXP_ERR_CIRCULARCOPY",
    -2147217048: "EXP_ERR_DIFFTREE",
    -2147217049: "EXP_ERR_EQUAL",
    -2147217047: "EXP_ERR_INVALIDTYPE",
    -2147217053: "EXP_ERR_LOSTLINK",
    -2147217052: "EXP_ERR_NOTARGET",
    -2147217046: "EXP_E_ROOT_EXIST",
    -2147209153: "E_ADD_STATS_FAILED",
    -2147209049: "E_BAD_DIAG_FLAG_VALUE",
    -2147205289: "E_CANNOT_INSTANTIATE_LICENSE",
    -2147205288: "E_CANNOT_LOCATE_LICENSE_FILE",
    -2147205287: "E_CANNOT_OPEN_LICENSE_FILE",
    -2147207933: "E_CAN_NOT_CLOSE_YOUR_OWN_SESSION",
    -2147072770: "E_CLIENT_SERVER_VERSION_INCOMPATIBLE",
    -2147206916: "E_CLUSTER_NOT_FOUND",
    -2147207877: "E_CONNECTIONMON_INIT_FAILED",
    -2147207872: "E_DATABASEADM_INIT_FAILED",
    -2147207873: "E_DATABASEMON_INIT_FAILED",
    -2147207874: "E_DBROLE_INIT_FAILED",
    -2147025891: "E_DESKTOP_CONNECTION_ERROR",
    -2147207887: "E_DSSJOBMGR_SERVER_DISCONNECTED",
    -2147208426: "E_DSSNET_BUFFER_TOO_SMALL",
    -2147208429: "E_DSSNET_GETBUF_FAILED",
    -2147208428: "E_DSSNET_PACK_FAILED",
    -2147208425: "E_DSSNET_SEEK_FAILED",
    -2147208427: "E_DSSNET_UNPACK_FAILED",
    -2147208424: "E_DSSNET_UNPACK_LOGMSG_FAILED",
    -2147207884: "E_DSSPROJINSTANCES_GETNAME_FAILED",
    -2147207885: "E_DSS_ENUMS_INIT_FAILED",
    -2147212335: "E_DSS_REPORT_TIMEOUT",
    -2147206917: "E_FAIL_INIT_CONNECTIONPOOL",
    -2147209156: "E_GETSTATS_SETTING_FAILED",
    -2147207875: "E_IDSSDATABASEMON_NOT_FOUND",
    -2147207879: "E_IDSSDBMON_DETAIL_NOT_INITIALIZED",
    -2147207878: "E_IDSSDBMON_NOT_FOUND",
    -2147207880: "E_IDSSDBMON_NOT_INITIALIZED",
    -2147207876: "E_IDSSDBROLEMON_NOT_FOUND",
    -2147072202: "E_ISERVER_CLOCK_SPEED_EXCEEDED",
    -2147073405: "E_ISERVER_DISABLED",
    -2147072559: "E_ISERVER_LICENCE_EXPIRED",
    -2147205286: "E_LICENSE_FEATURE_AUTHENTICATION_FAILED",
    -2147205284: "E_LICENSE_VERSION_OLD",
    -2147207881: "E_LOGROUTER_NOT_INIT",
    -2147207882: "E_LOGROUTER_REGISTRY",
    -2147209164: "E_MAX_JOBS_PER_PROJECT_ERROR",
    -2147209165: "E_MAX_JOBS_PER_PROJECT_EXCEEDED",
    -2147213296: "E_MODIFY_BETWEEN_SIMPLE_AND_OLAP",
    -2147207107: "E_MSIDBCPROVIDER_NOT_INITIALIZED",
    -2147202908: "E_MSIDBMGR_ACCOUNT_DELEGATION",
    -2147204459: "E_MSIDBMGR_AMBIGUOUS_CONN_MAP",
    -2147203537: "E_MSIDBMGR_AMBIGUOUS_CONN_MAP_PARAM",
    -2147206935: "E_MSIDBMGR_CFGMGR_RET_NULL_PROJ",
    -2147206936: "E_MSIDBMGR_DBC_LOADLMT_REACHED",
    -2147206947: "E_MSIDBMGR_DBC_NOT_FOUND",
    -2147206938: "E_MSIDBMGR_DBROLE_CONNLMT_REACHED",
    -2147206949: "E_MSIDBMGR_DBROLE_INT_NOT_FOUND",
    -2147206937: "E_MSIDBMGR_DBROLE_LOADLMT_REACHED",
    -2147206939: "E_MSIDBMGR_DBR_ALLDBCS_FULL",
    -2147206944: "E_MSIDBMGR_INIT_FAILED",
    -2147206943: "E_MSIDBMGR_INTERNAL_ERROR",
    -2147206948: "E_MSIDBMGR_INVALID_DBC",
    -2147206940: "E_MSIDBMGR_INV_DBC_DBMAP",
    -2147206941: "E_MSIDBMGR_INV_DBROLE_DBMAP",
    -2147206942: "E_MSIDBMGR_INV_SESSION_PTR",
    -2147206933: "E_MSIDBMGR_JOBSTRT_TIME_NOTSET",
    -2147206946: "E_MSIDBMGR_LOGCONN_NOT_FOUND",
    -2147206945: "E_MSIDBMGR_PHYCONN_NOT_FOUND",
    -2147206934: "E_MSIDBMGR_SQLSTRT_TIME_NOTSET",
    -2147207439: "E_MSINET_SIZE_TOO_SMALL",
    -2147209064: "E_MSIPU_MSISTATIONTASK_MSIEXCEPTION",
    -2147209065: "E_MSIPU_MSISTATIONTASK_SYSEXCEPTION",
    -2147207316: "E_MSIUSER_EMPTY_JOB",
    -2147207313: "E_MSIUSER_EMPTY_USERHANDLE",
    -2147207315: "E_MSIUSER_JOB_NOT_FOUND",
    -2147050188: "E_MSI_ACL_ERROR",
    -2147207424: "E_MSI_ADDTHREAD_FAILED",
    -2147207274: "E_MSI_ADD_DATA_VALUE_FAILED",
    -2147071801: "E_MSI_ATTRIBUTE_REMAPPING_FAIL_REPORT_SAVEAS",
    -2147207417: "E_MSI_AUTHENTICATION_ERROR",
    -2147207429: "E_MSI_BIND_FAIL",
    -2147207421: "E_MSI_BUFFER_TOO_SMALL",
    -2147180962: "E_MSI_CLIENTID_SECRET_NOFOUND",
    -2147205442: "E_MSI_CLUSTERING_NOT_AVAILABLE",
    -2147202924: "E_MSI_CLUSTER_COMMUNNICATION_MAY_FAIL",
    -2147071802: "E_MSI_CLUSTER_DATAPART_ID_NOT_FOUND",
    -2147202888: "E_MSI_CLUSTER_NO_WORKER_FOR_DATAPART",
    -2147206912: "E_MSI_CLUSTER_PROJECTS_NOT_MATCH",
    -2147206910: "E_MSI_CLUSTER_SERVER_ALREADY_IN",
    -2147206911: "E_MSI_CLUSTER_SERVER_JOIN_SELF",
    -2147206913: "E_MSI_CLUSTER_SERVER_NOT_FOUND",
    -2147207890: "E_MSI_COCREATE_DIAGMGR_FAILED",
    -2147207419: "E_MSI_CONNECT_FAILED",
    -2147204465: "E_MSI_CONNECT_HOSTDOWN_FAILURE",
    -2147209103: "E_MSI_CREATE_THREAD_FAILED",
    -2147208447: "E_MSI_CSINK_INIT_FAILED",
    -2147156975: "E_MSI_DOCUMENT_DATASET_MANIPULATION_NOT_SUPPORTED",
    -2147206914: "E_MSI_DSSCLUSTERS_INIT_FAILED",
    -2147208435: "E_MSI_DSSNET_AUTHENTICATION_ERROR",
    -2147208439: "E_MSI_DSSNET_CANT_CONNECT_TO_SERVER",
    -2147208438: "E_MSI_DSSNET_CANT_CONNECT_TO_WEBSERVER",
    -2147208434: "E_MSI_DSSNET_CANT_CREATE_LISTENER_THREAD",
    -2147208430: "E_MSI_DSSNET_WAIT_FAILED",
    -2147208436: "E_MSI_DSSNET_WEBSERVER_ERROR_OPEN_INI_FILE",
    -2147208437: "E_MSI_DSSNET_WEBSERVER_OFFLINE",
    -2147208440: "E_MSI_DSSNET_WRITE_FAILED",
    -2147208441: "E_MSI_DSSSERVERNET_GETBUF_FAILED",
    -2147208445: "E_MSI_DSSSERVERNET_NOT_CONNECTED",
    -2147208446: "E_MSI_DSSSERVERNET_NOT_INIT",
    -2147208444: "E_MSI_DSSSERVERNET_NULL_MSGPTR",
    -2147465054: "E_MSI_DUPLICATE_EMAIL",
    -2147465063: "E_MSI_EMAIL_EMPTY",
    -2147465061: "E_MSI_EMAIL_NOT_STRING",
    -2147465051: "E_MSI_EMPTY_COLUMNS",
    -2147209093: "E_MSI_EMPTY_FILENAME",
    -2147205247: "E_MSI_EMPTY_MSTR_FILE",
    -2147205248: "E_MSI_ERROR_COMPRESS_MSTR_FILE",
    -2147205249: "E_MSI_ERROR_DECOMPRESS_MSTR_FILE",
    -2147205241: "E_MSI_ERROR_DECOMPRESS_MSTR_FILE_NO_SPACE",
    -2147205239: "E_MSI_ERROR_IMPORT_NO_DATA_MSTR_IN_SERVER",
    -2147205232: "E_MSI_ERROR_MSTR_FILE_CHANGE_OLD_VERSION_HEADER",
    -2147205238: "E_MSI_ERROR_MSTR_FILE_CUBE_WITH_UNSUPPORT_OBJ",
    -2147205244: "E_MSI_ERROR_MSTR_FILE_DATASET_SIZE_EXCEED_MAXIMUM_CUBE_SETTING",
    -2147205233: "E_MSI_ERROR_MSTR_FILE_EXISTING_OBJ_MISSING",
    -2147205243: "E_MSI_ERROR_MSTR_FILE_FILTER_CONTAINS_EXTERNAL_OBJECT",
    -2147205242: "E_MSI_ERROR_MSTR_FILE_SAVING_FILE_FAILURE",
    -2147205234: "E_MSI_ERROR_MSTR_FILE_SMART_METRIC_WITH_FILTER",
    -2147205235: "E_MSI_ERROR_MSTR_FILE_UNSAFE_PATH_FOR_UNZIP_FILE",
    -2147205240: "E_MSI_ERROR_NO_DATA_EMMA_CUBE_FAIL",
    -2147049891: "E_MSI_FAILURE_BEFORE_JOB_CREATED",
    -2147207892: "E_MSI_GETCOMPNAME_FAILED",
    -2147209095: "E_MSI_GETLASTERR_FAILED",
    -2147207896: "E_MSI_GETSERVICE_FAILED",
    -2147207319: "E_MSI_GETUSERPROPS_FAILED",
    -2147208448: "E_MSI_IDSSSERVERNET_INVALIDPOINTER",
    -2147465057: "E_MSI_INCORRECT_DIRECTORY",
    -2147207893: "E_MSI_INVALID_ARGS",
    -2147465066: "E_MSI_INVALID_EMAIL_AND_NAME",
    -2147209098: "E_MSI_INVALID_MBCS_CHAR",
    -2147207888: "E_MSI_INVALID_SERVERADMIN",
    -2147207428: "E_MSI_INVA_SOCKET",
    -2147207897: "E_MSI_JOBINFO_NOT_AVAILABLE",
    -2147209161: "E_MSI_JOB_RUNING",
    -2147207426: "E_MSI_LISTEN_FAILED",
    -2147209107: "E_MSI_LOGGER_NOT_FOUND",
    -2147209102: "E_MSI_LOGRTR_REL_MUTEX_FAILED",
    -2147207275: "E_MSI_LOG_DATAVALUE_FAILED",
    -2147209105: "E_MSI_LOG_LEVEL_NOT_FOUND",
    -2147209166: "E_MSI_MAXCONNECTIONS_PER_PROJ_EXCEEDED",
    -2147207866: "E_MSI_MAXJOBS_PER_SERVER_EXCEEDED",
    -2147209053: "E_MSI_MAX_ACCTJOBS_EXCEEDED",
    -2147202906: "E_MSI_MAX_INTERACITVE_JOBS_PER_SERVER_EXCEEDED",
    -2147202904: "E_MSI_MAX_INTERACTIVE_JOBS_PER_PROJECT_EXCEEDED",
    -2147202902: "E_MSI_MAX_INTERACTIVE_JOBS_PER_USER_EXCEEDED",
    -2147209052: "E_MSI_MAX_PROJ_LOGIN_EXCEEDED",
    -2147072486: "E_MSI_MAX_PROJ_LOGIN_PERUSER_EXCEEDED",
    -2147202903: "E_MSI_MAX_SCHEDULED_JOBS_PER_PROJECT_EXCEEDED",
    -2147202905: "E_MSI_MAX_SCHEDULED_JOBS_PER_SERVER_EXCEEDED",
    -2147202901: "E_MSI_MAX_SCHEDULED_JOBS_PER_USER_EXCEEDED",
    -2147209054: "E_MSI_MAX_USERJOBS_EXCEEDED",
    -2147209096: "E_MSI_MBCS_CONVERSION_FAILED",
    -2147050197: "E_MSI_MISSING_EXTERNAL_SOURCE_ACCOUNT_ID",
    -2147209108: "E_MSI_MODULE_NOT_LOADED",
    -2147050189: "E_MSI_MPPMODE_UNMATCH",
    -2147209205: "E_MSI_MSIEXCEPTION",
    -2147208423: "E_MSI_MSTRONE_NONLOCAL_REQUEST",
    -2147465053: "E_MSI_NAME_EMPTY",
    -2147209094: "E_MSI_NEGATIVE_VALUE",
    -2147207436: "E_MSI_NEW_CONN_FAILED",
    -2147209104: "E_MSI_NO_LOGGER_FOUND",
    -2147205282: "E_MSI_NO_SERVER_AVAILABLE",
    -2147209149: "E_MSI_NO_TASKS_IN_PU",
    -2147207425: "E_MSI_NO_THREADPOOL",
    -2147209106: "E_MSI_NO_TRACE_NTEVENT",
    -2147207304: "E_MSI_NULL_AUTHSERVER_PTR",
    -2147207305: "E_MSI_NULL_CONFIG_PTR",
    -2147207438: "E_MSI_NULL_ELEMENT",
    -2147207302: "E_MSI_NULL_SERVEROBJECTSOURCE_PTR",
    -2147207303: "E_MSI_NULL_SERVERSESSION_PTR",
    -2147207427: "E_MSI_PORT_IN_USE",
    -2147465055: "E_MSI_PREDICATE_INCOMPATIBLE_WITH_BASEFORM_TYPE",
    -2147465056: "E_MSI_PREDICATE_MISUSE_ESCAPE",
    -2147203638: "E_MSI_PROJECT_DELETED",
    -2147209048: "E_MSI_PROJECT_LOAD_OFFLINEPENDING",
    -2147209151: "E_MSI_PROJECT_NOT_FOUND",
    -2147209183: "E_MSI_PROJECT_OFFLINE",
    -2147209150: "E_MSI_PROJECT_TO_REGISTER_NOT_OFFLINE",
    -2147209148: "E_MSI_PU_NOT_FOUND",
    -2147208433: "E_MSI_READFROM_CHANNEL_FAILED",
    -2147207423: "E_MSI_READ_ERROR",
    -2147208432: "E_MSI_RECEIVE_PROTOCOL_ERR",
    -2147207276: "E_MSI_RECURRENT_TASK_FAIL",
    -2147202857: "E_MSI_RETRIEVE_REFRESH_TOKEN_FAILED",
    -2147465064: "E_MSI_ROLE_EMPTY",
    -2147465062: "E_MSI_ROLE_NOT_STRING",
    -2147207273: "E_MSI_ROW_NOTFOUND",
    -2147208431: "E_MSI_SENDRECEIVE_PROTOCOL_ERROR",
    -2147207900: "E_MSI_SERVERADMIN_STATS_INVALID_PTR",
    -2147071815: "E_MSI_SERVER_DATAPARTID_NOT_EXIST",
    -2147071790: "E_MSI_SERVER_MEMBER_NOT_EXIST",
    -2146944575: "E_MSI_SERVER_STARTING",
    -2147207901: "E_MSI_SERVICEMGR_COCREATE_FAILED",
    -2147207891: "E_MSI_SERVICE_FAILURE_REMOTE_MACHINE",
    -2147207895: "E_MSI_SERVICE_NOTINSTALLED",
    -2147207894: "E_MSI_SERVICE_REGERROR",
    -2147156455: "E_MSI_SESSION_UNINTIALIZED",
    -2147208442: "E_MSI_SETCOOKIE_FAILED",
    -2147208443: "E_MSI_SETHEADER_FAILED",
    -2147207317: "E_MSI_SETUSERPROP_FAILED",
    -2147207420: "E_MSI_SOCKET_ERROR",
    -2147207889: "E_MSI_STARTSERVICE_FAILED",
    -2147071827: "E_MSI_STATSFORMAT_UNSUPPORTED",
    -2147207320: "E_MSI_TOUCHUSER_FAILED",
    -2147207418: "E_MSI_UNKNOWN_HOST",
    -2147207437: "E_MSI_UNPACKBINARYSIZE_FAILED",
    -2147209157: "E_MSI_UNPACK_STATS_DATAID",
    -2147209162: "E_MSI_UNPACK_STATS_MODULE",
    -2147465065: "E_MSI_UNRECOGNIZABLE_ROLE",
    -2147205245: "E_MSI_UNSUPPORTED_DASHBOARD_BY_CURRENT_MAD",
    -2147205246: "E_MSI_UNSUPPORTED_DASHBOARD_TYPE_TO_IMPORT",
    -2147207314: "E_MSI_UPDATESTATS_FAILED",
    -2147207318: "E_MSI_USERCONNECTION_NOT_FOUND",
    -2147207309: "E_MSI_USERMGR_ADDJOB_FAILED",
    -2147207310: "E_MSI_USERMGR_EMPTY_AUTHSERVER",
    -2147207322: "E_MSI_USERMGR_LOGIN_FAILED",
    -2147207323: "E_MSI_USERMGR_LOGOUT_FAILED",
    -2147209055: "E_MSI_USERMGR_MAXEXECUTINGJOBS_EXCEEDED",
    -2147209056: "E_MSI_USERMGR_MAX_SERVERUSERS_EXCEEDED",
    -2147207308: "E_MSI_USERMGR_REMOVEJOB_FAILED",
    -2147209210: "E_MSI_USERMGR_SIGNIN_ERROR",
    -2147207306: "E_MSI_USERMGR_USER_ALREADY_LOGGED_OUT",
    -2147209051: "E_MSI_USERMGR_USER_NOTFOUND",
    -2147207307: "E_MSI_USERMGR_USER_PROJ_NOT_FOUND",
    -2147202875: "E_MSI_USERRUNTIME_REFRESH_TOKEN_NOFOUND",
    -2147207898: "E_MSI_USERSESSION_INIT_FAILED",
    -2147209101: "E_MSI_WAIT_FOR_OBJ_FAILED",
    -2147209097: "E_MSI_WCHAR_CONVERSION_FAILED",
    -2147207422: "E_MSI_WRITE_ERROR",
    -2147468987: "E_MSI_XML_PROFILE_NOTEXISING",
    -2147071828: "E_MSI_XML_STATSMGR_NOTRUN",
    -2147209160: "E_MSI_XML_SYNTAX_ERROR",
    -2147468988: "E_MSI_XML_UNKNOWN_FOLDERNAME",
    -2147202269: "E_MSI_XML_UNSUPPORTED_CERTIFY_ATTRIBUTE",
    -2147211911: "E_NO_AVALIABLE_PROJECT",
    -2147206812: "E_NO_CONNECTION_FOUND",
    -2147216618: "E_NO_DEFAULT_CATALOG_DEFN",
    -2147206811: "E_NO_MEMBERSHIP_INFO",
    -2147209155: "E_NULL_STATS_MGR_PTR",
    -2147207902: "E_PROJINSTANCE_INIT_FAILED",
    -2147209154: "E_PURGESTATS_FAILED",
    -2147072203: "E_PURGESTATS_NOSTATSMGR",
    -2147206808: "E_RESPONSE_OBJECT_NOT_FOUND",
    -2147072771: "E_SERIALIZATION_FAILED",
    -2147207899: "E_SERVERADMIN_STATS_SERVER_DISCONNECTED",
    -2147206814: "E_SERVER_BUSY",
    -2147206810: "E_SERVER_OUT_CLUSTER",
    -2147207883: "E_SERVICE_WIN95_NOT_SUPPORTED",
    -2147074223: "E_SPACE_NOT_ENOUGH",
    -2147072255: "E_STATS_DISABLED",
    -2147071813: "E_STATS_SERVER_SHUTTINGDOWN",
    -2147205285: "E_SYSTEM_TIMER_MODIFIED",
    -2147209081: "E_TPSERIES_MBR_IS_RECURRENT",
    -2147209082: "E_TPSERIES_MBR_NOT_RECURRENT",
    -2147209080: "E_TPSERIES_RECURRENCE_ILLEGAL",
    -2147209079: "E_TSERIES_INCONSISTENT",
    -2147207867: "E_UNKNOWN_AUTHENTICATION_MODE",
    -2147209050: "E_UNKNOWN_DIAG_FLAG",
    -2147211912: "E_USER_HAS_NO_ACCESSIBLE_PROJECT",
    -2147025889: "E_USHER_REG_DISABLED",
    -2147025888: "E_USHER_REG_FAIL",
    -2147025890: "E_USHER_REG_INVALID_EMAIL",
    -2147206813: "E_WAIT_FOR_CONNECTION_FAILED",
    -2147049889: "E_WRAP_SEC_E_ACCESS_DENIED",
    -2147213307: "Engine_E_INDEX_OUTOFRANGE",
    -2147213311: "Engine_E_INTERNAL_ERROR",
    -2147213308: "Engine_E_METHOD_NOTSUPPORT",
    -2147213304: "Engine_E_NOTINITIALIZED",
    -2147213306: "Engine_E_OBJECT_DELETED",
    -2147213309: "Engine_E_PROPERTY_NOTSUPPORT",
    -2147213305: "Engine_E_REINITIALIZATION",
    -2147213310: "Engine_E_UNKNOWN_EXCEPTION",
    -2147204417: "FF_E_UNEXPECTED_EMPTY_RESULT",
    -2147211914: "FILE_IMPORT_UNDEFINED_DATATYPE_ERROR",
    -2147217044: "FOLDER_ERR_UNKNOWNTYPE",
    -2147217042: "FOLDER_E_DUPLICATENAME",
    -2147217043: "FOLDER_E_DUPLICATEOBJECT",
    -2147217041: "FOLDER_E_NOTFOUND",
    -2147211769: "FUNC_E_BAD_PARAMETER_COUNT",
    -2147211776: "FUNC_E_BAD_PARAM_COUNT",
    -2147211768: "FUNC_E_DIVIDEDBYZERO",
    -2147211774: "FUNC_E_DOMAIN_ERROR",
    -2147211770: "FUNC_E_INTERNAL",
    -2147211772: "FUNC_E_INVALID_PROPERTY",
    -2147211773: "FUNC_E_RANGE_ERROR",
    -2147211775: "FUNC_E_TYPE_MISMATCH",
    -2147211767: "FUNC_E_UNKNOWN_FUNCTION",
    -2147211771: "FUNC_E_UNSPECIFIED",
    -2147459047: "GENERICS_TAG_CANCELED_PROMPTS",
    -2147459055: "GENERICS_TAG_COLLECTION",
    -2147459326: "GENERICS_TAG_CUSTOM_OBJECT_ALIAS",
    -2147459327: "GENERICS_TAG_CUSTOM_OBJECT_DESCRIPTION",
    -2147459323: "GENERICS_TAG_CUSTOM_OBJECT_LONG_DESCRIPTION",
    -2147459328: "GENERICS_TAG_CUSTOM_OBJECT_NAME",
    -2147459324: "GENERICS_TAG_CUSTOM_PROMPT_DESCRIPTION",
    -2147459325: "GENERICS_TAG_CUSTOM_PROMPT_TITLE",
    -2147459267: "GENERICS_TAG_HR_ANNOTATION",
    -2147459319: "GENERICS_TAG_HR_ATTR_FORM_DESC",
    -2147459320: "GENERICS_TAG_HR_ATTR_FORM_NAME",
    -2147459321: "GENERICS_TAG_HR_ATTR_FORM_WRAPPER_DESC",
    -2147459322: "GENERICS_TAG_HR_ATTR_FORM_WRAPPER_NAME",
    -2147458783: "GENERICS_TAG_HR_COMMENT",
    -2147459296: "GENERICS_TAG_HR_DOCUMENT_SUBTOTAL_NAME",
    -2147459272: "GENERICS_TAG_HR_DOCUMENT_VIEW_NAME",
    -2147459316: "GENERICS_TAG_HR_DRILL_PATH_CLA_STRING",
    -2147459317: "GENERICS_TAG_HR_DRILL_PATH_DESC",
    -2147459318: "GENERICS_TAG_HR_DRILL_PATH_NAME",
    -2147459293: "GENERICS_TAG_HR_EXTENSION_DESC",
    -2147459294: "GENERICS_TAG_HR_EXTENSION_NAME",
    -2147442539: "GENERICS_TAG_HR_FEATUREFLAG_DISCLAIMER",
    -2147459313: "GENERICS_TAG_HR_GRAPH_FOOT_NOTE",
    -2147459311: "GENERICS_TAG_HR_GRAPH_SERIES_TITLE",
    -2147459314: "GENERICS_TAG_HR_GRAPH_SUBTITLE",
    -2147459315: "GENERICS_TAG_HR_GRAPH_TITLE",
    -2147459312: "GENERICS_TAG_HR_GRAPH_XTITLE",
    -2147459310: "GENERICS_TAG_HR_GRAPH_Y1_TITLE",
    -2147459308: "GENERICS_TAG_HR_GRAPH_Y2_METRIC_LABEL",
    -2147459309: "GENERICS_TAG_HR_GRAPH_Y2_TITLE",
    -2147459307: "GENERICS_TAG_HR_GRAPH_Y3_METRIC_LABEL",
    -2147459306: "GENERICS_TAG_HR_GRAPH_Y4_METRIC_LABEL",
    -2147459278: "GENERICS_TAG_HR_HYPERLINK_NAME",
    -2147459305: "GENERICS_TAG_HR_NODE_NAME",
    -2147459269: "GENERICS_TAG_HR_NODE_PLACEHOLDER_NAME",
    -2147459301: "GENERICS_TAG_HR_OBJECT_ALIAS",
    -2147459302: "GENERICS_TAG_HR_OBJECT_DESCRIPTION",
    -2147459303: "GENERICS_TAG_HR_OBJECT_NAME",
    -2147459277: "GENERICS_TAG_HR_PROJECT_CONFIDENTIALITY_TEXT",
    -2147459299: "GENERICS_TAG_HR_PROMPT_DESC",
    -2147459300: "GENERICS_TAG_HR_PROMPT_TITLE",
    -2147459298: "GENERICS_TAG_HR_RWFEILD_NODE_VALUE",
    -2147459280: "GENERICS_TAG_HR_RWNODE_CONTROL_ALLALIAS",
    -2147443440: "GENERICS_TAG_HR_RWNODE_CONTROL_DISPLAY_TEXT",
    -2147443441: "GENERICS_TAG_HR_RWNODE_CONTROL_SUBSEQUENT_DISPLAY_MESSAGE",
    -2147459273: "GENERICS_TAG_HR_RWNODE_CONTROL_TITLE",
    -2147459279: "GENERICS_TAG_HR_RWNODE_CONTROL_TOOLTIP",
    -2147459285: "GENERICS_TAG_HR_RWNODE_NAME",
    -2147459284: "GENERICS_TAG_HR_RWNODE_TITLE",
    -2147459283: "GENERICS_TAG_HR_RWNODE_TOOLTIP",
    -2147459275: "GENERICS_TAG_HR_RW_FIELD_HTML",
    -2147459274: "GENERICS_TAG_HR_RW_FIELD_HYPERLINK",
    -2147459282: "GENERICS_TAG_HR_RW_FIELD_NAME",
    -2147459281: "GENERICS_TAG_HR_RW_FIELD_TOOLTIP",
    -2147459276: "GENERICS_TAG_HR_RW_FIELD_URL",
    -2147459304: "GENERICS_TAG_HR_SHORTCUT_TARGET_NAME",
    -2147459268: "GENERICS_TAG_HR_STOP_WORDS",
    -2147459297: "GENERICS_TAG_HR_STRING_PARAM_ITEM_CONST",
    -2147459292: "GENERICS_TAG_HR_TEMPLATE_METRIC_ALIAS",
    -2147459295: "GENERICS_TAG_HR_TEMPLATE_SUBTOTAL_NAME",
    -2147459287: "GENERICS_TAG_HR_TEMPLATE_UNIT_ALIAS",
    -2147459291: "GENERICS_TAG_HR_THRESHOLD_NAME",
    -2147459290: "GENERICS_TAG_HR_THRESHOLD_PREFIX",
    -2147459288: "GENERICS_TAG_HR_THRESHOLD_REPLACE_STRING",
    -2147459289: "GENERICS_TAG_HR_THRESHOLD_SUFFIX",
    -2147459271: "GENERICS_TAG_HR_UNIT_INFO_ALIAS",
    -2147459270: "GENERICS_TAG_HR_UNIT_INFO_COMMENT",
    -2147459286: "GENERICS_TAG_HR_WIDGETS_MULTILINGUAL_STRING",
    -2147459050: "GENERICS_TAG_MULTILINGUAL_STRING",
    -2147459071: "GENERICS_TAG_NONE",
    -2147459053: "GENERICS_TAG_OBJECT_WITH_PROMPTS",
    -2147459051: "GENERICS_TAG_PROMPT_ANSWERS",
    -2147459056: "GENERICS_TAG_REFERENCE",
    -2147459054: "GENERICS_TAG_REFERENCES",
    -2147459052: "GENERICS_TAG_REPORTSOURCE",
    -2147459072: "GENERICS_TAG_RESERVED",
    -2147459073: "GENERICS_TAG_RESERVES",
    -2147459070: "GENERICS_TAG_ROOT",
    -2147459022: "GENERICS_TAG_ROOT_STAND_ALONE",
    -2147458964: "GENERICS_TAG_STRUCTURE_ATTR_DEFN",
    -2147458869: "GENERICS_TAG_STRUCTURE_ATTR_FORMS",
    -2147458867: "GENERICS_TAG_STRUCTURE_ATTR_FORMWRAPS",
    -2147458972: "GENERICS_TAG_STRUCTURE_ATTR_INFO",
    -2147458864: "GENERICS_TAG_STRUCTURE_ATTR_INFOS",
    -2147458969: "GENERICS_TAG_STRUCTURE_ATTR_RELATIONSHIP",
    -2147459021: "GENERICS_TAG_STRUCTURE_AXIS",
    -2147458974: "GENERICS_TAG_STRUCTURE_BASE_ATTR_FORM",
    -2147458973: "GENERICS_TAG_STRUCTURE_BASE_ATTR_FORMS",
    -2147458941: "GENERICS_TAG_STRUCTURE_BASE_ELEMENTS_PROXY",
    -2147458940: "GENERICS_TAG_STRUCTURE_BASE_ELEMENT_PROXY",
    -2147459024: "GENERICS_TAG_STRUCTURE_BEGIN",
    -2147456000: "GENERICS_TAG_STRUCTURE_BROWSER",
    -2147458800: "GENERICS_TAG_STRUCTURE_CHANGE_JOURNAL",
    -2147458793: "GENERICS_TAG_STRUCTURE_CHANGE_JOURNAL_COMMENTS",
    -2147458798: "GENERICS_TAG_STRUCTURE_CHANGE_JOURNAL_ENTRY",
    -2147458794: "GENERICS_TAG_STRUCTURE_CHANGE_JOURNAL_LINK_ITEM_ENTRY",
    -2147458795: "GENERICS_TAG_STRUCTURE_CHANGE_JOURNAL_LINK_ITEM_LIST",
    -2147458799: "GENERICS_TAG_STRUCTURE_CHANGE_JOURNAL_LIST",
    -2147458796: "GENERICS_TAG_STRUCTURE_CHANGE_JOURNAL_OBJECT_ENTRY",
    -2147458797: "GENERICS_TAG_STRUCTURE_CHANGE_JOURNAL_OBJECT_LIST",
    -2147458906: "GENERICS_TAG_STRUCTURE_COLUMNS",
    -2147455744: "GENERICS_TAG_STRUCTURE_COMMENTS",
    -2147458958: "GENERICS_TAG_STRUCTURE_CONDITIONALITY",
    -2147458901: "GENERICS_TAG_STRUCTURE_CUSTOM_SQL",
    -2147458900: "GENERICS_TAG_STRUCTURE_CUSTOM_SQLCOLUMN",
    -2147458910: "GENERICS_TAG_STRUCTURE_CUSTOM_SUBTOTAL",
    -2147458909: "GENERICS_TAG_STRUCTURE_CUSTOM_SUBTOTALS",
    -2147458911: "GENERICS_TAG_STRUCTURE_DATAMART_COLUMN",
    -2147458942: "GENERICS_TAG_STRUCTURE_DATAMART_UNIT",
    -2147458894: "GENERICS_TAG_STRUCTURE_DATA_ELEMENT",
    -2147458895: "GENERICS_TAG_STRUCTURE_DATA_ELEMENTS",
    -2147458871: "GENERICS_TAG_STRUCTURE_DBTABLE_KEY",
    -2147458870: "GENERICS_TAG_STRUCTURE_DBTABLE_KEYS",
    -2147455872: "GENERICS_TAG_STRUCTURE_DEFINITION",
    -2147458842: "GENERICS_TAG_STRUCTURE_DELIVERY_SECTION",
    -2147458843: "GENERICS_TAG_STRUCTURE_DELIVERY_SECTIONS",
    -2147458784: "GENERICS_TAG_STRUCTURE_DERIVEDELEMENTS",
    -2147458975: "GENERICS_TAG_STRUCTURE_DIMTY",
    -2147458976: "GENERICS_TAG_STRUCTURE_DIMTY_UNIT",
    -2147458863: "GENERICS_TAG_STRUCTURE_DIM_INFO",
    -2147458862: "GENERICS_TAG_STRUCTURE_DIM_INFOS",
    -2147458970: "GENERICS_TAG_STRUCTURE_DIRECTED_ATTR",
    -2147458880: "GENERICS_TAG_STRUCTURE_DIRECTED_GRAPH",
    -2147458968: "GENERICS_TAG_STRUCTURE_DRILLPATH",
    -2147458907: "GENERICS_TAG_STRUCTURE_DRILL_ACTION",
    -2147458929: "GENERICS_TAG_STRUCTURE_ELEMENT_BAND",
    -2147458939: "GENERICS_TAG_STRUCTURE_ELEMENT_CONCRETE",
    -2147458933: "GENERICS_TAG_STRUCTURE_ELEMENT_CONSOLIDATION",
    -2147458931: "GENERICS_TAG_STRUCTURE_ELEMENT_CUSTOM_GROUP",
    -2147458934: "GENERICS_TAG_STRUCTURE_ELEMENT_DIMENSION",
    -2147458926: "GENERICS_TAG_STRUCTURE_ELEMENT_END",
    -2147458932: "GENERICS_TAG_STRUCTURE_ELEMENT_FILTER",
    -2147458936: "GENERICS_TAG_STRUCTURE_ELEMENT_FIRST",
    -2147458930: "GENERICS_TAG_STRUCTURE_ELEMENT_JOINT",
    -2147458935: "GENERICS_TAG_STRUCTURE_ELEMENT_LAST",
    -2147458938: "GENERICS_TAG_STRUCTURE_ELEMENT_METRIC",
    -2147458928: "GENERICS_TAG_STRUCTURE_ELEMENT_RESIDUE",
    -2147458927: "GENERICS_TAG_STRUCTURE_ELEMENT_SUBEXPRESSION",
    -2147458937: "GENERICS_TAG_STRUCTURE_ELEMENT_SUBTOTAL",
    -2147450881: "GENERICS_TAG_STRUCTURE_END",
    -2147459007: "GENERICS_TAG_STRUCTURE_EXPRESSION",
    -2147458962: "GENERICS_TAG_STRUCTURE_EXPR_IMPL",
    -2147458966: "GENERICS_TAG_STRUCTURE_EXTENSION",
    -2147458956: "GENERICS_TAG_STRUCTURE_EXTENSIONS",
    -2147458965: "GENERICS_TAG_STRUCTURE_EXTENSION_UNIT",
    -2147458967: "GENERICS_TAG_STRUCTURE_FACTINFO",
    -2147458963: "GENERICS_TAG_STRUCTURE_FACTINFOS",
    -2147458996: "GENERICS_TAG_STRUCTURE_FERTILE_NODE",
    -2147458971: "GENERICS_TAG_STRUCTURE_FORMWRAP",
    -2147458905: "GENERICS_TAG_STRUCTURE_FUNCTIONS",
    -2147458876: "GENERICS_TAG_STRUCTURE_GRAPH_EDGE",
    -2147458878: "GENERICS_TAG_STRUCTURE_GRAPH_ENDNODE",
    -2147458877: "GENERICS_TAG_STRUCTURE_GRAPH_NODE",
    -2147458879: "GENERICS_TAG_STRUCTURE_GRAPH_NODEMAP",
    -2147458874: "GENERICS_TAG_STRUCTURE_GROUPBY_UNIT",
    -2147458875: "GENERICS_TAG_STRUCTURE_GROUPBY_UNITS",
    -2147458840: "GENERICS_TAG_STRUCTURE_LOCALIZED_DBCONNECTION",
    -2147458912: "GENERICS_TAG_STRUCTURE_MAP_TO_TARGET",
    -2147458859: "GENERICS_TAG_STRUCTURE_MDXSAPVAR_INFO",
    -2147458903: "GENERICS_TAG_STRUCTURE_MDX_COLUMN",
    -2147458904: "GENERICS_TAG_STRUCTURE_MDX_CUBE",
    -2147458898: "GENERICS_TAG_STRUCTURE_MDX_DIMENSION",
    -2147458899: "GENERICS_TAG_STRUCTURE_MDX_DIMENSIONS",
    -2147458897: "GENERICS_TAG_STRUCTURE_MDX_HIERARCHIES",
    -2147458896: "GENERICS_TAG_STRUCTURE_MDX_HIERARCHY",
    -2147458861: "GENERICS_TAG_STRUCTURE_MDX_SAPVARIABLE",
    -2147458860: "GENERICS_TAG_STRUCTURE_MDX_SAPVARIABLES",
    -2147458858: "GENERICS_TAG_STRUCTURE_MDX_SAPVAR_INFOS",
    -2147458857: "GENERICS_TAG_STRUCTURE_MDX_SAPVAR_SHELL",
    -2147458856: "GENERICS_TAG_STRUCTURE_MDX_SAPVAR_SHELLS",
    -2147458902: "GENERICS_TAG_STRUCTURE_MDX_SHAREDOBJECTS",
    -2147458866: "GENERICS_TAG_STRUCTURE_METRICINFO",
    -2147458865: "GENERICS_TAG_STRUCTURE_METRICINFOS",
    -2147458893: "GENERICS_TAG_STRUCTURE_METRICS",
    -2147459009: "GENERICS_TAG_STRUCTURE_METRIC_SUBTOTAL",
    -2147459008: "GENERICS_TAG_STRUCTURE_METRIC_SUBTOTALS",
    -2147455745: "GENERICS_TAG_STRUCTURE_MULTILINGUAL_COMMENTS",
    -2147459006: "GENERICS_TAG_STRUCTURE_NODE",
    -2147458990: "GENERICS_TAG_STRUCTURE_NODE_CELL_FORMAT_DATA",
    -2147459003: "GENERICS_TAG_STRUCTURE_NODE_CONSTANT",
    -2147459004: "GENERICS_TAG_STRUCTURE_NODE_ELEMENTS",
    -2147459005: "GENERICS_TAG_STRUCTURE_NODE_FORM_SHORTCUT",
    -2147458992: "GENERICS_TAG_STRUCTURE_NODE_GROUP",
    -2147458997: "GENERICS_TAG_STRUCTURE_NODE_ME",
    -2147459002: "GENERICS_TAG_STRUCTURE_NODE_OPERATOR",
    -2147458991: "GENERICS_TAG_STRUCTURE_NODE_REFERENCE",
    -2147458999: "GENERICS_TAG_STRUCTURE_NODE_RELATIONSHIP",
    -2147458989: "GENERICS_TAG_STRUCTURE_NODE_RESERVED1",
    -2147458988: "GENERICS_TAG_STRUCTURE_NODE_RESERVED2",
    -2147458998: "GENERICS_TAG_STRUCTURE_NODE_RESIDUE",
    -2147459001: "GENERICS_TAG_STRUCTURE_NODE_SHORTCUT",
    -2147458993: "GENERICS_TAG_STRUCTURE_NODE_SQL_COLUMN_SHORTCUT",
    -2147458994: "GENERICS_TAG_STRUCTURE_NODE_SQL_QUERY_COLUMN_SHORTCUT",
    -2147459000: "GENERICS_TAG_STRUCTURE_NODE_TIME",
    -2147458792: "GENERICS_TAG_STRUCTURE_OBJECT_REFERENCE",
    -2147458791: "GENERICS_TAG_STRUCTURE_OBJECT_REFERENCES",
    -2147458961: "GENERICS_TAG_STRUCTURE_OLAPSORTS",
    -2147458868: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_BIGDEC",
    -2147458922: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_DIMTY",
    -2147458921: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_DOUBLE",
    -2147458920: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_ELEMENTS",
    -2147458919: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_EXPRESSION",
    -2147458918: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_FOLDER",
    -2147458917: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_LONG",
    -2147458916: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_OBJECT",
    -2147458915: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_STRING",
    -2147458914: "GENERICS_TAG_STRUCTURE_PROMPTVALUE_TIME",
    -2147458855: "GENERICS_TAG_STRUCTURE_PROMPT_ANSWER",
    -2147458925: "GENERICS_TAG_STRUCTURE_PROMPT_INSTANCE",
    -2147458924: "GENERICS_TAG_STRUCTURE_PROMPT_INSTANCES",
    -2147458913: "GENERICS_TAG_STRUCTURE_PROMPT_QUESTION",
    -2147458943: "GENERICS_TAG_STRUCTURE_PROMPT_VALUE",
    -2147458923: "GENERICS_TAG_STRUCTURE_PROMPT_VALUES",
    -2147458957: "GENERICS_TAG_STRUCTURE_RELATIONSHIP",
    -2147458955: "GENERICS_TAG_STRUCTURE_RESERVED101",
    -2147458892: "GENERICS_TAG_STRUCTURE_RWNODE",
    -2147458887: "GENERICS_TAG_STRUCTURE_RWNODE_DOCUMENT",
    -2147458881: "GENERICS_TAG_STRUCTURE_RWNODE_END",
    -2147458888: "GENERICS_TAG_STRUCTURE_RWNODE_FIELD_GROUP",
    -2147458890: "GENERICS_TAG_STRUCTURE_RWNODE_RESERVED",
    -2147458891: "GENERICS_TAG_STRUCTURE_RWNODE_SECTION",
    -2147458889: "GENERICS_TAG_STRUCTURE_RWNODE_TEMPLATE",
    -2147458872: "GENERICS_TAG_STRUCTURE_RW_FIELD",
    -2147458873: "GENERICS_TAG_STRUCTURE_RW_FIELDS",
    -2147458908: "GENERICS_TAG_STRUCTURE_SEARCH_FOLDER",
    -2147459013: "GENERICS_TAG_STRUCTURE_SORT",
    -2147459012: "GENERICS_TAG_STRUCTURE_SORTS",
    -2147458850: "GENERICS_TAG_STRUCTURE_SQL_COLUMN",
    -2147458846: "GENERICS_TAG_STRUCTURE_SQL_COLUMNS",
    -2147458848: "GENERICS_TAG_STRUCTURE_SQL_JOIN",
    -2147458844: "GENERICS_TAG_STRUCTURE_SQL_JOINS",
    -2147458853: "GENERICS_TAG_STRUCTURE_SQL_QUERIES",
    -2147458852: "GENERICS_TAG_STRUCTURE_SQL_QUERY",
    -2147458849: "GENERICS_TAG_STRUCTURE_SQL_QUERY_COLUMN",
    -2147458845: "GENERICS_TAG_STRUCTURE_SQL_QUERY_COLUMNS",
    -2147458995: "GENERICS_TAG_STRUCTURE_SQL_QUERY_SHORTCUT",
    -2147458851: "GENERICS_TAG_STRUCTURE_SQL_TABLE",
    -2147458847: "GENERICS_TAG_STRUCTURE_SQL_TABLES",
    -2147458841: "GENERICS_TAG_STRUCTURE_TABLES",
    -2147458960: "GENERICS_TAG_STRUCTURE_TARGET_FOLDER",
    -2147458959: "GENERICS_TAG_STRUCTURE_TARGET_INFO",
    -2147459023: "GENERICS_TAG_STRUCTURE_TEMPLATES",
    -2147459014: "GENERICS_TAG_STRUCTURE_TEMPLATE_METRIC",
    -2147459010: "GENERICS_TAG_STRUCTURE_TEMPLATE_SUBTOTAL",
    -2147459011: "GENERICS_TAG_STRUCTURE_TEMPLATE_SUBTOTALS",
    -2147459020: "GENERICS_TAG_STRUCTURE_TEMPLATE_UNIT",
    -2147459019: "GENERICS_TAG_STRUCTURE_TEMPLATE_UNIT_ATTR",
    -2147459016: "GENERICS_TAG_STRUCTURE_TEMPLATE_UNIT_CG",
    -2147459015: "GENERICS_TAG_STRUCTURE_TEMPLATE_UNIT_CONS",
    -2147459018: "GENERICS_TAG_STRUCTURE_TEMPLATE_UNIT_DIM",
    -2147459017: "GENERICS_TAG_STRUCTURE_TEMPLATE_UNIT_METRICS",
    -2147458945: "GENERICS_TAG_STRUCTURE_THRESHOLD",
    -2147458944: "GENERICS_TAG_STRUCTURE_THRESHOLDS",
    -2147455488: "GENERICS_TAG_STRUCTURE_TYPE",
    -2147458854: "GENERICS_TAG_STRUCTURE_USER_ANSWERS",
    -2147459048: "GENERICS_TAG_TRANSLATION",
    -2147459049: "GENERICS_TAG_TRANSLATIONS",
    -2147171504: "GTWJSN_E_BAD_TEMPLATE",
    -2147171503: "GTWJSN_E_BAD_XTAB",
    -2147171501: "GTWJSN_E_GENERIC",
    -2147171502: "GTWJSN_E_INVALID_TYPE",
    -2147217000: "HEADINFO_ERR_FIRSTUNIT",
    -2147216999: "HEADINFO_ERR_SEQUENCE",
    -2147201744: "HGOS_E_CROSSJOIN",
    -2147201757: "HGOS_E_DATATYPECAST",
    -2147201747: "HGOS_E_HDFS",
    -2147201745: "HGOS_E_HDFSACL",
    -2147201749: "HGOS_E_HIVE",
    -2147201759: "HGOS_E_INTERNAL",
    -2147201755: "HGOS_E_NETWORKDNS",
    -2147201754: "HGOS_E_NOVALIDSHEET",
    -2147201758: "HGOS_E_PRIMEADDRESSMISSING",
    -2147201752: "HGOS_E_SCHEMAINCONSISTENT",
    -2147201746: "HGOS_E_SECURITYE",
    -2147201750: "HGOS_E_SPARKJOB",
    -2147201748: "HGOS_E_SPARKSQL",
    -2147201762: "HGOS_E_TRANSMITTER",
    -2147201760: "HGOS_E_TRANSMITTERINTERRUPTED",
    -2147201761: "HGOS_E_TRANSMITTERIO",
    -2147201756: "HGOS_E_UNKNOWNCOMMAND",
    -2147201751: "HGOS_E_UNSUPPORTEDEXPRESSION",
    -2147201753: "HGOS_E_UNSUPPORTEDFILETYPE",
    -2147215327: "IMPORT_E_ATTRIBUTE_CANNOT_BE_MAPPED_TWICE_DIFFERENTLY",
    -2147215328: "IMPORT_E_ATTRIBUTE_NOT_SUPPORTED_BY_TABLE",
    -2147215337: "IMPORT_E_CANNOT_DETERMINE_ORIGIN_FOR_PROMPT",
    -2147212015: "IMPORT_E_CANNOT_LINK_COMPOUND_ATTRIBUTE",
    -2147211997: "IMPORT_E_CANNOT_LINK_INCOMPATIBLE_DATATYPE",
    -2147215339: "IMPORT_E_CANNOT_MAP_ATTRIBUTE_WITH_COMPOUND_ID",
    -2147215340: "IMPORT_E_CANNOT_MAP_A_COMPOUND_FORM_OF_AN_ATTRIBUTE",
    -2147215317: "IMPORT_E_CLOUDELEMENT_TOKEN",
    -2147215316: "IMPORT_E_COLUMNS_MATCH",
    -2147215324: "IMPORT_E_CUBEEDIT_REMOTESOURCE",
    -2147215352: "IMPORT_E_DB_ERROR_SAP",
    -2147215346: "IMPORT_E_DB_ERROR_XDASOURCE",
    -2147215326: "IMPORT_E_DDASUPPORT_INCOMPATIBLE",
    -2147215347: "IMPORT_E_DESC_FORM_CATEGORY_MISSING_IN_PROJECT",
    -2147212449: "IMPORT_E_DIMENSION_NO_SCHEMA",
    -2147215355: "IMPORT_E_EXTERNAL_SOURCE_CONNECTION_LANGUAGE_CHANGED",
    -2147215348: "IMPORT_E_ID_FORM_CATEGORY_MISSING_IN_PROJECT",
    -2147215358: "IMPORT_E_INCOMPATIBLE_DBROLE",
    -2147215356: "IMPORT_E_INCOMPATIBLE_DBROLE_DEFAULT_CONNECTION",
    -2147215335: "IMPORT_E_INITIALIZATION_FAILED",
    -2147215334: "IMPORT_E_INVALID_DBROLE_CHANGE_REQUEST",
    -2147215357: "IMPORT_E_INVALID_DESTINATION_CODE",
    -2147211984: "IMPORT_E_INVALID_MAPPING_CHANGE_COMMAND",
    -2147215359: "IMPORT_E_INVALID_XDASOURCE_SPECIFICATION",
    -2147215351: "IMPORT_E_INVALID_XDATYPE_FOR_DBTABLE",
    -2147215360: "IMPORT_E_INVALID_XDATYPE_FOR_IMPORT_OPERATION",
    -2147212140: "IMPORT_E_IVE_CHANGE_SOURCE_NOT_SUPPORTED",
    -2147212142: "IMPORT_E_IVE_DUPLICATED_COLUMN_HEADERS",
    -2147212144: "IMPORT_E_IVE_EMPTY_SHEET",
    -2147212121: "IMPORT_E_IVE_FILESIZE_EXCEEDED_ERROR",
    -2147212076: "IMPORT_E_IVE_FILESIZE_EXCEEDED_ERROR2",
    -2147211972: "IMPORT_E_IVE_FILE_EMPTY_ERROR",
    -2147212123: "IMPORT_E_IVE_FILE_IMPORT_ERROR",
    -2147212064: "IMPORT_E_IVE_FILE_IMPORT_VERSION_ERROR",
    -2147212062: "IMPORT_E_IVE_FILE_NOT_EXIST_ERROR",
    -2147211913: "IMPORT_E_IVE_HGOS_VERSION_ERROR",
    -2147212082: "IMPORT_E_IVE_NO_PRIV",
    -2147212055: "IMPORT_E_IVE_OUT_OF_MEMORY_ERROR",
    -2147070694: "IMPORT_E_IVE_PUSH_DATA_ERROR",
    -2147211250: "IMPORT_E_IVE_SFDC_INVALID_GRANT",
    -2147212080: "IMPORT_E_IVE_SFDC_OBSOLETE_REPORT",
    -2147212074: "IMPORT_E_IVE_SFDC_UNRESOLVED_FILTER",
    -2147212081: "IMPORT_E_IVE_SFDC_UNSAVED_REPORT",
    -2147212063: "IMPORT_E_IVE_UNSUPPORTED_CODEPAGE_ERROR",
    -2147212122: "IMPORT_E_IVE_URL_ERROR",
    -2147211983: "IMPORT_E_LINK_ATTRIBUTE_FAILED",
    -2147211985: "IMPORT_E_LINK_METRIC_FAILED",
    -2147215319: "IMPORT_E_MERGE_DATASET_UNSUPPORT",
    -2147215322: "IMPORT_E_MERGE_INVALID_DATASETTYPE",
    -2147215325: "IMPORT_E_MERGE_INVALID_XDATYPE",
    -2147215323: "IMPORT_E_MERGE_PRIVILEGE",
    -2147215315: "IMPORT_E_MERGE_UNSUPPORT",
    -2147215341: "IMPORT_E_NEW_OBJECT_FOR_REPLACEMENT_ALREADY_MAPPED",
    -2147215336: "IMPORT_E_NOT_INITIALIZED",
    -2147215343: "IMPORT_E_OBJECTS_RELATIONSHIP_AMBIGUITY",
    -2147215342: "IMPORT_E_OBJECT_TYPE_MISMATCH_FOR_REPLACEOBJECT",
    -2147215344: "IMPORT_E_OBJECT_WITH_INCOMPATIBLE_XDATYPE",
    -2147215318: "IMPORT_E_PROJECT_ATTRIBUTE_DUPLICATE_NAME",
    -2147215321: "IMPORT_E_RA_DATATYPE_INCOMPATIBLE",
    -2147215320: "IMPORT_E_RA_TABLESCHEMA_CHANGED",
    -2147215338: "IMPORT_E_REPLACEMENT_WITH_INCOMPATIBLE_PROMPT",
    -2147215354: "IMPORT_E_SAP_MDX_CUBES_VARIABLES_NOT_SUPPORTED",
    -2147215349: "IMPORT_E_SAP_MDX_MANDATORY_HIERARCHY_VARIABLE",
    -2147215350: "IMPORT_E_SAP_UNEXPECTED_DATE_FORMAT",
    -2147211977: "IMPORT_E_SCHEMA_OBJECTS_CHANGED",
    -2147215345: "IMPORT_E_SOURCEORDER_FORM_CATEGORY_MISSING_IN_PROJECT",
    -2147215353: "IMPORT_E_SPECIAL_FOLDER_NOT_FOUND",
    -2147209143: "INCOMPATIBLE_COMPARE",
    -2147025904: "INFO_DESKTOP_PROGRESS_DESKTOP_IMPORT",
    -2147025905: "INFO_DESKTOP_PROGRESS_NETWORK_TRANSMISSION",
    -2147025902: "INFO_DESKTOP_PROGRESS_RENDER_DASHBOARD",
    -2147025906: "INFO_DESKTOP_PROGRESS_SERVER_EXPORT",
    -2147025892: "INFO_DESKTOP_PROMPT_NOT_SUPPOTED",
    -2147048421: "INVALID_DDA_CUBE",
    -2147213297: "LINKED_ATTRS_IN_SAME_DATASET",
    -2147464147: "MCE_LINK_E_DATASET",
    -2147464146: "MCE_LINK_E_GENERAL",
    -2147464148: "MCE_LINK_E_RELATION",
    -2147202308: "MDSRV_E_CHANGE_LOCALE_ID",
    -2147202310: "MDSRV_E_CHANGE_SYSTEM_OBJECT_ID",
    -2147202312: "MDSRV_E_DUP_ID",
    -2147212308: "MDSRV_E_INVALID_NTSID",
    -2147212291: "MDSRV_E_UNSUPPORTED_AUTH_SEARCH",
    -2147212309: "MDSRV_E_USER_DATA_TOO_LONG",
    -2147202309: "MDSRV_E_WELL_KNOWN_ID",
    -2147483070: "MDSVR_3RDPARTYUSERGROUP",
    -2147483077: "MDSVR_AdministratorUserName",
    -2147483228: "MDSVR_AttributeFormsFolderName",
    -2147483262: "MDSVR_AttributesFolderName",
    -2147483271: "MDSVR_AuxiliaryObjectsFolderName",
    -2147483236: "MDSVR_BaseFormulasFolderName",
    -2147482694: "MDSVR_C_INUSE",
    -2147482695: "MDSVR_C_LOCKED",
    -2147482817: "MDSVR_C_MISSING_DESC_FORM",
    -2147483264: "MDSVR_ColumnsFolderName",
    -2147483234: "MDSVR_ConsolidationsFolderName",
    -2147483233: "MDSVR_CustomGroupsFolderName",
    -2147286476: "MDSVR_DBConnectionFolderName",
    -2147483083: "MDSVR_DBLoginFolderName",
    -2147483079: "MDSVR_DBMSFolderName",
    -2147483085: "MDSVR_DBRoleFolderName",
    -2147483261: "MDSVR_DataExplorerFolderName",
    -2147216382: "MDSVR_E_ALREADY_INITIALIZED",
    -2147216366: "MDSVR_E_ATTR_CHILDREN",
    -2147216310: "MDSVR_E_BINARY_PROPERTY_VALUE",
    -2147213719: "MDSVR_E_CANNOT_SEARCH_PROJECT",
    -2147216319: "MDSVR_E_CANT_CONNECT",
    -2147216344: "MDSVR_E_CONNECT_FAILED",
    -2147216331: "MDSVR_E_CONSOLIDATION_ELEMENT",
    -2147213482: "MDSVR_E_CONSTITUENT_LOCKED",
    -2147212059: "MDSVR_E_CORRUPT_ANTS",
    -2147216312: "MDSVR_E_CORRUPT_DEFN",
    -2147216346: "MDSVR_E_CORRUPT_ID",
    -2147212477: "MDSVR_E_CORRUPT_ID_EX",
    -2147213455: "MDSVR_E_CORRUPT_LOCK",
    -2147216376: "MDSVR_E_CORRUPT_MD",
    -2147213724: "MDSVR_E_COUNT_METRIC_WARNING",
    -2147216380: "MDSVR_E_DB_ERROR",
    -2147216360: "MDSVR_E_DIMTY_ENTITY",
    -2147216347: "MDSVR_E_DUP_ID",
    -2147216363: "MDSVR_E_DUP_OBJECT",
    -2147213481: "MDSVR_E_DYNAMIC_DATE",
    -2147216381: "MDSVR_E_EXCEPTION",
    -2147216332: "MDSVR_E_EXTENDED_TYPE",
    -2147216365: "MDSVR_E_FAIL_COCREATEINSTANCE",
    -2147216359: "MDSVR_E_FIL_QUAL",
    -2147202314: "MDSVR_E_FORCE_COLLECTED_GARBAGE",
    -2147216342: "MDSVR_E_FORM_OVERFLOW",
    -2147202315: "MDSVR_E_GARBAGE_INFO",
    -2147213404: "MDSVR_E_GOVERNOR_LOCKED_EX",
    -2147216345: "MDSVR_E_ID_EXISTS",
    -2147216321: "MDSVR_E_ID_EXISTS_IN_CONFIGURATION",
    -2147216322: "MDSVR_E_ID_EXISTS_IN_PROJECT",
    -2147216384: "MDSVR_E_INTERNAL",
    -2147216374: "MDSVR_E_INVALID_ID",
    -2147213477: "MDSVR_E_INVALID_ID_MAP",
    -2147216377: "MDSVR_E_INVALID_PROJECT",
    -2147216317: "MDSVR_E_INVALID_PROP_RESTRICTION",
    -2147216316: "MDSVR_E_INVALID_PROP_TYPE",
    -2147213720: "MDSVR_E_INVALID_SEARCH_DOMAIN",
    -2147216372: "MDSVR_E_INVALID_TYPE",
    -2147216355: "MDSVR_E_LOADFILTER",
    -2147212306: "MDSVR_E_LOCK_COMMENT_TOO_LONG",
    -2147213496: "MDSVR_E_LOCK_KIND_MISMATCH",
    -2147216336: "MDSVR_E_MD4_NO_REPOSITORY",
    -2147216337: "MDSVR_E_MD4_SAVEBACK",
    -2147216311: "MDSVR_E_MDMOVER_COMPARE_FAIL",
    -2147216369: "MDSVR_E_MD_CHANGED",
    -2147216368: "MDSVR_E_MD_CHANGED2",
    -2147212482: "MDSVR_E_METADATA_SCHEMA_VERSION_MISMATCH",
    -2147213495: "MDSVR_E_MISSING_DESC_FORM",
    -2147213399: "MDSVR_E_MISSING_OR_INVALID_TRIGGER",
    -2147216353: "MDSVR_E_MQ_DIMTYLIST",
    -2147216354: "MDSVR_E_MQ_EMPTYLIST",
    -2147216356: "MDSVR_E_MQ_FAILED",
    -2147216352: "MDSVR_E_MQ_FUNCTYPE",
    -2147216357: "MDSVR_E_MQ_NODETYPE",
    -2147216358: "MDSVR_E_MQ_OPNODE",
    -2147216350: "MDSVR_E_MQ_RKNODE",
    -2147216351: "MDSVR_E_MQ_TARGETTYPE",
    -2147216383: "MDSVR_E_NOT_INITIALIZED",
    -2147216343: "MDSVR_E_NO_DEFN_ID",
    -2147216313: "MDSVR_E_NO_DEPENDENT",
    -2147216373: "MDSVR_E_NO_ID",
    -2147212463: "MDSVR_E_NO_ID_IGNORE_INTERNAL",
    -2147216364: "MDSVR_E_NO_OBJECT",
    -2147216318: "MDSVR_E_NO_OWNER",
    -2147216328: "MDSVR_E_NO_PERSISTENT_IDSET",
    -2147216375: "MDSVR_E_NO_PROJECT",
    -2147216349: "MDSVR_E_NO_REPOSITORY",
    -2147216314: "MDSVR_E_NO_SOURCE_FOLDER",
    -2147216340: "MDSVR_E_NO_TARGET_FOLDER",
    -2147216370: "MDSVR_E_OBJDEF_NAME",
    -2147212298: "MDSVR_E_OBJECT_DEF_COMPRESS_ERR",
    -2147212297: "MDSVR_E_OBJECT_DEF_DECOMPRESS_ERR",
    -2147212296: "MDSVR_E_OBJECT_DEF_MIGRATION_LOAD",
    -2147212295: "MDSVR_E_OBJECT_DEF_MIGRATION_SAVE",
    -2147212293: "MDSVR_E_OBJECT_DEF_UNKNOWN",
    -2147213500: "MDSVR_E_OBJECT_LOCKED",
    -2147213405: "MDSVR_E_OBJECT_LOCKED_EX",
    -2147213497: "MDSVR_E_OBJECT_NOT_LOCKED",
    -2147213478: "MDSVR_E_OPEN_IDMAP",
    -2147216327: "MDSVR_E_PARSE_DATATYPE",
    -2147216326: "MDSVR_E_PARSE_EXPRESSION",
    -2147216329: "MDSVR_E_PART_FILTER",
    -2147216367: "MDSVR_E_QUAL_LUTABLE",
    -2147216378: "MDSVR_E_QUERY_CANCELLED",
    -2147478453: "MDSVR_E_QUOTE_STRING",
    -2147216330: "MDSVR_E_READ_PMT",
    -2147217343: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ",
    -2147217341: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ_1",
    -2147217339: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ_2",
    -2147217338: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ_3",
    -2147217340: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ_4",
    -2147217337: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ_5",
    -2147217336: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ_6",
    -2147217335: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ_7",
    -2147217334: "MDSVR_E_SAVE_DELEGATED_SECURITY_OBJ_8",
    -2147216325: "MDSVR_E_SAVE_DELETED_OBJECT",
    -2147213323: "MDSVR_E_SAVE_NEW_MANAGED_OBJECT",
    -2147216341: "MDSVR_E_SAVE_PARTIAL_OBJECT",
    -2147216338: "MDSVR_E_SAVE_PROPERTYGROUP",
    -2147216334: "MDSVR_E_SCRIPT_NOT_FOUND",
    -2147216379: "MDSVR_E_SQL_RESULT",
    -2147216361: "MDSVR_E_TEMPLATEOBJ_NAME",
    -2147216362: "MDSVR_E_TU_TYPE",
    -2147216371: "MDSVR_E_TYPE_MISMATCH",
    -2147216339: "MDSVR_E_UNEXPECTED",
    -2147216333: "MDSVR_E_UNKNOWN_WS_ENTTYPE",
    -2147213498: "MDSVR_E_UNLOCK_NO_PERMISSION",
    -2147212111: "MDSVR_E_UNSUPPORTED_INTENTLOCK",
    -2147216335: "MDSVR_E_UNSUPPORTED_MD4_SEARCH",
    -2147213340: "MDSVR_E_UNSUPPORTED_SEARCH_PATTERN",
    -2147213476: "MDSVR_E_WRITE_IDMAP",
    -2147213401: "MDSVR_E_WRONG_MD_RDBMS",
    -2147216348: "MDSVR_E_WRONG_MD_VERSION",
    -2147213400: "MDSVR_E_WRONG_MD_VERSION_EX",
    -2147213417: "MDSVR_E_WRONG_MD_VERSION_EX2",
    -2147212099: "MDSVR_E_WRONG_MD_VERSION_TOOHIGH",
    -2147216324: "MDSVR_E_WRONG_PROJECT",
    -2147483082: "MDSVR_EventFolderName",
    -2147483076: "MDSVR_EveryoneGroupName",
    -2147483266: "MDSVR_FactGroupsFolderName",
    -2147483260: "MDSVR_FactsFolderName",
    -2147483235: "MDSVR_FiltersFolderName",
    -2147483258: "MDSVR_FuncApplyFolderName",
    -2147483257: "MDSVR_FuncArithmeticFolderName",
    -2147483256: "MDSVR_FuncBandingFolderName",
    -2147483255: "MDSVR_FuncComparisonFolderName",
    -2147483254: "MDSVR_FuncDatabaseFolderName",
    -2147483253: "MDSVR_FuncLogicalFolderName",
    -2147483252: "MDSVR_FuncMathematicalFolderName",
    -2147483247: "MDSVR_FuncOtherFolderName",
    -2147483251: "MDSVR_FuncPlugInPackagesFolderName",
    -2147483250: "MDSVR_FuncPlugInSPSSFolderName",
    -2147483249: "MDSVR_FuncPlugInStatisticalFolderName",
    -2147483248: "MDSVR_FuncPlugInTIPSFolderName",
    -2147483246: "MDSVR_FuncStatisticalFolderName",
    -2147483259: "MDSVR_FunctionsFolderName",
    -2147483245: "MDSVR_HierarchiesFolderName",
    -2147482798: "MDSVR_LDAPPublicGroupName",
    -2147482799: "MDSVR_LDAPUserGroupName",
    -2147482800: "MDSVR_MDSecurityFiltersFolderName",
    -2147483237: "MDSVR_MetricsFolderName",
    -2147483268: "MDSVR_MyAnswersFolderName",
    -2147442745: "MDSVR_MyDossierFolderName",
    -2147483267: "MDSVR_MyFavoritesFolderName",
    -2147483269: "MDSVR_MyObjectsFolderName",
    -2147483270: "MDSVR_MyReportsFolderName",
    -2147479279: "MDSVR_MySegmentsFolderName",
    -2147442744: "MDSVR_MySharedDossierFolderName",
    -2147483071: "MDSVR_NormalUserSecurityRoleName",
    -2147483063: "MDSVR_Object_Delete",
    -2147443196: "MDSVR_Object_ID_Change",
    -2147483067: "MDSVR_Object_Loading",
    -2147483064: "MDSVR_Object_Save_Existing",
    -2147483065: "MDSVR_Object_Save_New",
    -2147483224: "MDSVR_PartitionFilterName",
    -2147483243: "MDSVR_PartitionFiltersFolderName",
    -2147483242: "MDSVR_PartitionMappingsFolderName",
    -2147483072: "MDSVR_PowerUserSecurityRoleName",
    -2147483273: "MDSVR_ProfilesFolderName",
    -2147482772: "MDSVR_ProjectBuilderFolderName",
    -2147483278: "MDSVR_ProjectFolderName",
    -2147483229: "MDSVR_PromptsFolderName",
    -2147483066: "MDSVR_PropertyGroup_Loading",
    -2147483274: "MDSVR_PropertySetsFolderName",
    -2147483073: "MDSVR_PublicGroupName",
    -2147483276: "MDSVR_PublicObjectsFolderName",
    -2147483231: "MDSVR_ReportsFolderName",
    -2147483080: "MDSVR_ScheduleObjectFolderName",
    -2147483081: "MDSVR_ScheduleTriggerFolderName",
    -2147482815: "MDSVR_SchemaColumnsFolderName",
    -2147483227: "MDSVR_SchemaObjName",
    -2147483277: "MDSVR_SchemaObjectsFolderName",
    -2147482810: "MDSVR_SchemaSystemHierarchyFolderName",
    -2147482811: "MDSVR_SchemaWarehouseCatalogFolderName",
    -2147483230: "MDSVR_SearchesFolderName",
    -2147483087: "MDSVR_SecurityRoleFolderName",
    -2147483088: "MDSVR_ServerDefinitionFolderName",
    -2147483241: "MDSVR_SubtotalsFolderName",
    -2147483222: "MDSVR_SysDimensionObjName",
    -2147483075: "MDSVR_SystemAdministratorGroupName",
    -2147482808: "MDSVR_SystemDrillMapFolderName",
    -2147483279: "MDSVR_SystemFolderName",
    -2147483244: "MDSVR_SystemHierarchyFolderName",
    -2147482814: "MDSVR_SystemLinksFolderName",
    -2147483074: "MDSVR_SystemMonitorGroupName",
    -2147482812: "MDSVR_SystemParserFolderName",
    -2147482813: "MDSVR_SystemPropertySetsFolderName",
    -2147482809: "MDSVR_SystemSchemaFolderName",
    -2147483078: "MDSVR_TableSourceFolderName",
    -2147483240: "MDSVR_TablesFolderName",
    -2147483275: "MDSVR_TemplateObjectsFolderName",
    -2147483232: "MDSVR_TemplatesFolderName",
    -2147483238: "MDSVR_TransformationAttributesFolderName",
    -2147483239: "MDSVR_TransformationsFolderName",
    -2147483272: "MDSVR_UserFolderName",
    -2147483086: "MDSVR_UserGroupFolderName",
    -2147483265: "MDSVR_WHCatalogFolderName",
    -2147483223: "MDSVR_WHCatalogObjectName",
    -2147483225: "MDSVR_WHDBConnName",
    -2147483226: "MDSVR_WHDBRoleName",
    -2147483263: "MDSVR_WHTablesFolderName",
    -2147483069: "MDSVR_WHUSERSNAME",
    -2147216323: "MDSVR_W_INVALID_PROPERTY",
    -2147482711: "MDUPD_C_AmbiguousSearchResult",
    -2147482706: "MDUPD_C_BulkSaveObjectsRelatedToObjectError",
    -2147482707: "MDUPD_C_BulkSavedObjectsRelatedToObject",
    -2147482775: "MDUPD_C_CheckingProgress",
    -2147482794: "MDUPD_C_ConfigVersion",
    -2147482789: "MDUPD_C_Create",
    -2147482778: "MDUPD_C_CreateNewProperty",
    -2147482785: "MDUPD_C_CreateObject",
    -2147482748: "MDUPD_C_DUP_LOCALE_ID",
    -2147482796: "MDUPD_C_DataSourceName",
    -2147482720: "MDUPD_C_Delete",
    -2147482721: "MDUPD_C_DeleteObject",
    -2147482692: "MDUPD_C_DuplicateNameType",
    -2147482792: "MDUPD_C_Error",
    -2147482782: "MDUPD_C_ErrorSave",
    -2147482682: "MDUPD_C_FinishPropagateACL",
    -2147482684: "MDUPD_C_FunctionPackageDefinitionMissing",
    -2147482716: "MDUPD_C_GrantExecuteAccess",
    -2147443648: "MDUPD_C_HL_ConvertContactError",
    -2147443647: "MDUPD_C_HL_ConvertSubscriptionError",
    -2147443646: "MDUPD_C_HL_SavingSubscriptionError",
    -2147482681: "MDUPD_C_ID_MISMATCH",
    -2147482797: "MDUPD_C_MD_UPDATE_NAME",
    -2147482717: "MDUPD_C_Move",
    -2147482718: "MDUPD_C_MoveObject",
    -2147458782: "MDUPD_C_NEEDUPGRADECHECK",
    -2147482787: "MDUPD_C_NoUpdate",
    -2147482745: "MDUPD_C_PrivilegesUpdated",
    -2147482795: "MDUPD_C_ProjectName",
    -2147482788: "MDUPD_C_ProjectVersion",
    -2147482709: "MDUPD_C_PropertySetValidation",
    -2147443424: "MDUPD_C_REMOVE_FAILED_HL_SCHEDULER",
    -2147482693: "MDUPD_C_RemoveInvalidColumnAlias",
    -2147482687: "MDUPD_C_RootFolderMissing",
    -2147482710: "MDUPD_C_SaveObjectError",
    -2147482686: "MDUPD_C_SchemaMissing",
    -2147482713: "MDUPD_C_ScriptErrorFolderMissingOrEmpty",
    -2147482714: "MDUPD_C_ScriptErrorMissingSymbol",
    -2147482683: "MDUPD_C_StartPropagateACL",
    -2147482685: "MDUPD_C_SystemDimensionMissing",
    -2147482747: "MDUPD_C_UNIFY_NOT_DELETE",
    -2147482715: "MDUPD_C_UnexpectedError",
    -2147443431: "MDUPD_C_UnifyDSInstance",
    -2147443430: "MDUPD_C_UnifyDSInstanceID",
    -2147443432: "MDUPD_C_UnifyDSObject",
    -2147482790: "MDUPD_C_Update",
    -2147482786: "MDUPD_C_UpdateComplete",
    -2147482777: "MDUPD_C_UpdateDBMS",
    -2147482749: "MDUPD_C_UpdateEntryDescription",
    -2147482773: "MDUPD_C_UpdateEntryName",
    -2147479848: "MDUPD_C_UpdateHLSchedule",
    -2147443421: "MDUPD_C_UpdateInstanceStatus",
    -2147482719: "MDUPD_C_UpdateObject",
    -2147482780: "MDUPD_C_UpdatePropDefault",
    -2147482779: "MDUPD_C_UpdatePropGroups",
    -2147482781: "MDUPD_C_UpdatePropName",
    -2147482783: "MDUPD_C_UpdateSysPropSet",
    -2147482784: "MDUPD_C_UpdateSystemLink",
    -2147483068: "MDUPD_C_UpdateTranslation",
    -2147482776: "MDUPD_C_UpdateUserGroup",
    -2147482708: "MDUPD_C_UpdatedObjectInMemory",
    -2147482746: "MDUPD_C_VERSION_ID_UPDATED",
    -2147482774: "MDUPD_C_VersionHistory",
    -2147482793: "MDUPD_C_VersionNotSupported",
    -2147482791: "MDUPD_C_Warning",
    -2147213722: "MDUPD_E_CANNOT_LOAD_BINARY_GRAPH_DATA",
    -2147213489: "MDUPD_E_COMPLETE_WITH_ERRORS",
    -2147213488: "MDUPD_E_DATASOURCE_TYPE",
    -2147216855: "MDUPD_E_GRANT_ACCESS_DSOBJ",
    -2147212328: "MDUPD_E_INCONSISTENT_OBJECT",
    -2147213392: "MDUPD_E_LANGUAGE_MISMATCH",
    -2147213379: "MDUPD_E_LINK_DIMENSIONALITY_CHANGE",
    -2147213378: "MDUPD_E_LINK_DIMENSION_CHANGE",
    -2147213487: "MDUPD_E_LOAD_SCRIPT",
    -2147213380: "MDUPD_E_OBJECT_NAME_CHANGE",
    -2147212341: "MDUPD_E_OLD_SCHEMA_VERSION",
    -2147213381: "MDUPD_E_OLD_SERVER_VERSION",
    -2147213502: "MDUPD_E_OPEN_LOGFILE",
    -2147212141: "MDUPD_E_PROJECTLOCKED",
    -2147213391: "MDUPD_E_PROJECT_LANGUAGE",
    -2147213486: "MDUPD_E_PROPNAME_CHANGE",
    -2147213438: "MDUPD_E_PROPNAME_CHANGE_EX",
    -2147213485: "MDUPD_E_PROPTYPE_CHANGE",
    -2147213437: "MDUPD_E_PROPTYPE_CHANGE_EX",
    -2147212098: "MDUPD_E_SYSTEM_OBJECTS_NOT_UPDATED",
    -2147213504: "MDUPD_E_TARGET_VERSION",
    -2147213503: "MDUPD_E_UNSUPPORTED_VERSION",
    -2147213501: "MDUPD_E_UPDATE_FAILED",
    -2147212479: "MDUPD_E_UPDATE_HL_SCHEDULE",
    -2147213484: "MDUPD_E_UPDATE_WITH_ERROR",
    -2147212071: "MDUPD_E_UnifyDSObject",
    -2147212069: "MDUPD_E_UnifyDS_GetPSLError",
    -2147212067: "MDUPD_E_UnifyDS_PopulatePSLError",
    -2147212066: "MDUPD_E_UnifyDS_SaveInstanceError",
    -2147212068: "MDUPD_E_UnifyDS_SerializePSLError",
    -2147181276: "MDUPD_E_UpdateInstanceStatus",
    -2147213393: "MDUPD_E_VALIDATION_FAILURE",
    -2147212307: "MDUPD_E_WRONG_SESSION_FOR_PRIVILEGES",
    -2147204433: "MDX_E_ATTR_NOT_IN_SOURCETABLE",
    -2147204419: "MDX_E_DUP_MEMBER_UNAME",
    -2147204430: "MDX_E_EMPTY_ATTR_ELEM_LIST",
    -2147204410: "MDX_E_FILTER_RA_AND_NA_SAME_DIM",
    -2147204432: "MDX_E_FOUND_DUP_ATTR",
    -2147204421: "MDX_E_INVALID_CONTEXT",
    -2147204412: "MDX_E_INVALID_METRIC_LIMIT_MISSING_ATTR",
    -2147204431: "MDX_E_INVALID_SCHEMA_ATTR_BROWSING",
    -2147204414: "MDX_E_MEASURES_NORMAL_DIM_AT_LEAST_ONE_LEVEL",
    -2147204415: "MDX_E_MEASURES_NORMAL_DIM_NO_MEASURE_EXPR",
    -2147204413: "MDX_E_MEASURES_NORMAL_DIM_NO_METRIC_QUAL",
    -2147204416: "MDX_E_MEASURES_NORMAL_DIM_NO_REPORT_LIMITS",
    -2147204434: "MDX_E_MISSING_ATTR_UNIT_LIMIT",
    -2147204420: "MDX_E_MISSING_REL_DIM",
    -2147204448: "MDX_E_MULTATTR_IN_OUTPUT_LEVEL",
    -2147204447: "MDX_E_MULTDIM_IN_OR",
    -2147204409: "MDX_E_MULT_DIM_IN_REL_FILTER",
    -2147204435: "MDX_E_MULT_HIER_SAME_DIM",
    -2147204446: "MDX_E_NO_LEVELINFO",
    -2147204411: "MDX_E_RECURSIVE_ATTR_NORM_ATTR_SAME_HIER",
    -2147204418: "MDX_E_SAP_VARIABLE_INTERVAL_MIXED_VALUES",
    -2147204427: "MDX_E_SF_SELECT_BELOW_BOTTOM",
    -2147204425: "MDX_E_STRUCTURE_FREEFORM_MEASURE",
    -2147204424: "MDX_E_STRUCTURE_SOURCE_ORDER_QUALIFICATION",
    -2147204422: "MDX_E_UNABLE_TO_FIND_DEFAULT_FORMATS",
    -2147204436: "MDX_E_UNEXPECTED_LEVEL",
    -2147204428: "MDX_E_UNEXPECTED_PROPERTY",
    -2147204423: "MDX_E_UNKNOWN_FORM_IN_DIM",
    -2147204441: "MDX_E_UNSUPPORTED_ATTR_QUALIFICATION",
    -2147204449: "MDX_E_UNSUPPORTED_FILTER_NODETYPE",
    -2147204442: "MDX_E_UNSUPPORTED_FORM_QUALIFICATION",
    -2147204451: "MDX_E_UNSUPPORTED_FUNCTION",
    -2147204443: "MDX_E_UNSUPPORTED_METRIC_EXPR",
    -2147204445: "MDX_E_UNSUPPORTED_NOT_NODE",
    -2147204440: "MDX_E_UNSUPPORTED_REL_FILTER",
    -2147204426: "MDX_E_UNSUPPORTED_SF_EB_COMBINATION",
    -2147204450: "MDX_E_UNSUPPORTED_TEMPLATE_LIMIT_COMBINATION",
    -2147204444: "MDX_E_UNSUPPORTED_TEMPLATE_UNIT_TYPE",
    -2147204429: "MDX_E_WRONG_NUMBER_OF_ARGS",
    -2147209144: "MEMORY_ALLOC_FAILED",
    -2147207431: "MSICHANNEL_E_CHANNEL_CLOSE",
    -2147207430: "MSICHANNEL_E_NULL_INPUT_PARAM",
    -2147207432: "MSICHANNEL_E_READ_FAIL",
    -2147207435: "MSICHANNEL_E_READ_NOT_SUPPORT",
    -2147207433: "MSICHANNEL_E_WRITE_FAIL",
    -2147207434: "MSICHANNEL_E_WRITE_NOT_SUPPORT",
    -2147207442: "MSICONFIG_EMPTY_PULIST",
    -2147207443: "MSICONFIG_LOGDIR",
    -2146944584: "MSIDATEIME_INVALIDTIME",
    -2147209090: "MSIDATETIME_BEGINTIME",
    -2147209087: "MSIDATETIME_BUFINSUFFICIENT",
    -2147209085: "MSIDATETIME_DAYOFWEEK_NOGETSHIFT",
    -2147209089: "MSIDATETIME_ENDTIME",
    -2147074339: "MSIDATETIME_E_INVALIDYEAR",
    -2146944355: "MSIDATETIME_INVALIDDAY",
    -2146944354: "MSIDATETIME_INVALIDMONTH",
    -2146944352: "MSIDATETIME_INVALIDTIMESPAN",
    -2147209084: "MSIDATETIME_INVALID_MEMBER",
    -2147209083: "MSIDATETIME_INVALID_WEEK",
    -2147209086: "MSIDATETIME_MILLISEC_NOTDYN",
    -2147209088: "MSIDATETIME_NOTDYNTIME",
    -2147209092: "MSIDATETIME_NOTTIME",
    -2147207111: "MSIDBCPR_CREATECONNECTION_FAILED",
    -2147207112: "MSIDBCPR_INVALID_CACHE_OPTION",
    -2147207113: "MSIDBCPR_INVALID_DBC",
    -2147207300: "MSIDBD_CONSTRUCTOR_FAILED",
    -2147207298: "MSIDBD_DBD_EXISTS",
    -2147207297: "MSIDBD_DELETEDBD_FAILED",
    -2147207295: "MSIDBD_GETPROPERTY_FAILED",
    -2147207296: "MSIDBD_SETPROPERTY_FAILED",
    -2147207299: "MSIDBF_CONSTRUCTOR_FAILED",
    -2147207076: "MSIDBODBC_LOGIN_FAILED",
    -2147207110: "MSIDBPR_DBMGR_NOT_SET",
    -2147207108: "MSIDBPR_INT_ERROR",
    -2147207109: "MSIDBPR_INV_CONNID",
    -2147207142: "MSIDB_COINIT_FAILED",
    -2147207094: "MSIDB_CONNMGR_CLOSE_CONNECTION",
    -2147207132: "MSIDB_CONNMGR_CLOSE_CONNECTION_EXCEPTION",
    -2147207131: "MSIDB_CONNMGR_CLOSE_CONNECTION_UNKNOWN_EXCEPTION",
    -2147207095: "MSIDB_CONNMGR_CONNECTTING_TO_DB",
    -2147207089: "MSIDB_CONNMGR_DELETE_FREE_CONNECTIONS",
    -2147207123: "MSIDB_CONNMGR_DELETE_FREE_CONNECTIONS_DB_ERROR",
    -2147207124: "MSIDB_CONNMGR_DELETE_FREE_CONNECTIONS_DB_LOGIC_ERROR",
    -2147207122: "MSIDB_CONNMGR_DELETE_FREE_CONNECTIONS_UNKNOWN_EXCEPTION",
    -2147207120: "MSIDB_CONNMGR_DELETE_LRU_CONNECTIONS_EXCEPTION",
    -2147207084: "MSIDB_CONNMGR_FREE_CACHED_CONNECTION",
    -2147207119: "MSIDB_CONNMGR_FREE_CACHED_CONNECTION_EXCEPTION",
    -2147207083: "MSIDB_CONNMGR_FREE_CACHED_CONNECTION_FOUND",
    -2147207088: "MSIDB_CONNMGR_FREE_CONNECTIONS_CNT_1",
    -2147207087: "MSIDB_CONNMGR_FREE_CONNECTIONS_CNT_2",
    -2147207085: "MSIDB_CONNMGR_FREE_TIMEDOUT_CONNECTION",
    -2147207121: "MSIDB_CONNMGR_FREE_TIMEDOUT_CONNECTION_EXCEPTION",
    -2147207100: "MSIDB_CONNMGR_GETNEWCONNECTION",
    -2147207135: "MSIDB_CONNMGR_GET_NEW_CONNECTION_EXCEPTION1",
    -2147207134: "MSIDB_CONNMGR_GET_NEW_CONNECTION_EXCEPTION2",
    -2147207133: "MSIDB_CONNMGR_GET_NEW_CONNECTION_EXCEPTION3",
    -2147207102: "MSIDB_CONNMGR_INIT",
    -2147207098: "MSIDB_CONNMGR_MAKE_NEW_CONNECTION1",
    -2147207097: "MSIDB_CONNMGR_MAKE_NEW_CONNECTION2",
    -2147207136: "MSIDB_CONNMGR_MAKE_NEW_CONNECTION_UNKNOWN_EXCEPTION",
    -2147207099: "MSIDB_CONNMGR_MAX_CONNECTIONS",
    -2147207096: "MSIDB_CONNMGR_MAX_CONNECTIONS_EXCEEDED",
    -2147207092: "MSIDB_CONNMGR_MOVE_TO_FREE_LIST",
    -2147207130: "MSIDB_CONNMGR_MOVE_TO_FREE_LIST_EXCEPTION",
    -2147207091: "MSIDB_CONNMGR_MOVE_TO_USED_LIST",
    -2147207129: "MSIDB_CONNMGR_MOVE_TO_USED_LIST_EXCEPTION",
    -2147207082: "MSIDB_CONNMGR_SET_CONNECTION_IDLE_TIME",
    -2147207093: "MSIDB_CONNMGR_SET_MAX_CONNECTIONS",
    -2147207101: "MSIDB_CONNMGR_UNINIT",
    -2147207145: "MSIDB_CONNMGR_UNINIT_EXCEPTION",
    -2147207144: "MSIDB_CONNMGR_UNINIT_OPEN_CONNECTIONS",
    -2147207090: "MSIDB_CONNMGR_UPDATE_LIST",
    -2147207126: "MSIDB_CONNMGR_UPDATE_LIST_DB_ERROR",
    -2147207127: "MSIDB_CONNMGR_UPDATE_LIST_DB_LOGIC_ERROR",
    -2147207128: "MSIDB_CONNMGR_UPDATE_LIST_TIMING_OUT",
    -2147207125: "MSIDB_CONNMGR_UPDATE_LIST_UNKNOWN_EXCEPTION",
    -2147207086: "MSIDB_CONNMGR_USED_CONNECTIONS_CNT",
    -2147207104: "MSIDB_DRIVER_CREATECONNECTION",
    -2147207103: "MSIDB_DRIVER_DELETECONNECTION",
    -2147207138: "MSIDB_FEATURE_NOT_SUPPORTED",
    -2147207137: "MSIDB_FREELIBRARY_FAILED",
    -2147207139: "MSIDB_GETPROCADDRESS_FAILED",
    -2147465988: "MSIDB_LOADLIBRARY_ERROR",
    -2147207140: "MSIDB_LOADLIBRARY_FAILED",
    -2147207115: "MSIDB_MSITABLE_GOT_INVALID_DATA_TYPE",
    -2147207114: "MSIDB_MSITABLE_ROWSET_INTO_VECTOR_FAILURE",
    -2147207116: "MSIDB_MSITABLE_ROW_INSERTION_FAILURE",
    -2147207077: "MSIDB_ODBC_ERROR",
    -2147207081: "MSIDB_ROWSET_COPY_CONSTRUCTOR",
    -2147207118: "MSIDB_ROWSET_INVALID_COLUMN",
    -2147207117: "MSIDB_ROWSET_UNIDENTIFIED_DATATYPE",
    -2147207155: "MSINET_MSINETLOG_ASSERT",
    -2147207160: "MSINET_MSINETLOG_LOG",
    -2147207149: "MSINET_MSINETLOG_LOG_ERROR",
    -2147207148: "MSINET_MSINETLOG_LOG_WARNING",
    -2147207161: "MSINET_MSINETLOG_START_LOGGING",
    -2147207158: "MSINET_MSINETLOG_STREAM_ERROR",
    -2147207156: "MSINET_MSINETLOG_SYSTEM_ERROR",
    -2147207159: "MSINET_MSINETLOG_TRACEWSA",
    -2147207157: "MSINET_MSINETLOG_TRACE_CONNECTION",
    -2147207152: "MSINET_MSINETLOG_TRACE_RECV_INT",
    -2147207153: "MSINET_MSINETLOG_TRACE_RECV_MSG",
    -2147207150: "MSINET_MSINETLOG_TRACE_SEND_INT",
    -2147207151: "MSINET_MSINETLOG_TRACE_SEND_MSG",
    -2147207154: "MSINET_MSINETLOG_WSASYSTEM_ERROR",
    -2147207079: "MSIODBC_CONN_UNKNOWN_EXCEPTION",
    -2147207078: "MSIODBC_SQL_STMT",
    -2147207446: "MSIPERFCOUNTER_COLLECT_FUNCTION_FAILURE",
    -2147207448: "MSIPERFCOUNTER_COUNTERS_NUM",
    -2147207447: "MSIPERFCOUNTER_ERROR_MORE_DATA",
    -2147207455: "MSIPERFCOUNTER_FIRSTCOUNTER_ERROR",
    -2147207454: "MSIPERFCOUNTER_FIRSTCOUNTER_VALUE",
    -2147207453: "MSIPERFCOUNTER_FIRSTHELP_ERROR",
    -2147207452: "MSIPERFCOUNTER_FIRSTHELP_VALUE",
    -2147207449: "MSIPERFCOUNTER_INSTANCES_NUM",
    -2147207456: "MSIPERFCOUNTER_OPENKEY_FAILURE",
    -2147207459: "MSIPERFCOUNTER_OPEN_FUNCTION_FAILURE",
    -2147207458: "MSIPERFCOUNTER_OPEN_FUNCTION_SUCCESS",
    -2147207457: "MSIPERFCOUNTER_PERF_KEY",
    -2147207451: "MSIPERFCOUNTER_SHARED_MEMORY_INIT",
    -2147207450: "MSIPERFCOUNTER_SHARED_MEMORY_READ",
    -2147207465: "MSIPUCONFIG_END_LOGGING",
    -2147207466: "MSIPUCONFIG_START_LOGGING",
    -2147207472: "MSIPU_BUILD_HIERARCHICALQ",
    -2147207483: "MSIPU_JOBID",
    -2147207474: "MSIPU_MAX_THREADS",
    -2147207482: "MSIPU_MESSAGE",
    -2147207478: "MSIPU_MINMAX_THREADS",
    -2147207476: "MSIPU_MIN_THREADS",
    -2147207473: "MSIPU_MSIPUTRACE",
    -2147207486: "MSIPU_MSIQTASK_GETNAME",
    -2147207487: "MSIPU_MSIQTASK_QPATH",
    -2147207484: "MSIPU_MSIQTASK_SERVING_SUBQ",
    -2147207485: "MSIPU_MSIQTASK_SUBQPATH",
    -2147207488: "MSIPU_MSIQTASK_TRACE",
    -2147207481: "MSIPU_MSISTATIONTASK_MSIEXCEPTION",
    -2147207480: "MSIPU_MSISTATIONTASK_UNKNOWN_EXCEPTION",
    -2147207479: "MSIPU_PUNAME",
    -2147207475: "MSIPU_PUNAME_MAX",
    -2147207477: "MSIPU_PUNAME_MIN",
    -2147207471: "MSIPU_TASK_TO_THREAD_POOL",
    -2147209063: "MSIPU_THREADPOOL_CONFIGURATION_ERROR",
    -2147207463: "MSIQ_INVALID_PROCESS",
    -2147207462: "MSIQ_NULLJOB",
    -2147207464: "MSIQ_NULL_QTASK",
    -2147207460: "MSIQ_QSTRUCTURE_ERROR",
    -2147207461: "MSIQ_RUN_UNKNOWN_EXCEPTION",
    -2147207162: "MSISTATS_EMPTY_NULL_CONFIGMGR",
    -2147207277: "MSISTATS_NULL_CONFIGMGR",
    -2147206976: "MSISYNCH_ASSERT",
    -2147206952: "MSISYNCH_ASSERTFAILED",
    -2147206977: "MSISYNCH_ASSERT_SYSTEM_CALL",
    -2147206968: "MSISYNCH_DEADLOCK_POSSIBILITY",
    -2147206961: "MSISYNCH_DELETELOCK_FAILED",
    -2147206966: "MSISYNCH_DIFFERENT_LOCKENTER",
    -2147206956: "MSISYNCH_DOWNGRADE_FAILED",
    -2147206967: "MSISYNCH_LOCKENTER",
    -2147206999: "MSISYNCH_LOCKMGR_DEADLOCK_CHECK",
    -2147206998: "MSISYNCH_LOCKMGR_DESTROY",
    -2147206997: "MSISYNCH_LOCKMGR_DESTRUCTING",
    -2147207005: "MSISYNCH_LOCKMGR_INFO",
    -2147206996: "MSISYNCH_LOCKMGR_LOCK",
    -2147207003: "MSISYNCH_LOCKMGR_LOG",
    -2147207008: "MSISYNCH_LOCKSTACK_LOG",
    -2147206969: "MSISYNCH_LOCKVIOLATION",
    -2147207006: "MSISYNCH_LOGNOLOCK_LOCK",
    -2147207001: "MSISYNCH_LOGNOLOCK_LOCK_LIST",
    -2147207000: "MSISYNCH_LOGNOLOCK_LOCK_LIST_ELEMENT",
    -2147207007: "MSISYNCH_LOGNOLOCK_WAITING",
    -2147206978: "MSISYNCH_LOG_SYSTEM_ERROR",
    -2147206972: "MSISYNCH_MSIEVENT_LOG",
    -2147206975: "MSISYNCH_MSISIMPLE_CRITICALSECTION_LOG",
    -2147206974: "MSISYNCH_MSISIMPLE_MUTEX_LOG",
    -2147206973: "MSISYNCH_MSISIMPLE_RWLOCK_LOG",
    -2147206988: "MSISYNCH_MSISYNCHCONFIG_CLEAR_FLAG",
    -2147206992: "MSISYNCH_MSISYNCHCONFIG_DESTRUCTING",
    -2147206995: "MSISYNCH_MSISYNCHCONFIG_INIT",
    -2147206991: "MSISYNCH_MSISYNCHCONFIG_LOG",
    -2147206989: "MSISYNCH_MSISYNCHCONFIG_SET_CLASS_TRACE",
    -2147206990: "MSISYNCH_MSISYNCHCONFIG_SET_FLAG",
    -2147206994: "MSISYNCH_MSISYNCHCONFIG_START_LOGGING",
    -2147206993: "MSISYNCH_MSISYNCHCONFIG_STOP_LOGGING",
    -2147206962: "MSISYNCH_NOMATCHINGLOCK",
    -2147207004: "MSISYNCH_PARAMETER_ONLY",
    -2147206958: "MSISYNCH_READTOWRITE_FAILED",
    -2147206960: "MSISYNCH_STACKLOCKORDER",
    -2147206959: "MSISYNCH_STACK_NOTREADONLY",
    -2147206957: "MSISYNCH_STACK_NOTREADWRITE",
    -2147206951: "MSISYNCH_SYNCHEXCEPTION",
    -2147206950: "MSISYNCH_SYNCHEXCEPTION_REVALIDATE",
    -2147206970: "MSISYNCH_THREADALREADYWAIT",
    -2147207002: "MSISYNCH_THREADID",
    -2147206971: "MSISYNCH_THREADNOWAIT",
    -2147206965: "MSISYNCH_THREADWAIT",
    -2147206987: "MSISYNCH_TRACE_CALL",
    -2147206985: "MSISYNCH_TRACE_CREATION",
    -2147206984: "MSISYNCH_TRACE_DESTRUCTION",
    -2147206986: "MSISYNCH_TRACE_DETAIL",
    -2147206981: "MSISYNCH_TRACE_LOCK",
    -2147206980: "MSISYNCH_TRACE_LOCK_TIMEOUT",
    -2147206979: "MSISYNCH_TRACE_UNLOCK",
    -2147206983: "MSISYNCH_TRACE_WAIT",
    -2147206982: "MSISYNCH_TRACE_WAIT_FOR_LOCK",
    -2147206953: "MSISYNCH_UNDOCHECKUPGRADE_FAILED",
    -2147206954: "MSISYNCH_UNDO_DIFFERENTWAIT",
    -2147206955: "MSISYNCH_UNDO_NOWAIT",
    -2147206963: "MSISYNCH_UNLOCKMODE",
    -2147206964: "MSISYNCH_UNLOCKORDER",
    -2147207080: "MSITABLE_UNKNOWN_EXCEPTION",
    -2147207059: "MSITHREAD_ASSERT",
    -2147207058: "MSITHREAD_ASSERT_NEW",
    -2147207060: "MSITHREAD_ASSERT_SYSTEM_CALL",
    -2147207026: "MSITHREAD_BASICTHREADPOOL_CANCELLED_THREADS",
    -2147207022: "MSITHREAD_BASICTHREADPOOL_INIT",
    -2147207030: "MSITHREAD_BASICTHREADPOOL_LOG",
    -2147207028: "MSITHREAD_BASICTHREADPOOL_MINMAX_THREADS",
    -2147207027: "MSITHREAD_BASICTHREADPOOL_MSITHREAD",
    -2147207024: "MSITHREAD_BASICTHREADPOOL_MSITHREADPOOL_TASK",
    -2147207029: "MSITHREAD_BASICTHREADPOOL_STATUS_READERS",
    -2147207025: "MSITHREAD_BASICTHREADPOOL_TASK_SHADOW",
    -2147207023: "MSITHREAD_BASICTHREADPOOL_TRACE",
    -2147207052: "MSITHREAD_CANCEL_THREAD",
    -2147207067: "MSITHREAD_CATCH_ALL",
    -2147207068: "MSITHREAD_CATCH_SYNCH",
    -2147207036: "MSITHREAD_CHECKOUTINFO_LOG",
    -2147207013: "MSITHREAD_EXCEPTION_CAUGHT",
    -2147207053: "MSITHREAD_LOG",
    -2147207061: "MSITHREAD_LOG_SYSTEM_ERROR",
    -2147207042: "MSITHREAD_MSITHREADCONFIG_CLEAR_FLAG",
    -2147207048: "MSITHREAD_MSITHREADCONFIG_CONSTRUCT",
    -2147207047: "MSITHREAD_MSITHREADCONFIG_DESTRUCT",
    -2147207044: "MSITHREAD_MSITHREADCONFIG_LOG",
    -2147207043: "MSITHREAD_MSITHREADCONFIG_SET_FLAG",
    -2147207046: "MSITHREAD_MSITHREADCONFIG_START_LOGGING",
    -2147207045: "MSITHREAD_MSITHREADCONFIG_STOP_LOGGING",
    -2147207041: "MSITHREAD_MSITHREADMGR_CATCH_SYNCH",
    -2147207040: "MSITHREAD_MSITHREADMGR_CATCH_THREAD",
    -2147207033: "MSITHREAD_MSITHREADMGR_CHECKEDIN_BUSY",
    -2147207034: "MSITHREAD_MSITHREADMGR_CHECKEDOUT_THREADS",
    -2147207032: "MSITHREAD_MSITHREADMGR_FREE",
    -2147207035: "MSITHREAD_MSITHREADMGR_LOG",
    -2147207031: "MSITHREAD_MSITHREADMGR_SYSTEM_THREAD",
    -2147207039: "MSITHREAD_MSITHREADMGR_TRACE1",
    -2147207038: "MSITHREAD_MSITHREADMGR_TRACE2",
    -2147207037: "MSITHREAD_MSITHREADMGR_TRACE_CALL",
    -2147207050: "MSITHREAD_PREPARE_FOR_MURDER",
    -2147207051: "MSITHREAD_PREPARE_FOR_SUICIDE",
    -2147207049: "MSITHREAD_SET_TASK",
    -2147207057: "MSITHREAD_STARTFUNCTION_MSIEXCEPTION",
    -2147207055: "MSITHREAD_STARTFUNCTION_MSISYNCHEXCEPTION",
    -2147207056: "MSITHREAD_STARTFUNCTION_UNKNOWN_EXCEPTION",
    -2147207054: "MSITHREAD_STARTFUNCTION_UNKNOWN_EXCEPTION2",
    -2147207017: "MSITHREAD_THREADPOOLTASK_LOG",
    -2147207016: "MSITHREAD_THREADPOOLTASK_LOGNOLOCK",
    -2147207015: "MSITHREAD_THREADPOOLTASK_LOGNOLOCK_MTHREAD",
    -2147207014: "MSITHREAD_THREADPOOLTASK_LOGNOLOCK_NULL_THREAD",
    -2147207018: "MSITHREAD_THREADPOOLTASK_TRACE",
    -2147207019: "MSITHREAD_THREADPOOL_LIST",
    -2147207021: "MSITHREAD_THREADPOOL_LOG",
    -2147207020: "MSITHREAD_THREADPOOL_LOGNOLOCK",
    -2147207074: "MSITHREAD_TRACE_CALL",
    -2147207070: "MSITHREAD_TRACE_CANCEL",
    -2147207069: "MSITHREAD_TRACE_DESTRUCTION",
    -2147207073: "MSITHREAD_TRACE_DETAIL",
    -2147207071: "MSITHREAD_TRACE_OBJECT_CREATION",
    -2147207063: "MSITHREAD_TRACE_OWNERSHIP",
    -2147207062: "MSITHREAD_TRACE_RELEASE",
    -2147207072: "MSITHREAD_TRACE_TASK",
    -2147207064: "MSITHREAD_TRACE_TIMEOUT",
    -2147207066: "MSITHREAD_TRACE_WAIT",
    -2147207065: "MSITHREAD_TRACE_WAIT_COMPLETION",
    -2147207012: "MSITHREAD_UNEXCEPTION_CAUGHT",
    -2146944612: "MSITIMESERIES_INVALID_BEGINTIME",
    -2146944611: "MSITIMESERIES_NOLEGALDAY",
    -2147207379: "MSI_ACTMGR_ADDUSERPROPS",
    -2147207346: "MSI_ACTMGR_DELETEVALUE_FAILED",
    -2147207345: "MSI_ACTMGR_DELPROPS_FAILED",
    -2147207378: "MSI_ACTMGR_DELUSERPROPS",
    -2147207341: "MSI_ACTMGR_EXCEPTION_CAUGHT",
    -2147207343: "MSI_ACTMGR_GETPROPS_FAILED",
    -2147207381: "MSI_ACTMGR_GETUSERPROPS",
    -2147207385: "MSI_ACTMGR_INIT",
    -2147207380: "MSI_ACTMGR_INIT_DEFAULT_PROPS",
    -2147207344: "MSI_ACTMGR_LOADPROPS_FAILED",
    -2147207347: "MSI_ACTMGR_LOAD_PARAMTREE_FAILED",
    -2147207383: "MSI_ACTMGR_LOAD_PROPS",
    -2147207342: "MSI_ACTMGR_SETPROPS_FAILED",
    -2147207382: "MSI_ACTMGR_SETUSERPROPS",
    -2147207384: "MSI_ACTMGR_UNINIT",
    -2147207294: "MSI_ADDDBF_FAILED",
    -2147207444: "MSI_ADDJOB_ERROR",
    -2147207445: "MSI_ADDJOB_PROJECT_ERROR",
    -2147207282: "MSI_ADDPROJECT_FAILED",
    -2147209194: "MSI_ADDSTEP_ERROR",
    -2147209185: "MSI_ADDUSERJOB_ERROR",
    -2147209171: "MSI_ADD_SCHEDREQUEST_ERROR",
    -2147207583: "MSI_ANALYTICAL_ENGINE_SVR_TASK_RUN_MSIEXCEPTION",
    -2147207582: "MSI_ANALYTICAL_ENGINE_SVR_TASK_RUN_SYSTEM_EXCEPTION",
    -2147207291: "MSI_ASSIGNDEFDBD_FAILED",
    -2147206909: "MSI_AUTHEN_E_LOGIN_FAIL",
    -2147207191: "MSI_AUTOPROMPTTASK_ClosedChannel",
    -2147207200: "MSI_AUTOPROMPTTASK_MSIException",
    -2147207190: "MSI_AUTOPROMPTTASK_NULLChannel",
    -2147207194: "MSI_AUTOPROMPTTASK_NoJobErrorMessage",
    -2147207196: "MSI_AUTOPROMPTTASK_NoJobInMessage",
    -2147207195: "MSI_AUTOPROMPTTASK_NoJobOutMessage",
    -2147207197: "MSI_AUTOPROMPTTASK_NoJobReportInstance",
    -2147207198: "MSI_AUTOPROMPTTASK_NoProjectId",
    -2147207192: "MSI_AUTOPROMPTTASK_NoReportSourceServer",
    -2147207193: "MSI_AUTOPROMPTTASK_ReportSourceServerError",
    -2147207199: "MSI_AUTOPROMPTTASK_SystemException",
    -2147207865: "MSI_BACKUPDIRECTORY_ERROR",
    -2147207719: "MSI_BACKUP_FILEREAD_ERROR",
    -2147071867: "MSI_BINARY_SIZE_EXCEED_LIMIT",
    -2147073416: "MSI_CACHE_LOOKUP_SIZE_LIMITED",
    -2147073419: "MSI_CACHE_MEM_LIMITED",
    -2147468864: "MSI_CDSSINBOX_CLEAR_ERROR",
    -2147207910: "MSI_CDSSSERVERADMIN_DATA_TYPE_ERROR",
    -2147207903: "MSI_CDSSSERVERADMIN_DBF_PACKING_ERROR",
    -2147207923: "MSI_CDSSSERVERADMIN_ERROR_PACKING_CREATE_MSG",
    -2147207920: "MSI_CDSSSERVERADMIN_INCORRECT_LOGIN",
    -2147207917: "MSI_CDSSSERVERADMIN_LOGIN_DBF_FORMAT_ERROR",
    -2147207918: "MSI_CDSSSERVERADMIN_LOGIN_DBF_UNPACK_FAILURE",
    -2147207919: "MSI_CDSSSERVERADMIN_LOGIN_NO_DBF",
    -2147207916: "MSI_CDSSSERVERADMIN_LOGIN_NO_ID_PASSWORD",
    -2147207927: "MSI_CDSSSERVERADMIN_MSG_PACKING_ERROR",
    -2147207926: "MSI_CDSSSERVERADMIN_MSG_SENDING_ERROR",
    -2147207922: "MSI_CDSSSERVERADMIN_MSG_UNPACK_ERROR",
    -2147207907: "MSI_CDSSSERVERADMIN_MSIEXCEPTION",
    -2147207906: "MSI_CDSSSERVERADMIN_NOT_UNITIALIZE_QUEUE_STRUCTURE",
    -2147207935: "MSI_CDSSSERVERADMIN_NO_PROJECT_FOR_NEGATIVE_ID",
    -2147207921: "MSI_CDSSSERVERADMIN_NULL_ARGUMENT_POINTER",
    -2147207925: "MSI_CDSSSERVERADMIN_OUT_OF_MEMORY",
    -2147207930: "MSI_CDSSSERVERADMIN_PROJECTID_SET_FAILURE",
    -2147207931: "MSI_CDSSSERVERADMIN_PROJECT_ADD_FAILURE",
    -2147207929: "MSI_CDSSSERVERADMIN_PROJECT_DELETE_FAILURE",
    -2147207932: "MSI_CDSSSERVERADMIN_PROJECT_LOAD_FAILURE",
    -2147207913: "MSI_CDSSSERVERADMIN_PU_ADD_FAILURE",
    -2147207912: "MSI_CDSSSERVERADMIN_PU_DELETE_FAILURE",
    -2147207909: "MSI_CDSSSERVERADMIN_QUEUE_LOAD_FAILURE",
    -2147207934: "MSI_CDSSSERVERADMIN_REGISTRY_OPEN_FAILURE",
    -2147207914: "MSI_CDSSSERVERADMIN_ROOTQ_CREATION_FAILURE",
    -2147207905: "MSI_CDSSSERVERADMIN_SERVERADMIN_PARAM_LOAD_FAILURE",
    -2147207904: "MSI_CDSSSERVERADMIN_SERVERADMIN_STRUCTURE_ERROR",
    -2147207928: "MSI_CDSSSERVERADMIN_SERVERNET_NOT_SET",
    -2147207908: "MSI_CDSSSERVERADMIN_SERVER_CHANGE_ERROR",
    -2147207915: "MSI_CDSSSERVERADMIN_TASKLIST_CREATION_FAILURE",
    -2147207924: "MSI_CDSSSERVERADMIN_UNEXPECTED_ERROR",
    -2147207936: "MSI_CDSSSERVERADMIN_UNIT_LOAD_FAILURE",
    -2147207911: "MSI_CDSSSERVERADMIN_UPDATE_PARAMETER_FAILURE",
    -2147207286: "MSI_CHANGEDBPWD_FAILED",
    -2147209197: "MSI_CLOSEJOB_ERROR",
    -2147071907: "MSI_CLUSTER_AFFINITY_LOGIN_SERVER",
    -2147073418: "MSI_CLUSTER_DISABLED",
    -2147466620: "MSI_CLUSTER_SINGLE_NODE",
    -2147207167: "MSI_COMMANDPERMISSION_ERROR",
    -2147207170: "MSI_COMPONENTTASK_ComponentCancelError",
    -2147207171: "MSI_COMPONENTTASK_ComponentError",
    -2147207173: "MSI_COMPONENTTASK_GetNextStepError",
    -2147207176: "MSI_COMPONENTTASK_MSIException",
    -2147207172: "MSI_COMPONENTTASK_NoComponent",
    -2147207164: "MSI_COMPONENTTASK_NoErrorMessage",
    -2147207169: "MSI_COMPONENTTASK_NoJobProcessContext",
    -2147207163: "MSI_COMPONENTTASK_NoJobReportInstance",
    -2147207165: "MSI_COMPONENTTASK_NoOutputMessage",
    -2147207175: "MSI_COMPONENTTASK_NoProjectId",
    -2147207166: "MSI_COMPONENTTASK_NoRequestMessage",
    -2147207174: "MSI_COMPONENTTASK_SystemException",
    -2147209129: "MSI_COMUTIL_BACKUP_FAILED",
    -2147209130: "MSI_COMUTIL_EMPTY_FILENAME",
    -2147209128: "MSI_COMUTIL_FILECLOSED",
    -2147209132: "MSI_COMUTIL_FILEOPENED",
    -2147209131: "MSI_COMUTIL_FILEOPEN_FAILED",
    -2147206929: "MSI_CREATECLIENTFAIL",
    -2147207289: "MSI_CREATEDBLOGIN_FAILED",
    -2147209214: "MSI_CREATEJOB_ERROR",
    -2147072550: "MSI_CREATE_CUBEENTRY_FAILED",
    -2147207858: "MSI_CREATE_NEW_DBD",
    -2147209118: "MSI_CREATE_NTEVENT_FAILED",
    -2147072549: "MSI_CUBEENTRY_NOT_FOUND",
    -2147071814: "MSI_CUBEENTRY_NOT_FOUND2",
    -2147072537: "MSI_CUBEENTRY_UPDATE_FAILED",
    -2147025927: "MSI_CUBEFILE_READ",
    -2147072509: "MSI_CUBEMANANGER_CUBEEXEC_DIRTY",
    -2147072548: "MSI_CUBEMANANGER_NOT_INITIALIZED",
    -2147072541: "MSI_CUBE_ADMIN_FAILED",
    -2147072527: "MSI_CUBE_ADMIN_REMOTE_DISALLOWED",
    -2147072552: "MSI_CUBE_EXCEED_MAX_COUNT",
    -2147072551: "MSI_CUBE_EXCEED_MAX_MEMORY_USAGE",
    -2147071797: "MSI_CUBE_EXCEED_MAX_SERVER_MEMORY_USAGE",
    -2147071870: "MSI_CUBE_EXCEED_QUOTA",
    -2147071825: "MSI_CUBE_EXCEED_QUOTA2",
    -2147071811: "MSI_CUBE_EXCEED_QUOTA3",
    -2147072538: "MSI_CUBE_EXECUTING",
    -2147072194: "MSI_CUBE_EXECUTING_CUBE",
    -2147071789: "MSI_CUBE_EXPORT_FAIL",
    -2147025916: "MSI_CUBE_EXPORT_LOCK",
    -2147025929: "MSI_CUBE_FILE",
    -2147072543: "MSI_CUBE_FILE_CORRUPTED",
    -2147025917: "MSI_CUBE_FILE_EMPTY",
    -2147072546: "MSI_CUBE_FILE_NOT_FOUND",
    -2147072545: "MSI_CUBE_FILE_WRONG_VERSION",
    -2147025932: "MSI_CUBE_IMPORT_FAILED_IN_COPY",
    -2147025919: "MSI_CUBE_LOAD_ERROR",
    -2147071791: "MSI_CUBE_LOAD_FAILED",
    -2147071794: "MSI_CUBE_LOAD_IGNORED",
    -2147071792: "MSI_CUBE_LOAD_PUBLISH_READY",
    -2147071793: "MSI_CUBE_LOAD_SUCCEED",
    -2147072488: "MSI_CUBE_NOT_PUBLISHED",
    -2147072542: "MSI_CUBE_OFFLINE",
    -2147072540: "MSI_CUBE_PAGEIN_FAILED",
    -2147072539: "MSI_CUBE_PAGEOUT_FAILED",
    -2147025914: "MSI_CUBE_READ_LOCK",
    -2147072534: "MSI_CUBE_REQUEST_FAILED",
    -2147025925: "MSI_CUBE_UNUSABLE",
    -2147025924: "MSI_CUBE_UPGRADING",
    -2147156973: "MSI_DATASET_NOT_ADD_BECAUSE_OLDDE",
    -2147207863: "MSI_DATASOURCE_ERROR",
    -2147207853: "MSI_DBCONFIG_EXCEPTION",
    -2147207857: "MSI_DBDMANAGER_CONSTRUCTION",
    -2147207847: "MSI_DBDMANAGER_DELETEDBD",
    -2147207852: "MSI_DBDMANAGER_DESTRUCTION",
    -2147207844: "MSI_DBDMANAGER_GET_ALL_DBD_INFO",
    -2147207843: "MSI_DBDMANAGER_GET_ALL_DBD_INFO_FAILURE",
    -2147207845: "MSI_DBDMANAGER_GET_DBD_PROPERTIES",
    -2147207846: "MSI_DBDMANAGER_GET_DBD_PROPERTY",
    -2147207856: "MSI_DBDMANAGER_INIT",
    -2147207854: "MSI_DBDMANAGER_INIT_FAILURE",
    -2147207855: "MSI_DBDMANAGER_INIT_SUCCESS",
    -2147207848: "MSI_DBDMANAGER_SET_DBD_PROPERTY",
    -2147207842: "MSI_DBDMANAGER_SET_DEFAULT_DBD",
    -2147207106: "MSI_DBDRIVER_INIT",
    -2147207105: "MSI_DBDRIVER_UNINIT",
    -2147207850: "MSI_DBD_ADDKEY_FAILURE",
    -2147207851: "MSI_DBD_ALREADY_EXIST",
    -2147207849: "MSI_DBD_SETVALUECOPY_FAILURE",
    -2147207783: "MSI_DBROLEMGR_GETTING_CONNECTION",
    -2147207782: "MSI_DBROLEMGR_GOT_CONNECTION",
    -2147207141: "MSI_DB_DRIVER_INIT_FAILED",
    -2147209123: "MSI_DECRYPTION_FAILED",
    -2147025909: "MSI_DESKTOP_SERVER_INCOMPATIBLE",
    -2147270982: "MSI_DEVWKG_MAXSESSION_REACHED",
    -2147270983: "MSI_DEVWKG_MAX_USER_REACHED",
    -2147207498: "MSI_DISPLAYBASE_DISPLAYBASECONFIG_CONSTRUCT",
    -2147207497: "MSI_DISPLAYBASE_DISPLAYBASECONFIG_DESTRUCT",
    -2147207496: "MSI_DISPLAYBASE_DISPLAYBASECONFIG_START_LOGGING",
    -2147207495: "MSI_DISPLAYBASE_DISPLAYBASECONFIG_STOP_LOGGING",
    -2147207492: "MSI_DISPLAYCONTROLLERBASE_LOGNOLOCK",
    -2147207494: "MSI_DISPLAYCONTROLLERBASE_TRACE",
    -2147071866: "MSI_DI_ERROR_NO_SUBSCRIPTION",
    -2147466602: "MSI_DOCUMENT_STATIC",
    -2147071905: "MSI_DOC_CUBE_NOT_FOUND",
    -2147207576: "MSI_DSSACCOUNTMGR_MSIEXCEPTION",
    -2147207578: "MSI_DSSACCOUNTMGR_SERVER_NAME_NOT_INITIALIZED",
    -2147207577: "MSI_DSSACCOUNTMGR_UNKNOWN_ERROR",
    -2147207574: "MSI_DSSACCOUNTPROPERTY_MSIEXCEPTION",
    -2147207575: "MSI_DSSACCOUNTPROPERTY_UNKNOWN_ERROR",
    -2147205458: "MSI_DSSDATAMARTEXECUTETASK_INVALID_STEP",
    -2147205457: "MSI_DSSDATAMARTEXECUTETASK_MSIEXCEPTION",
    -2147205467: "MSI_DSSDATAMARTEXECUTETASK_NOPROCESSCONTEXT",
    -2147205460: "MSI_DSSDATAMARTEXECUTETASK_NOPROJECT",
    -2147205459: "MSI_DSSDATAMARTEXECUTETASK_PROMPT_NOANSWER",
    -2147205456: "MSI_DSSDATAMARTEXECUTETASK_SYSTEMEXCEPTION",
    -2147205443: "MSI_DSSDATAMARTREPORT_NO_REPORT",
    -2147207571: "MSI_DSSDBDS_DBD_NOT_FOUND",
    -2147207572: "MSI_DSSDBD_MSIEXCEPTION",
    -2147207573: "MSI_DSSDBD_UNKNOWN_ERROR",
    -2147207568: "MSI_DSSDBFS_DBF_NOT_FOUND",
    -2147207569: "MSI_DSSDBF_MSIEXCEPTION",
    -2147207570: "MSI_DSSDBF_UNKNOWN_ERROR",
    -2147207565: "MSI_DSSDBLOGINS_LOGIN_NOT_FOUND",
    -2147207566: "MSI_DSSDBLOGIN_MSIEXCEPTION",
    -2147207567: "MSI_DSSDBLOGIN_UNKNOWN_ERROR",
    -2147466492: "MSI_DSSDocumentDataPreparationTask_CreateDataModelFailed",
    -2147466600: "MSI_DSSDocumentDataPreparationTask_EvalViews",
    -2147466491: "MSI_DSSDocumentDataPreparationTask_InitDataModelFailed",
    -2147466489: "MSI_DSSDocumentDataPreparationTask_MSIException",
    -2147466494: "MSI_DSSDocumentDataPreparationTask_NoJobID",
    -2147466495: "MSI_DSSDocumentDataPreparationTask_NoProcessContext",
    -2147466493: "MSI_DSSDocumentDataPreparationTask_NoProject",
    -2147466490: "MSI_DSSDocumentDataPreparationTask_NoSession",
    -2147466601: "MSI_DSSDocumentDataPreparationTask_PopViews",
    -2147466599: "MSI_DSSDocumentDataPreparationTask_ResolveDocDef",
    -2147466488: "MSI_DSSDocumentDataPreparationTask_SystemException",
    -2147466631: "MSI_DSSDocumentExecuteTask_BadResolution",
    -2147468905: "MSI_DSSDocumentExecuteTask_CacheGraphBinary",
    -2147468910: "MSI_DSSDocumentExecuteTask_ErrorCreatingXMLContext",
    -2147468915: "MSI_DSSDocumentExecuteTask_ErrorCreatingXMLDocument",
    -2147469026: "MSI_DSSDocumentExecuteTask_ErrorReplyMessage",
    -2147469050: "MSI_DSSDocumentExecuteTask_Execute",
    -2147469034: "MSI_DSSDocumentExecuteTask_FindReport",
    -2147466630: "MSI_DSSDocumentExecuteTask_GetChildrenRes",
    -2147469049: "MSI_DSSDocumentExecuteTask_GetCount",
    -2147469014: "MSI_DSSDocumentExecuteTask_GetExecutionID",
    -2147468909: "MSI_DSSDocumentExecuteTask_GetInBoxMessageResult",
    -2147468907: "MSI_DSSDocumentExecuteTask_GetNodeXML",
    -2147468908: "MSI_DSSDocumentExecuteTask_GetOutXMLNode",
    -2147468911: "MSI_DSSDocumentExecuteTask_GetSessionManager",
    -2147469018: "MSI_DSSDocumentExecuteTask_InMsgBegin",
    -2147469030: "MSI_DSSDocumentExecuteTask_InReplyMessage",
    -2147469009: "MSI_DSSDocumentExecuteTask_MSIException",
    -2147469033: "MSI_DSSDocumentExecuteTask_NewInstance",
    -2147469041: "MSI_DSSDocumentExecuteTask_NoDefinition",
    -2147469051: "MSI_DSSDocumentExecuteTask_NoJobID",
    -2147469036: "MSI_DSSDocumentExecuteTask_NoObjectSource",
    -2147469052: "MSI_DSSDocumentExecuteTask_NoProcessContext",
    -2147469048: "MSI_DSSDocumentExecuteTask_NoProject",
    -2147469011: "MSI_DSSDocumentExecuteTask_NoReportInstance",
    -2147469035: "MSI_DSSDocumentExecuteTask_NoReportSource",
    -2147469040: "MSI_DSSDocumentExecuteTask_NoResolution",
    -2147469046: "MSI_DSSDocumentExecuteTask_NoServiceManager",
    -2147469047: "MSI_DSSDocumentExecuteTask_NoSession",
    -2147469043: "MSI_DSSDocumentExecuteTask_NoSessionID",
    -2147469044: "MSI_DSSDocumentExecuteTask_NoSessionManager",
    -2147469042: "MSI_DSSDocumentExecuteTask_NoUserHandle",
    -2147469045: "MSI_DSSDocumentExecuteTask_NoUserRuntime",
    -2147469028: "MSI_DSSDocumentExecuteTask_OutReplyMessage",
    -2147468914: "MSI_DSSDocumentExecuteTask_PopulateXMLContext",
    -2147469031: "MSI_DSSDocumentExecuteTask_ProcessContext",
    -2147469024: "MSI_DSSDocumentExecuteTask_ProcessContextInit",
    -2147469039: "MSI_DSSDocumentExecuteTask_PromptCount",
    -2147466629: "MSI_DSSDocumentExecuteTask_PutChildrenRes",
    -2147469020: "MSI_DSSDocumentExecuteTask_PutContextID",
    -2147469010: "MSI_DSSDocumentExecuteTask_PutDocumentReportInstance",
    -2147468906: "MSI_DSSDocumentExecuteTask_PutElementXML",
    -2147469025: "MSI_DSSDocumentExecuteTask_PutErrorSessionID",
    -2147468916: "MSI_DSSDocumentExecuteTask_PutExecuteFlags",
    -2147469029: "MSI_DSSDocumentExecuteTask_PutInSessionID",
    -2147206883: "MSI_DSSDocumentExecuteTask_PutOutSessionID",
    -2147469015: "MSI_DSSDocumentExecuteTask_PutParentID",
    -2147469021: "MSI_DSSDocumentExecuteTask_PutProjectID",
    -2147468912: "MSI_DSSDocumentExecuteTask_PutReportInBoxID",
    -2147469022: "MSI_DSSDocumentExecuteTask_PutReportInstance",
    -2147469013: "MSI_DSSDocumentExecuteTask_PutReportJobID",
    -2147469012: "MSI_DSSDocumentExecuteTask_PutReportStatus",
    -2147469019: "MSI_DSSDocumentExecuteTask_PutReturnCode",
    -2147469016: "MSI_DSSDocumentExecuteTask_PutUserHandle",
    -2147469017: "MSI_DSSDocumentExecuteTask_PutUserRuntime",
    -2147468913: "MSI_DSSDocumentExecuteTask_PutXMLContext",
    -2147469023: "MSI_DSSDocumentExecuteTask_ReportExecutionActions",
    -2147074304: "MSI_DSSDocumentExecuteTask_ReportPutExecutionStatus",
    -2147469038: "MSI_DSSDocumentExecuteTask_Resolve",
    -2147469037: "MSI_DSSDocumentExecuteTask_SetCount",
    -2147469008: "MSI_DSSDocumentExecuteTask_SystemException",
    -2147469032: "MSI_DSSDocumentExecuteTask_UserData",
    -2147468892: "MSI_DSSDocumentInstance_ErrorOpeningHTMLTemplate",
    -2147468637: "MSI_DSSDocumentInstance_ErrorOpeningHTMLTemplatePara",
    -2147468891: "MSI_DSSDocumentInstance_ErrorOpeningXSLFile",
    -2147468636: "MSI_DSSDocumentInstance_ErrorOpeningXSLFilePara",
    -2147467420: "MSI_DSSDocumentInstance_ErrorPopulatingGraphBinary",
    -2147468475: "MSI_DSSDocumentInstance_ErrorTransformingNode",
    -2147468890: "MSI_DSSDocumentInstance_ErrorWritingGraphFiles",
    -2147204461: "MSI_DSSDocumentInstance_NoExportDocument",
    -2147465075: "MSI_DSSDocumentManipulationTask_GenericError",
    -2147156466: "MSI_DSSDocumentManipulationTask_MSIException",
    -2147469003: "MSI_DSSDocumentSenderTask_HTMLOutput",
    -2147468999: "MSI_DSSDocumentSenderTask_MSIException",
    -2147469004: "MSI_DSSDocumentSenderTask_MsgBegin",
    -2147469006: "MSI_DSSDocumentSenderTask_NoDocumentInstance",
    -2147469005: "MSI_DSSDocumentSenderTask_NoOutMessage",
    -2147469007: "MSI_DSSDocumentSenderTask_NoProcessContext",
    -2147467402: "MSI_DSSDocumentSenderTask_PutCommandID",
    -2147469002: "MSI_DSSDocumentSenderTask_PutReportStatus",
    -2147469000: "MSI_DSSDocumentSenderTask_PutReturnCode",
    -2147469001: "MSI_DSSDocumentSenderTask_SaveToStream",
    -2147468998: "MSI_DSSDocumentSenderTask_SystemException",
    -2147207562: "MSI_DSSHOSTADMIN_CONFIGURATION_ERROR",
    -2147207555: "MSI_DSSHOSTADMIN_MACHINE_PARAM_LOAD_ERROR",
    -2147207563: "MSI_DSSHOSTADMIN_MSIEXCEPTION",
    -2147207556: "MSI_DSSHOSTADMIN_NOT_UNINITIALIZE_QUEUE",
    -2147207554: "MSI_DSSHOSTADMIN_PROCESSINGUNIT_LOAD_FAILURE",
    -2147207560: "MSI_DSSHOSTADMIN_REGISTRY_OPEN_ERROR",
    -2147207561: "MSI_DSSHOSTADMIN_REGISTRY_UPDATING_ERROR",
    -2147207557: "MSI_DSSHOSTADMIN_SERVERADMIN_STRUCTURE_ERROR",
    -2147207559: "MSI_DSSHOSTADMIN_SERVER_ADD_ERROR",
    -2147207558: "MSI_DSSHOSTADMIN_SERVER_DELETE_ERROR",
    -2147207564: "MSI_DSSHOSTADMIN_UNKNOWN_ERROR",
    -2147156464: "MSI_DSSImportDashboardsAsyncTask_MSIException",
    -2147207886: "MSI_DSSJOBS_INIT_FAILED",
    -2147207549: "MSI_DSSLOGINGRPS_LOGIN_GROUP_NOT_FOUND",
    -2147207550: "MSI_DSSLOGINGRP_MSIEXCEPTION",
    -2147207551: "MSI_DSSLOGINGRP_UNKNOWN_ERROR",
    -2147207547: "MSI_DSSLOGINMGR_MSIEXCEPTION",
    -2147207548: "MSI_DSSLOGINMGR_UNKNOWN_ERROR",
    -2147207546: "MSI_DSSLOGINS_LOGIN_NOT_FOUND",
    -2147207552: "MSI_DSSLOGIN_MSIEXCEPTION",
    -2147207553: "MSI_DSSLOGIN_UNKNOWN_ERROR",
    -2147071819: "MSI_DSSMPPPROFILE_RECEIVE_SUCCEED",
    -2147468920: "MSI_DSSMessageSenderTask_CachingGraphBinary",
    -2147207230: "MSI_DSSMessageSenderTask_ClosedChannel",
    -2147468925: "MSI_DSSMessageSenderTask_ErrorCreatingXMLDOMDocument",
    -2147468919: "MSI_DSSMessageSenderTask_ErrorFindingParentJob",
    -2147468924: "MSI_DSSMessageSenderTask_ErrorGettingInBoxMessageResult",
    -2147468935: "MSI_DSSMessageSenderTask_ErrorGettingJobManager",
    -2147468931: "MSI_DSSMessageSenderTask_ErrorGettingJobStatus",
    -2147468922: "MSI_DSSMessageSenderTask_ErrorGettingOutXML",
    -2147468923: "MSI_DSSMessageSenderTask_ErrorGettingOutXMLNode",
    -2147468929: "MSI_DSSMessageSenderTask_ErrorGettingParentDocumentInstance",
    -2147468934: "MSI_DSSMessageSenderTask_ErrorGettingParentJobID",
    -2147468930: "MSI_DSSMessageSenderTask_ErrorGettingParentProcessContext",
    -2147468933: "MSI_DSSMessageSenderTask_ErrorGettingReportInstance",
    -2147468926: "MSI_DSSMessageSenderTask_ErrorGettingSessionManager",
    -2147468932: "MSI_DSSMessageSenderTask_ErrorGettingUserData",
    -2147468927: "MSI_DSSMessageSenderTask_ErrorSettingDocumentReportStatus",
    -2147207231: "MSI_DSSMessageSenderTask_ErrorSettingReturnCode",
    -2147468921: "MSI_DSSMessageSenderTask_ErrorSettingXMLOnDocument",
    -2147207237: "MSI_DSSMessageSenderTask_MSIException",
    -2147207229: "MSI_DSSMessageSenderTask_NULLChannel",
    -2147207233: "MSI_DSSMessageSenderTask_NoErrorMessage",
    -2147207234: "MSI_DSSMessageSenderTask_NoOutputMessage",
    -2147207236: "MSI_DSSMessageSenderTask_NoProjectId",
    -2147207235: "MSI_DSSMessageSenderTask_SystemException",
    -2147207232: "MSI_DSSMessageSenderTask_UnknownMessage",
    -2147209115: "MSI_DSSPARAMETERS_FAILED",
    -2147207528: "MSI_DSSPROJECTADMIN_MSIEXCEPTION",
    -2147207529: "MSI_DSSPROJECTADMIN_UNKNOWN_ERROR",
    -2147207527: "MSI_DSSPROJECTS_PROJECT_NOT_FOUND",
    -2147207530: "MSI_DSSPROJECT_MSIEXCEPTION",
    -2147207531: "MSI_DSSPROJECT_UNKNOWN_ERROR",
    -2147207533: "MSI_DSSPUS_PU_NAME_GET_FAILURE",
    -2147207532: "MSI_DSSPUS_PU_NOT_FOUND",
    -2147207539: "MSI_DSSPU_DATA_TYPE_ERROR",
    -2147207534: "MSI_DSSPU_LOADDEF_MSIEXCEPTION",
    -2147207541: "MSI_DSSPU_NAME_CHANGE_FAILURE",
    -2147207537: "MSI_DSSPU_NOT_UNITIALIZE_QUEUE",
    -2147207499: "MSI_DSSPU_NULL_ARGUMENT_POINTER",
    -2147207538: "MSI_DSSPU_PARAM_UPDATE_ERROR",
    -2147207545: "MSI_DSSPU_PU_DEF_FAILURE",
    -2147207536: "MSI_DSSPU_PU_PARAM_FAILURE",
    -2147207535: "MSI_DSSPU_PU_STRUCTURE_FAILURE",
    -2147207540: "MSI_DSSPU_QUEUE_DEF_ERROR",
    -2147207544: "MSI_DSSPU_REGISTRY_OPEN_ERROR",
    -2147207543: "MSI_DSSPU_SUBQ_ADD_FAILURE",
    -2147207512: "MSI_DSSQUEUES_QNAME_GET_FAILURE",
    -2147207511: "MSI_DSSQUEUES_QUEUE_NOT_FOUND",
    -2147207515: "MSI_DSSQUEUE_ARG_PF_ERROR",
    -2147207513: "MSI_DSSQUEUE_DATA_TYPE_ERROR",
    -2147207522: "MSI_DSSQUEUE_LOWER_BOUND_FAILURE",
    -2147207519: "MSI_DSSQUEUE_NOT_UNITIALIZE_QUEUE",
    -2147207517: "MSI_DSSQUEUE_NULL_ARGUMENT_POINTER",
    -2147207516: "MSI_DSSQUEUE_PARAM_UPDATE_ERROR",
    -2147207526: "MSI_DSSQUEUE_QUEUE_DEF_ERROR",
    -2147207514: "MSI_DSSQUEUE_QUEUE_NAME_UPDATE_ERROR",
    -2147207518: "MSI_DSSQUEUE_QUEUE_STRUCTURE_ERROR",
    -2147207525: "MSI_DSSQUEUE_REGISTRY_OPEN_ERROR",
    -2147207523: "MSI_DSSQUEUE_SUBQ_ADD_FAILURE",
    -2147207520: "MSI_DSSQUEUE_SUBQ_DELETE_FAILURE",
    -2147207542: "MSI_DSSQUEUE_TASK_DELETE_FAILURE",
    -2147207521: "MSI_DSSQUEUE_UPPER_BOUND_FAILURE",
    -2147468850: "MSI_DSSREQUESTEXECUTETASK_EXECUTE",
    -2147468849: "MSI_DSSREQUESTEXECUTETASK_MSIEXCEPTION",
    -2147468852: "MSI_DSSREQUESTEXECUTETASK_NOJOBID",
    -2147468853: "MSI_DSSREQUESTEXECUTETASK_NOPROCESSCONTEXT",
    -2147468851: "MSI_DSSREQUESTEXECUTETASK_NOPROJECT",
    -2147468848: "MSI_DSSREQUESTEXECUTETASK_SYSTEMEXCEPTION",
    -2147468843: "MSI_DSSREQUESTINSTANCE_CONSTRUCT_USERRUNTIME_FAIL",
    -2147468846: "MSI_DSSREQUESTINSTANCE_CORRUPT_REQUEST",
    -2147468842: "MSI_DSSREQUESTINSTANCE_NO_REPORT_EXECUTE_RIGHT",
    -2147468845: "MSI_DSSREQUESTINSTANCE_REPORT_NOT_FOUND",
    -2147468844: "MSI_DSSREQUESTINSTANCE_USER_NOT_EXISTED",
    -2147207580: "MSI_DSSSERVERADMIN_FAIL_TO_GET_SERVER_NAME",
    -2147207579: "MSI_DSSSERVERADMIN_NOT_FOUND",
    -2147207795: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_DISPLAYLOAD_EXCEPTION",
    -2147207796: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_FAILED",
    -2147207785: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_JOB_EXCEPTION",
    -2147207787: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_LOGGING_EXCEPTION",
    -2147207789: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_PROJECTMONITOR_EXCEPTION",
    -2147207793: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_THREAD_EXCEPTION",
    -2147207794: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_UNKNOWN_DISPLAYLOAD_EXCEPTION",
    -2147207784: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_UNKNOWN_JOB_EXCEPTION",
    -2147207786: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_UNKNOWN_LOGGING_EXCEPTION",
    -2147207788: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_UNKNOWN_PROJECTMONITOR_EXCEPTION",
    -2147207792: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_UNKNOWN_THREAD_EXCEPTION",
    -2147207790: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_UNKNOWN_USERMONITOR_EXCEPTION",
    -2147207791: "MSI_DSSSERVER_CONSOLE_ADMIN_TASK_RUN_USERMONITOR_EXCEPTION",
    -2147207749: "MSI_DSSSERVER_CREATING_SERVICE",
    -2147207745: "MSI_DSSSERVER_DELETE_SERVICE_ERROR",
    -2147207760: "MSI_DSSSERVER_ERROR_SETTING_TO_START_PENDING",
    -2147207800: "MSI_DSSSERVER_FIND_CONSOLE_WINDOW",
    -2147207799: "MSI_DSSSERVER_FIND_CONSOLE_WINDOW_ERROR",
    -2147207798: "MSI_DSSSERVER_FIND_CONSOLE_WINDOW_TITLE_MATCH",
    -2147207797: "MSI_DSSSERVER_FIND_CONSOLE_WINDOW_TITLE_NOT_MATCH",
    -2147207750: "MSI_DSSSERVER_GET_DIRECTORY_ERROR",
    -2147207772: "MSI_DSSSERVER_INVALID_USERPASSWORD",
    -2147207802: "MSI_DSSSERVER_LOG_SYSTEM_ERROR",
    -2147207751: "MSI_DSSSERVER_OPEN_SCMANAGER_ERROR",
    -2147207746: "MSI_DSSSERVER_OPEN_SERVICE_ERROR",
    -2147207801: "MSI_DSSSERVER_PRINT_JOB_ERROR",
    -2147207779: "MSI_DSSSERVER_SERVICE_CONTROL",
    -2147207774: "MSI_DSSSERVER_SERVICE_CONTROL_ERROR",
    -2147207777: "MSI_DSSSERVER_SERVICE_CONTROL_INTERROGATE",
    -2147207762: "MSI_DSSSERVER_SERVICE_CONTROL_REGISTER",
    -2147207761: "MSI_DSSSERVER_SERVICE_CONTROL_REGISTER_ERROR",
    -2147207778: "MSI_DSSSERVER_SERVICE_CONTROL_STOP",
    -2147207776: "MSI_DSSSERVER_SERVICE_CONTROL_UNKNOWN_CODE",
    -2147207748: "MSI_DSSSERVER_SERVICE_CREATION_ERROR",
    -2147207747: "MSI_DSSSERVER_SERVICE_CREATION_SUCCESS",
    -2147207744: "MSI_DSSSERVER_SERVICE_DELETION_SUCCESS",
    -2147207753: "MSI_DSSSERVER_SET_SERVICE_CONTROL_DISPATCHER",
    -2147207756: "MSI_DSSSERVER_SET_WORKING_DIRECTORY",
    -2147207755: "MSI_DSSSERVER_SET_WORKING_DIRECTORY_ERROR",
    -2147207754: "MSI_DSSSERVER_STARTING_SERVICE",
    -2147207765: "MSI_DSSSERVER_START_ATTEMPTING_TO_SHUTDOWN",
    -2147207773: "MSI_DSSSERVER_START_ERROR",
    -2147207771: "MSI_DSSSERVER_START_ERROR_SETTING_TO_RUNNING",
    -2147207770: "MSI_DSSSERVER_START_ERROR_SETTING_TO_STOPPED",
    -2147207769: "MSI_DSSSERVER_START_EXCEPTION",
    -2147207763: "MSI_DSSSERVER_START_EXCEPTION_IN_SHUTDOWN",
    -2147207752: "MSI_DSSSERVER_START_SERVICE_CONTROL_DISPATCHER_ERROR",
    -2147207767: "MSI_DSSSERVER_START_SETTING_TO_RUNNING",
    -2147207764: "MSI_DSSSERVER_START_SHUTDOWN_SUCCESS",
    -2147207768: "MSI_DSSSERVER_START_UNKNOWN_EXCEPTION",
    -2147207766: "MSI_DSSSERVER_START_WAITING_FOR_SHUTDOWN",
    -2147207501: "MSI_DSSTASKS_TASK_NAME_GET_ERROR",
    -2147207500: "MSI_DSSTASKS_TASK_NOT_FOUND",
    -2147207507: "MSI_DSSTASK_DATA_TYPE_ERROR",
    -2147207503: "MSI_DSSTASK_MSIEXCEPTION",
    -2147207510: "MSI_DSSTASK_NAME_CHANGE_ERROR",
    -2147207505: "MSI_DSSTASK_NOT_UNITIALIZE_QUEUE",
    -2147207509: "MSI_DSSTASK_NULL_ARGUMENT_POINTER",
    -2147207506: "MSI_DSSTASK_PARAM_UPDATE_ERROR",
    -2147207508: "MSI_DSSTASK_QUEUE_DEF_ERROR",
    -2147207524: "MSI_DSSTASK_REGISTRY_OPEN_ERROR",
    -2147207504: "MSI_DSSTASK_TASK_PARAM_LOAD_ERROR",
    -2147207502: "MSI_DSSTASK_TASK_STRUCT_LOAD_ERROR",
    -2147207736: "MSI_DSS_SQL_ENGINE_SERVER_TASK_RUN_MSIEXCEPTION",
    -2147207735: "MSI_DSS_SQL_ENGINE_SERVER_TASK_RUN_SYSTEM_EXCEPTION",
    -2147049892: "MSI_DS_EMMA_CUBE_TABLE_MISMATCH",
    -2147072205: "MSI_DS_E_ABSOLUTE_PATH_NOT_SUPPORTED",
    -2147072245: "MSI_DS_E_CONTACT_DISABLED",
    -2147072246: "MSI_DS_E_CONTACT_NOT_FOUND",
    -2147072207: "MSI_DS_E_FAILED_INITIALIZING_PRINT_DATA_TRANSMITTER",
    -2147072200: "MSI_DS_E_INCREMENTAL_FETCH_SIZE_TOO_BIG",
    -2147072247: "MSI_DS_E_NOT_SUPPORTED_CUBE",
    -2147072201: "MSI_DS_E_UNKNOWN_CONTENT_SERVICE_TYPE",
    -2147071915: "MSI_DS_MAX_JOB_IS_ZERO",
    -2147050191: "MSI_DS_SYSSCHEDULE_MISMATCH",
    -2147050192: "MSI_DS_SYSSCHEDULE_MISSING",
    -2147071853: "MSI_DUPLICATE_SCHEMA_INSTANCE_ID",
    -2147466604: "MSI_DocumentDataPreparationTask_ReportIncomplete",
    -2147205441: "MSI_EDITION_LIMITED_COMMAND",
    -2147207211: "MSI_ELEMENTSERVERTASK_ClosedChannel",
    -2147207213: "MSI_ELEMENTSERVERTASK_ElementServerError",
    -2147207220: "MSI_ELEMENTSERVERTASK_MSIException",
    -2147207210: "MSI_ELEMENTSERVERTASK_NULLChannel",
    -2147207212: "MSI_ELEMENTSERVERTASK_NoElementServer",
    -2147207214: "MSI_ELEMENTSERVERTASK_NoJobErrorMessage",
    -2147207215: "MSI_ELEMENTSERVERTASK_NoJobInMessage",
    -2147207216: "MSI_ELEMENTSERVERTASK_NoJobOutMessage",
    -2147207217: "MSI_ELEMENTSERVERTASK_NoJobReportInstance",
    -2147207218: "MSI_ELEMENTSERVERTASK_NoProjectId",
    -2147207219: "MSI_ELEMENTSERVERTASK_SystemException",
    -2147209124: "MSI_ENCRYPTION_FAILED",
    -2147209125: "MSI_ENCRYPTOR_APICALL_FAILED",
    -2147209119: "MSI_ENCRYPTOR_DECRYPT",
    -2147209126: "MSI_ENCRYPTOR_INIT_FAILED",
    -2147209127: "MSI_ENCRYPTOR_INIT_SUCCESS",
    -2147209122: "MSI_ENCRYPTOR_INTERNAL_ERROR",
    -2147209121: "MSI_ENCRYPTOR_NULL_KEY",
    -2147209120: "MSI_ENCRYPTOR_NULL_KEY1",
    -2147205452: "MSI_EVAL_VERSION_EXPIRED",
    -2147206930: "MSI_EXCEEDPOOLLIMIT",
    -2147209146: "MSI_EXCEPTION_CAUGHT",
    -2147209209: "MSI_EXTRACTDBF_ERROR",
    -2147209172: "MSI_EXTRACT_SCHEDBUFSIZE_ERROR",
    -2147209174: "MSI_EXTRACT_SCHEDREQUEST_ERROR",
    -2147464993: "MSI_E_ADD_CUBE_WITH_RA",
    -2147206926: "MSI_E_CACHE_ADMINISTRATION",
    -2147203633: "MSI_E_CLIENT_NEWER_THAN_SERVER",
    -2147072587: "MSI_E_CLIENT_TOO_OLD",
    -2147025407: "MSI_E_CLIENT_UPGRADE_DUE_TO_HASH",
    -2147205280: "MSI_E_CONTRACT_MANAGER_ALLOC_FAIL",
    -2147464994: "MSI_E_CREATE_VI_WITH_RA",
    -2147071843: "MSI_E_CUBE_IN_USE",
    -2147464995: "MSI_E_CUBE_WITH_RA",
    -2147464985: "MSI_E_DOSSIER_FORBIDDEN_ATL",
    -2147464986: "MSI_E_DOSSIER_FORBIDDEN_RWD_PUBLISHED",
    -2147464987: "MSI_E_DOSSIER_FORBIDDEN_SAVE_OFP",
    -2147464988: "MSI_E_DOSSIER_NONPERSISTED_PUBLISH",
    -2147464982: "MSI_E_DOSSIER_PROMPT_NO_ANSWER",
    -2147074309: "MSI_E_DSSDocumentInstance_HTMLTemplate_ElemIDNotFound",
    -2147074308: "MSI_E_DSSDocumentInstance_HTMLTemplate_XSLNotFound",
    -2147467423: "MSI_E_DUPLICATE_RI_FAILED",
    -2147074305: "MSI_E_DocumentInstance_HTMLTemplate_AbruptEnd",
    -2147074307: "MSI_E_DocumentInstance_HTMLTemplate_IncompleteXSLFileName",
    -2147074306: "MSI_E_DocumentInstance_HTMLTemplate_XSLFileNameEndNotFound",
    -2147205477: "MSI_E_ENCRYPTION_VERSION_INCOMPATIBLE",
    -2147205260: "MSI_E_ETL_FAILED_CONNECT_REPOSITORY",
    -2147205259: "MSI_E_ETL_FAILED_LOAD_MAPPINGS",
    -2147074299: "MSI_E_ETL_FAIL_EXECUTE",
    -2147074206: "MSI_E_ETL_MUST_USE_PROJ_SESSION",
    -2147074301: "MSI_E_ETL_SERVICE_NOT_AVAILABLE",
    -2147072513: "MSI_E_EXCEED_MAX_FAILED_LOGIN",
    -2147206927: "MSI_E_GET_CACHE_INFO",
    -2147473392: "MSI_E_IMPORT_FROM_OTHER_PROJECT",
    -2147205405: "MSI_E_INCORRECT_LDAP_CONFIG_AUTH_USER",
    -2147206928: "MSI_E_INDEX_OUTOF_RANGE",
    -2147025406: "MSI_E_ISERVER_UPGRADE_DUE_TO_HASH",
    -2147025419: "MSI_E_JWT_CERTIFICATE_LOAD_FAILURE",
    -2147025422: "MSI_E_JWT_DIGITAL_SIGN_FAILURE",
    -2147025418: "MSI_E_JWT_ENCRYPTOR_CREATION_FAILURE",
    -2147025424: "MSI_E_JWT_RSA_KEY_LOAD_FAILURE",
    -2147025423: "MSI_E_JWT_TOKEN_DECODE_FAILURE",
    -2147025421: "MSI_E_JWT_TOKEN_INVALID_JWT",
    -2147025420: "MSI_E_JWT_VERIFY_TOKEN_FAILURE",
    -2147205406: "MSI_E_LDAP_ANONYMOUS_BIND_FAIL",
    -2147072515: "MSI_E_LDAP_ANOTHER_BATCH_IMPORT",
    -2147202978: "MSI_E_LDAP_ATTRIBUTE_PROMPT",
    -2147203660: "MSI_E_LDAP_CERTIFICATE_NOT_FOUND",
    -2147202957: "MSI_E_LDAP_FIND_USER",
    -2147205410: "MSI_E_LDAP_FUNTION_NOT_FIND",
    -2147205408: "MSI_E_LDAP_NO_DLLS",
    -2147072512: "MSI_E_LDAP_NO_SEARCH_FILTER_FOR_DN",
    -2147466616: "MSI_E_LDAP_SEARCH_FILTER",
    -2147205271: "MSI_E_LDAP_SERVER_ERROR",
    -2147205409: "MSI_E_LDAP_SERVER_NOT_CONFIG",
    -2147205407: "MSI_E_LDAP_SESSION_INIT",
    -2147205370: "MSI_E_LDAP_SETTING_INCOMPLETE",
    -2147205404: "MSI_E_LDAP_VENDOR_NO_SSL",
    -2147204467: "MSI_E_LICENSE_NO_CPU",
    -2147204469: "MSI_E_LICENSE_OUT_OF_COMPLIANCE",
    -2147467416: "MSI_E_LOAD_CACHED_BASE_ERROR",
    -2147049887: "MSI_E_MAX_DATA_CELLS_EXCEEDED",
    -2147071817: "MSI_E_MAX_SCHEDULED_REFRESH_PER_DASHBOARD_EXCEEDED",
    -2147073423: "MSI_E_MAX_SESSION_EXCEEDED",
    -2147073424: "MSI_E_MAX_USER_EXCEEDED",
    -2147072562: "MSI_E_MCM_MEM_FRAGMENTED",
    -2147072563: "MSI_E_MCM_PB_LIMIT_REACHED",
    -2147072565: "MSI_E_MCM_SINGLE_ALLOC_LIMIT_REACHED",
    -2147072564: "MSI_E_MCM_VB_LIMIT_REACHED",
    -2147073380: "MSI_E_MEMORY_DEPLETION",
    -2147007855: "MSI_E_METADATA_NOT_INITIALIZED",
    -2147071767: "MSI_E_METADATA_SEARCH_WRONG_DOMAIN",
    -2147464999: "MSI_E_NO_CONVERT_TO_RWD_WITH_HA",
    -2147204466: "MSI_E_NO_CPU_ALLOWED",
    -2147464998: "MSI_E_NO_DATASET_WITH_HA",
    -2147204454: "MSI_E_NO_NT_SECURITY_SUPPORT",
    -2147072204: "MSI_E_NO_NT_SECURITY_SUPPORT_2",
    -2147464997: "MSI_E_NO_REPLACE_DATASET_WITH_HA",
    -2147465000: "MSI_E_NO_RWD_ON_HA",
    -2147025426: "MSI_E_OIDC_CERTIFICATE_LOAD_FAILURE",
    -2147025429: "MSI_E_OIDC_DIGITAL_SIGN_FAILURE",
    -2147025425: "MSI_E_OIDC_ENCRYPTOR_CREATION_FAILURE",
    -2147025431: "MSI_E_OIDC_RSA_KEY_LOAD_FAILURE",
    -2147025430: "MSI_E_OIDC_TOKEN_DECODE_FAILURE",
    -2147025428: "MSI_E_OIDC_TOKEN_INVALID_JWT",
    -2147025427: "MSI_E_OIDC_VERIFY_TOKEN_FAILURE",
    -2147464984: "MSI_E_PUBLISH_DOSSIER_FAILED",
    -2147071818: "MSI_E_REFRESHHISTORY_PROJECT_LEVEL",
    -2147205277: "MSI_E_REMOVE_CACHED_DBCONNECTION",
    -2147074354: "MSI_E_RQMGR_INVALIDCACHEOPTION",
    -2147074355: "MSI_E_RQMGR_INVALID_CACHECMD",
    -2147074340: "MSI_E_SCHEDULEALREADYEXISTS",
    -2147074341: "MSI_E_SCHEDULERLINKOBJECT_NOTFOUND",
    -2147205386: "MSI_E_SCHEDULER_COPYSCHEDULE",
    -2147205399: "MSI_E_SCHEDULER_FIREEVENT",
    -2147205384: "MSI_E_SCHEDULER_GETPERSONALIZATION",
    -2147205385: "MSI_E_SCHEDULER_GETSERVERLOCALTIME",
    -2147205402: "MSI_E_SCHEDULER_LOADSCHEDULEOBJECT",
    -2147205401: "MSI_E_SCHEDULER_LOADSCHEDULEOBJECTS",
    -2147205274: "MSI_E_SCHEDULER_NOT_INITIALIZED",
    -2147205393: "MSI_E_SCHEDULER_SCHEDULE",
    -2147205403: "MSI_E_SCHEDULER_SCHEDULEINSTANCES",
    -2147205398: "MSI_E_SCHEDULER_SCHEDULEINSTANCESALL",
    -2147205394: "MSI_E_SCHEDULER_SCHEDULEINSTANCESCONFIGURATION",
    -2147205395: "MSI_E_SCHEDULER_SCHEDULEINSTANCESDOCUMENT",
    -2147205397: "MSI_E_SCHEDULER_SCHEDULEINSTANCESGENERAL",
    -2147205396: "MSI_E_SCHEDULER_SCHEDULEINSTANCESREPORT",
    -2147203841: "MSI_E_SCHEDULER_SCHEDULEROBJECTS_FOLDER",
    -2147205383: "MSI_E_SCHEDULER_UNLOAD",
    -2147205400: "MSI_E_SCHEDULER_UNLOADSCHEDULEINSTANCES",
    -2147205392: "MSI_E_SCHEDULER_UNSCHEDULE",
    -2147205391: "MSI_E_SCHEDULER_UNSCHEDULEALL",
    -2147205387: "MSI_E_SCHEDULER_UNSCHEDULECONFIGURATION",
    -2147205388: "MSI_E_SCHEDULER_UNSCHEDULEDOCUMENT",
    -2147205390: "MSI_E_SCHEDULER_UNSCHEDULEGENERAL",
    -2147205389: "MSI_E_SCHEDULER_UNSCHEDULEREPORT",
    -2147204470: "MSI_E_SERIALIZATION_DATA_MISMATCH",
    -2147072589: "MSI_E_SERIALIZATION_EXCEPTION_DETECTED",
    -2147072492: "MSI_E_SERVERCONTROL",
    -2147007854: "MSI_E_SERVER_INSTANCE_IN_USE",
    -2147073381: "MSI_E_SERVER_STALLED",
    -2147025885: "MSI_E_SSL_PORT_SETUP_FAILURE",
    -2147072460: "MSI_E_SSO_GET_GROUPINFO",
    -2147072461: "MSI_E_SSO_GET_USERINFO",
    -2147073249: "MSI_E_TRUSTED_WEB_SERVER_EXISTED",
    -2147205281: "MSI_E_UNKNOWN_EXCEPTION_CAUGHT",
    -2147205382: "MSI_E_UNKNOWN_REQUEST",
    -2147204471: "MSI_E_UNKNOWN_SERIALIZATION_VERSION",
    -2147071916: "MSI_E_USER_NO_PERMISSION_TO_SERVER",
    -2147464996: "MSI_E_VI_WITH_RA",
    -2147207284: "MSI_GETALLDBLOGINS_FAILED",
    -2147207278: "MSI_GETDBFS_FAILED",
    -2147209208: "MSI_GETDBF_ERROR",
    -2147207285: "MSI_GETDBLOGIN_FAILED",
    -2147207292: "MSI_GETLISTOFDBFS_FAILED",
    -2147207283: "MSI_GETPROJECTLIST_FAILED",
    -2147209198: "MSI_GETUSERJOBS_USER_ERROR",
    -2147209163: "MSI_GET_DBMGR_FAILED",
    -2147071812: "MSI_GRAPH_BUDGETING_DIFFERENCE",
    -2147468855: "MSI_GRAPH_CANNOT_LOAD_DEFAULTTEMPLATE",
    -2147072490: "MSI_GRAPH_CATEGORY",
    -2147468856: "MSI_GRAPH_ENGINE_ERROR",
    -2147071981: "MSI_GRAPH_GANTT_DURATION",
    -2147071851: "MSI_GRAPH_GRAPH_HL_OVERFLOW",
    -2147071986: "MSI_GRAPH_HIST_BUCKET_COUNT",
    -2147071987: "MSI_GRAPH_HIST_BUCKET_RANGE",
    -2147071988: "MSI_GRAPH_HIST_RANGE_END",
    -2147071989: "MSI_GRAPH_HIST_RANGE_START",
    -2147468858: "MSI_GRAPH_INSUFFICIENT_DATA",
    -2147465267: "MSI_GRAPH_INSUFFICIENT_DATA_SUBTYPE",
    -2147467419: "MSI_GRAPH_INVALID_ATTRIBUTE_VALUE",
    -2147468857: "MSI_GRAPH_NO_DATA",
    -2147205479: "MSI_GRAPH_SAVE_FAIL",
    -2147072491: "MSI_GRAPH_SERIES",
    -2147071982: "MSI_GRAPH_STOCK_CLOSE",
    -2147071985: "MSI_GRAPH_STOCK_HIGH",
    -2147071984: "MSI_GRAPH_STOCK_LOW",
    -2147071983: "MSI_GRAPH_STOCK_OPEN",
    -2147072489: "MSI_GRAPH_VALUE",
    -2147203316: "MSI_HLCS_INIT_FAILED",
    -2147207468: "MSI_HYPHEN",
    -2147467417: "MSI_IDLEPROJECT_QUERYCANCEL_ERROR",
    -2147207324: "MSI_INBOXFILECORRUPTED",
    -2147468865: "MSI_INBOXMSG_CONSTRUCTRSLTERROR",
    -2147072195: "MSI_INBOXMSG_CUBENOTREADY",
    -2147465742: "MSI_INBOXMSG_CUBEREADY",
    -2147071914: "MSI_INBOXMSG_CUBE_REPUBLISHED",
    -2147468866: "MSI_INBOXMSG_DUPLICATEMSG",
    -2147468876: "MSI_INBOXMSG_EXECUTINGSQL",
    -2147468638: "MSI_INBOXMSG_EXECUTION_INTERRUPTED",
    -2147465806: "MSI_INBOXMSG_EXPORT_FILE_NOT_FOUND",
    -2147468861: "MSI_INBOXMSG_GENERAL_MSGTITLE",
    -2147468877: "MSI_INBOXMSG_GENERATINGSQL",
    -2147465079: "MSI_INBOXMSG_INCRERPT_ADD_READY",
    -2147465078: "MSI_INBOXMSG_INCRERPT_DELETE_READY",
    -2147465081: "MSI_INBOXMSG_INCRERPT_READY",
    -2147465080: "MSI_INBOXMSG_INCRERPT_READY_WITHTYPE",
    -2147465077: "MSI_INBOXMSG_INCRERPT_UPDATE_READY",
    -2147465076: "MSI_INBOXMSG_INCRERPT_UPSERT_READY",
    -2147467401: "MSI_INBOXMSG_LOADINGPROMPT",
    -2147466618: "MSI_INBOXMSG_MANIPULATION_NOT_SUPPORTED",
    -2147468647: "MSI_INBOXMSG_MAXSERVERUSERS_EXCEEDED",
    -2147467641: "MSI_INBOXMSG_MISMATCH",
    -2147468868: "MSI_INBOXMSG_NOFOLDERNAME",
    -2147468869: "MSI_INBOXMSG_NOOBJCREATORNAME",
    -2147468870: "MSI_INBOXMSG_NOOBJDESC",
    -2147468871: "MSI_INBOXMSG_NOOBJNAME",
    -2147468867: "MSI_INBOXMSG_NOPROJNAME",
    -2147071913: "MSI_INBOXMSG_NO_CUBE_BUT_PDF",
    -2147071912: "MSI_INBOXMSG_NO_CUBE_BUT_XSL",
    -2147468882: "MSI_INBOXMSG_PACKINGOUTPUT",
    -2147467612: "MSI_INBOXMSG_PERSISTERROR_STATUS_NOT_SAVED",
    -2147468854: "MSI_INBOXMSG_PERSISTRSLTERROR",
    -2147468885: "MSI_INBOXMSG_RESOLVINGRQST",
    -2147468878: "MSI_INBOXMSG_RQSTCANCELLED",
    -2147468887: "MSI_INBOXMSG_RQSTQUEUED",
    -2147467627: "MSI_INBOXMSG_RQST_NOT_SAVED",
    -2147468840: "MSI_INBOXMSG_RSLTNOTFOUND",
    -2147468888: "MSI_INBOXMSG_RSLTREADY",
    -2147466608: "MSI_INBOXMSG_RUNNINGONOTHERNODE",
    -2147468474: "MSI_INBOXMSG_STATEID_OVERFLOW",
    -2147072199: "MSI_INBOXMSG_STATICMSG_NO_RESULT",
    -2147467519: "MSI_INBOXMSG_SUBSETTINGMSG",
    -2147468875: "MSI_INBOXMSG_UNKNOWNSTATUS",
    -2147468883: "MSI_INBOXMSG_UPDATINGCACHE",
    -2147071856: "MSI_INBOXMSG_VERSIONID_NOT_MATCH",
    -2147468884: "MSI_INBOXMSG_WAITINGFORCACHE",
    -2147468879: "MSI_INBOXMSG_WAITINGFORCHILD",
    -2147137334: "MSI_INBOXMSG_WAITINGFORLOCALFILE",
    -2147468880: "MSI_INBOXMSG_WAITINGFORPROJECT",
    -2147468881: "MSI_INBOXMSG_WAITINGFORPROMPT",
    -2147468874: "MSI_INBOXMSG_WAITINGFORPU",
    -2147468873: "MSI_INBOXMSG_WAITINGONGOVERNOR",
    -2147468886: "MSI_INBOXMSG_XTABING",
    -2147467618: "MSI_INBOX_CACHEDRSLT_NOT_FOUND",
    -2147468975: "MSI_INBOX_CHANGE_MSGSTATUS_FAILED",
    -2147468973: "MSI_INBOX_CHILDRPT_MSG",
    -2147468976: "MSI_INBOX_CREATE_MSG_FAILED",
    -2147468974: "MSI_INBOX_DELETE_MSG_FAILED",
    -2147468639: "MSI_INBOX_DIRECTORY_ERROR",
    -2147071858: "MSI_INBOX_DOC_INST_INCOMPATIBLE",
    -2147468971: "MSI_INBOX_DUPLICATE_MSG_FAILED",
    -2147270773: "MSI_INBOX_FILESIZE_EXCEED_SYSTEM_LIMIT",
    -2147206853: "MSI_INBOX_FULL",
    -2147468645: "MSI_INBOX_GETMSGRSLT_ERROR",
    -2147468979: "MSI_INBOX_GETUSERINBOX_FAILED",
    -2147468977: "MSI_INBOX_INIT_MSG_FAILED",
    -2147272386: "MSI_INBOX_INVALID_REQTYPE",
    -2147272381: "MSI_INBOX_INVALID_RQSTSTATUS",
    -2147466627: "MSI_INBOX_KEEPASIS_LIMITED_MANIPULATION",
    -2147442746: "MSI_INBOX_MAXIMUM_FILESIZE_REACHED",
    -2147271032: "MSI_INBOX_MSG_HAS_NO_PROMPTANSWER",
    -2147206852: "MSI_INBOX_MSG_HAS_NO_RESULTS",
    -2147468986: "MSI_INBOX_MSG_NOT_FOUND",
    -2147468904: "MSI_INBOX_MSG_REACTIVATED",
    -2147468903: "MSI_INBOX_MSG_RSLT_NOT_READY",
    -2147072042: "MSI_INBOX_NEED_EXEC",
    -2147468928: "MSI_INBOX_NOT_ACTIVEMSG",
    -2147468860: "MSI_INBOX_NOT_GUEST_INBOX",
    -2147272385: "MSI_INBOX_NOT_PERSISTENTMSG",
    -2147272384: "MSI_INBOX_NOT_REPORTREQ",
    -2147466628: "MSI_INBOX_NOT_SUPPORTED",
    -2147272387: "MSI_INBOX_NO_PROJREPSOURCE",
    -2147468839: "MSI_INBOX_PARENT_NOT_FOUND",
    -2147468847: "MSI_INBOX_PERSIST_ERROR",
    -2147467518: "MSI_INBOX_REBUILD_UNFINISHED",
    -2147468972: "MSI_INBOX_SET_RQST_STATUS_FAILED",
    -2147468646: "MSI_INBOX_UNEXPECTED_MSGRSLT",
    -2147468978: "MSI_INBOX_USERINBOX_NOT_FOUND",
    -2147468902: "MSI_INBOX_ZERO_MAXMSGCOUNT",
    -2147209179: "MSI_INITMETA_ERROR",
    -2147209175: "MSI_INVALIDJOB_ERROR",
    -2147468991: "MSI_INVALID_AUTHMODE",
    -2147270981: "MSI_INVALID_LICENSE_KEY",
    -2147071854: "MSI_INVALID_SCHEMA_INSTANCE_ID",
    -2147206924: "MSI_INVALID_SESSION_ID",
    -2147071872: "MSI_IVE_ERROR_APPLY_TRANSFORMATIONS",
    -2147071871: "MSI_IVE_ERROR_MAP_COLUMNS",
    -2147071844: "MSI_IVE_ERROR_NO_EXTERNAL_SESSION",
    -2147071873: "MSI_IVE_ERROR_OBTAIN_DATA",
    -2147071874: "MSI_IVE_ERROR_OBTAIN_SOURCE",
    -2147071823: "MSI_IVE_ERROR_URL_DISABLED",
    -2147071822: "MSI_IVE_ERROR_URL_FILE_DISABLED",
    -2147071821: "MSI_IVE_ERROR_URL_FTP_DISABLED",
    -2147071820: "MSI_IVE_ERROR_URL_HTTP_DISABLED",
    -2147071869: "MSI_IVE_IMPORT_DATA_SUCCEED",
    -2147209176: "MSI_JOBEXECUTING_ERROR",
    -2147209069: "MSI_JOBEXEC_JOBCLOSE",
    -2147209070: "MSI_JOBEXEC_JOBREMOVE",
    -2147209068: "MSI_JOBEXEC_JOBWAITINGONGOVERNORS",
    -2147205498: "MSI_JOBEXEC_STOPPED",
    -2147205500: "MSI_JOBEXEC_WAITFORPROJECT",
    -2147205499: "MSI_JOBEXEC_WAITONGOVERNOR",
    -2147209196: "MSI_JOB_CANCELED_ERROR",
    -2147209204: "MSI_JOB_CREATION",
    -2147074194: "MSI_JOB_DESC_BATCH_CHILD_REPORT",
    -2147074193: "MSI_JOB_DESC_BATCH_REQUEST_EXECUTE",
    -2147074189: "MSI_JOB_DESC_CHILD_REPORT",
    -2147074192: "MSI_JOB_DESC_DATAMART_REPORT",
    -2147074195: "MSI_JOB_DESC_DOCUMENT",
    -2147074190: "MSI_JOB_DESC_DYNAMIC_REPORT",
    -2147074197: "MSI_JOB_DESC_ELEMENT",
    -2147074198: "MSI_JOB_DESC_METADATA",
    -2147074196: "MSI_JOB_DESC_REPORT",
    -2147074191: "MSI_JOB_DESC_UNKNOWN",
    -2147209074: "MSI_JOB_EXCEPTION",
    -2147209078: "MSI_JOB_GETPRIORITY_ERROR",
    -2147209072: "MSI_JOB_JOBINFO_EXCEPTION",
    -2147209071: "MSI_JOB_JOBINFO_SYSTEMEXCEPTION",
    -2147209073: "MSI_JOB_SYSTEMEXCEPTION",
    -2147209075: "MSI_JOB_TIMEOUTPERIODEXCEEDED",
    -2147209077: "MSI_JOB_UNEXPECTED_MSIEXCEPTION",
    -2147209076: "MSI_JOB_UNEXPECTED_SYSEXCEPTION",
    -2147203529: "MSI_JOB_WAITFORPROMPT_TIMEOUT",
    -2147025908: "MSI_KEYMANAGER_ERROR",
    -2147071826: "MSI_LAUNCH_BG_JOB",
    -2147207470: "MSI_LEFT_BRACKET",
    -2147204468: "MSI_LICENSE_CHECK_DISABLED",
    -2147073422: "MSI_LISTERNER_LIMITED",
    -2147209212: "MSI_LOADPROJ_ERROR",
    -2147025923: "MSI_LOAD_CUBE_FAILED",
    -2147207581: "MSI_LOAD_DBFS_FAILED",
    -2147209114: "MSI_LOAD_PARAMETER_TREE_DONE",
    -2147209113: "MSI_LOAD_PARAMETER_TREE_FAILED",
    -2147207335: "MSI_LOGINMGR_ACCESS_DENIED",
    -2147207406: "MSI_LOGINMGR_ADDGROUP",
    -2147207359: "MSI_LOGINMGR_ADDGROUP_FAILED",
    -2147207411: "MSI_LOGINMGR_ADDUSER",
    -2147207374: "MSI_LOGINMGR_ADDUSER_FAILED",
    -2147207368: "MSI_LOGINMGR_ADDUSER_TOGROUP_FAILED",
    -2147207404: "MSI_LOGINMGR_ADDUSER_TO_GROUP",
    -2147207377: "MSI_LOGINMGR_API_CALL_FAILED",
    -2147207357: "MSI_LOGINMGR_ASSUME_ID_EMPTY_HANDLE",
    -2147207356: "MSI_LOGINMGR_ASSUME_ID_FAILED",
    -2147207330: "MSI_LOGINMGR_BAD_PASSWD",
    -2147207397: "MSI_LOGINMGR_CHANGE_PASSWD",
    -2147207363: "MSI_LOGINMGR_CHANGE_PASSWD_FAILED",
    -2147207348: "MSI_LOGINMGR_CONFIG_PRIV_FAILED",
    -2147207413: "MSI_LOGINMGR_CONTROLLER_NAME",
    -2147207327: "MSI_LOGINMGR_DC_NOT_FOUND",
    -2147207410: "MSI_LOGINMGR_DELETEUSER",
    -2147207373: "MSI_LOGINMGR_DELETEUSER_FAILED",
    -2147207405: "MSI_LOGINMGR_DELETE_GROUP",
    -2147207350: "MSI_LOGINMGR_DELETE_GROUP_FAILED",
    -2147207388: "MSI_LOGINMGR_DUP_LOGINHANDLE",
    -2147207358: "MSI_LOGINMGR_DUP_LOGINHANDLE_FAILED",
    -2147207416: "MSI_LOGINMGR_EMPTY_DOMAIN_NAME",
    -2147207390: "MSI_LOGINMGR_GETALLGROUPS_LOCAL",
    -2147207389: "MSI_LOGINMGR_GETALLGROUPS_REMOTE",
    -2147207391: "MSI_LOGINMGR_GETALLUSERS",
    -2147207400: "MSI_LOGINMGR_GETGROUP_PROPS",
    -2147207386: "MSI_LOGINMGR_GETLOGIN_UNIQUE_ID",
    -2147207387: "MSI_LOGINMGR_GETUSERNAME",
    -2147207392: "MSI_LOGINMGR_GETUSER_PROP",
    -2147207393: "MSI_LOGINMGR_GETUSER_PROPS",
    -2147207360: "MSI_LOGINMGR_GET_ALLUSERS_FAILED",
    -2147207402: "MSI_LOGINMGR_GET_GROUPMEMBERS_LOCAL",
    -2147207401: "MSI_LOGINMGR_GET_GROUPMEMBERS_REMOTE",
    -2147207366: "MSI_LOGINMGR_GET_GROUPUSERS_FAILED",
    -2147207365: "MSI_LOGINMGR_GET_GROUP_PROP_FAILED",
    -2147207355: "MSI_LOGINMGR_GET_UNIQUE_LOGINID_FAILED",
    -2147207352: "MSI_LOGINMGR_GET_USER_PROP_FAILED",
    -2147207332: "MSI_LOGINMGR_GROUP_ALREADY_EXISTS",
    -2147207333: "MSI_LOGINMGR_GROUP_NOT_FOUND",
    -2147207415: "MSI_LOGINMGR_INIT",
    -2147207398: "MSI_LOGINMGR_INITUSER_PROPS",
    -2147207376: "MSI_LOGINMGR_INIT_FAILED",
    -2147207338: "MSI_LOGINMGR_INPUT_PARAM_ERROR",
    -2147207337: "MSI_LOGINMGR_INVALID_COMPUTER_NAME",
    -2147207375: "MSI_LOGINMGR_INVALID_SYSHANDLE",
    -2147207409: "MSI_LOGINMGR_LOGINUSER",
    -2147207371: "MSI_LOGINMGR_LOGINUSER_FAILED",
    -2147207407: "MSI_LOGINMGR_LOGOUTUSER",
    -2147207369: "MSI_LOGINMGR_LOGOUT_FAILED",
    -2147207408: "MSI_LOGINMGR_LOGTIME",
    -2147207334: "MSI_LOGINMGR_NETUSER_NOT_FOUND",
    -2147207336: "MSI_LOGINMGR_NOT_PRIMARY_DOMAIN",
    -2147207339: "MSI_LOGINMGR_PASSWD_TOO_SHORT",
    -2147207367: "MSI_LOGINMGR_REMUSER_FROMGROUP_FAILED",
    -2147207403: "MSI_LOGINMGR_REM_USER_FROM_GROUP",
    -2147207372: "MSI_LOGINMGR_REVERTSELF_FAILED",
    -2147207412: "MSI_LOGINMGR_SETDOMAIN",
    -2147207399: "MSI_LOGINMGR_SETGROUP_PROPS",
    -2147207394: "MSI_LOGINMGR_SETUSER_PROPERTY",
    -2147207395: "MSI_LOGINMGR_SETUSER_PROPS",
    -2147207353: "MSI_LOGINMGR_SET_GROUP_PROP_FAILED",
    -2147207361: "MSI_LOGINMGR_SET_USERPROP_FAILED",
    -2147207331: "MSI_LOGINMGR_SPECIAL_OP_VIOLATION",
    -2147207396: "MSI_LOGINMGR_SYS_CHANGE_PASSWD",
    -2147207414: "MSI_LOGINMGR_UNINIT",
    -2147207328: "MSI_LOGINMGR_UNKNOWN_ERROR",
    -2147207349: "MSI_LOGINMGR_UNKNOWN_EXCEPTION",
    -2147207340: "MSI_LOGINMGR_USER_EXISTS",
    -2147207370: "MSI_LOGINMGR_USER_MUST_CHANGE_PASSWD",
    -2147207329: "MSI_LOGINMGR_USER_NOTIN_GROUP",
    -2147207351: "MSI_LOGINMGR_USER_NOT_FOUND",
    -2147207354: "MSI_LOGIN_MGR_CHANGE_USERNAME_FAILED",
    -2147207362: "MSI_LOGIN_MGR_GET_USER_PROP_FAILED",
    -2147207364: "MSI_LOGIN_MGR_SET_GROUP_PROP_FAILED",
    -2147209199: "MSI_LOGOUTPROJECT_ERROR",
    -2147203124: "MSI_LOGOUTPROJECT_NOPROJNAME_ERROR",
    -2147209137: "MSI_LOGROUTER_PROCESS_ID",
    -2147209138: "MSI_LOGROUTER_THREAD_ID",
    -2147209136: "MSI_LOGROUTER_TIMESTAMP",
    -2147209099: "MSI_LOGRTR_CREATE_MUTEX_FAIL",
    -2147209100: "MSI_LOGRTR_NOTIFY_FAILED",
    -2147209110: "MSI_LOGRTR_NO_MSGDLL",
    -2147209134: "MSI_LOGRTR_NTEVENT_ON",
    -2147209111: "MSI_LOGRTR_REG_OPEN_FAIL",
    -2147209133: "MSI_LOGRTR_TRACING_ON",
    -2147209135: "MSI_LOGRTR_USING_DEFMSGDLL",
    -2147468841: "MSI_LOGUNPACKMSG_STRINGONLY",
    -2147209109: "MSI_LOG_RTR_EMPTY_SUBKEYS",
    -2147468990: "MSI_MD4_NOT_SUPPORTED",
    -2147207781: "MSI_METADATATASK_RUN_EXCEPTION",
    -2147207780: "MSI_METADATATASK_RUN_SYSTEM_EXCEPTION",
    -2147071804: "MSI_MPP_AGREE_SWITCH_CUBE",
    -2147071855: "MSI_MPP_CONTENTNODE_DOWN",
    -2147071842: "MSI_MPP_CONTENT_JOBLIMIT_EXCEEDED",
    -2147071805: "MSI_MPP_REQUEST_SWITCH_CUBE",
    -2147207440: "MSI_MSGBUF_E_BUFFER_TOO_SMALL",
    -2147207441: "MSI_MSGBUF_E_INVALID_MSG",
    -2147205473: "MSI_MSG_NOT_SAVED",
    -2147072061: "MSI_MSIDeliveryEngine_DeviceNoAccessRights",
    -2147072070: "MSI_MSIDeliveryEngine_Execute",
    -2147072069: "MSI_MSIDeliveryEngine_GetCount",
    -2147072065: "MSI_MSIDeliveryEngine_MSIException",
    -2147071810: "MSI_MSIDeliveryEngine_NoData",
    -2147072071: "MSI_MSIDeliveryEngine_NoJobID",
    -2147072072: "MSI_MSIDeliveryEngine_NoProcessContext",
    -2147072068: "MSI_MSIDeliveryEngine_NoProject",
    -2147072063: "MSI_MSIDeliveryEngine_NoReportInstance",
    -2147072067: "MSI_MSIDeliveryEngine_NoSession",
    -2147072066: "MSI_MSIDeliveryEngine_NoUserRuntime",
    -2147071809: "MSI_MSIDeliveryEngine_PartialData",
    -2147072064: "MSI_MSIDeliveryEngine_SystemException",
    -2147207489: "MSI_MSIJOBMGR_CLOSEJOB_ERROR",
    -2147207490: "MSI_MSIJOBMGR_CLOSING_JOB",
    -2147207491: "MSI_MSIJOBMGR_TIMEOUT_JOB",
    -2147207493: "MSI_MSILOG_OPERATOR_OVERLOAD",
    -2147071857: "MSI_NCS_AUTHEN_E_USER_NO_PRIV",
    -2147072198: "MSI_NCS_BULKEXPORT_TIMEOUT",
    -2147071799: "MSI_NCS_CONTACT_NOT_FOUND",
    -2147072519: "MSI_NCS_CS_NOT_AVAILABLE",
    -2147025886: "MSI_NCS_DDA_NOT_SUPPORT",
    -2147072193: "MSI_NCS_DEL_NOT_ADMINISTATOR",
    -2147072185: "MSI_NCS_DEL_NOT_CACHE",
    -2147072164: "MSI_NCS_DEL_NOT_CREATED_BY",
    -2147072187: "MSI_NCS_DEL_NOT_CUSTOM",
    -2147072167: "MSI_NCS_DEL_NOT_CUSTOM_DELIVERY",
    -2147072192: "MSI_NCS_DEL_NOT_DEAR",
    -2147072177: "MSI_NCS_DEL_NOT_DELIVERY",
    -2147072159: "MSI_NCS_DEL_NOT_DELIVERY_NOT",
    -2147072181: "MSI_NCS_DEL_NOT_DELIVERY_NO_SUCCESS",
    -2147072182: "MSI_NCS_DEL_NOT_DELIVERY_SUCCESS",
    -2147072176: "MSI_NCS_DEL_NOT_DEL_DEST_INFO",
    -2147072147: "MSI_NCS_DEL_NOT_DOCUMENT_NAME",
    -2147072191: "MSI_NCS_DEL_NOT_EMAIL",
    -2147072172: "MSI_NCS_DEL_NOT_EMAIL_ADDRESS",
    -2147072173: "MSI_NCS_DEL_NOT_EMAIL_ADDRESSES",
    -2147072166: "MSI_NCS_DEL_NOT_ERR_MSG",
    -2147072141: "MSI_NCS_DEL_NOT_FAILURE_DELIVERY",
    -2147072189: "MSI_NCS_DEL_NOT_FILE",
    -2147072169: "MSI_NCS_DEL_NOT_FILE_LOCATION",
    -2147072140: "MSI_NCS_DEL_NOT_FILE_NAME",
    -2147050202: "MSI_NCS_DEL_NOT_FTP",
    -2147072188: "MSI_NCS_DEL_NOT_HISTORY_LIST",
    -2147072168: "MSI_NCS_DEL_NOT_LINK_TO_FILE",
    -2147072146: "MSI_NCS_DEL_NOT_LINK_TO_HISTORY_LIST",
    -2147072145: "MSI_NCS_DEL_NOT_LINK_TO_HIST_NO_PRIV",
    -2147072186: "MSI_NCS_DEL_NOT_MOBILE",
    -2147072179: "MSI_NCS_DEL_NOT_NO_SUCCESS",
    -2147072190: "MSI_NCS_DEL_NOT_PRINT",
    -2147072170: "MSI_NCS_DEL_NOT_PRINTER_NAME",
    -2147072171: "MSI_NCS_DEL_NOT_PRINTER_NAMES",
    -2147072162: "MSI_NCS_DEL_NOT_PROJECT_NAME",
    -2147072174: "MSI_NCS_DEL_NOT_RECIPIENT",
    -2147072163: "MSI_NCS_DEL_NOT_REPORT_DOC_NAME",
    -2147072148: "MSI_NCS_DEL_NOT_REPORT_NAME",
    -2147072175: "MSI_NCS_DEL_NOT_RUN_AT",
    -2147072161: "MSI_NCS_DEL_NOT_SCHEDULE",
    -2147072143: "MSI_NCS_DEL_NOT_SCHEDULE_SEND_NOW",
    -2147072165: "MSI_NCS_DEL_NOT_SUBSCRIPTION_INFO",
    -2147072144: "MSI_NCS_DEL_NOT_SUBSCRIPTION_NAME",
    -2147072180: "MSI_NCS_DEL_NOT_SUCCESS",
    -2147072142: "MSI_NCS_DEL_NOT_SUCCESS_DELIVERY",
    -2147072178: "MSI_NCS_DEL_NOT_UPDATE",
    -2147072160: "MSI_NCS_DEL_NOT_UPDATE_NOT",
    -2147072183: "MSI_NCS_DEL_NOT_UPDATE_NO_SUCCESS",
    -2147072184: "MSI_NCS_DEL_NOT_UPDATE_SUCCESS",
    -2147072082: "MSI_NCS_DUPLICATE_ADDRESS_NAME",
    -2147072081: "MSI_NCS_DUPLICATE_ADDRESS_VALUE",
    -2147072521: "MSI_NCS_DUPLICATE_OBJECT_NAME",
    -2147072046: "MSI_NCS_END_OF_IN_LIST",
    -2147072463: "MSI_NCS_EXPIRATION_TIME_NOT_SET",
    -2147025883: "MSI_NCS_EXTERNAL_NOTIFICATION_PARAM_INVALID",
    -2147025884: "MSI_NCS_EXTERNAL_NOTIFICATION_USERS_NONFOUND",
    -2147072248: "MSI_NCS_E_DISALLOWED_CHAR",
    -2147072250: "MSI_NCS_E_INVALID_CONTACT_TYPE",
    -2147072249: "MSI_NCS_E_INVALID_DELIVERY_TYPE",
    -2147072459: "MSI_NCS_E_NO_DEFAULT_ADDRESS",
    -2147050203: "MSI_NCS_E_NO_DSPROP_TABLES",
    -2147072251: "MSI_NCS_E_NO_NCS_CS_TABLES",
    -2147072518: "MSI_NCS_INVALID_FILE_LOCATION",
    -2147071904: "MSI_NCS_INVALID_FILE_LOCATION_NOT_WRITABLE",
    -2147050199: "MSI_NCS_INVALID_FTP_LOCATION",
    -2147050198: "MSI_NCS_INVALID_FTP_LOCATION_COULDNT_CONNECT",
    -2147050201: "MSI_NCS_INVALID_FTP_LOCATION_LOGIN_ERROR",
    -2147071786: "MSI_NCS_INVALID_FTP_LOCATION_NOT_OVERWRITABLE",
    -2147050200: "MSI_NCS_INVALID_FTP_LOCATION_NOT_WRITABLE",
    -2147072523: "MSI_NCS_INVALID_GUID",
    -2147072520: "MSI_NCS_INVALID_OBJECT",
    -2147072522: "MSI_NCS_INVALID_POINTER",
    -2147072517: "MSI_NCS_INVALID_PRINTER",
    -2147072504: "MSI_NCS_MAX_SUBSCRIPTION_EXCEEDED",
    -2147072487: "MSI_NCS_MISMATCH_ADDRESS_CONTACT",
    -2147072524: "MSI_NCS_OBJECT_NOT_FOUND",
    -2147072464: "MSI_NCS_UNKNOWN_DELIVERY_TYPE",
    -2147071806: "MSI_NEED_RA_JOB",
    -2147209112: "MSI_NEW_DSSPARAMETERS_FAILED",
    -2147209186: "MSI_NEXTSTEP_ERROR",
    -2147207859: "MSI_NODATASOURCE_ERROR",
    -2147207326: "MSI_NOINBOXOBJECTFORUSER",
    -2147209195: "MSI_NOJOB_ERROR",
    -2147207325: "MSI_NOMESSAGEFOLDERFORUSER",
    -2147209189: "MSI_NOPUFORTASK",
    -2147207864: "MSI_NOSERVERDATASOURCE_ERROR",
    -2147207862: "MSI_NOSERVERDEF_ERROR",
    -2147206920: "MSI_NO_CONNECTION_FOUND",
    -2147205372: "MSI_NO_ENCRYPTION_SUPPORT",
    -2147209116: "MSI_NTEVENT_INIT_FAILED",
    -2147209142: "MSI_NT_EVENT_ERR_MSG",
    -2147209140: "MSI_NT_EVENT_INF_MSG",
    -2147209139: "MSI_NT_EVENT_SUCCESS_MSG",
    -2147209141: "MSI_NT_EVENT_WARNING_MSG",
    -2147207642: "MSI_NULLELEMENTSERVER_ERROR",
    -2147209191: "MSI_NULLMSGPROCESSOR_ERROR",
    -2147209188: "MSI_NULLREPORTINSTANCE_ERROR",
    -2147209190: "MSI_NULLREPORTSOURCESERVER_ERROR",
    -2147207279: "MSI_NULL_DBDRIVER",
    -2147207202: "MSI_OBJECTSERVERTASK_ClosedChannel",
    -2147207209: "MSI_OBJECTSERVERTASK_MSIException",
    -2147207204: "MSI_OBJECTSERVERTASK_MsgProcessorError",
    -2147207201: "MSI_OBJECTSERVERTASK_NULLChannel",
    -2147207206: "MSI_OBJECTSERVERTASK_NoJobInMessage",
    -2147207205: "MSI_OBJECTSERVERTASK_NoJobOutMessage",
    -2147207203: "MSI_OBJECTSERVERTASK_NoMsgProcessor",
    -2147207207: "MSI_OBJECTSERVERTASK_NoProjectId",
    -2147207208: "MSI_OBJECTSERVERTASK_SystemException",
    -2147205478: "MSI_OPEN_FILE_FAILED",
    -2147209167: "MSI_PACK_SCHEDREQUESTLIST_ERROR",
    -2147209168: "MSI_PACK_SCHEDREQUESTSIZE_ERROR",
    -2146943358: "MSI_PACK_SNAPSHOT_ADDR_ERROR",
    -2146943360: "MSI_PACK_SNAPSHOT_COUNT_ERROR",
    -2146943359: "MSI_PACK_SNAPSHOT_SIZE_ERROR",
    -2147207467: "MSI_PARAMETER_ONLY",
    -2147072516: "MSI_PASSWORDPOLICY_COMPLEXITY",
    -2147072462: "MSI_PASSWORDPOLICY_COMPLEXITY_ERROR",
    -2147072514: "MSI_PASSWORDPOLICY_HISTORY",
    -2147072525: "MSI_PASSWORDPOLICY_MINIMUM_LENGTH",
    -2147180957: "MSI_PASSWORDPOLICY_VIOLATION",
    -2147072768: "MSI_PERFCOUNTER_ALLOCATED_SWAP_SPACE",
    -2147072618: "MSI_PERFCOUNTER_ALLOCATED_SWAP_SPACE_HELP",
    -2147072767: "MSI_PERFCOUNTER_AVAILABLE_SWAP_SPACE",
    -2147072617: "MSI_PERFCOUNTER_AVAILABLE_SWAP_SPACE_HELP",
    -2147072033: "MSI_PERFCOUNTER_AVERAGE_BISEARCH_TIME",
    -2147072032: "MSI_PERFCOUNTER_AVERAGE_BISEARCH_TIME_HELP",
    -2147072017: "MSI_PERFCOUNTER_AVERAGE_CACHESEARCH_TIME",
    -2147072016: "MSI_PERFCOUNTER_AVERAGE_CACHESEARCH_TIME_HELP",
    -2147071991: "MSI_PERFCOUNTER_AVERAGE_CHART_GENERATION_TIME",
    -2147071993: "MSI_PERFCOUNTER_AVERAGE_CLUSTERING_TIME",
    -2147071992: "MSI_PERFCOUNTER_AVERAGE_CLUSTERING_TIME_HELP",
    -2147072001: "MSI_PERFCOUNTER_AVERAGE_GETDOCUMENTS_TIME",
    -2147072000: "MSI_PERFCOUNTER_AVERAGE_GETDOCUMENTS_TIME_HELP",
    -2147071990: "MSI_PERFCOUNTER_AVERAGE_IMAGEMAP_GENERATION_TIME",
    -2147072025: "MSI_PERFCOUNTER_AVERAGE_MDSEARCH_TIME",
    -2147072024: "MSI_PERFCOUNTER_AVERAGE_MDSEARCH_TIME_HELP",
    -2147072752: "MSI_PERFCOUNTER_AVERAGE_REPORT_QUEUE_TIME",
    -2147072661: "MSI_PERFCOUNTER_AVERAGE_REPORT_QUEUE_TIME_HELP",
    -2147072751: "MSI_PERFCOUNTER_AVERAGE_REPORT_RESPONSE_TIME",
    -2147072660: "MSI_PERFCOUNTER_AVERAGE_REPORT_RESPONSE_TIME_HELP",
    -2147072009: "MSI_PERFCOUNTER_AVERAGE_SQLSEARCH_TIME",
    -2147072008: "MSI_PERFCOUNTER_AVERAGE_SQLSEARCH_TIME_HELP",
    -2147072728: "MSI_PERFCOUNTER_AVERAGE_USER_SESSION_LENGTH",
    -2147072637: "MSI_PERFCOUNTER_AVERAGE_USER_SESSION_LENGTH_HELP",
    -2147072035: "MSI_PERFCOUNTER_BISEARCH_COUNT",
    -2147072034: "MSI_PERFCOUNTER_BISEARCH_COUNT_HELP",
    -2147071942: "MSI_PERFCOUNTER_CACHECRAWLER_AVERAGE_GENERATEDOCUMENT_TIME",
    -2147071941: "MSI_PERFCOUNTER_CACHECRAWLER_AVERAGE_GENERATEDOCUMENT_TIME_HELP",
    -2147071950: "MSI_PERFCOUNTER_CACHECRAWLER_AVERAGE_LOADCACHE_TIME",
    -2147071949: "MSI_PERFCOUNTER_CACHECRAWLER_AVERAGE_LOADCACHE_TIME_HELP",
    -2147071934: "MSI_PERFCOUNTER_CACHECRAWLER_AVERAGE_SENDCOMMAND_TIME",
    -2147071933: "MSI_PERFCOUNTER_CACHECRAWLER_AVERAGE_SENDCOMMAND_TIME_HELP",
    -2147071944: "MSI_PERFCOUNTER_CACHECRAWLER_GENERATEDOCUMENT_COUNT",
    -2147071943: "MSI_PERFCOUNTER_CACHECRAWLER_GENERATEDOCUMENT_COUNT_HELP",
    -2147071948: "MSI_PERFCOUNTER_CACHECRAWLER_LAST_GENERATEDOCUMENT_TIME",
    -2147071947: "MSI_PERFCOUNTER_CACHECRAWLER_LAST_GENERATEDOCUMENT_TIME_HELP",
    -2147071956: "MSI_PERFCOUNTER_CACHECRAWLER_LAST_LOADCACHE_TIME",
    -2147071955: "MSI_PERFCOUNTER_CACHECRAWLER_LAST_LOADCACHE_TIME_HELP",
    -2147071940: "MSI_PERFCOUNTER_CACHECRAWLER_LAST_SENDCOMMAND_TIME",
    -2147071939: "MSI_PERFCOUNTER_CACHECRAWLER_LAST_SENDCOMMAND_TIME_HELP",
    -2147071952: "MSI_PERFCOUNTER_CACHECRAWLER_LOADCACHE_COUNT",
    -2147071951: "MSI_PERFCOUNTER_CACHECRAWLER_LOADCACHE_COUNT_HELP",
    -2147071936: "MSI_PERFCOUNTER_CACHECRAWLER_SENDCOMMAND_COUNT",
    -2147071935: "MSI_PERFCOUNTER_CACHECRAWLER_SENDCOMMAND_COUNT_HELP",
    -2147071946: "MSI_PERFCOUNTER_CACHECRAWLER_TOTAL_GENERATEDOCUMENT_TIME",
    -2147071945: "MSI_PERFCOUNTER_CACHECRAWLER_TOTAL_GENERATEDOCUMENT_TIME_HELP",
    -2147071954: "MSI_PERFCOUNTER_CACHECRAWLER_TOTAL_LOADCACHE_TIME",
    -2147071953: "MSI_PERFCOUNTER_CACHECRAWLER_TOTAL_LOADCACHE_TIME_HELP",
    -2147071938: "MSI_PERFCOUNTER_CACHECRAWLER_TOTAL_SENDCOMMAND_TIME",
    -2147071937: "MSI_PERFCOUNTER_CACHECRAWLER_TOTAL_SENDCOMMAND_TIME_HELP",
    -2147072019: "MSI_PERFCOUNTER_CACHESEARCH_COUNT",
    -2147072018: "MSI_PERFCOUNTER_CACHESEARCH_COUNT_HELP",
    -2147071995: "MSI_PERFCOUNTER_CLUSTERING_COUNT",
    -2147071994: "MSI_PERFCOUNTER_CLUSTERING_COUNT_HELP",
    -2147072592: "MSI_PERFCOUNTER_CPU",
    -2147072607: "MSI_PERFCOUNTER_CPU_TIME",
    -2147072237: "MSI_PERFCOUNTER_CUBES",
    -2147072236: "MSI_PERFCOUNTER_CUBES_HELP",
    -2147072239: "MSI_PERFCOUNTER_CUBES_IN_MEMORY",
    -2147072238: "MSI_PERFCOUNTER_CUBES_IN_MEMORY_HELP",
    -2147072243: "MSI_PERFCOUNTER_CUBE_COMPLETION",
    -2147072242: "MSI_PERFCOUNTER_CUBE_COMPLETION_HELP",
    -2147025411: "MSI_PERFCOUNTER_CUBE_ELEMENTBLOCKS_MEMORY",
    -2147025410: "MSI_PERFCOUNTER_CUBE_ELEMENTBLOCKS_MEMORY_HELP",
    -2147025386: "MSI_PERFCOUNTER_CUBE_INDEXKEYS_MEMORY",
    -2147025385: "MSI_PERFCOUNTER_CUBE_INDEXKEYS_MEMORY_HELP",
    -2147025409: "MSI_PERFCOUNTER_CUBE_ROWMAPS_MEMORY",
    -2147025408: "MSI_PERFCOUNTER_CUBE_ROWMAPS_MEMORY_HELP",
    -2147072231: "MSI_PERFCOUNTER_CUBE_SWAPS",
    -2147072230: "MSI_PERFCOUNTER_CUBE_SWAPS_HELP",
    -2147071911: "MSI_PERFCOUNTER_DBTABLE_MEMORY_USAGE",
    -2147071910: "MSI_PERFCOUNTER_DBTABLE_MEMORY_USAGE_HELP",
    -2147072225: "MSI_PERFCOUNTER_DOC_CACHES",
    -2147072224: "MSI_PERFCOUNTER_DOC_CACHES_HELP",
    -2147072227: "MSI_PERFCOUNTER_DOC_CACHES_IN_MEMORY",
    -2147072226: "MSI_PERFCOUNTER_DOC_CACHES_IN_MEMORY_HELP",
    -2147071758: "MSI_PERFCOUNTER_DOC_CACHE_HIT_RATIO",
    -2147071757: "MSI_PERFCOUNTER_DOC_CACHE_HIT_RATIO_HELP",
    -2147071901: "MSI_PERFCOUNTER_DOC_CACHE_INDEX",
    -2147071900: "MSI_PERFCOUNTER_DOC_CACHE_INDEX_HELP",
    -2147072217: "MSI_PERFCOUNTER_DOC_CACHE_SWAPS",
    -2147072216: "MSI_PERFCOUNTER_DOC_CACHE_SWAPS_HELP",
    -2147071754: "MSI_PERFCOUNTER_DOC_CACHE_UTILIZATION_RATIO",
    -2147071753: "MSI_PERFCOUNTER_DOC_CACHE_UTILIZATION_RATIO_HELP",
    -2147072606: "MSI_PERFCOUNTER_ELAPSE_TIME",
    -2147072750: "MSI_PERFCOUNTER_ELEMENT_BROWSE_SUBMISSION_RATE",
    -2147072659: "MSI_PERFCOUNTER_ELEMENT_BROWSE_SUBMISSION_RATE_HELP",
    -2147071897: "MSI_PERFCOUNTER_ELEMENT_SERVER_CACHE",
    -2147071896: "MSI_PERFCOUNTER_ELEMENT_SERVER_CACHE_HELP",
    -2147072749: "MSI_PERFCOUNTER_EXECUTING_REPORTS",
    -2147072658: "MSI_PERFCOUNTER_EXECUTING_REPORTS_HELP",
    -2147072764: "MSI_PERFCOUNTER_FREE_MEMORY",
    -2147072614: "MSI_PERFCOUNTER_FREE_MEMORY_HELP",
    -2147072766: "MSI_PERFCOUNTER_FREE_PAGING_SPACE",
    -2147072671: "MSI_PERFCOUNTER_FREE_PAGING_SPACE_HELP",
    -2147072765: "MSI_PERFCOUNTER_FREE_REAL_MEMORY",
    -2147072670: "MSI_PERFCOUNTER_FREE_REAL_MEMORY_HELP",
    -2147072763: "MSI_PERFCOUNTER_FREE_SWAP_SPACE",
    -2147072616: "MSI_PERFCOUNTER_FREE_SWAP_SPACE_HELP",
    -2147072003: "MSI_PERFCOUNTER_GETDOCUMENTS_COUNT",
    -2147072002: "MSI_PERFCOUNTER_GETDOCUMENTS_COUNT_HELP",
    -2147071882: "MSI_PERFCOUNTER_HEAP_CACHED",
    -2147071881: "MSI_PERFCOUNTER_HEAP_CACHED_HELP",
    -2147071884: "MSI_PERFCOUNTER_HEAP_INUSE",
    -2147071883: "MSI_PERFCOUNTER_HEAP_INUSE_HELP",
    -2147072727: "MSI_PERFCOUNTER_INVALID_LOGIN_ATTEMPTS",
    -2147072636: "MSI_PERFCOUNTER_INVALID_LOGIN_ATTEMPTS_HELP",
    -2147072723: "MSI_PERFCOUNTER_KBYTES_RECEIVED",
    -2147072722: "MSI_PERFCOUNTER_KBYTES_SENT",
    -2147072050: "MSI_PERFCOUNTER_LARGEST_FREE_REGION",
    -2147072049: "MSI_PERFCOUNTER_LARGEST_FREE_REGION_HELP",
    -2147072039: "MSI_PERFCOUNTER_LAST_BISEARCH_TIME",
    -2147072038: "MSI_PERFCOUNTER_LAST_BISEARCH_TIME_HELP",
    -2147072023: "MSI_PERFCOUNTER_LAST_CACHESEARCH_TIME",
    -2147072022: "MSI_PERFCOUNTER_LAST_CACHESEARCH_TIME_HELP",
    -2147071999: "MSI_PERFCOUNTER_LAST_CLUSTERING_TIME",
    -2147071998: "MSI_PERFCOUNTER_LAST_CLUSTERING_TIME_HELP",
    -2147072007: "MSI_PERFCOUNTER_LAST_GETDOCUMENTS_TIME",
    -2147072006: "MSI_PERFCOUNTER_LAST_GETDOCUMENTS_TIME_HELP",
    -2147072031: "MSI_PERFCOUNTER_LAST_MDSEARCH_TIME",
    -2147072030: "MSI_PERFCOUNTER_LAST_MDSEARCH_TIME_HELP",
    -2147072015: "MSI_PERFCOUNTER_LAST_SQLSEARCH_TIME",
    -2147072014: "MSI_PERFCOUNTER_LAST_SQLSEARCH_TIME_HELP",
    -2147071966: "MSI_PERFCOUNTER_MDCRAWLER_AVERAGE_GENERATEDOCUMENT_TIME",
    -2147071965: "MSI_PERFCOUNTER_MDCRAWLER_AVERAGE_GENERATEDOCUMENT_TIME_HELP",
    -2147071926: "MSI_PERFCOUNTER_MDCRAWLER_AVERAGE_LOADOBJECT_TIME",
    -2147071925: "MSI_PERFCOUNTER_MDCRAWLER_AVERAGE_LOADOBJECT_TIME_HELP",
    -2147071974: "MSI_PERFCOUNTER_MDCRAWLER_AVERAGE_RETRIEVEOBJECT_TIME",
    -2147071973: "MSI_PERFCOUNTER_MDCRAWLER_AVERAGE_RETRIEVEOBJECT_TIME_HELP",
    -2147071958: "MSI_PERFCOUNTER_MDCRAWLER_AVERAGE_SENDCOMMAND_TIME",
    -2147071957: "MSI_PERFCOUNTER_MDCRAWLER_AVERAGE_SENDCOMMAND_TIME_HELP",
    -2147071968: "MSI_PERFCOUNTER_MDCRAWLER_GENERATEDOCUMENT_COUNT",
    -2147071967: "MSI_PERFCOUNTER_MDCRAWLER_GENERATEDOCUMENT_COUNT_HELP",
    -2147071972: "MSI_PERFCOUNTER_MDCRAWLER_LAST_GENERATEDOCUMENT_TIME",
    -2147071971: "MSI_PERFCOUNTER_MDCRAWLER_LAST_GENERATEDOCUMENT_TIME_HELP",
    -2147071980: "MSI_PERFCOUNTER_MDCRAWLER_LAST_RETRIEVEOBJECT_TIME",
    -2147071979: "MSI_PERFCOUNTER_MDCRAWLER_LAST_RETRIEVEOBJECT_TIME_HELP",
    -2147071964: "MSI_PERFCOUNTER_MDCRAWLER_LAST_SENDCOMMAND_TIME",
    -2147071963: "MSI_PERFCOUNTER_MDCRAWLER_LAST_SENDCOMMAND_TIME_HELP",
    -2147071928: "MSI_PERFCOUNTER_MDCRAWLER_LOADOBJECT_COUNT",
    -2147071927: "MSI_PERFCOUNTER_MDCRAWLER_LOADOBJECT_COUNT_HELP",
    -2147071976: "MSI_PERFCOUNTER_MDCRAWLER_RETRIEVEOBJECT_COUNT",
    -2147071975: "MSI_PERFCOUNTER_MDCRAWLER_RETRIEVEOBJECT_COUNT_HELP",
    -2147071960: "MSI_PERFCOUNTER_MDCRAWLER_SENDCOMMAND_COUNT",
    -2147071959: "MSI_PERFCOUNTER_MDCRAWLER_SENDCOMMAND_COUNT_HELP",
    -2147071970: "MSI_PERFCOUNTER_MDCRAWLER_TOTAL_GENERATEDOCUMENT_TIME",
    -2147071969: "MSI_PERFCOUNTER_MDCRAWLER_TOTAL_GENERATEDOCUMENT_TIME_HELP",
    -2147071930: "MSI_PERFCOUNTER_MDCRAWLER_TOTAL_LOADOBJECT_TIME",
    -2147071929: "MSI_PERFCOUNTER_MDCRAWLER_TOTAL_LOADOBJECT_TIME_HELP",
    -2147071978: "MSI_PERFCOUNTER_MDCRAWLER_TOTAL_RETRIEVEOBJECT_TIME",
    -2147071977: "MSI_PERFCOUNTER_MDCRAWLER_TOTAL_RETRIEVEOBJECT_TIME_HELP",
    -2147071962: "MSI_PERFCOUNTER_MDCRAWLER_TOTAL_SENDCOMMAND_TIME",
    -2147071961: "MSI_PERFCOUNTER_MDCRAWLER_TOTAL_SENDCOMMAND_TIME_HELP",
    -2147072027: "MSI_PERFCOUNTER_MDSEARCH_COUNT",
    -2147072026: "MSI_PERFCOUNTER_MDSEARCH_COUNT_HELP",
    -2147072602: "MSI_PERFCOUNTER_MEMORY",
    -2147071889: "MSI_PERFCOUNTER_MEMORY_FOR_EXCEL_EXPORTING",
    -2147071888: "MSI_PERFCOUNTER_MEMORY_FOR_EXCEL_EXPORTING_HELP",
    -2147071876: "MSI_PERFCOUNTER_MEMORY_FOR_FLASH_EXPORTING",
    -2147071875: "MSI_PERFCOUNTER_MEMORY_FOR_FLASH_EXPORTING_HELP",
    -2147071878: "MSI_PERFCOUNTER_MEMORY_FOR_HTML_EXPORTING",
    -2147071877: "MSI_PERFCOUNTER_MEMORY_FOR_HTML_EXPORTING_HELP",
    -2147071891: "MSI_PERFCOUNTER_MEMORY_FOR_PDF_EXPORTING",
    -2147071890: "MSI_PERFCOUNTER_MEMORY_FOR_PDF_EXPORTING_HELP",
    -2147071880: "MSI_PERFCOUNTER_MEMORY_FOR_PLAIN_TEXT_EXPORTING",
    -2147071879: "MSI_PERFCOUNTER_MEMORY_FOR_PLAIN_TEXT_EXPORTING_HELP",
    -2147071887: "MSI_PERFCOUNTER_MEMORY_FOR_XML_EXPORTING",
    -2147071886: "MSI_PERFCOUNTER_MEMORY_FOR_XML_EXPORTING_HELP",
    -2147071895: "MSI_PERFCOUNTER_MEMORY_FOR_XML_GENERATION",
    -2147071894: "MSI_PERFCOUNTER_MEMORY_FOR_XML_GENERATION_HELP",
    -2147072601: "MSI_PERFCOUNTER_MEMORY_HELP",
    -2147072473: "MSI_PERFCOUNTER_MEM_FRAG",
    -2147072472: "MSI_PERFCOUNTER_MEM_FRAG_HELP",
    -2147072608: "MSI_PERFCOUNTER_MICROSTRATEGY_INTELLIGENT_SERVER_PROFILER",
    -2147072609: "MSI_PERFCOUNTER_MICROSTRATEGY_OBJECT_INSTANCE",
    -2147072041: "MSI_PERFCOUNTER_MICROSTRATEGY_SEARCHENGINE",
    -2147072040: "MSI_PERFCOUNTER_MICROSTRATEGY_SEARCHENGINE_HELP",
    -2147072613: "MSI_PERFCOUNTER_MICROSTRATEGY_SERVER_JOBS",
    -2147072612: "MSI_PERFCOUNTER_MICROSTRATEGY_SERVER_JOBS_HELP",
    -2147072611: "MSI_PERFCOUNTER_MICROSTRATEGY_SERVER_USERS",
    -2147072610: "MSI_PERFCOUNTER_MICROSTRATEGY_SERVER_USERS_HELP",
    -2147137458: "MSI_PERFCOUNTER_MULTIPROCESS_COUNT_AE",
    -2147137457: "MSI_PERFCOUNTER_MULTIPROCESS_COUNT_AE_HELP",
    -2147137460: "MSI_PERFCOUNTER_MULTIPROCESS_COUNT_DB",
    -2147137459: "MSI_PERFCOUNTER_MULTIPROCESS_COUNT_DB_HELP",
    -2147137456: "MSI_PERFCOUNTER_MULTIPROCESS_COUNT_DS",
    -2147137455: "MSI_PERFCOUNTER_MULTIPROCESS_COUNT_DS_HELP",
    -2147137454: "MSI_PERFCOUNTER_MULTIPROCESS_COUNT_OTHER",
    -2147137453: "MSI_PERFCOUNTER_MULTIPROCESS_COUNT_OTHER_HELP",
    -2147072600: "MSI_PERFCOUNTER_NETWORK_INTERFACE",
    -2147072599: "MSI_PERFCOUNTER_NETWORK_INTERFACE_HELP",
    -2147072715: "MSI_PERFCOUNTER_NUMBER_OF_512_BYTES_BLOCKS_READ",
    -2147072714: "MSI_PERFCOUNTER_NUMBER_OF_512_BYTES_BLOCKS_WRITTEN",
    -2147072697: "MSI_PERFCOUNTER_NUMBER_OF_ACTIVE_CPUS",
    -2147072721: "MSI_PERFCOUNTER_NUMBER_OF_COLLISIONS",
    -2147072696: "MSI_PERFCOUNTER_NUMBER_OF_CONTEXT_SWITCHES",
    -2147072713: "MSI_PERFCOUNTER_NUMBER_OF_DISKS",
    -2147072695: "MSI_PERFCOUNTER_NUMBER_OF_FORKS_SYSTEM_CALLS_EXECUTED",
    -2147072720: "MSI_PERFCOUNTER_NUMBER_OF_INPUT_ERRORS",
    -2147072718: "MSI_PERFCOUNTER_NUMBER_OF_NETWORK_INTERFACES",
    -2147072719: "MSI_PERFCOUNTER_NUMBER_OF_OUTPUT_ERRORS",
    -2147072694: "MSI_PERFCOUNTER_NUMBER_OF_SYSTEM_CALLS_EXECUTED",
    -2147072748: "MSI_PERFCOUNTER_OBJECT_BROWSE_SUBMISSION_RATE",
    -2147072657: "MSI_PERFCOUNTER_OBJECT_BROWSE_SUBMISSION_RATE_HELP",
    -2147071899: "MSI_PERFCOUNTER_OBJECT_SERVER_CACHE",
    -2147071898: "MSI_PERFCOUNTER_OBJECT_SERVER_CACHE_HELP",
    -2147072726: "MSI_PERFCOUNTER_OPEN_PROJECT_SESSIONS",
    -2147072635: "MSI_PERFCOUNTER_OPEN_PROJECT_SESSIONS_HELP",
    -2147072747: "MSI_PERFCOUNTER_OPEN_REPORTS",
    -2147072656: "MSI_PERFCOUNTER_OPEN_REPORTS_HELP",
    -2147072725: "MSI_PERFCOUNTER_OPEN_SESSIONS",
    -2147072634: "MSI_PERFCOUNTER_OPEN_SESSIONS_HELP",
    -2147072762: "MSI_PERFCOUNTER_PAGE_IN",
    -2147072669: "MSI_PERFCOUNTER_PAGE_IN_HELP",
    -2147072761: "MSI_PERFCOUNTER_PAGE_OUT",
    -2147072668: "MSI_PERFCOUNTER_PAGE_OUT_HELP",
    -2147072704: "MSI_PERFCOUNTER_PERCENT_CPU_TIME",
    -2147072632: "MSI_PERFCOUNTER_PERCENT_CPU_TIME_HELP",
    -2147072701: "MSI_PERFCOUNTER_PERCENT_IDLE_TIME",
    -2147072629: "MSI_PERFCOUNTER_PERCENT_IDLE_TIME_HELP",
    -2147072700: "MSI_PERFCOUNTER_PERCENT_SYSTEM_TIME",
    -2147072628: "MSI_PERFCOUNTER_PERCENT_SYSTEM_TIME_HELP",
    -2147072699: "MSI_PERFCOUNTER_PERCENT_USER_TIME",
    -2147072627: "MSI_PERFCOUNTER_PERCENT_USER_TIME_HELP",
    -2147072698: "MSI_PERFCOUNTER_PERCENT_WAIT_TIME",
    -2147072626: "MSI_PERFCOUNTER_PERCENT_WAIT_TIME_HELP",
    -2147072598: "MSI_PERFCOUNTER_PHYSICAL_DISK",
    -2147072597: "MSI_PERFCOUNTER_PHYSICAL_DISK_HELP",
    -2147072760: "MSI_PERFCOUNTER_PINNED_MEMORY",
    -2147072667: "MSI_PERFCOUNTER_PINNED_MEMORY_HELP",
    -2147072594: "MSI_PERFCOUNTER_PROCESS",
    -2147072596: "MSI_PERFCOUNTER_PROCESSOR",
    -2147072595: "MSI_PERFCOUNTER_PROCESSOR_HELP",
    -2147072693: "MSI_PERFCOUNTER_PROCESSOR_SPEED_IN_MHZ",
    -2147072593: "MSI_PERFCOUNTER_PROCESS_HELP",
    -2147072692: "MSI_PERFCOUNTER_RAM_USED",
    -2147072625: "MSI_PERFCOUNTER_RAM_USED_HELP",
    -2147072744: "MSI_PERFCOUNTER_REPORTS_COMPLETION_RATE",
    -2147072653: "MSI_PERFCOUNTER_REPORTS_COMPLETION_RATE_HELP",
    -2147072531: "MSI_PERFCOUNTER_REPORT_CACHES",
    -2147072530: "MSI_PERFCOUNTER_REPORT_CACHES_HELP",
    -2147072215: "MSI_PERFCOUNTER_REPORT_CACHES_IN_MEMORY",
    -2147072214: "MSI_PERFCOUNTER_REPORT_CACHES_IN_MEMORY_HELP",
    -2147072746: "MSI_PERFCOUNTER_REPORT_CACHE_HIT_RATIO",
    -2147072655: "MSI_PERFCOUNTER_REPORT_CACHE_HIT_RATIO_HELP",
    -2147071903: "MSI_PERFCOUNTER_REPORT_CACHE_INDEX",
    -2147071902: "MSI_PERFCOUNTER_REPORT_CACHE_INDEX_HELP",
    -2147072529: "MSI_PERFCOUNTER_REPORT_CACHE_MEMORY",
    -2147072528: "MSI_PERFCOUNTER_REPORT_CACHE_MEMORY_HELP",
    -2147072209: "MSI_PERFCOUNTER_REPORT_CACHE_SWAP",
    -2147072208: "MSI_PERFCOUNTER_REPORT_CACHE_SWAP_HELP",
    -2147072045: "MSI_PERFCOUNTER_REPORT_MANIPULATIONS",
    -2147072044: "MSI_PERFCOUNTER_REPORT_MANIPULATIONS_HELP",
    -2147072745: "MSI_PERFCOUNTER_REPORT_SUBMISSION_RATE",
    -2147072654: "MSI_PERFCOUNTER_REPORT_SUBMISSION_RATE_HELP",
    -2147072759: "MSI_PERFCOUNTER_RESERVED_PAGING_SPACE",
    -2147072666: "MSI_PERFCOUNTER_RESERVED_PAGING_SPACE_HELP",
    -2147072758: "MSI_PERFCOUNTER_RESERVED_SWAP_SPACE",
    -2147072619: "MSI_PERFCOUNTER_RESERVED_SWAP_SPACE_HELP",
    -2147025416: "MSI_PERFCOUNTER_REST_TOTAL_REQUESTS_COUNT",
    -2147025413: "MSI_PERFCOUNTER_REST_TOTAL_REQUESTS_COUNT_HELP",
    -2147025415: "MSI_PERFCOUNTER_REST_TOTAL_TIME",
    -2147025412: "MSI_PERFCOUNTER_REST_TOTAL_TIME_HELP",
    -2147072703: "MSI_PERFCOUNTER_RSS",
    -2147072631: "MSI_PERFCOUNTER_RSS_HELP",
    -2147072481: "MSI_PERFCOUNTER_SH_FRAG_FREE_NUM",
    -2147072480: "MSI_PERFCOUNTER_SH_FRAG_FREE_NUM_HELP",
    -2147072485: "MSI_PERFCOUNTER_SH_FRAG_FREE_SIZE",
    -2147072484: "MSI_PERFCOUNTER_SH_FRAG_FREE_SIZE_HELP",
    -2147072483: "MSI_PERFCOUNTER_SH_FRAG_LARGEST_FREE",
    -2147072482: "MSI_PERFCOUNTER_SH_FRAG_LARGEST_FREE_HELP",
    -2147072702: "MSI_PERFCOUNTER_SIZE",
    -2147072630: "MSI_PERFCOUNTER_SIZE_HELP",
    -2147072011: "MSI_PERFCOUNTER_SQLSEARCH_COUNT",
    -2147072010: "MSI_PERFCOUNTER_SQLSEARCH_COUNT_HELP",
    -2147072241: "MSI_PERFCOUNTER_SUBSET_COMPLETION",
    -2147072240: "MSI_PERFCOUNTER_SUBSET_COMPLETION_HELP",
    -2147072691: "MSI_PERFCOUNTER_SWAP_USED",
    -2147072624: "MSI_PERFCOUNTER_SWAP_USED_HELP",
    -2147072604: "MSI_PERFCOUNTER_SYSTEM",
    -2147072603: "MSI_PERFCOUNTER_SYSTEM_HELP",
    -2147072743: "MSI_PERFCOUNTER_TIMED_OUT_JOBS",
    -2147072652: "MSI_PERFCOUNTER_TIMED_OUT_JOBS_HELP",
    -2147072591: "MSI_PERFCOUNTER_TOTAL",
    -2147072037: "MSI_PERFCOUNTER_TOTAL_BISEARCH_TIME",
    -2147072036: "MSI_PERFCOUNTER_TOTAL_BISEARCH_TIME_HELP",
    -2147072021: "MSI_PERFCOUNTER_TOTAL_CACHESEARCH_TIME",
    -2147072020: "MSI_PERFCOUNTER_TOTAL_CACHESEARCH_TIME_HELP",
    -2147072686: "MSI_PERFCOUNTER_TOTAL_CDSS_DOCUMENT_DEFINITION_OBJECTS",
    -2147072685: "MSI_PERFCOUNTER_TOTAL_CDSS_DOCUMENT_INSTANCE_OBJECTS",
    -2147072684: "MSI_PERFCOUNTER_TOTAL_CDSS_MSG_OBJECTS",
    -2147072683: "MSI_PERFCOUNTER_TOTAL_CDSS_PROCESS_CONTEXT_OBJECTS",
    -2147072682: "MSI_PERFCOUNTER_TOTAL_CDSS_REPORT_INSTANCE_OBJECTS",
    -2147072681: "MSI_PERFCOUNTER_TOTAL_CDSS_RES_WORKSPACE_OBJECTS",
    -2147072679: "MSI_PERFCOUNTER_TOTAL_CDSS_SERVER_MESSAGE_OBJECTS",
    -2147072680: "MSI_PERFCOUNTER_TOTAL_CDSS_SQLS_OBJECTS",
    -2147072678: "MSI_PERFCOUNTER_TOTAL_CDSS_XMLCONTEXT_OBJECTS",
    -2147072677: "MSI_PERFCOUNTER_TOTAL_CDSS_XMLDOCUMENT_OBJECTS",
    -2147072676: "MSI_PERFCOUNTER_TOTAL_CDSS_XMLNODE_OBJECTS",
    -2147071931: "MSI_PERFCOUNTER_TOTAL_CHARTENGINE_TIME",
    -2147072206: "MSI_PERFCOUNTER_TOTAL_CHART_OBJECTS",
    -2147071997: "MSI_PERFCOUNTER_TOTAL_CLUSTERING_TIME",
    -2147071996: "MSI_PERFCOUNTER_TOTAL_CLUSTERING_TIME_HELP",
    -2147072742: "MSI_PERFCOUNTER_TOTAL_COMPLETED_DOCUMENTS",
    -2147072651: "MSI_PERFCOUNTER_TOTAL_COMPLETED_DOCUMENTS_HELP",
    -2147072741: "MSI_PERFCOUNTER_TOTAL_COMPLETED_REPORTS",
    -2147072650: "MSI_PERFCOUNTER_TOTAL_COMPLETED_REPORTS_HELP",
    -2147025417: "MSI_PERFCOUNTER_TOTAL_COMPLETED_REST_REQUESTS",
    -2147025414: "MSI_PERFCOUNTER_TOTAL_COMPLETED_REST_REQUESTS_HELP",
    -2147072740: "MSI_PERFCOUNTER_TOTAL_COMPLETED_WEB_REPORTS",
    -2147072649: "MSI_PERFCOUNTER_TOTAL_COMPLETED_WEB_REPORTS_HELP",
    -2147072605: "MSI_PERFCOUNTER_TOTAL_COUNTS",
    -2147072690: "MSI_PERFCOUNTER_TOTAL_CPU",
    -2147072623: "MSI_PERFCOUNTER_TOTAL_CPU_HELP",
    -2147072235: "MSI_PERFCOUNTER_TOTAL_CUBE_RESPONSE_TIME",
    -2147072234: "MSI_PERFCOUNTER_TOTAL_CUBE_RESPONSE_TIME_HELP",
    -2147072222: "MSI_PERFCOUNTER_TOTAL_CUBE_SIZE",
    -2147072221: "MSI_PERFCOUNTER_TOTAL_CUBE_SIZE_HELP",
    -2147071796: "MSI_PERFCOUNTER_TOTAL_CUBE_SIZE_IN_MEMORY",
    -2147071795: "MSI_PERFCOUNTER_TOTAL_CUBE_SIZE_IN_MEMORY_HELP",
    -2147072757: "MSI_PERFCOUNTER_TOTAL_DISK_BASED_SWAP_SPACE",
    -2147072615: "MSI_PERFCOUNTER_TOTAL_DISK_BASED_SWAP_SPACE_HELP",
    -2147072712: "MSI_PERFCOUNTER_TOTAL_DISK_SIZE",
    -2147072739: "MSI_PERFCOUNTER_TOTAL_DOCUMENTS",
    -2147072648: "MSI_PERFCOUNTER_TOTAL_DOCUMENTS_HELP",
    -2147071756: "MSI_PERFCOUNTER_TOTAL_DOC_CACHE_CHECKS",
    -2147071755: "MSI_PERFCOUNTER_TOTAL_DOC_CACHE_CHECKS_HELP",
    -2147072229: "MSI_PERFCOUNTER_TOTAL_DOC_CACHE_HIT",
    -2147072228: "MSI_PERFCOUNTER_TOTAL_DOC_CACHE_HIT_HELP",
    -2147072219: "MSI_PERFCOUNTER_TOTAL_DOC_CACHE_SIZE",
    -2147072218: "MSI_PERFCOUNTER_TOTAL_DOC_CACHE_SIZE_HELP",
    -2147071788: "MSI_PERFCOUNTER_TOTAL_DOC_CACHE_SIZE_IN_MEMORY",
    -2147071787: "MSI_PERFCOUNTER_TOTAL_DOC_CACHE_SIZE_IN_MEMORY_HELP",
    -2147072223: "MSI_PERFCOUNTER_TOTAL_DOC_RESPONSE_TIME",
    -2147072220: "MSI_PERFCOUNTER_TOTAL_DOC_RESPONSE_TIME_HELP",
    -2147072738: "MSI_PERFCOUNTER_TOTAL_ELEMENT_BROWSE_REQUESTS",
    -2147072647: "MSI_PERFCOUNTER_TOTAL_ELEMENT_BROWSE_REQUESTS_HELP",
    -2147072737: "MSI_PERFCOUNTER_TOTAL_ERROR_DOCUMENTS",
    -2147072646: "MSI_PERFCOUNTER_TOTAL_ERROR_DOCUMENTS_HELP",
    -2147072736: "MSI_PERFCOUNTER_TOTAL_ERROR_ELEMENT_BROWSE_REQUESTS",
    -2147072645: "MSI_PERFCOUNTER_TOTAL_ERROR_ELEMENT_BROWSE_REQUESTS_HELP",
    -2147072735: "MSI_PERFCOUNTER_TOTAL_ERROR_OBJECT_BROWSE_REQUESTS",
    -2147072644: "MSI_PERFCOUNTER_TOTAL_ERROR_OBJECT_BROWSE_REQUESTS_HELP",
    -2147072734: "MSI_PERFCOUNTER_TOTAL_ERROR_REPORTS",
    -2147072643: "MSI_PERFCOUNTER_TOTAL_ERROR_REPORTS_HELP",
    -2147072711: "MSI_PERFCOUNTER_TOTAL_FREE_DISK_SPACE",
    -2147072005: "MSI_PERFCOUNTER_TOTAL_GETDOCUMENTS_TIME",
    -2147072004: "MSI_PERFCOUNTER_TOTAL_GETDOCUMENTS_TIME_HELP",
    -2147071760: "MSI_PERFCOUNTER_TOTAL_HIGH_PRIORITY_DOC_CACHE_SIZE_IN_MEMORY",
    -2147071759: "MSI_PERFCOUNTER_TOTAL_HIGH_PRIORITY_DOC_CACHE_SIZE_IN_MEMORY_HELP",
    -2147072467: "MSI_PERFCOUNTER_TOTAL_HISTORY_LIST_MESSAGES",
    -2147072466: "MSI_PERFCOUNTER_TOTAL_HISTORY_LIST_MESSAGES_HELP",
    -2147071762: "MSI_PERFCOUNTER_TOTAL_LOW_PRIORITY_DOC_CACHE_SIZE_IN_MEMORY",
    -2147071761: "MSI_PERFCOUNTER_TOTAL_LOW_PRIORITY_DOC_CACHE_SIZE_IN_MEMORY_HELP",
    -2147072048: "MSI_PERFCOUNTER_TOTAL_MCM_DENIAL",
    -2147072047: "MSI_PERFCOUNTER_TOTAL_MCM_DENIAL_HELP",
    -2147072029: "MSI_PERFCOUNTER_TOTAL_MDSEARCH_TIME",
    -2147072028: "MSI_PERFCOUNTER_TOTAL_MDSEARCH_TIME_HELP",
    -2147071932: "MSI_PERFCOUNTER_TOTAL_MSIGRAPH_TIME",
    -2147072673: "MSI_PERFCOUNTER_TOTAL_MSIJOBTASK_OBJECTS",
    -2147072674: "MSI_PERFCOUNTER_TOTAL_MSIJOB_OBJECTS",
    -2147071893: "MSI_PERFCOUNTER_TOTAL_MSITABLE_MEMORY_USAGE",
    -2147071892: "MSI_PERFCOUNTER_TOTAL_MSITABLE_MEMORY_USAGE_HELP",
    -2147071808: "MSI_PERFCOUNTER_TOTAL_MSIUSERINBOX_OBJECTS",
    -2147072672: "MSI_PERFCOUNTER_TOTAL_MSIUSERSESSION_OBJECTS",
    -2147071807: "MSI_PERFCOUNTER_TOTAL_MSIWORKINGSET_OBJECTS",
    -2147072675: "MSI_PERFCOUNTER_TOTAL_MSI_COMMAND_SERVER_CONTEXT_OBJECTS",
    -2147072710: "MSI_PERFCOUNTER_TOTAL_NUMBER_OF_BYTES_READ",
    -2147072709: "MSI_PERFCOUNTER_TOTAL_NUMBER_OF_BYTES_WRITTEN",
    -2147072717: "MSI_PERFCOUNTER_TOTAL_NUMBER_OF_INPUT_PACKETS_RECEIVED",
    -2147072716: "MSI_PERFCOUNTER_TOTAL_NUMBER_OF_OUTPUT_PACKETS_SENT",
    -2147072708: "MSI_PERFCOUNTER_TOTAL_NUMBER_OF_READ_OPERATIONS",
    -2147072707: "MSI_PERFCOUNTER_TOTAL_NUMBER_OF_TRANSFERS_TO_AND_FROM_DISK",
    -2147072706: "MSI_PERFCOUNTER_TOTAL_NUMBER_OF_WRITE_OPERATIONS",
    -2147072733: "MSI_PERFCOUNTER_TOTAL_OBJECT_BROWSER_REQUESTS",
    -2147072642: "MSI_PERFCOUNTER_TOTAL_OBJECT_BROWSER_REQUESTS_HELP",
    -2147072756: "MSI_PERFCOUNTER_TOTAL_PAGING_SPACE",
    -2147072665: "MSI_PERFCOUNTER_TOTAL_PAGING_SPACE_HELP",
    -2147072688: "MSI_PERFCOUNTER_TOTAL_PROJECT_SESSIONS",
    -2147072621: "MSI_PERFCOUNTER_TOTAL_PROJECT_SESSIONS_HELP",
    -2147072755: "MSI_PERFCOUNTER_TOTAL_REAL_MEMORY",
    -2147072664: "MSI_PERFCOUNTER_TOTAL_REAL_MEMORY_HELP",
    -2147072731: "MSI_PERFCOUNTER_TOTAL_REPORTS_CACHE_HITS",
    -2147072640: "MSI_PERFCOUNTER_TOTAL_REPORTS_CACHE_HITS_HELP",
    -2147072732: "MSI_PERFCOUNTER_TOTAL_REPORT_CACHE_CHECKS",
    -2147072641: "MSI_PERFCOUNTER_TOTAL_REPORT_CACHE_CHECKS_HELP",
    -2147072211: "MSI_PERFCOUNTER_TOTAL_REPORT_CACHE_SIZE",
    -2147072210: "MSI_PERFCOUNTER_TOTAL_REPORT_CACHE_SIZE_HELP",
    -2147072043: "MSI_PERFCOUNTER_TOTAL_REPORT_DEFINITION",
    -2147072730: "MSI_PERFCOUNTER_TOTAL_REPORT_REQUESTS",
    -2147072639: "MSI_PERFCOUNTER_TOTAL_REPORT_REQUESTS_HELP",
    -2147072213: "MSI_PERFCOUNTER_TOTAL_REPORT_RESPONSE_TIME",
    -2147072212: "MSI_PERFCOUNTER_TOTAL_REPORT_RESPONSE_TIME_HELP",
    -2147072729: "MSI_PERFCOUNTER_TOTAL_REQUESTS",
    -2147072638: "MSI_PERFCOUNTER_TOTAL_REQUESTS_HELP",
    -2147072687: "MSI_PERFCOUNTER_TOTAL_SESSIONS",
    -2147072620: "MSI_PERFCOUNTER_TOTAL_SESSIONS_HELP",
    -2147072013: "MSI_PERFCOUNTER_TOTAL_SQLSEARCH_TIME",
    -2147072012: "MSI_PERFCOUNTER_TOTAL_SQLSEARCH_TIME_HELP",
    -2147072233: "MSI_PERFCOUNTER_TOTAL_SUBSET_RESPONSE_TIME",
    -2147072232: "MSI_PERFCOUNTER_TOTAL_SUBSET_RESPONSE_TIME_HELP",
    -2147072724: "MSI_PERFCOUNTER_TOTAL_TIMED_OUT_USERS",
    -2147072633: "MSI_PERFCOUNTER_TOTAL_TIMED_OUT_USERS_HELP",
    -2147072705: "MSI_PERFCOUNTER_TOTAL_TRANSFER_RATE_CAPABILITY",
    -2147072754: "MSI_PERFCOUNTER_TOTAL_VIRTUAL_MEMORY",
    -2147072663: "MSI_PERFCOUNTER_TOTAL_VIRTUAL_MEMORY_HELP",
    -2147072753: "MSI_PERFCOUNTER_USED_REAL_MEMORY",
    -2147072662: "MSI_PERFCOUNTER_USED_REAL_MEMORY_HELP",
    -2147072477: "MSI_PERFCOUNTER_VB_FRAG_LARGEST_RESERVED",
    -2147072476: "MSI_PERFCOUNTER_VB_FRAG_LARGEST_RESERVED_HELP",
    -2147072475: "MSI_PERFCOUNTER_VB_FRAG_RESERVED_NUM",
    -2147072474: "MSI_PERFCOUNTER_VB_FRAG_RESERVED_NUM_HELP",
    -2147072479: "MSI_PERFCOUNTER_VB_FRAG_RESERVED_SIZE",
    -2147072478: "MSI_PERFCOUNTER_VB_FRAG_RESERVED_SIZE_HELP",
    -2147072471: "MSI_PERFCOUNTER_VIRTUAL_BYTES",
    -2147072470: "MSI_PERFCOUNTER_VIRTUAL_BYTES_HELP",
    -2147072689: "MSI_PERFCOUNTER_VIRTUAL_MEMORY_USED",
    -2147072622: "MSI_PERFCOUNTER_VIRTUAL_MEMORY_USED_HELP",
    -2147072469: "MSI_PERFCOUNTER_WORKING_SET_CACHE_RAM",
    -2147072468: "MSI_PERFCOUNTER_WORKING_SET_CACHE_RAM_HELP",
    -2147071909: "MSI_PERFCOUNTER_XML_MEMORY_USAGE",
    -2147071908: "MSI_PERFCOUNTER_XML_MEMORY_USAGE_HELP",
    -2147072547: "MSI_PERSIST_CUBE_FAILED",
    -2147025921: "MSI_PERSIST_FILE_EXECPTION",
    -2147025926: "MSI_PERSIST_FILE_FAILED",
    -2147206794: "MSI_PRIVILEGE_MASK_TOO_LONG",
    -2147207168: "MSI_PROCESSCONTEXTINIT_ERROR",
    -2147207838: "MSI_PROJDBDMANAGER_ADD_DBD_TO_DBF",
    -2147207807: "MSI_PROJDBDMANAGER_ADD_PROJECT",
    -2147207806: "MSI_PROJDBDMANAGER_ADD_PROJECT_EXCEPTION",
    -2147207826: "MSI_PROJDBDMANAGER_ASSIGN_DEFAULT_DBD",
    -2147207825: "MSI_PROJDBDMANAGER_ASSIGN_DEFAULT_DBD_EXCEPTION",
    -2147207815: "MSI_PROJDBDMANAGER_CHANGE_DB_LOGIN_PASSWORD",
    -2147207814: "MSI_PROJDBDMANAGER_CHANGE_DB_LOGIN_PASSWORD_EXCEPTION",
    -2147207841: "MSI_PROJDBDMANAGER_CONSTRUCTION",
    -2147207821: "MSI_PROJDBDMANAGER_CREATE_DB_LOGIN",
    -2147207820: "MSI_PROJDBDMANAGER_CREATE_DB_LOGIN_EXCEPTION",
    -2147207840: "MSI_PROJDBDMANAGER_DBDRIVER_INCORRECT",
    -2147207839: "MSI_PROJDBDMANAGER_DESTRUCTION",
    -2147207811: "MSI_PROJDBDMANAGER_GET_ALL_DB_LOGINS",
    -2147207835: "MSI_PROJDBDMANAGER_GET_DBFS",
    -2147207832: "MSI_PROJDBDMANAGER_GET_DBFS_EXCEPTION",
    -2147207813: "MSI_PROJDBDMANAGER_GET_DB_LOGIN",
    -2147207812: "MSI_PROJDBDMANAGER_GET_DB_LOGIN_EXCEPTION",
    -2147207830: "MSI_PROJDBDMANAGER_GET_LIST_OF_DBF",
    -2147207828: "MSI_PROJDBDMANAGER_GET_LIST_OF_DBF2",
    -2147207827: "MSI_PROJDBDMANAGER_GET_LIST_OF_DBF2_EXCEPTION",
    -2147207829: "MSI_PROJDBDMANAGER_GET_LIST_OF_DBF_EXCEPTION",
    -2147207809: "MSI_PROJDBDMANAGER_GET_LIST_OF_PROJECTS",
    -2147207833: "MSI_PROJDBDMANAGER_LOAD_DBFS",
    -2147207804: "MSI_PROJDBDMANAGER_NO_DBFS_FOUND",
    -2147207810: "MSI_PROJDBDMANAGER_NO_DB_LOGINS",
    -2147207808: "MSI_PROJDBDMANAGER_NULL_MSITABLE",
    -2147207837: "MSI_PROJDBDMANAGER_REMOVE_DBD_FROM_DBF",
    -2147207836: "MSI_PROJDBDMANAGER_REMOVE_DBD_FROM_UNIQUE_DBF",
    -2147207819: "MSI_PROJDBDMANAGER_REMOVE_DB_LOGIN",
    -2147207818: "MSI_PROJDBDMANAGER_REMOVE_DB_LOGIN_EXCEPTION",
    -2147207805: "MSI_PROJDBDMANAGER_REMOVE_PROJECT",
    -2147207803: "MSI_PROJDBDMANAGER_REMOVE_PROJECT_EXCEPTION",
    -2147207817: "MSI_PROJDBDMANAGER_RENAME_DB_LOGIN",
    -2147207816: "MSI_PROJDBDMANAGER_RENAME_DB_LOGIN_EXCEPTION",
    -2147207822: "MSI_PROJDBDMANAGER_SET_DEFAULT_VALUES",
    -2147207834: "MSI_PROJDBDMANAGER_UNLOAD_DBFS",
    -2147207831: "MSI_PROJDBDMANAGER_UNLOAD_DBFS_EXCEPTION",
    -2147207824: "MSI_PROJDBDMANAGER_UPDATE_DBF",
    -2147207823: "MSI_PROJDBDMANAGER_UPDATE_DBF_EXCEPTION",
    -2147209192: "MSI_PROJECTIDLE_ERROR",
    -2147209200: "MSI_PROJECTNOTFOUND_ERROR",
    -2147209177: "MSI_PROJECTOFFLINE_ERROR",
    -2147207860: "MSI_PROJECTREFERENCES_ERROR",
    -2147209182: "MSI_PROJECTSCHEDULEOBJECTSLOAD_ERROR",
    -2147209181: "MSI_PROJECTSCHEDULEOBJECTSUNLOAD_ERROR",
    -2147209211: "MSI_PROJIDLE_SIGNIN_ERROR",
    -2147209066: "MSI_PU_ADDTHREADFAILED",
    -2147072560: "MSI_PU_ADJUST_PRIORITY_FAILED",
    -2147209062: "MSI_PU_ERROR",
    -2147209061: "MSI_PU_JOBENQUEUEFAILED",
    -2147073421: "MSI_PU_LIMITED",
    -2147209057: "MSI_PU_QDEFREEZEFAILED",
    -2147209060: "MSI_PU_QFREEZEFAILED",
    -2147209067: "MSI_PU_RELEASETHREADFAILED",
    -2147209059: "MSI_PU_STARTTHREADSFAILED",
    -2147073420: "MSI_PU_THREAD_LIMITED",
    -2147209058: "MSI_PU_WAITFORTHREADSFAILED",
    -2147207010: "MSI_READONLY",
    -2147207009: "MSI_READWRITE",
    -2147025918: "MSI_REMAPPING_CUBE_INUSE",
    -2147025920: "MSI_REMAPPING_FAILED",
    -2147025911: "MSI_REMAPPING_FAILED_OFFINE",
    -2147207293: "MSI_REMOVEDBF_FAILED",
    -2147207288: "MSI_REMOVEDBLOGIN_FAILED",
    -2147207281: "MSI_REMOVEPROJECT_FAILED",
    -2147207287: "MSI_RENAMEDBLOGIN_FAILED",
    -2147207178: "MSI_REPORTNETSERVERTASK_ClosedChannel",
    -2147207189: "MSI_REPORTNETSERVERTASK_GetNextStepError",
    -2147207188: "MSI_REPORTNETSERVERTASK_InvalidNextStep",
    -2147207187: "MSI_REPORTNETSERVERTASK_MSIException",
    -2147207177: "MSI_REPORTNETSERVERTASK_NULLChannel",
    -2147207181: "MSI_REPORTNETSERVERTASK_NoJobErrorMessage",
    -2147207182: "MSI_REPORTNETSERVERTASK_NoJobInMessage",
    -2147207183: "MSI_REPORTNETSERVERTASK_NoJobOutMessage",
    -2147207184: "MSI_REPORTNETSERVERTASK_NoJobReportInstance",
    -2147207185: "MSI_REPORTNETSERVERTASK_NoProjectId",
    -2147207179: "MSI_REPORTNETSERVERTASK_NoReportSourceServer",
    -2147207180: "MSI_REPORTNETSERVERTASK_ReportSourceServerError",
    -2147207186: "MSI_REPORTNETSERVERTASK_SystemException",
    -2147207239: "MSI_REPORTSENDERTASK_ClosedChannel",
    -2147207246: "MSI_REPORTSENDERTASK_MSIException",
    -2147207238: "MSI_REPORTSENDERTASK_NULLChannel",
    -2147207243: "MSI_REPORTSENDERTASK_NoJobOutMessage",
    -2147207240: "MSI_REPORTSENDERTASK_NoJobReportInstance",
    -2147207245: "MSI_REPORTSENDERTASK_NoProjectId",
    -2147207241: "MSI_REPORTSENDERTASK_NoReportSourceServer",
    -2147207242: "MSI_REPORTSENDERTASK_PackageInstanceError",
    -2147207244: "MSI_REPORTSENDERTASK_SystemException",
    -2147209117: "MSI_REPORT_NTEVENT_FAILED",
    -2147025396: "MSI_REQUEST_CANCELED",
    -2147025403: "MSI_REQUEST_EXECUTION_ERROR",
    -2147025401: "MSI_REQUEST_INVALID_EXECUTION_ID",
    -2147025397: "MSI_REQUEST_INVALID_INPUT",
    -2147025399: "MSI_REQUEST_INVALID_JOB",
    -2147025402: "MSI_REQUEST_INVALID_SESSION_ID",
    -2147025398: "MSI_REQUEST_PARSE_ERROR",
    -2147090940: "MSI_REQUEST_SENT",
    -2147090941: "MSI_REQUEST_SUCCESS",
    -2147206497: "MSI_REQUEST_TIMEOUT",
    -2147025395: "MSI_REQUEST_TRANSFORM_ERROR",
    -2147025400: "MSI_REQUEST_UNAUTHORIZED",
    -2147207228: "MSI_RESOLUTIONSERVERTASK_GetNextStepError",
    -2147207227: "MSI_RESOLUTIONSERVERTASK_InvalidNextStep",
    -2147207226: "MSI_RESOLUTIONSERVERTASK_MSIException",
    -2147207222: "MSI_RESOLUTIONSERVERTASK_NoJobReportInstance",
    -2147207221: "MSI_RESOLUTIONSERVERTASK_NoProjectId",
    -2147207223: "MSI_RESOLUTIONSERVERTASK_NoResolutionServer",
    -2147207224: "MSI_RESOLUTIONSERVERTASK_ResolutionServerError",
    -2147207225: "MSI_RESOLUTIONSERVERTASK_SystemException",
    -2147206915: "MSI_RESPONSE_OBJECT_NOT_FOUND",
    -2147207718: "MSI_RESTORE_ERROR",
    -2147202872: "MSI_RESULT_DISCARDED",
    -2147207640: "MSI_RESUMEAUTOPROMPT_ERROR",
    -2147209178: "MSI_RESUMEPROJECT_ERROR",
    -2147209187: "MSI_REWINDMESSAGE_ERROR",
    -2147207469: "MSI_RIGHT_BRACKET",
    -2147206931: "MSI_RQMGR_INVALID_GUID",
    -2147206932: "MSI_RQMGR_INVPROJECTID",
    -2147156463: "MSI_RestGeneralTask_MSIException",
    -2147156462: "MSI_RestReservedTask_MSIException",
    -2147025930: "MSI_SAVE_CUBE_FAILED",
    -2147025922: "MSI_SAVE_RI_FAILED",
    -2147209169: "MSI_SCHEDREQUEST_ERROR",
    -2147209170: "MSI_SCHEDULER_DISABLED",
    -2147072584: "MSI_SCHEDULE_REQUESTNAME_DOCUMENT",
    -2147072253: "MSI_SCHEDULE_REQUESTNAME_DSSACTIVATECUBES",
    -2147072571: "MSI_SCHEDULE_REQUESTNAME_DSSCLEANUPHISTORYLIST",
    -2147072570: "MSI_SCHEDULE_REQUESTNAME_DSSCMDCACHEADMIN",
    -2147072579: "MSI_SCHEDULE_REQUESTNAME_DSSCMDCLOSEPROJECT",
    -2147073250: "MSI_SCHEDULE_REQUESTNAME_DSSCMDCUBEADMIN",
    -2147072577: "MSI_SCHEDULE_REQUESTNAME_DSSCMDDATAMARTREPORTEXECUTE",
    -2147072569: "MSI_SCHEDULE_REQUESTNAME_DSSCMDHISTORYLISTADMINUNKNOWN",
    -2147072583: "MSI_SCHEDULE_REQUESTNAME_DSSCMDIDLEPROJECT",
    -2147050190: "MSI_SCHEDULE_REQUESTNAME_DSSCMDNEWSSTAND",
    -2147072567: "MSI_SCHEDULE_REQUESTNAME_DSSCMDOBJECTSERVERGARBAGECOLLECT",
    -2147072580: "MSI_SCHEDULE_REQUESTNAME_DSSCMDOPENPROJECT",
    -2147072582: "MSI_SCHEDULE_REQUESTNAME_DSSCMDREPORTSERVERCMDS",
    -2147072578: "MSI_SCHEDULE_REQUESTNAME_DSSCMDREQUESTEXECUTE",
    -2147072581: "MSI_SCHEDULE_REQUESTNAME_DSSCMDRESUMEPROJECT",
    -2147072252: "MSI_SCHEDULE_REQUESTNAME_DSSDEACTIVATECUBES",
    -2147072574: "MSI_SCHEDULE_REQUESTNAME_DSSDELETEALLCACHES",
    -2147072573: "MSI_SCHEDULE_REQUESTNAME_DSSDELETECACHE",
    -2147072254: "MSI_SCHEDULE_REQUESTNAME_DSSDELETECUBES",
    -2147072196: "MSI_SCHEDULE_REQUESTNAME_DSSDELETEMULTIPLECACHE",
    -2147071868: "MSI_SCHEDULE_REQUESTNAME_DSSDELETEUSELESSCACHE",
    -2147072572: "MSI_SCHEDULE_REQUESTNAME_DSSELEMENTCACHEPURGE",
    -2147072576: "MSI_SCHEDULE_REQUESTNAME_DSSINVALIDALLCACHES",
    -2147072575: "MSI_SCHEDULE_REQUESTNAME_DSSINVALIDATECACHE",
    -2147072197: "MSI_SCHEDULE_REQUESTNAME_DSSINVALIDATEMULTIPLECACHE",
    -2147072506: "MSI_SCHEDULE_REQUESTNAME_DSSLDAPBATCHIMPORT",
    -2147072505: "MSI_SCHEDULE_REQUESTNAME_DSSPURGESTATISTICS",
    -2147073251: "MSI_SCHEDULE_REQUESTNAME_DSSREFRESHCUBES",
    -2147025887: "MSI_SCHEDULE_REQUESTNAME_DSSUSHERBATCHIMPORT",
    -2147072586: "MSI_SCHEDULE_REQUESTNAME_REPORT",
    -2147072585: "MSI_SCHEDULE_REQUESTNAME_UNKNOWN",
    -2147072568: "MSI_SCHEDULE_REQUESTNAME_UNKNOWNSERVERCOMMAND",
    -2147209207: "MSI_SERIALIZEDBF_ERROR",
    -2147468644: "MSI_SERVERADMIN_NO_OBJSRC_IN_SESSION",
    -2147207861: "MSI_SERVERDEF_ERROR",
    -2147206922: "MSI_SERVER_BUSY",
    -2147206918: "MSI_SERVER_CONNECTING",
    -2147206919: "MSI_SERVER_DISCONNECTING",
    -2147209213: "MSI_SERVER_INIT_SEQUENCE_ERROR",
    -2147206925: "MSI_SERVER_NAME_NOT_INITIALIZED",
    -2147206923: "MSI_SERVER_NOT_FOUND",
    -2147074342: "MSI_SERVER_REJECT_REQUEST",
    -2147090920: "MSI_SERVER_START_REST_FAILED",
    -2147207759: "MSI_SERVICEMAIN_ARG_INFO",
    -2147207758: "MSI_SERVICEMAIN_ERROR_THREAD_CREATION",
    -2147207757: "MSI_SERVICEMAIN_THREAD_CREATION",
    -2147207588: "MSI_SERVICEMGR_ADD_PROJECT",
    -2147207589: "MSI_SERVICEMGR_CALL_CDSSOBJMANAGERIMPL",
    -2147207634: "MSI_SERVICEMGR_DSSOBJSVR",
    -2147207633: "MSI_SERVICEMGR_DSSOBJSVR_FAILURE",
    -2147207631: "MSI_SERVICEMGR_DSSOBJSVR_INIT",
    -2147207630: "MSI_SERVICEMGR_DSSOBJSVR_INIT_FAILURE",
    -2147207632: "MSI_SERVICEMGR_DSSOBJSVR_QI_FAILURE",
    -2147207602: "MSI_SERVICEMGR_DSSRESOLUTIONSVR",
    -2147207601: "MSI_SERVICEMGR_DSSRESOLUTIONSVR_FAILURE",
    -2147207599: "MSI_SERVICEMGR_DSSRESOLUTIONSVR_INIT_FAILURE",
    -2147207600: "MSI_SERVICEMGR_DSSRESOLUTIONSVR_QI_FAILURE",
    -2147207619: "MSI_SERVICEMGR_DSSRPTSRCSVR",
    -2147207618: "MSI_SERVICEMGR_DSSRPTSRCSVR_FAILURE",
    -2147207616: "MSI_SERVICEMGR_DSSRPTSRCSVR_INIT",
    -2147207615: "MSI_SERVICEMGR_DSSRPTSRCSVR_INIT_FAILURE",
    -2147207617: "MSI_SERVICEMGR_DSSRPTSRCSVR_QI_FAILURE",
    -2147207624: "MSI_SERVICEMGR_DSSRPTSVR",
    -2147207623: "MSI_SERVICEMGR_DSSRPTSVR_FAILURE",
    -2147207621: "MSI_SERVICEMGR_DSSRPTSVR_INIT",
    -2147207620: "MSI_SERVICEMGR_DSSRPTSVR_INIT_FAILURE",
    -2147207622: "MSI_SERVICEMGR_DSSRPTSVR_QI_FAILURE",
    -2147207608: "MSI_SERVICEMGR_DSSSOURCE_GET_SCHEMA",
    -2147207607: "MSI_SERVICEMGR_DSSSOURCE_GET_SCHEMA_FAILURE",
    -2147207606: "MSI_SERVICEMGR_DSSSQLENGSVR",
    -2147207605: "MSI_SERVICEMGR_DSSSQLENGSVR_FAILURE",
    -2147207604: "MSI_SERVICEMGR_DSSSQLENGSVR_QI_FAILURE",
    -2147207603: "MSI_SERVICEMGR_DSSSQLENGSVR_SET_SCHEMA",
    -2147207614: "MSI_SERVICEMGR_DSSSQLSVR",
    -2147207613: "MSI_SERVICEMGR_DSSSQLSVR_FAILURE",
    -2147207612: "MSI_SERVICEMGR_DSSSQLSVR_QI_FAILURE",
    -2147207629: "MSI_SERVICEMGR_DSSSRCSVR",
    -2147207628: "MSI_SERVICEMGR_DSSSRCSVR_FAILURE",
    -2147207626: "MSI_SERVICEMGR_DSSSRCSVR_PUT_SOURCE",
    -2147207625: "MSI_SERVICEMGR_DSSSRCSVR_PUT_SOURCE_FAILURE",
    -2147207627: "MSI_SERVICEMGR_DSSSRCSVR_QI_FAILURE",
    -2147207611: "MSI_SERVICEMGR_DSSXTABFACTORY",
    -2147207610: "MSI_SERVICEMGR_DSSXTABFACTORY_FAILURE",
    -2147207609: "MSI_SERVICEMGR_DSSXTABFACTORY_QI_FAILURE",
    -2147207592: "MSI_SERVICEMGR_FREE_DBCONNECTION",
    -2147207594: "MSI_SERVICEMGR_GET_DBCONNECTION",
    -2147207587: "MSI_SERVICEMGR_INITMDENV_MSIEXCEPTION",
    -2147207586: "MSI_SERVICEMGR_INITMDENV_SYSTEM_EXCEPTION",
    -2147207595: "MSI_SERVICEMGR_INIT_DFCMD4DATA",
    -2147207590: "MSI_SERVICEMGR_INIT_DSSOBJSOURCEMD4IMPL",
    -2147207593: "MSI_SERVICEMGR_LOADMD4",
    -2147207639: "MSI_SERVICEMGR_MD4SVR",
    -2147207638: "MSI_SERVICEMGR_MD4SVR_FAILURE",
    -2147207635: "MSI_SERVICEMGR_MD4SVR_INIT",
    -2147207636: "MSI_SERVICEMGR_MD4SVR_INITMDS_FAILURE",
    -2147207637: "MSI_SERVICEMGR_MD4SVR_QI_FAILURE",
    -2147207597: "MSI_SERVICEMGR_NEW_CDSSOBJMANAGERIMPL",
    -2147207598: "MSI_SERVICEMGR_NEW_DFCMD4DATA",
    -2147207591: "MSI_SERVICEMGR_NEW_DSSOBJSOURCEMD4IMPL",
    -2147207596: "MSI_SERVICEMGR_NEW_VLDBDRIVER",
    -2147072558: "MSI_SERVICE_CONTINUE_PENDING",
    -2147072553: "MSI_SERVICE_FAILED",
    -2147207743: "MSI_SERVICE_MANAGER_MSIEXCEPTION",
    -2147207742: "MSI_SERVICE_MANAGER_SYSTEM_EXCEPTION",
    -2147207740: "MSI_SERVICE_MANAGER_TRACE_INFO",
    -2147207741: "MSI_SERVICE_MANAGER_TRACE_MESSAGE",
    -2147207739: "MSI_SERVICE_MANAGER_TRACE_STEPS",
    -2147072555: "MSI_SERVICE_PAUSED",
    -2147072556: "MSI_SERVICE_RUNNING",
    -2147072557: "MSI_SERVICE_STOP_PENDING",
    -2147072554: "MSI_SERVICE_UNKNOWN_STATUS",
    -2147467626: "MSI_SESSIONMGR_HITCACHE_RQST_NOT_SAVED",
    -2147467620: "MSI_SESSIONMGR_JOB_RQST_NOT_SAVED",
    -2147468648: "MSI_SESSIONMGR_MAXSERVERUSERS_EXCEEDED",
    -2147209184: "MSI_SETPROJECTSTATUS_ERROR",
    -2147205283: "MSI_SETTING_EXCEED_LICENSE_LIMIT",
    -2147207254: "MSI_SQLENGINETASK_GetNextStepError",
    -2147207252: "MSI_SQLENGINETASK_InvalidNextStep",
    -2147207251: "MSI_SQLENGINETASK_MSIException",
    -2147207247: "MSI_SQLENGINETASK_NoJobReportInstance",
    -2147207253: "MSI_SQLENGINETASK_NoProjectId",
    -2147207248: "MSI_SQLENGINETASK_NoSQLEngineServer",
    -2147207249: "MSI_SQLENGINETASK_SQLEngineServerError",
    -2147207250: "MSI_SQLENGINETASK_SystemException",
    -2147207255: "MSI_SQLEXECTASK_DBConnectError",
    -2147207256: "MSI_SQLEXECTASK_DBException",
    -2147207264: "MSI_SQLEXECTASK_GetNextStepError",
    -2147207262: "MSI_SQLEXECTASK_InvalidNextStep",
    -2147207261: "MSI_SQLEXECTASK_MSIException",
    -2147207257: "MSI_SQLEXECTASK_NoJobReportInstance",
    -2147207263: "MSI_SQLEXECTASK_NoProjectId",
    -2147207258: "MSI_SQLEXECTASK_NoQueryEngineServer",
    -2147207259: "MSI_SQLEXECTASK_QueryEngineServerError",
    -2147207260: "MSI_SQLEXECTASK_SystemException",
    -2147207738: "MSI_SQL_ENGINE_TASK_RUN_MSIEXCEPTION",
    -2147207737: "MSI_SQL_ENGINE_TASK_RUN_SYSTEM_EXCEPTION",
    -2147207656: "MSI_STARTUPMGR_ADD_PROJECT",
    -2147207707: "MSI_STARTUPMGR_ANALYTICAL_ENGINE_CREATION_ERROR",
    -2147207706: "MSI_STARTUPMGR_ANALYTICAL_ENGINE_QI_ERROR",
    -2147207720: "MSI_STARTUPMGR_BACKUP_DIRECTORY_OPEN_ERROR",
    -2147207657: "MSI_STARTUPMGR_CALL_CDSSOBJMANAGERIMPL",
    -2147207725: "MSI_STARTUPMGR_CHANNELTHREADS_COUNT",
    -2147207726: "MSI_STARTUPMGR_CHANNEL_CREATED",
    -2147207708: "MSI_STARTUPMGR_CHANNEL_DELETE",
    -2147207727: "MSI_STARTUPMGR_CHANNEL_DISABLED",
    -2147207722: "MSI_STARTUPMGR_CHANNEL_IGNORED",
    -2147207724: "MSI_STARTUPMGR_CHANNEL_PORT",
    -2147207709: "MSI_STARTUPMGR_CHANNEL_STOP",
    -2147207723: "MSI_STARTUPMGR_CHANNEL_THREAD",
    -2147207695: "MSI_STARTUPMGR_DSSOBJSVR_INIT",
    -2147207694: "MSI_STARTUPMGR_DSSOBJSVR_INIT_FAILURE",
    -2147207679: "MSI_STARTUPMGR_DSSRPTSRCSVR",
    -2147207678: "MSI_STARTUPMGR_DSSRPTSRCSVR_FAILURE",
    -2147207676: "MSI_STARTUPMGR_DSSRPTSRCSVR_INIT",
    -2147207675: "MSI_STARTUPMGR_DSSRPTSRCSVR_INIT_FAILURE",
    -2147207677: "MSI_STARTUPMGR_DSSRPTSRCSVR_QI_FAILURE",
    -2147207682: "MSI_STARTUPMGR_DSSRPTSVR",
    -2147207681: "MSI_STARTUPMGR_DSSRPTSVR_FAILURE",
    -2147207674: "MSI_STARTUPMGR_DSSRPTSVR_INIT",
    -2147207673: "MSI_STARTUPMGR_DSSRPTSVR_INIT_FAILURE",
    -2147207680: "MSI_STARTUPMGR_DSSRPTSVR_QI_FAILURE",
    -2147207672: "MSI_STARTUPMGR_DSSSOURCE_GET_SCHEMA",
    -2147207671: "MSI_STARTUPMGR_DSSSOURCE_GET_SCHEMA_FAILURE",
    -2147207670: "MSI_STARTUPMGR_DSSSQLENGSVR",
    -2147207669: "MSI_STARTUPMGR_DSSSQLENGSVR_FAILURE",
    -2147207668: "MSI_STARTUPMGR_DSSSQLENGSVR_QI_FAILURE",
    -2147207667: "MSI_STARTUPMGR_DSSSQLENGSVR_SET_SCHEMA",
    -2147207688: "MSI_STARTUPMGR_DSSSQLSVR",
    -2147207687: "MSI_STARTUPMGR_DSSSQLSVR_FAILURE",
    -2147207686: "MSI_STARTUPMGR_DSSSQLSVR_QI_FAILURE",
    -2147207693: "MSI_STARTUPMGR_DSSSRCSVR",
    -2147207692: "MSI_STARTUPMGR_DSSSRCSVR_FAILURE",
    -2147207690: "MSI_STARTUPMGR_DSSSRCSVR_PUT_SOURCE",
    -2147207689: "MSI_STARTUPMGR_DSSSRCSVR_PUT_SOURCE_FAILURE",
    -2147207691: "MSI_STARTUPMGR_DSSSRCSVR_QI_FAILURE",
    -2147207685: "MSI_STARTUPMGR_DSSXTABFACTORY",
    -2147207684: "MSI_STARTUPMGR_DSSXTABFACTORY_FAILURE",
    -2147207683: "MSI_STARTUPMGR_DSSXTABFACTORY_QI_FAILURE",
    -2147207733: "MSI_STARTUPMGR_EMPTY_CHANNEL_LIST",
    -2147207652: "MSI_STARTUPMGR_EMPTY_PROJECT_KEY_LIST",
    -2147207660: "MSI_STARTUPMGR_FREE_DBCONNECTION",
    -2147207662: "MSI_STARTUPMGR_GET_DBCONNECTION",
    -2147207712: "MSI_STARTUPMGR_IGNORE_BACKUP",
    -2147207655: "MSI_STARTUPMGR_INITMDENV_MSIEXCEPTION",
    -2147207654: "MSI_STARTUPMGR_INITMDENV_SYSTEM_EXCEPTION",
    -2147207663: "MSI_STARTUPMGR_INIT_DFCMD4DATA",
    -2147207658: "MSI_STARTUPMGR_INIT_DSSOBJSOURCEMD4IMPL",
    -2147207702: "MSI_STARTUPMGR_INIT_MDENV",
    -2147207698: "MSI_STARTUPMGR_INIT_MDENV_DSSOBJSVR",
    -2147207697: "MSI_STARTUPMGR_INIT_MDENV_DSSOBJSVR_FAILURE",
    -2147207696: "MSI_STARTUPMGR_INIT_MDENV_DSSOBJSVR_QI_FAILURE",
    -2147207701: "MSI_STARTUPMGR_INIT_MDENV_FAILED",
    -2147207699: "MSI_STARTUPMGR_INIT_MDENV_INITMDS_FAILED",
    -2147207700: "MSI_STARTUPMGR_INIT_MDENV_QI_FAILED",
    -2147207661: "MSI_STARTUPMGR_LOADMD4",
    -2147207715: "MSI_STARTUPMGR_LOG_DIRECTORY_OPEN_ERROR",
    -2147207730: "MSI_STARTUPMGR_MSISYNCH_LOGGING_IN",
    -2147207729: "MSI_STARTUPMGR_MSITHREAD_LOGGING_IN",
    -2147207665: "MSI_STARTUPMGR_NEW_CDSSOBJMANAGERIMPL",
    -2147207666: "MSI_STARTUPMGR_NEW_DFCMD4DATA",
    -2147207659: "MSI_STARTUPMGR_NEW_DSSOBJSOURCEMD4IMPL",
    -2147207664: "MSI_STARTUPMGR_NEW_VLDBDRIVER",
    -2147207734: "MSI_STARTUPMGR_NO_CHANNEL_IN_REGISTRY",
    -2147207653: "MSI_STARTUPMGR_NO_PROJECT_KEY",
    -2147207721: "MSI_STARTUPMGR_PARAMETER_LOAD_ERROR",
    -2147207651: "MSI_STARTUPMGR_PROJECT_DISABLED",
    -2147207645: "MSI_STARTUPMGR_PROJECT_INIT",
    -2147207644: "MSI_STARTUPMGR_PROJECT_INVALID_LOGIN",
    -2147207650: "MSI_STARTUPMGR_PROJECT_LOAD_ON_DEMAND",
    -2147207643: "MSI_STARTUPMGR_PROJECT_MD4_SCHEMA_ERROR",
    -2147207646: "MSI_STARTUPMGR_PROJECT_NO_DBF",
    -2147207649: "MSI_STARTUPMGR_PROJECT_NO_ID",
    -2147207647: "MSI_STARTUPMGR_PROJECT_PROPERTY_NOT_FOUND",
    -2147207648: "MSI_STARTUPMGR_PROJECT_UNKNOWN_MODE",
    -2147207705: "MSI_STARTUPMGR_QUERY_ENGINE_CREATION_ERROR",
    -2147207703: "MSI_STARTUPMGR_QUERY_ENGINE_INIT_ERROR",
    -2147207704: "MSI_STARTUPMGR_QUERY_ENGINE_QI_ERROR",
    -2147207732: "MSI_STARTUPMGR_SERVER_LOCK_OFF",
    -2147207731: "MSI_STARTUPMGR_SERVER_LOCK_ON",
    -2147207728: "MSI_STARTUPMGR_STARTUPSERVER_FAILED",
    -2147207711: "MSI_STARTUPMGR_START_SUCCESS",
    -2147207710: "MSI_STARTUPMGR_TRACE_MESSAGE",
    -2147207716: "MSI_STARTUPMGR_USE_BACKUP_DIRECTORY",
    -2147207713: "MSI_STARTUPMGR_USE_BACKUP_FREQUENCY",
    -2147207714: "MSI_STARTUPMGR_USE_LOG_DIRECTORY",
    -2147207775: "MSI_STARTUP_MANAGER_FAILED",
    -2147468463: "MSI_STR_JOB_CANCELED",
    -2147468465: "MSI_STR_JOB_COMPELETED",
    -2147468464: "MSI_STR_JOB_ERROR",
    -2147468467: "MSI_STR_JOB_EXECUTING",
    -2147468468: "MSI_STR_JOB_READY",
    -2147468455: "MSI_STR_JOB_RESERVED1",
    -2147468454: "MSI_STR_JOB_RESERVED2",
    -2147468453: "MSI_STR_JOB_RESERVED3",
    -2147468452: "MSI_STR_JOB_RESERVED4",
    -2147468462: "MSI_STR_JOB_STOPPED",
    -2147468466: "MSI_STR_JOB_WAITING",
    -2147468460: "MSI_STR_JOB_WAITING_FOR_AUTO_PROMPT",
    -2147468458: "MSI_STR_JOB_WAITING_FOR_CACHE",
    -2147468457: "MSI_STR_JOB_WAITING_FOR_CHILDREN",
    -2147468456: "MSI_STR_JOB_WAITING_FOR_FETCHING_RESULTS",
    -2147468459: "MSI_STR_JOB_WAITING_FOR_PROJECT",
    -2147468461: "MSI_STR_JOB_WAITING_ON_GOVERNER",
    -2146943357: "MSI_TAKE_SNAPSHOT_ERROR",
    -2147073417: "MSI_THREAD_BALANCE_DISABLED",
    -2147209145: "MSI_THREAD_CREATION_FAILED",
    -2147072062: "MSI_Transmission_GeneralError",
    -2147207717: "MSI_UNKNOWNTASK",
    -2147209180: "MSI_UNKNOWN_DBCONNECTIONMODE_ERROR",
    -2147209206: "MSI_UNKNOWN_ERROR",
    -2147156465: "MSI_UNKNOWN_EXCEPTION",
    -2147209147: "MSI_UNKNOWN_EXCEPTION_CAUGHT",
    -2147209173: "MSI_UNKNOWN_SCHEDREQUEST_ERROR",
    -2147207280: "MSI_UNLOADDBFS_FAILED",
    -2147207869: "MSI_UNPACKCONNLIMIT_ERROR",
    -2147207871: "MSI_UNPACKDBCID_ERROR",
    -2147207870: "MSI_UNPACKDBROLEID_ERROR",
    -2147207641: "MSI_UNPACKJOBID_ERROR",
    -2147207868: "MSI_UNPACKLOADLIMIT_ERROR",
    -2147209201: "MSI_UNPACKPROJECTID_ERROR",
    -2147471360: "MSI_UNPACK_ERROR",
    -2147209152: "MSI_UNPACK_PURGEDATE_ERROR",
    -2147207290: "MSI_UPDATEDBF_FAILED",
    -2147025931: "MSI_UPDATE_CUBE_FAILED",
    -2147209202: "MSI_USERDISCONNECT_ERROR",
    -2147209203: "MSI_USERLOGOUT_ERROR",
    -2147209193: "MSI_USERNOTLOGGEDIN_ERROR",
    -2147209215: "MSI_USERPROPS_ERROR",
    -2147468901: "MSI_USER_SESSION_CLOSED",
    -2147025910: "MSI_USING_DUP_DOC_INST",
    -2147206921: "MSI_WAIT_FOR_CONNECTION_FAILED",
    -2147270772: "MSI_WORKINGSET_MESSAGE_NOT_FOUND",
    -2147205484: "MSI_WORKINGSET_SIZE_NOT_CHANGEABLE",
    -2147025907: "MSI_WRONG_ENCRYPTION_FORMAT",
    -2147025928: "MSI_WRONG_VERSION",
    -2147010165: "MSI_XML_CACHE_NOT_FOUND",
    -2147010107: "MSI_XML_FOLDER_NOTFOUND",
    -2147008845: "MSI_XML_GETFOLDERID_ERROR",
    -2147209159: "MSI_XML_INVALID_JOBSTATUS",
    -2147468918: "MSI_XML_NOTICE_NOT_SENT",
    -2147209158: "MSI_XML_USERNOTLOGGED_PROJECT_ERROR",
    -2147207267: "MSI_XTABTASK_AnalyticalEngineError",
    -2147207272: "MSI_XTABTASK_GetNextStepError",
    -2147207271: "MSI_XTABTASK_InvalidNextStep",
    -2147207269: "MSI_XTABTASK_MSIException",
    -2147207266: "MSI_XTABTASK_NoAnalyticalEngine",
    -2147207265: "MSI_XTABTASK_NoJobReportInstance",
    -2147207270: "MSI_XTABTASK_NoProjectId",
    -2147207585: "MSI_XTABTASK_RUN_MSIEXCEPTION",
    -2147207584: "MSI_XTABTASK_RUN_SYSTEM_EXCEPTION",
    -2147207268: "MSI_XTABTASK_SystemException",
    -2147483062: "MSQL_Transaction_Begin",
    -2147483061: "MSQL_Transaction_Commit",
    -2147483060: "MSQL_Transaction_Rollback",
    -2147481071: "MWS_C_ACCESS_RIGHTS",
    -2147481070: "MWS_C_ATTRIBUTE",
    -2147481065: "MWS_C_CONSTRUCTION",
    -2147481074: "MWS_C_DOCUMENT",
    -2147481075: "MWS_C_DOCUMENT_ID",
    -2147481076: "MWS_C_DOCUMENT_NAME",
    -2147481067: "MWS_C_GET_ATTRIBUTE",
    -2147481068: "MWS_C_GET_HIERARCHY",
    -2147481069: "MWS_C_HIERARCHY",
    -2147481088: "MWS_C_MAX_OBJECTS",
    -2147481087: "MWS_C_MAX_WAIT_TIME",
    -2147481080: "MWS_C_MESSAGE_ID",
    -2147481078: "MWS_C_OBJECT_ID",
    -2147481079: "MWS_C_OBJECT_NAME",
    -2147481066: "MWS_C_PARSING",
    -2147481086: "MWS_C_POLL_FREQUENCY",
    -2147481083: "MWS_C_PROJ_SRCS_PATH",
    -2147481077: "MWS_C_PROMPT",
    -2147481072: "MWS_C_PROPERTIES",
    -2147481073: "MWS_C_REPORT",
    -2147481081: "MWS_C_REPORT_ID",
    -2147481082: "MWS_C_REPORT_NAME",
    -2147481064: "MWS_C_TEXT_NODE",
    -2147481084: "MWS_C_USEDBY_SEARCH",
    -2147481085: "MWS_C_USING_SEARCH",
    -2147200959: "MWS_E_ACCESS_OBJ_INFO",
    -2147200911: "MWS_E_ALL_NT_AUTH_PROJECTS",
    -2147200929: "MWS_E_APPEND_XML_FILTER",
    -2147200996: "MWS_E_ATTR_ELEMENTS_FAILED",
    -2147200997: "MWS_E_BAD_OBJECT_ID",
    -2147200910: "MWS_E_BAD_OBJ_PROPERTY_NAME",
    -2147200999: "MWS_E_BROWSE_CANCEL_FAILED",
    -2147200919: "MWS_E_BUILD_VERSION",
    -2147200988: "MWS_E_CANCEL_DETECT",
    -2147201010: "MWS_E_CATCHALL_THROWABLE",
    -2147220210: "MWS_E_CATCHALL_THROWABLE1",
    -2147200916: "MWS_E_CONFIG_FILE_LOAD",
    -2147200984: "MWS_E_CONNECTION_FAILED",
    -2147200952: "MWS_E_COPY_OBJ_INFO",
    -2147200931: "MWS_E_CREATE_DRILL_FILTER",
    -2147200926: "MWS_E_CREATE_ELEMENT_LIST_FILTER",
    -2147200955: "MWS_E_DIMTY_PROMPTS",
    -2147200962: "MWS_E_DOCUMENT_EXECUTION",
    -2147200963: "MWS_E_DOCUMENT_NOT_FOUND",
    -2147200951: "MWS_E_DOCUMENT_RESULTS",
    -2147200956: "MWS_E_ELEMENT_PROMPTS",
    -2147200928: "MWS_E_ELEMENT_SEARCH_STR",
    -2147201012: "MWS_E_EXECUTION_STATUS",
    -2147220212: "MWS_E_EXECUTION_STATUS1",
    -2147200961: "MWS_E_EXEC_CANCEL",
    -2147200953: "MWS_E_EXPRESSION_PROMPTS",
    -2147201015: "MWS_E_GETINBOX_MSGS",
    -2147220215: "MWS_E_GETINBOX_MSGS1",
    -2147201018: "MWS_E_GETOBJECT_BY_ID",
    -2147220218: "MWS_E_GETOBJECT_BY_ID1",
    -2147201016: "MWS_E_GETOBJECT_OWNER",
    -2147220216: "MWS_E_GETOBJECT_OWNER1",
    -2147200949: "MWS_E_GET_DOCUMENT_XML",
    -2147200975: "MWS_E_GET_PROJECT_LIST",
    -2147200950: "MWS_E_GET_REPORT_XML",
    -2147201023: "MWS_E_INACTIVE_SESSION",
    -2147220223: "MWS_E_INACTIVE_SESSION1",
    -2147200965: "MWS_E_INBOX_OBJECT_FAILED",
    -2147200986: "MWS_E_INBOX_REPORT_FAILED",
    -2147200906: "MWS_E_INCOMPATIBLE_ISERVER",
    -2147200969: "MWS_E_INCREMENTAL_REPORT",
    -2147201011: "MWS_E_INVALID_INPUTS",
    -2147220211: "MWS_E_INVALID_INPUTS1",
    -2147200907: "MWS_E_INVALID_OFFICE_INSTALL_URI",
    -2147200920: "MWS_E_JAR_FILE_NOT_FOUND",
    -2147201019: "MWS_E_JAVA_STRING_TO_INT",
    -2147220219: "MWS_E_JAVA_STRING_TO_INT1",
    -2147201008: "MWS_E_LICENSE_CHECK",
    -2147220208: "MWS_E_LICENSE_CHECK1",
    -2147201014: "MWS_E_LOGON_FAILED",
    -2147220214: "MWS_E_LOGON_FAILED1",
    -2147200972: "MWS_E_NO_SERVER_NAME",
    -2147200915: "MWS_E_NUMERIC_FORMAT",
    -2147200964: "MWS_E_OBJECT_EXECUTION",
    -2147200966: "MWS_E_OBJECT_NOT_FOUND",
    -2147200954: "MWS_E_OBJECT_PROMPTS",
    -2147200960: "MWS_E_OBJECT_SRCH",
    -2147200973: "MWS_E_OBJ_FOLDER_PATH",
    -2147200918: "MWS_E_OFFICE_INSTALL_MISSING",
    -2147200927: "MWS_E_PARSE_XML_ELEMENT_LIST",
    -2147201017: "MWS_E_POPULATE_OBJ",
    -2147220217: "MWS_E_POPULATE_OBJ1",
    -2147200930: "MWS_E_POPULATE_XML_FILTER",
    -2147201013: "MWS_E_PROJECT_SRCS_XML",
    -2147220213: "MWS_E_PROJECT_SRCS_XML1",
    -2147200924: "MWS_E_PROMPT_KEY",
    -2147200923: "MWS_E_PROMPT_ORIGIN_TYPE",
    -2147200944: "MWS_E_PROMPT_RESOLUTION",
    -2147200922: "MWS_E_PROMPT_TYPE",
    -2147200967: "MWS_E_REPORT_FAILED",
    -2147200957: "MWS_E_REPORT_MANIPULATION",
    -2147200968: "MWS_E_REPORT_NOT_FOUND",
    -2147200948: "MWS_E_REPORT_RESULTS",
    -2147200958: "MWS_E_REPORT_VALIDATION",
    -2147200913: "MWS_E_RESOLVE_HOSTNAME",
    -2147201022: "MWS_E_ROOTFOLDER_ACCESS",
    -2147220222: "MWS_E_ROOTFOLDER_ACCESS1",
    -2147201021: "MWS_E_ROOTFOLDER_SEARCH",
    -2147220221: "MWS_E_ROOTFOLDER_SEARCH1",
    -2147201020: "MWS_E_SEARCHROOT_NOT_FOUND",
    -2147220220: "MWS_E_SEARCHROOT_NOT_FOUND1",
    -2147200982: "MWS_E_SESSION_CHK_FAILED",
    -2147200974: "MWS_E_SESSION_CLOSE",
    -2147200943: "MWS_E_SESSION_NOT_CREATED",
    -2147200970: "MWS_E_SESSION_NULL",
    -2147200994: "MWS_E_USERINFO_FAILED",
    -2147201005: "MWS_E_USER_MISSING",
    -2147220205: "MWS_E_USER_MISSING1",
    -2147200987: "MWS_E_USER_SEARCH_FAILED",
    -2147200945: "MWS_E_VERSION_DETECT",
    -2147200917: "MWS_E_VERSION_NUMBER_FORMAT",
    -2147200992: "MWS_E_WEBSEARCH_EXCEPTION",
    -2147200914: "MWS_E_XML_NODE_TYPE",
    -2147200971: "MWS_I_AUTHMODE",
    -2147200990: "MWS_I_BROWSE_CANCEL_STATUS",
    -2147200940: "MWS_I_BUSY_TIMEOUT",
    -2147201004: "MWS_I_EXECUTION_CANCELLED",
    -2147220204: "MWS_I_EXECUTION_CANCELLED1",
    -2147200947: "MWS_I_EXEC_CANCEL_STATUS",
    -2147200935: "MWS_I_POOL_SIZE",
    -2147200938: "MWS_I_REQUEST_TIMEOUT",
    -2147200985: "MWS_I_VERSION_NUMBERS",
    -2147200921: "MWS_W_AXISLOGGING_INIT",
    -2147201002: "MWS_W_BAD_INBOX_ITEM_ID",
    -2147201001: "MWS_W_BAD_INBOX_ITEM_LINK",
    -2147200993: "MWS_W_BEGIN_END_MISMATCH",
    -2147200989: "MWS_W_BROWSE_CANCEL_STATUS",
    -2147201000: "MWS_W_BROWSE_IS_CANCELLED",
    -2147200939: "MWS_W_BUSY_TIMEOUT_FAILED",
    -2147200934: "MWS_W_CLUSTER_ACCESS",
    -2147200936: "MWS_W_CLUSTER_CONNECT_FAILED",
    -2147200932: "MWS_W_CONNECT_PROPERTIES_ERROR",
    -2147200946: "MWS_W_EXEC_CANCEL_STATUS",
    -2147200991: "MWS_W_FOLDERPATH_CALC",
    -2147200925: "MWS_W_LICENSE_OUT_OF_COMPLIANCE",
    -2147200978: "MWS_W_NO_ACTIVE_PROJECTS",
    -2147200998: "MWS_W_NO_ATTR_ELEMENTS",
    -2147200983: "MWS_W_NO_CONNECTION",
    -2147200977: "MWS_W_NO_MYREPORTS",
    -2147200979: "MWS_W_NO_PROJECTS",
    -2147200981: "MWS_W_NO_PROJECT_SRCS",
    -2147200976: "MWS_W_NO_SHAREDREPORTS",
    -2147200912: "MWS_W_NT_AUTH_PROJECT",
    -2147200933: "MWS_W_POOL_SIZE_FAILED",
    -2147200937: "MWS_W_REQ_TIMEOUT_FAILED",
    -2147200909: "MWS_W_RESOURCE_BUNDLE_NOT_FOUND",
    -2147200995: "MWS_W_SEARCH_PURGE_FAILED",
    -2147201003: "MWS_W_SESSION_NOT_CLOSED",
    -2147200941: "MWS_W_UNKNOWN_ACCESS_RIGHT",
    -2147200980: "MWS_W_UNKNOWN_AUTHMODE",
    -2147200942: "MWS_W_UNKNOWN_PROPERTY",
    -2147200908: "MWS_W_WSDLVERSION_CONSTRUCTION",
    -2147212450: "NEWPROJECT_E_CONFIGURATION_OLDER_THAN_CODE",
    -2147217054: "NODE_ERR_CORRUPTED",
    -2147217055: "NODE_ERR_DELETED",
    -2147156459: "NO_ACCESS_TO_TOUCH_DOC_WITH_MTDI_CUBE",
    -2147156460: "NO_ACCESS_TO_TOUCH_MANAGED_MTDI_CUBE",
    -2147156461: "NO_ACCESS_TO_TOUCH_STANDALONE_MTDI_CUBE",
    -2147217059: "OBJECTINFO_ERR_CORRUPTED",
    -2147212201: "OBJECTINFO_ERR_CORRUPTED_2P",
    -2147217060: "OBJECTINFO_ERR_DELETED",
    -2147217058: "OBJECTINFO_ERR_INVALIDID",
    -2147217061: "OBJECTINFO_ERR_LOSTSERVER",
    -2147217057: "OBJECTINFO_ERR_NOOWNER",
    -2147217056: "OBJECTINFO_ERR_NOPARENT",
    -2147216988: "OBJECT_COLLECTION_ITEM_NOT_EXISTED",
    -2147216989: "OBJECT_COLLECTION_LOADED_TWICE",
    -2147216990: "OBJECT_COLLECTION_NOT_LOADED",
    -2147216991: "OBJECT_COLLECTION_WRONG_ITEM",
    -2147213343: "OBJSRV_E_NEEDS_CONTEXT",
    -2147213781: "OBJSRV_E_VIEWFILTER_LINKED",
    -2147213780: "OBJSRV_E_VIEWTEMPLATE_LINKED",
    -2147481843: "OBJSVR_C_ALLELEMENTNAME",
    -2147481839: "OBJSVR_C_ANYELEMENTNAME",
    -2147482827: "OBJSVR_C_DEFAULTBANDNAME",
    -2147483281: "OBJSVR_C_NEW",
    -2147481841: "OBJSVR_C_NULLELEMENTNAME",
    -2147213483: "OBJSVR_E_ADMINISTRATOR_PROTECTION",
    -2147217116: "OBJSVR_E_ATTRIBUTE_USED",
    -2147212145: "OBJSVR_E_ATTR_WRAPPER_WITH_NO_GOVERNOR",
    -2147217122: "OBJSVR_E_BADNAME",
    -2147217115: "OBJSVR_E_BADPROPERTYTYPE",
    -2147217090: "OBJSVR_E_BAD_ANSWER",
    -2147217082: "OBJSVR_E_BAD_ATTRIBUTE_TYPE",
    -2147217079: "OBJSVR_E_BAD_BASE_ATTRIBUTE",
    -2147202305: "OBJSVR_E_BAD_CONSOLIDATIONELEMENT_TYPE",
    -2147217136: "OBJSVR_E_BAD_CYCLE",
    -2147202306: "OBJSVR_E_BAD_DIMENSION_TYPE",
    -2147217104: "OBJSVR_E_BAD_DIMTY_SYSTEMDIM",
    -2147217105: "OBJSVR_E_BAD_DIMTY_TARGET",
    -2147217106: "OBJSVR_E_BAD_DIMTY_TYPE",
    -2147217119: "OBJSVR_E_BAD_ELEMENT_TYPE",
    -2147217085: "OBJSVR_E_BAD_ER_TYPE",
    -2147216621: "OBJSVR_E_BAD_FUNCTION_TYPE",
    -2147217091: "OBJSVR_E_BAD_PROMPT_CANCEL",
    -2147217078: "OBJSVR_E_BAD_ROLE_TYPE",
    -2147216620: "OBJSVR_E_BAD_RWNODE_TYPE",
    -2147217089: "OBJSVR_E_BAD_VALIDATION",
    -2147217069: "OBJSVR_E_BASE_VIEW_TEMPLATE",
    -2147217068: "OBJSVR_E_BASE_VIEW_TEMPLATE_POSITION",
    -2147212192: "OBJSVR_E_BETWEEN_PROMPT_NOT_MATCH",
    -2147212501: "OBJSVR_E_CANT_LINK_SYSTEM_USER_GROUP",
    -2147202268: "OBJSVR_E_CERTIFYSTATUS_CANNOT_GET",
    -2147202267: "OBJSVR_E_CERTIFYSTATUS_CANNOT_SET",
    -2147202270: "OBJSVR_E_CERTIFYSTATUS_PROPERTY_NOT_EXIST",
    -2147217126: "OBJSVR_E_CHANGED_ON_DISC",
    -2147217141: "OBJSVR_E_CIRCULARCOPY",
    -2147212110: "OBJSVR_E_CONFLICTS_LOCK_TYPE",
    -2147217097: "OBJSVR_E_CONFLICTS_PROMPT_TYPE",
    -2147217140: "OBJSVR_E_COPY_FOLDER",
    -2147217100: "OBJSVR_E_CUSTOM_FUNCTION",
    -2147217124: "OBJSVR_E_DATAMARTEXEC_DIRTY",
    -2147217125: "OBJSVR_E_DATAMARTEXEC_NOTPERSISTED",
    -2147216625: "OBJSVR_E_DBPASSWORD_ENCRYPTION",
    -2147217128: "OBJSVR_E_DELETE_FORCE_TEMP",
    -2147217134: "OBJSVR_E_DIFFORIGINAL",
    -2147202304: "OBJSVR_E_DIMENSION_FIXED",
    -2147217074: "OBJSVR_E_EMBEDDED_METHODS",
    -2147217062: "OBJSVR_E_EMBEDDED_USES_OTHERS",
    -2147217137: "OBJSVR_E_EXACTCOPY",
    -2147217080: "OBJSVR_E_EXTENDED_TYPE_IN_USE",
    -2147217088: "OBJSVR_E_FIXED_IN_RESOLUTION",
    -2147217077: "OBJSVR_E_FOLDER_INVALID_TYPE",
    -2147217076: "OBJSVR_E_FOLDER_TYPE",
    -2147217087: "OBJSVR_E_GLOBAL_PROMPT",
    -2147212196: "OBJSVR_E_GRAPH_PROPERTY_NOT_PRESENT",
    -2147217072: "OBJSVR_E_INCOMPLETE_LINK_ITEM_SPEC",
    -2147217063: "OBJSVR_E_INCONSISTANT_SMARTTOTAL",
    -2147216930: "OBJSVR_E_INCORRECT_SEARCH_USAGE",
    -2147217101: "OBJSVR_E_INFERTILE_NODE",
    -2147217075: "OBJSVR_E_INVALID_EMBEDDED_TYPE",
    -2147212292: "OBJSVR_E_ITERATION_ABORTED",
    -2147216939: "OBJSVR_E_LINKITEMS_IN_USE",
    -2147217073: "OBJSVR_E_LINK_NON_EMPTY",
    -2147217070: "OBJSVR_E_LINK_NOT_DEFINED",
    -2147216943: "OBJSVR_E_LINK_NOT_SAVED",
    -2147217001: "OBJSVR_E_LOAD_DSN_FAIL",
    -2147217083: "OBJSVR_E_LOCAL_SEARCH_NOT_SUPPORTED",
    -2147216630: "OBJSVR_E_LOGIN_TOO_LONG",
    -2147217139: "OBJSVR_E_MOVETOTEMP",
    -2147217102: "OBJSVR_E_MULTIPLE_CHILDREN",
    -2147217118: "OBJSVR_E_NEED_ATTRIBUTE",
    -2147217099: "OBJSVR_E_NEED_QUESTION",
    -2147217127: "OBJSVR_E_NOINTERFACE",
    -2147217130: "OBJSVR_E_NOSOURCE",
    -2147217086: "OBJSVR_E_NOT_ON_PROMPT_OBJECT",
    -2147217107: "OBJSVR_E_NO_CONFIGURATION",
    -2147217153: "OBJSVR_E_NO_FUNCTION",
    -2147217151: "OBJSVR_E_NO_PROJECT",
    -2147217150: "OBJSVR_E_NO_PROJECT_CONFIG",
    -2147217098: "OBJSVR_E_NO_PROMPT_TYPE",
    -2147202272: "OBJSVR_E_OBJECT_ALREADY_CERTIFIED",
    -2147202271: "OBJSVR_E_OBJECT_ALREADY_DECERTIFIED",
    -2147217144: "OBJSVR_E_OBJECT_COPY_IDENTICAL",
    -2147217145: "OBJSVR_E_OBJECT_COPY_WRONGTYPE",
    -2147217146: "OBJSVR_E_OBJECT_NONPERSISTED",
    -2147217152: "OBJSVR_E_OBJECT_NOTFIRSTCLASS",
    -2147217149: "OBJSVR_E_OBJECT_PARTIAL",
    -2147216932: "OBJSVR_E_OBJECT_PATH_AMBIGUOUS",
    -2147216933: "OBJSVR_E_OBJECT_PATH_NOT_FOUND",
    -2147217142: "OBJSVR_E_OBJECT_UNAVAILABLE",
    -2147217148: "OBJSVR_E_OBJECT_UNKNOWN",
    -2147217147: "OBJSVR_E_OBJECT_WRONGTYPE",
    -2147213459: "OBJSVR_E_OLD_METADATA",
    -2147213403: "OBJSVR_E_OLD_SERVER",
    -2147217005: "OBJSVR_E_ONE_METRIC_SUBTOTAL",
    -2147217071: "OBJSVR_E_OVERSPECIFIED_LINK_ITEM",
    -2147216624: "OBJSVR_E_PASSWORD_ENCRYPTION",
    -2147212495: "OBJSVR_E_PROMPTANSWER_PROMPT_FIXED",
    -2147217092: "OBJSVR_E_PROMPT_INCOMPLETE",
    -2147217093: "OBJSVR_E_PROMPT_LOCKED",
    -2147217094: "OBJSVR_E_PROMPT_OBJECT_ONLY",
    -2147217095: "OBJSVR_E_PROMPT_TYPE_FIXED",
    -2147213790: "OBJSVR_E_PROMPT_VALIDATION",
    -2147217344: "OBJSVR_E_PUT_OWNER_ID",
    -2147216623: "OBJSVR_E_PWD_ENCRYPTION_MISMATCH",
    -2147216629: "OBJSVR_E_RDBMSLOGIN_TOO_LONG",
    -2147217133: "OBJSVR_E_REMOTEFOLDER",
    -2147217132: "OBJSVR_E_REMOTEOBJECT",
    -2147217154: "OBJSVR_E_REPLACE_EMBEDDED",
    -2147213499: "OBJSVR_E_SCHDREQ_STMT_NOTFOUND",
    -2147217121: "OBJSVR_E_SEPARATORNAME",
    -2147217084: "OBJSVR_E_SHORTCUT_TO_SHORTCUT",
    -2147217131: "OBJSVR_E_SOURCELOST",
    -2147212089: "OBJSVR_E_STRING_PARAMETER_BACKSLASH_MISUSED",
    -2147212093: "OBJSVR_E_STRING_PARAMETER_BACKSLASH_NEEDED",
    -2147212087: "OBJSVR_E_STRING_PARAMETER_DANGLING_QUESTION_MARK",
    -2147212092: "OBJSVR_E_STRING_PARAMETER_ID_NEED_TYPE",
    -2147212091: "OBJSVR_E_STRING_PARAMETER_NOT_ONE_MATCH",
    -2147212090: "OBJSVR_E_STRING_PARAMETER_NO_CLOSING",
    -2147212088: "OBJSVR_E_STRING_PARAMETER_TYPE_IRRECOGNIZABLE",
    -2147217003: "OBJSVR_E_SUBTOTAL_DEFN_IN_USE",
    -2147217112: "OBJSVR_E_SUBTOTAL_INUSE",
    -2147217346: "OBJSVR_E_SYNCHRONIZE_OBJECT",
    -2147217067: "OBJSVR_E_SYSTEMFUNCTION_NOTFOUND",
    -2147217065: "OBJSVR_E_SYSTEMLINK_NOTFOUND",
    -2147217066: "OBJSVR_E_SYSTEMSUBTOTAL_NOTFOUND",
    -2147212333: "OBJSVR_E_TOO_MANY_EXTERNAL_KEY_FORMS",
    -2147216937: "OBJSVR_E_TOO_MANY_FORMS",
    -2147216631: "OBJSVR_E_TOO_MANY_PROP_RESTRICTIONS",
    -2147217064: "OBJSVR_E_TYPE_EQUALS_NOTTYPE",
    -2147217081: "OBJSVR_E_TYPE_IS_GENERATED",
    -2147213451: "OBJSVR_E_UNABLE_SET_DEST_FOLDER",
    -2147213421: "OBJSVR_E_UNIT_EXISTS_IN_THE_AXIS",
    -2147217108: "OBJSVR_E_UNSAVED_DESTFOLDER",
    -2147217096: "OBJSVR_E_UNSUPPORTED_PROMPT",
    -2147217307: "OBJSVR_E_USER_NOT_PERSISTED_BEFORE_MODIFYING_MEMBERSHIP",
    -2147217129: "OBJSVR_E_WRONGSOURCE",
    -2147217117: "OBJSVR_E_WRONG_ATTRIBUTE",
    -2147217103: "OBJSVR_E_WRONG_EXPRESSION",
    -2147217113: "OBJSVR_E_WRONG_INTERNALTYPE",
    -2147217002: "OBJSVR_E_WRONG_SUBTOTAL",
    -2147217114: "OBJSVR_E_WRONG_TEMPLATE",
    -2147217004: "OBJSVR_E_WRONG_TEMPLATEUNIT",
    -2147443118: "ONETIER_FAIL_BUNDLE_MISSING",
    -2147443119: "ONETIER_FAIL_ESRI_UNEXPECTED",
    -2147443120: "ONETIER_FAIL_KEY_INVALID",
    -2147443121: "ONETIER_FAIL_LOAD_FILE",
    -2147443131: "ONETIER_UPDATE_CANCEL",
    -2147443129: "ONETIER_UPDATE_CHECKING",
    -2147442592: "ONETIER_UPDATE_CLICK_DESC",
    -2147443082: "ONETIER_UPDATE_CLOSE",
    -2147443130: "ONETIER_UPDATE_DOWNLOAD",
    -2147443126: "ONETIER_UPDATE_DOWNLOADING",
    -2147443122: "ONETIER_UPDATE_INSTALL",
    -2147442593: "ONETIER_UPDATE_INSTALL_INQUERY",
    -2147443124: "ONETIER_UPDATE_LATEST",
    -2147443171: "ONETIER_UPDATE_NEW_VERSION",
    -2147442591: "ONETIER_UPDATE_NOTIFY_AVAILABLE",
    -2147442596: "ONETIER_UPDATE_NO_UPDATE",
    -2147442595: "ONETIER_UPDATE_NO_UPDATE_DESC",
    -2147443125: "ONETIER_UPDATE_RETRY",
    -2147443128: "ONETIER_UPDATE_UNAVAILABLE",
    -2147443127: "ONETIER_UPDATE_UNAVAILABLE_DESC",
    -2147443123: "ONETIER_UPDATE_UPDATE",
    -2147443081: "ONETIER_UPDATE_WINTITLE",
    -2147481618: "Obsolete_SDK_C_ATTRIBUTEFORM_Obsolete",
    -2147481247: "Obsolete_SDK_C_OP_AND_Obsolete",
    -2147483280: "PARSER_C_RIGHT_PAREN",
    -2147214820: "PARSER_E_ATTR_FORM_NOT_FOUND_ON_ATTR",
    -2147214824: "PARSER_E_ATTR_MULTIFORM_NOT_ALLOWED",
    -2147212441: "PARSER_E_ATTR_NOT_SUPPORTED_BY_CUBE",
    -2147214799: "PARSER_E_BANDINGP_FUN_ARGS_BAD",
    -2147214800: "PARSER_E_BANDING_FUN_ARGS_BAD",
    -2147211982: "PARSER_E_BOOL_FUN_NOT_ALLOWED",
    -2147214762: "PARSER_E_CIRCLE_REFERENCE_NOT_ALLOWED",
    -2147214827: "PARSER_E_CONDITION_NOT_ALLOWED",
    -2147212301: "PARSER_E_DBONLY_FUNCTION_NOT_ALLOWED",
    -2147211990: "PARSER_E_DE_NOT_SUPPORTED",
    -2147214830: "PARSER_E_DIMENSIONALITY_NOT_ALLOWED",
    -2147212337: "PARSER_E_DIMTY_UNIT_NOT_FOUND",
    -2147212448: "PARSER_E_ELEMENT_LIST_PROMPT_ATTRIBUTE_NOT_SUPPORTED_BY_CUBE",
    -2147214831: "PARSER_E_EMPTY_EXPRESSION",
    -2147214842: "PARSER_E_EXTRA_TOKENS_AT_END",
    -2147214847: "PARSER_E_FIND_ERROR",
    -2147214841: "PARSER_E_FOUND_TOKEN_EXPECTING",
    -2147476909: "PARSER_E_FUNC_NOT_AVAILABLE",
    -2147214832: "PARSER_E_INCOMPLETE_EXPRESSION",
    -2147214829: "PARSER_E_INTERNAL_ERROR",
    -2147214819: "PARSER_E_INVALID_ATTR_FORM_ID_INFO",
    -2147214840: "PARSER_E_INVALID_CHARACTERS",
    -2147214817: "PARSER_E_INVALID_DATE_TIME",
    -2147214811: "PARSER_E_INVALID_DIMTY_MERGE_RULE",
    -2147214839: "PARSER_E_INVALID_EXPRESSION",
    -2147214835: "PARSER_E_INVALID_FUNCTION_ARG",
    -2147214815: "PARSER_E_INVALID_JOIN_TYPE_OPTION",
    -2147214826: "PARSER_E_INVALID_LIST_SEPARATOR",
    -2147214809: "PARSER_E_INVALID_OUTPUT_LEVEL",
    -2147214813: "PARSER_E_INVALID_PROPERTY_FOR_OP_NODE",
    -2147214812: "PARSER_E_INVALID_SYMBOLIC_AXIS",
    -2147211980: "PARSER_E_INVALID_SYMBOLIC_AXIS_OR_DROPZONE",
    -2147214833: "PARSER_E_INVALID_TARGET_TYPE",
    -2147214816: "PARSER_E_JOIN_ATTRS_NOT_ALLOWED",
    -2147211973: "PARSER_E_MDX_METRIC_NOT_SUPPORTED",
    -2147214846: "PARSER_E_MULTIPLE_DEFS",
    -2147214845: "PARSER_E_NO_DEFS",
    -2147214843: "PARSER_E_NO_MORE_TOKENS_EXPECTING",
    -2147180453: "PARSER_E_NO_PLACEHOLDER_NOT_ALLOWED",
    -2147214848: "PARSER_E_NO_SEARCH_SPACE",
    -2147214844: "PARSER_E_NO_SOURCE",
    -2147214838: "PARSER_E_NO_SYS_FUNCTIONS_FOLDER",
    -2147214834: "PARSER_E_NO_TARGET_OBJECT",
    -2147214825: "PARSER_E_OBJECT_OF_TYPE_NOT_ALLOWED",
    -2147214818: "PARSER_E_OBJECT_PATH_NOT_FOUND",
    -2147214766: "PARSER_E_OBJ_OF_SUBTYPE_NOT_ALLOWED",
    -2147214808: "PARSER_E_OBJ_OF_TYPE_NOT_ALLOWED",
    -2147214807: "PARSER_E_OBJ_OF_TYPE_NOT_ALLOWED_IN_ATTR_FORM",
    -2147214764: "PARSER_E_OLAP_FUNCTION_NOT_ALLOWED",
    -2147211978: "PARSER_E_OLAP_OBJECT_NOT_ALLOWED",
    -2147214810: "PARSER_E_OUTPUT_LEVEL_REQUIRED",
    -2147214828: "PARSER_E_PROMPT_OF_TYPE_NOT_ALLOWED",
    -2147214814: "PARSER_E_REF_ALLOWED_ONLY_IN_SUBTOTALS",
    -2147214763: "PARSER_E_SELF_REFERENCE_NOT_ALLOWED",
    -2147214821: "PARSER_E_SORTBY_INVALID_AXIS",
    -2147214822: "PARSER_E_SORTBY_INVALID_DIRECTION",
    -2147214806: "PARSER_E_SORTBY_INVALID_LIST_CONTENT",
    -2147214823: "PARSER_E_SORTBY_NOT_ALLOWED",
    -2147214767: "PARSER_E_TOKENIZE_INVALID_OBJ_EXPR",
    -2147214768: "PARSER_E_TOKENIZE_OBJ_EXPR_NOT_SUPPORTED",
    -2147214837: "PARSER_E_TOO_FEW_FUNCTION_ARGS",
    -2147214836: "PARSER_E_TOO_MANY_FUNCTION_ARGS",
    -2147467397: "POOL_GET_OBJECT_SIZE_FAIL",
    -2147467399: "POOL_MAXIMUM_MEMORY_CONSUMPTION_REACHED",
    -2147467400: "POOL_MAXIMUM_OBJECT_COUNT_REACHED",
    -2147467395: "POOL_OBJECT_LOADFROMFILE_FAIL",
    -2147467398: "POOL_OBJECT_NOT_FOUND_BY_ID",
    -2147467396: "POOL_OBJECT_SAVETOFILE_FAIL",
    -2147467394: "POOL_SWAPPATH_ERROR",
    -2147214647: "PRJCRE_E_CONFIGURATION_CREATION_FAILED",
    -2147214652: "PRJCRE_E_INVALID_CONFIGURATION_DEFN_SCRIPT",
    -2147214653: "PRJCRE_E_INVALID_MD4_PROJECT_DEFN_SCRIPT",
    -2147214654: "PRJCRE_E_INVALID_PROJECT_DEFN_SCRIPT",
    -2147212072: "PRJCRE_E_MULTIPLE_PRODUCTS_SPECIFIED",
    -2147214648: "PRJCRE_E_PROJECT_CREATION_AND_CLEANUP_FAILED",
    -2147214649: "PRJCRE_E_PROJECT_CREATION_FAILED",
    -2147214651: "PRJCRE_E_SYMBOL_NOT_DEFINED",
    -2147214646: "PRJCRE_E_TEMP_FILE_CREATION_FAILED",
    -2147217109: "PROPERTY_E_DESIGN_CHANGE",
    -2147217110: "PROPERTY_E_DIFF_COMPONENTS",
    -2147217111: "PROPERTY_E_TYPE",
    -2147212536: "QE_E_CANNOT_CANCEL",
    -2147212542: "QE_E_CANNOT_CONNECT_WH",
    -2147206753: "QE_E_CUBE_FROM_TABULAR_DATA",
    -2147181051: "QE_E_DATA_TRANCATED",
    -2147212541: "QE_E_ELEMENT_INVALID_DATA",
    -2147212543: "QE_E_ExecuteID_ALREADY_EXIST",
    -2147212544: "QE_E_GENERAL",
    -2147179501: "QE_E_HEADINFO_EMPTY",
    -2147212535: "QE_E_INTERNAL_ERROR",
    -2147212537: "QE_E_MSI_DB_EXCEPTION",
    -2147212538: "QE_E_MSI_DB_LOGIC_ERROR_EXECPTION",
    -2147212540: "QE_E_NOELEMENTS_RETURNED",
    -2147212534: "QE_E_POPULATE_DATA_TYPE_MISMATCH",
    -2147212533: "QE_E_POPULATE_DATA_TYPE_UNKOWN",
    -2147212532: "QE_E_POPULATION_AE_REDUCE",
    -2147206754: "QE_E_POPU_REPORT",
    -2147202391: "QE_E_TOO_MANY_ROWS",
    -2147212539: "QE_E_UNEXPECTED_DATA_TYPE",
    -2147482623: "QE_STR_JOBCOMPLETE",
    -2147467443: "QE_STR_STAT_ACCESSED",
    -2147478615: "QE_STR_STAT_AE_PERSISTING",
    -2147467564: "QE_STR_STAT_ANA_DURA",
    -2147467447: "QE_STR_STAT_ANA_PASSES",
    -2147464477: "QE_STR_STAT_ANA_PROCESSING",
    -2147467561: "QE_STR_STAT_COLS",
    -2147465632: "QE_STR_STAT_CUBES_ACCESSED",
    -2147478614: "QE_STR_STAT_CUBE_PUBLISH_TIME",
    -2147465631: "QE_STR_STAT_CUBE_SQLS",
    -2147465630: "QE_STR_STAT_CUBE_SQL_DURA",
    -2147465633: "QE_STR_STAT_CUBE_SQL_PASSES",
    -2147464498: "QE_STR_STAT_DATA_FETCH",
    -2147464495: "QE_STR_STAT_DATA_FETCH_DURA",
    -2147464494: "QE_STR_STAT_DATA_FETCH_FROM_DS",
    -2147464479: "QE_STR_STAT_DATA_FETCH_PROC",
    -2147464478: "QE_STR_STAT_DATA_XFER_FROM_DS",
    -2147467445: "QE_STR_STAT_DB_INSTANCE",
    -2147467446: "QE_STR_STAT_DB_USER",
    -2147467567: "QE_STR_STAT_END_TIME",
    -2147464496: "QE_STR_STAT_EXEC_DURA",
    -2147443644: "QE_STR_STAT_IDT_BEGIN",
    -2147443643: "QE_STR_STAT_IDT_END",
    -2147466581: "QE_STR_STAT_MDX",
    -2147466583: "QE_STR_STAT_MDX_DURA",
    -2147466582: "QE_STR_STAT_MDX_PASSES",
    -2147204478: "QE_STR_STAT_NO_DATA",
    -2147464481: "QE_STR_STAT_NUM_ANA_PASSES",
    -2147464482: "QE_STR_STAT_NUM_DS_QUERY_PASSES",
    -2147467560: "QE_STR_STAT_NUM_TEMP_TABLES",
    -2147467563: "QE_STR_STAT_OTHER_DURA",
    -2147464476: "QE_STR_STAT_OTHER_PROCESSING",
    -2147464497: "QE_STR_STAT_OTHER_PROC_DURA",
    -2147443645: "QE_STR_STAT_PARTITION",
    -2147467559: "QE_STR_STAT_PASSES",
    -2147418116: "QE_STR_STAT_PASS_END_TIME",
    -2147418117: "QE_STR_STAT_PASS_START_TIME",
    -2147464489: "QE_STR_STAT_PROJ_EXEC_TIME_PSE",
    -2147464487: "QE_STR_STAT_PSE_EXPLAIN",
    -2147464475: "QE_STR_STAT_PSE_NOT_SUPPORTED",
    -2147464473: "QE_STR_STAT_PSE_NOT_SUPPORTED_HDA",
    -2147464471: "QE_STR_STAT_PSE_NOT_SUPPORTED_HDA_UD",
    -2147464472: "QE_STR_STAT_PSE_NOT_SUPPORTED_UD",
    -2147464490: "QE_STR_STAT_QUERY_EXEC",
    -2147464480: "QE_STR_STAT_QUERY_EXECUTION",
    -2147464491: "QE_STR_STAT_QUERY_GEN",
    -2147467562: "QE_STR_STAT_ROWS",
    -2147467442: "QE_STR_STAT_SQLS",
    -2147467565: "QE_STR_STAT_SQL_DURA",
    -2147464499: "QE_STR_STAT_SQL_EXEC_DBROLE",
    -2147464500: "QE_STR_STAT_SQL_GENERATION",
    -2147467441: "QE_STR_STAT_SQL_PASS",
    -2147467448: "QE_STR_STAT_SQL_PASSES",
    -2147467440: "QE_STR_STAT_SQL_PASS_DURA",
    -2147467568: "QE_STR_STAT_START_TIME",
    -2147464484: "QE_STR_STAT_SUM_ANA_PROC_TIME",
    -2147464486: "QE_STR_STAT_SUM_DATA_FETCHING",
    -2147464485: "QE_STR_STAT_SUM_DATA_TRANSFER",
    -2147464483: "QE_STR_STAT_SUM_OTHER_PROC",
    -2147467444: "QE_STR_STAT_TABLE_ACCESSED",
    -2147478616: "QE_STR_STAT_TEMPLATE_CAL",
    -2147464493: "QE_STR_STAT_TOTAL_DATA_FETCH_DURA",
    -2147467566: "QE_STR_STAT_TOTAL_DURA",
    -2147464488: "QE_STR_STAT_TOTAL_ELAPSED_TIME",
    -2147213329: "RESSVR_E_BAD_SF_PROMPT",
    -2147216980: "RESSVR_E_ITEM_EXISTED",
    -2147214077: "RESSVR_E_NOT_PART_NOT_LOADED",
    -2147216979: "RESSVR_E_NOT_PROMPTABLE",
    -2147216981: "RESSVR_E_TYPE_MISMATCH",
    -2147216128: "RPTEXE_E_CANNOT_MAKE_COMPONENT",
    -2147216127: "RPTEXE_E_CANNOT_MAKE_INSTANCE",
    -2147216126: "RPTEXE_E_NEED_COMPONENT",
    -2147216869: "RPTIST_E_CHANGE_TYPE",
    -2147216887: "RPTIST_E_INCONSISTENCY",
    -2147216888: "RPTIST_E_NODEFN",
    -2147215488: "RPTNETCLT_E_NO_RESULT",
    -2147215487: "RPTNETCLT_E_RESULT_CORRUPTED",
    -2147215486: "RPTNETCLT_E_UNEXPECTED_MESSAGE",
    -2147215104: "RPTNETSVR_E_MSG_CORRUPT",
    -2147215103: "RPTNETSVR_E_UNKNOWN_COMMAND",
    -2147479747: "RPTSVC_C_CubeLimit",
    -2147479748: "RPTSVC_C_Cube_Filter",
    -2147482704: "RPTSVC_C_DERIVED_METRIC_NAME",
    -2147442594: "RPTSVC_C_NEW_DATASET",
    -2147482700: "RPTSVC_C_PCT_TO_GRAND_TOTAL_NAME",
    -2147482701: "RPTSVC_C_PCT_TO_PAGE_TOTAL_NAME",
    -2147482699: "RPTSVC_C_PCT_TO_TOTAL_ACCROSS_ATTR_NAME",
    -2147482597: "RPTSVC_C_PCT_TO_TOTAL_BY_CELL_NAME",
    -2147482596: "RPTSVC_C_PCT_TO_TOTAL_BY_SHAPE_NAME",
    -2147482696: "RPTSVC_C_PCT_TO_TOTAL_NAME",
    -2147482702: "RPTSVC_C_PCT_TO_TOTAL_OVER_COLUMNS_NAME",
    -2147482703: "RPTSVC_C_PCT_TO_TOTAL_OVER_ROWS_NAME",
    -2147482697: "RPTSVC_C_RANK_BREAKBY_NAME",
    -2147443439: "RPTSVC_C_RANK_BREAKBY_NAME_ASCENDING",
    -2147443438: "RPTSVC_C_RANK_BREAKBY_NAME_DESCENDING",
    -2147482698: "RPTSVC_C_RANK_NAME",
    -2147443437: "RPTSVC_C_RANK_NAME_ASCENDING",
    -2147443436: "RPTSVC_C_RANK_NAME_DESCENDING",
    -2147422207: "RPTSVC_C_RWD_CHAPTER_NAME",
    -2147481840: "RPTSVC_C_RWD_LAYOUT_NAME",
    -2147422206: "RPTSVC_C_RWD_PAGE_NAME",
    -2147481629: "RPTSVC_C_RWD_PANEL_NAME",
    -2147481630: "RPTSVC_C_RWD_SHEET_NAME",
    -2147443433: "RPTSVC_C_RWD_TAB_NAME",
    -2147481628: "RPTSVC_C_RWD_VISUALIZATION_NAME",
    -2147482557: "RPTSVC_C_SHORTCUT_METRIC_AVERAGE",
    -2147482558: "RPTSVC_C_SHORTCUT_METRIC_COUNT",
    -2147482588: "RPTSVC_C_SHORTCUT_METRIC_DIFFERENCE_FIRST",
    -2147482587: "RPTSVC_C_SHORTCUT_METRIC_DIFFERENCE_LAST",
    -2147482589: "RPTSVC_C_SHORTCUT_METRIC_DIFFERENCE_NEXT",
    -2147482590: "RPTSVC_C_SHORTCUT_METRIC_DIFFERENCE_PREVIOUS",
    -2147482554: "RPTSVC_C_SHORTCUT_METRIC_GEOMEAN",
    -2147482561: "RPTSVC_C_SHORTCUT_METRIC_GREATEST_PREFIX",
    -2147482563: "RPTSVC_C_SHORTCUT_METRIC_LEAST_PREFIX",
    -2147482556: "RPTSVC_C_SHORTCUT_METRIC_MAX",
    -2147482553: "RPTSVC_C_SHORTCUT_METRIC_MEDIAN",
    -2147482555: "RPTSVC_C_SHORTCUT_METRIC_MIN",
    -2147482560: "RPTSVC_C_SHORTCUT_METRIC_MODE",
    -2147482564: "RPTSVC_C_SHORTCUT_METRIC_MOVING_AVG",
    -2147482565: "RPTSVC_C_SHORTCUT_METRIC_MOVING_COUNT",
    -2147482566: "RPTSVC_C_SHORTCUT_METRIC_MOVING_DIFFERENCE",
    -2147482567: "RPTSVC_C_SHORTCUT_METRIC_MOVING_MAX",
    -2147482568: "RPTSVC_C_SHORTCUT_METRIC_MOVING_MIN",
    -2147482569: "RPTSVC_C_SHORTCUT_METRIC_MOVING_STDEV",
    -2147482570: "RPTSVC_C_SHORTCUT_METRIC_MOVING_STDEVP",
    -2147482571: "RPTSVC_C_SHORTCUT_METRIC_MOVING_SUM",
    -2147482595: "RPTSVC_C_SHORTCUT_METRIC_PERCENTILE_RANK",
    -2147482580: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_CHANGE_FIRST",
    -2147482579: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_CHANGE_LAST",
    -2147482581: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_CHANGE_NEXT",
    -2147482582: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_CHANGE_PREVIOUS",
    -2147482584: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_OF_FIRST",
    -2147482583: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_OF_LAST",
    -2147482585: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_OF_NEXT",
    -2147482586: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_OF_PREVIOUS",
    -2147482548: "RPTSVC_C_SHORTCUT_METRIC_PERCENT_RUNNING_TOTAL",
    -2147482552: "RPTSVC_C_SHORTCUT_METRIC_PRODUCT",
    -2147482549: "RPTSVC_C_SHORTCUT_METRIC_ROW_COUNT",
    -2147482572: "RPTSVC_C_SHORTCUT_METRIC_RUNNING_AVG",
    -2147482573: "RPTSVC_C_SHORTCUT_METRIC_RUNNING_COUNT",
    -2147482574: "RPTSVC_C_SHORTCUT_METRIC_RUNNING_MAX",
    -2147482575: "RPTSVC_C_SHORTCUT_METRIC_RUNNING_MIN",
    -2147482576: "RPTSVC_C_SHORTCUT_METRIC_RUNNING_STDEV",
    -2147482577: "RPTSVC_C_SHORTCUT_METRIC_RUNNING_STDEVP",
    -2147482578: "RPTSVC_C_SHORTCUT_METRIC_RUNNING_SUM",
    -2147482551: "RPTSVC_C_SHORTCUT_METRIC_STDEV",
    -2147482559: "RPTSVC_C_SHORTCUT_METRIC_SUM",
    -2147482550: "RPTSVC_C_SHORTCUT_METRIC_VAR",
    -2147213445: "RPTSVC_E_ADDITION_ON_LINKED_TEMPLATE_NOT_ALLOWED",
    -2147213426: "RPTSVC_E_ADDUNITTOBASE_ALREADY_EXISTS",
    -2147213449: "RPTSVC_E_ADDUNIT_BAD_OBJECT",
    -2147213447: "RPTSVC_E_ADD_TRANSFORMATION_BAD_INPUT_METRIC",
    -2147213441: "RPTSVC_E_CANNOT_EDIT_NON_SQL_METRIC_TO_SQL",
    -2147213436: "RPTSVC_E_CANNOT_PERFORM_MANIPULATIONS",
    -2147213423: "RPTSVC_E_CANNOT_SET_DATAMART_WITHOUT_CONVERSION",
    -2147213422: "RPTSVC_E_CANNOT_UNSET_DATAMART",
    -2147213439: "RPTSVC_E_CANNOT_USE_DERIVED_METRIC_IN_SQL_METRIC",
    -2147213395: "RPTSVC_E_CIRCULAR_ACTION",
    -2147213461: "RPTSVC_E_CLOSED",
    -2147212458: "RPTSVC_E_DE0_NOT_MANAGED",
    -2147212485: "RPTSVC_E_DEPENDENCY_CYCLE_IN_DEFINITION",
    -2147211979: "RPTSVC_E_DEPENDENCY_CYCLE_IN_EXPRESSION",
    -2147213440: "RPTSVC_E_DEPENDENCY_CYCLE_IN_METRIC_DEFINITION",
    -2147212336: "RPTSVC_E_DERIVED_ELEMENT_INCOMPATIBLE",
    -2147212460: "RPTSVC_E_DERIVED_ELEMENT_MANAGED",
    -2147212484: "RPTSVC_E_DERIVED_ELEMENT_NOT_FOUND",
    -2147213448: "RPTSVC_E_EVALUATION_ORDER_CONFLICT",
    -2147212445: "RPTSVC_E_INVALID_DE_TO_SELECT",
    -2147213450: "RPTSVC_E_INVALID_INSTANCE",
    -2147213434: "RPTSVC_E_INVALID_SORT_TYPE",
    -2147212455: "RPTSVC_E_MANIPULATION_NOT_SUPPORTED",
    -2147217345: "RPTSVC_E_METRIC_NOT_ACCESSIBLE",
    -2147213435: "RPTSVC_E_METRIC_NOT_EDITABLE",
    -2147213444: "RPTSVC_E_METRIC_NOT_FOUND_BY_NAME_ON_THE_REPORT",
    -2147213460: "RPTSVC_E_NOTINITIALIZED",
    -2147212459: "RPTSVC_E_NOT_DERIVED_ELEMENT",
    -2147212461: "RPTSVC_E_NO_UNIT_LIMIT",
    -2147081397: "RPTSVC_E_SET_EVAL_ORDER_NOT_SUPPORTED",
    -2147213446: "RPTSVC_E_SORT_HIERARCHICAL_BAD_SUBTOTAL",
    -2147213443: "RPTSVC_E_SQL_MANIPULATION_NO_PRIV",
    -2147213442: "RPTSVC_E_SQL_METRIC_ON_BASE_EMBEDDED_IN_VIEW",
    -2147213456: "RPTSVC_E_SQL_NOT_ACCEPTED",
    -2147483095: "RPTSVR_BASE_CACHED",
    -2147483093: "RPTSVR_CACHE_EXPIRED",
    -2147482820: "RPTSVR_CACHE_FILE_NOT_FOUND",
    -2147483100: "RPTSVR_CACHE_HIT",
    -2147482821: "RPTSVR_CACHE_INVALID",
    -2147483098: "RPTSVR_CACHE_IN_PROCESS",
    -2147483099: "RPTSVR_CACHE_NOT_FOUND",
    -2147466619: "RPTSVR_CACHE_TO_BE_UPDATED",
    -2147482819: "RPTSVR_CACHING_DISABLED",
    -2147483091: "RPTSVR_CREATE_CACHE_FAILED",
    -2147479742: "RPTSVR_C_DocumentNotes",
    -2147482824: "RPTSVR_C_METRICSTITLE",
    -2147482676: "RPTSVR_C_PromptDetails",
    -2147479744: "RPTSVR_C_ReportDescription",
    -2147482691: "RPTSVR_C_ReportFilter",
    -2147482689: "RPTSVR_C_ReportLimit",
    -2147479743: "RPTSVR_C_ReportNotes",
    -2147482705: "RPTSVR_C_SECURITYFILTERS",
    -2147479746: "RPTSVR_C_TemplateUnitsLimit",
    -2147479745: "RPTSVR_C_UserFilter",
    -2147482690: "RPTSVR_C_ViewFilter",
    -2147482688: "RPTSVR_C_ViewLimit",
    -2147212491: "RPTSVR_E_ADD_MIXEDOBJECTPROMPT_AS_METRIC_UNIT",
    -2147216895: "RPTSVR_E_ALREADYINIT",
    -2147216872: "RPTSVR_E_BAD_PROMPT_EVENT",
    -2147216879: "RPTSVR_E_BINDINGTABLE_NO_CG",
    -2147216890: "RPTSVR_E_BNDTBL_CORRUPT",
    -2147216889: "RPTSVR_E_BNDTBL_CORRUPT_ON_DISK",
    -2147213433: "RPTSVR_E_BNDTBL_OBJECTNOTFOUND",
    -2147216876: "RPTSVR_E_CACHE_ADMIN_NOT_INITIALIZED",
    -2147475529: "RPTSVR_E_CACHE_KEEPASIS_NO_BASE",
    -2147213803: "RPTSVR_E_CANNOT_FIND_SECURITYFILTER",
    -2147213822: "RPTSVR_E_CANNOT_HANDLE_PROMPT",
    -2147216870: "RPTSVR_E_COORDINATES",
    -2147216877: "RPTSVR_E_CORRUPTED_CACHE",
    -2147212496: "RPTSVR_E_CUBE_ELEMENT_NOSOURCE",
    -2147212457: "RPTSVR_E_CUBE_HAS_PROMPT",
    -2147216856: "RPTSVR_E_DRILLOUT",
    -2147211251: "RPTSVR_E_DRILL_FROM_UNSUPPORTED_REPORT_TYPE",
    -2147212492: "RPTSVR_E_ELEMENT_INVALID_XTABHEADER",
    -2147212493: "RPTSVR_E_ELEMENT_NO_UNIT",
    -2147212494: "RPTSVR_E_ELEMENT_NO_XTABHEADER",
    -2147211998: "RPTSVR_E_EMMA_DISCOVER_DATA_FAILED",
    -2147216886: "RPTSVR_E_EXECUTION_IN_PROGRESS",
    -2147483092: "RPTSVR_E_GRAPH",
    -2147216861: "RPTSVR_E_GRAPH_DRILL_OUTOFRANGE",
    -2147216878: "RPTSVR_E_INVALID_ACTION",
    -2147216882: "RPTSVR_E_INVALID_ELEMENT",
    -2147216881: "RPTSVR_E_INVALID_ELEMENTS",
    -2147216862: "RPTSVR_E_INVALID_REPORT_INSTANCE",
    -2147216884: "RPTSVR_E_INVALID_RPT_DEF",
    -2147216874: "RPTSVR_E_INVALID_USERDATA",
    -2147216865: "RPTSVR_E_INVALID_WORKINGSET_REPORT",
    -2147216868: "RPTSVR_E_INVALID_XTABHEADER",
    -2147214328: "RPTSVR_E_LINKED_VIEWTEMPOLATE",
    -2147216871: "RPTSVR_E_LOST_BASE",
    -2147216858: "RPTSVR_E_MDXDRILL_DIFFAXIS",
    -2147216860: "RPTSVR_E_MDXDRILL_ELEMENT_MORETHANONE",
    -2147216859: "RPTSVR_E_MDXDRILL_ELEMENT_TYPE",
    -2147216885: "RPTSVR_E_MISSING_ERROR_MSG",
    -2147216894: "RPTSVR_E_NOEXECUTION",
    -2147216892: "RPTSVR_E_NOSQLSSERVER",
    -2147216864: "RPTSVR_E_NOTIMPL_SUBSETTING_REPORT",
    -2147216896: "RPTSVR_E_NOTINIT",
    -2147216883: "RPTSVR_E_NOT_DRILLINSTANCE",
    -2147216867: "RPTSVR_E_NOT_EXECUTED",
    -2147216891: "RPTSVR_E_NOXTABFACTORY",
    -2147216880: "RPTSVR_E_NO_BINDINGTABLE",
    -2147475607: "RPTSVR_E_NO_CACHEACTION_FOR_ELEMENT",
    -2147212483: "RPTSVR_E_NO_DERIVED_ELEMENT_DEFINED",
    -2147475606: "RPTSVR_E_NO_ELEMENT",
    -2147216873: "RPTSVR_E_NO_EVENT_HANDLER",
    -2147213815: "RPTSVR_E_NO_OBJSRC_IN_RPT_DEF",
    -2147213816: "RPTSVR_E_NO_OBJSRC_IN_SESSION",
    -2147213820: "RPTSVR_E_NO_PROJECT",
    -2147212456: "RPTSVR_E_NO_VIEW_RESULT",
    -2147212340: "RPTSVR_E_OVERWRITE_CUBE_WITH_NONCUBE",
    -2147212339: "RPTSVR_E_OVERWRITE_NONCUBE_WITH_CUBE",
    -2147212338: "RPTSVR_E_OVERWRITE_REPORT_WITH_DIFFERENT_STRUCTURE_TYPE",
    -2147213800: "RPTSVR_E_RCM_ADD_RESULT",
    -2147213804: "RPTSVR_E_RCM_CORRUPTED_CACHE_ENTRY",
    -2147213813: "RPTSVR_E_RCM_CREATE_CACHE_DIR",
    -2147213811: "RPTSVR_E_RCM_CREATE_CACHE_FILE",
    -2147475608: "RPTSVR_E_RCM_DISK_FULL",
    -2147213812: "RPTSVR_E_RCM_GET_CURRENT_DIR",
    -2147213817: "RPTSVR_E_RCM_INIT_INVALID_RPTSVR",
    -2147213801: "RPTSVR_E_RCM_INSERT_LKUPTABLE",
    -2147213809: "RPTSVR_E_RCM_INVALID_CACHE_FILE_NAME",
    -2147213802: "RPTSVR_E_RCM_INVALID_CACHE_IDTYPE",
    -2147213821: "RPTSVR_E_RCM_LOAD_CACHE_FILE",
    -2147213807: "RPTSVR_E_RCM_LOAD_CACHE_INFO",
    -2147213819: "RPTSVR_E_RCM_LOAD_VERSION",
    -2147213799: "RPTSVR_E_RCM_NULL_CACHE_ID",
    -2147213808: "RPTSVR_E_RCM_SAVE_CACHE",
    -2147213810: "RPTSVR_E_RCM_SAVE_VERSION",
    -2147213814: "RPTSVR_E_RCM_UPDATE_MEMORY_SIZE",
    -2147213818: "RPTSVR_E_RCM_WRONG_VERSION",
    -2147216863: "RPTSVR_E_REMOVE_UNIT",
    -2147216875: "RPTSVR_E_REPORT_TYPE_NOT_INITIALIZED",
    -2147216857: "RPTSVR_E_SAVEAS_8iWARNING",
    -2147213389: "RPTSVR_E_SAVEAS_BADTEMPLATE",
    -2147213390: "RPTSVR_E_SAVEAS_STATIC_LINK",
    -2147213782: "RPTSVR_E_SAVEAS_VIEWTEMPLATE",
    -2147482801: "RPTSVR_E_SETTING_CANNOT_DECREASE_RUNTIME",
    -2147216866: "RPTSVR_E_STRUCTURE_FATAL",
    -2147212443: "RPTSVR_E_VIEW_ELEMENT_CUBEINACTIVE",
    -2147212499: "RPTSVR_E_VIEW_ELEMENT_NOCUBE",
    -2147212452: "RPTSVR_E_VIEW_ELEMENT_NOOBJECT",
    -2147212498: "RPTSVR_E_VIEW_ELEMENT_NOSOURCE",
    -2147212497: "RPTSVR_E_VIEW_OBJECT_NOSOURCE",
    -2147216893: "RPTSVR_E_WRONGINSTANCE",
    -2147483096: "RPTSVR_HAS_PROMPT",
    -2147483097: "RPTSVR_IN_WAITINGLIST",
    -2147213806: "RPTSVR_MAXIMUM_CACHE_COUNT_REACHED",
    -2147213805: "RPTSVR_MAXIMUM_CACHE_MEMORY_USAGE_REACHED",
    -2147482818: "RPTSVR_MAY_HAS_PROMPT",
    -2147483094: "RPTSVR_OUTOF_CACHE_MEMORY",
    -2147474644: "RPTSVR_RCM_UNKNOWN_DBTABLE",
    -2147482823: "RPTSVR_XML_MAXNODES_EXCEED",
    -2147214332: "RSLSVR_E_BAD_EMBEDDED",
    -2147214335: "RSLSVR_E_CYCLIC_DEFINITION",
    -2147214333: "RSLSVR_E_INCONSISTENT_BLANK_PROMPTS",
    -2147214334: "RSLSVR_E_INCONSISTENT_PROMPTS",
    -2147214336: "RSLSVR_E_NO_DEFINITION",
    -2147214331: "RSLSVR_E_ROOT_CONTAINER_IN_RESOLUTION",
    -2147214330: "RSLSVR_E_ROOT_IS_EMBEDDED",
    -2147214329: "RSLSVR_E_SUBST_CYCLE",
    -2147483090: "RSSVR_S_NOTINITIALIZED",
    -2147214079: "SCHDLR_NOT_EVENT_TYPE",
    -2147214078: "SCHDLR_NOT_TPOINTSERIES_TYPE",
    -2147214080: "SCHDLR_OBJ_CORRUPTED",
    -2147217030: "SCHEMA_ERR_ADD",
    -2147217032: "SCHEMA_ERR_COLLECTION",
    -2147217040: "SCHEMA_ERR_CONSTRUCTION",
    -2147217031: "SCHEMA_ERR_ENUM",
    -2147217027: "SCHEMA_ERR_FORMTYPE",
    -2147217037: "SCHEMA_ERR_GETI",
    -2147217036: "SCHEMA_ERR_GETINFO",
    -2147217035: "SCHEMA_ERR_GETUNK",
    -2147217034: "SCHEMA_ERR_INDEX",
    -2147217038: "SCHEMA_ERR_INNEROBJ",
    -2147217033: "SCHEMA_ERR_NOTFOUND",
    -2147217039: "SCHEMA_ERR_OBJECTSRV",
    -2147217029: "SCHEMA_ERR_TABLETYPE",
    -2147217028: "SCHEMA_ERR_TEMPLATEDEFAULT",
    -2147217023: "SCHEMA_E_DIMCYCLE",
    -2147217022: "SCHEMA_E_DIM_ADD_INVALIDARG",
    -2147217026: "SCHEMA_E_FRMNOTINATTR",
    -2147217025: "SCHEMA_E_FRSTCLSFORM",
    -2147217024: "SCHEMA_E_GUIDETYPE",
    -2147212085: "SCHMNP_E_FACTID_REQUIRED",
    -2147212086: "SCHMNP_E_FUNCTIONTYPE_REQUIRED",
    -2147212107: "SCHMNP_E_INVALID_MANIPULATION_TYPE",
    -2147211974: "SCHMNP_E_MSO_COLUMN_INCOMPATIBLE",
    -2147211975: "SCHMNP_E_MSO_COLUMN_MISSING",
    -2147212100: "SCHMNP_E_OBJ_WITH_SAME_TYPE_NAME_EXIST",
    -2147212101: "SCHMNP_E_UNSUPPORTED_OBJ_TYPE",
    -2147217021: "SCHSRVC_E_BAD_OBJECT_TYPE",
    -2147206793: "SCRSVR_E_CLOSED",
    -2147206792: "SCRSVR_E_MSG_CORRUPT",
    -2147214659: "SCR_E_ATTR_EXPECTED",
    -2147214662: "SCR_E_ATTR_TYPE_MISMATCH",
    -2147214655: "SCR_E_INVALID_ROOT_TAG_NAME",
    -2147214658: "SCR_E_SCRIPT_ATTR_VALUE",
    -2147214656: "SCR_E_SCRIPT_FORMAT",
    -2147214657: "SCR_E_SCRIPT_URL",
    -2147214660: "SCR_E_SYMBOL_NOT_DEFINED",
    -2147214661: "SCR_E_UNSPECIFIED_SCRIPT_ERROR",
    -2147481501: "SDK_C_APRIL",
    -2147481585: "SDK_C_ATTRFORMSHORTCUT",
    -2147481569: "SDK_C_ATTRIBUTE",
    -2147481568: "SDK_C_ATTRIBUTEFORM",
    -2147481586: "SDK_C_ATTRSHORTCUT",
    -2147481089: "SDK_C_ATTR_OF_HIER",
    -2147481497: "SDK_C_AUGUST",
    -2147481570: "SDK_C_BASEATTRIBUTEFORM",
    -2147480975: "SDK_C_CERT_SRV_MESSAGE",
    -2147481101: "SDK_C_CHOOSE_ELEMENT_OF",
    -2147481094: "SDK_C_CHOOSE_FILETERS_FROM_THE_LIST",
    -2147481097: "SDK_C_CHOOSE_REPORTS_FROM_THE_LIST",
    -2147481600: "SDK_C_COLLECTION",
    -2147481536: "SDK_C_COLUMN",
    -2147481604: "SDK_C_COLUMN_DATA_VALUES",
    -2147481605: "SDK_C_COLUMN_EXTRA",
    -2147481603: "SDK_C_COLUMN_METRICS",
    -2147481246: "SDK_C_COMPOUND_METRICS_FOLDER_NAME",
    -2147480990: "SDK_C_COPY_OF_X",
    -2147481458: "SDK_C_DAYS",
    -2147481452: "SDK_C_DAY_OF_MONTH",
    -2147481461: "SDK_C_DAY_OF_MONTH_WITH_OFF",
    -2147481535: "SDK_C_DBTABLE",
    -2147481493: "SDK_C_DECEMBER",
    -2147481576: "SDK_C_DEFAULT",
    -2147481567: "SDK_C_DIMENSION",
    -2147481563: "SDK_C_DIRECTEDATTRIBUTE",
    -2147481542: "SDK_C_DM_DEFAULT_LVL",
    -2147481207: "SDK_C_DM_PREF_BREAKBY",
    -2147481209: "SDK_C_DM_PREF_EVALSET",
    -2147481208: "SDK_C_DM_PREF_SETOF",
    -2147481544: "SDK_C_DM_REPT_BASE_LVL",
    -2147481206: "SDK_C_DM_RPT_BASE_LVL",
    -2147481543: "SDK_C_DM_RPT_LVL",
    -2147481541: "SDK_C_DM_UNKNOWN_LVL",
    -2147481241: "SDK_C_DM_WHERE",
    -2147481462: "SDK_C_DOW_OF_MONTH_WITH_OFF",
    -2147481450: "SDK_C_DOW_OF_WEEK",
    -2147481451: "SDK_C_DOW_OF_WEEK_WITH_OFF",
    -2147481597: "SDK_C_DRILLACTION",
    -2147481512: "SDK_C_DRILLING_TARGET",
    -2147481595: "SDK_C_DRILLTYPE",
    -2147481011: "SDK_C_DYN_CURR_HOUR",
    -2147481012: "SDK_C_DYN_CURR_MINUTE",
    -2147481010: "SDK_C_DYN_ON_SPECIFIC_MINUTE",
    -2147481584: "SDK_C_ELEMENT",
    -2147481579: "SDK_C_ELEMENTID",
    -2147481531: "SDK_C_ELEMENTS",
    -2147481100: "SDK_C_ELEMENT_SELECTION_OF",
    -2147481520: "SDK_C_EVAL_SET",
    -2147481583: "SDK_C_EXPRESSION",
    -2147481530: "SDK_C_EXPRESSIONXML",
    -2147481565: "SDK_C_EXTENSION",
    -2147481564: "SDK_C_EXTENSIONUNIT",
    -2147481571: "SDK_C_FACT",
    -2147481572: "SDK_C_FACTINFO",
    -2147481136: "SDK_C_FD_BETWEENSENTENCE",
    -2147481199: "SDK_C_FD_BOTTOM",
    -2147481195: "SDK_C_FD_EXCLUDE",
    -2147481120: "SDK_C_FD_LIKESENTENCE",
    -2147481152: "SDK_C_FD_PERCENTOFSENTENCE",
    -2147481151: "SDK_C_FD_PERCENTOFSENTENCE1",
    -2147481150: "SDK_C_FD_PERCENTOFSENTENCE2",
    -2147481149: "SDK_C_FD_PERCENTOFSENTENCE3",
    -2147481197: "SDK_C_FD_PERCENT_OF",
    -2147481167: "SDK_C_FD_RANKOFSENTENCE1",
    -2147481166: "SDK_C_FD_RANKOFSENTENCE2",
    -2147481165: "SDK_C_FD_RANKOFSENTENCE3",
    -2147481168: "SDK_C_FD_RANKOFSENTENCEFIRST",
    -2147481198: "SDK_C_FD_RANK_OF",
    -2147481196: "SDK_C_FD_RELATE_BY",
    -2147481184: "SDK_C_FD_RELATIONSENTENCE",
    -2147481200: "SDK_C_FD_TOP",
    -2147481503: "SDK_C_FEBRUARY",
    -2147481488: "SDK_C_FIFTH",
    -2147481539: "SDK_C_FILTER",
    -2147481095: "SDK_C_FILTERS",
    -2147481492: "SDK_C_FIRST",
    -2147481210: "SDK_C_FN_APPLY_AGGREGATION",
    -2147481213: "SDK_C_FN_APPLY_COMPARISON",
    -2147481211: "SDK_C_FN_APPLY_LOGIC",
    -2147481212: "SDK_C_FN_APPLY_RELATIVE",
    -2147481214: "SDK_C_FN_APPLY_SYMPLE",
    -2147481489: "SDK_C_FOURTH",
    -2147481482: "SDK_C_FRIDAY",
    -2147481106: "SDK_C_GRIDGRAPH",
    -2147481515: "SDK_C_HAS",
    -2147481009: "SDK_C_HOURS",
    -2147481102: "SDK_C_HTML",
    -2147481109: "SDK_C_IMAGE",
    -2147481514: "SDK_C_IS",
    -2147481504: "SDK_C_JANUARY",
    -2147481562: "SDK_C_JOINATTRIBUTE",
    -2147481498: "SDK_C_JULY",
    -2147481499: "SDK_C_JUNE",
    -2147481460: "SDK_C_LAST_OF_MONTH_WITH_OFF",
    -2147481602: "SDK_C_LAST_OF_THIS_MONTH",
    -2147481582: "SDK_C_LEVEL",
    -2147481108: "SDK_C_LINE",
    -2147481093: "SDK_C_LIST_OF_FILETERS",
    -2147481091: "SDK_C_LIST_OF_OBJECTS",
    -2147481096: "SDK_C_LIST_OF_REPORTS",
    -2147480977: "SDK_C_LOGIN",
    -2147481502: "SDK_C_MARCH",
    -2147481500: "SDK_C_MAY",
    -2147481591: "SDK_C_METHOD",
    -2147481513: "SDK_C_METRIC",
    -2147481479: "SDK_C_MINUS",
    -2147481601: "SDK_C_MINUS_N_DAYS",
    -2147481115: "SDK_C_MINUS_N_HOURS",
    -2147481113: "SDK_C_MINUS_N_MINUTES",
    -2147481117: "SDK_C_MINUS_N_MONTHS",
    -2147481008: "SDK_C_MINUTES",
    -2147481486: "SDK_C_MONDAY",
    -2147481456: "SDK_C_MONTHS",
    -2147481236: "SDK_C_MRP_BETWEEN",
    -2147481234: "SDK_C_MRP_EQUAL",
    -2147481238: "SDK_C_MRP_EXCL_HIGHEST",
    -2147481237: "SDK_C_MRP_EXCL_LOWEST",
    -2147481240: "SDK_C_MRP_HIGHEST",
    -2147481239: "SDK_C_MRP_LOWEST",
    -2147481235: "SDK_C_MRP_NOT_BETWEEN",
    -2147481233: "SDK_C_MRP_NOT_EQUAL",
    -2147481231: "SDK_C_MRP_PERCENT_TEMPLATE",
    -2147481232: "SDK_C_MRP_RANK_TEMPLATE",
    -2147481021: "SDK_C_NEW_SECURITY_ROLE",
    -2147481561: "SDK_C_NODE",
    -2147481588: "SDK_C_NODETYPE",
    -2147481494: "SDK_C_NOVEMBER",
    -2147481478: "SDK_C_NOW",
    -2147481119: "SDK_C_NO_DAY_OF_MONTH",
    -2147481111: "SDK_C_NTH_DAY_OF_MONTH_WITH_OFF",
    -2147481454: "SDK_C_NTH_DOW_OF_MONTH",
    -2147481164: "SDK_C_NTH_TO_LAST_DAY_OF_MONTH",
    -2147481112: "SDK_C_NTH_TO_LAST_OF_MONTH_WITH_OFF",
    -2147481453: "SDK_C_N_TO_LAST_DAY_OF_MONTH",
    -2147481459: "SDK_C_N_TO_LAST_OF_MONTH_WITH_OFF",
    -2147481598: "SDK_C_OBJECT",
    -2147481092: "SDK_C_OBJECTS",
    -2147481495: "SDK_C_OCTOBER",
    -2147481204: "SDK_C_OPERATOR_AND",
    -2147481205: "SDK_C_OPERATOR_OR",
    -2147481547: "SDK_C_OP_AND",
    -2147481016: "SDK_C_OP_BANDING",
    -2147481015: "SDK_C_OP_BANDINGC",
    -2147481013: "SDK_C_OP_BANDINGM",
    -2147481014: "SDK_C_OP_BANDINGP",
    -2147481224: "SDK_C_OP_BEGINS_WITH",
    -2147481560: "SDK_C_OP_BETWEEN",
    -2147481220: "SDK_C_OP_CONTAINS",
    -2147481222: "SDK_C_OP_ENDS_WITH",
    -2147481230: "SDK_C_OP_EQUAL",
    -2147481552: "SDK_C_OP_EXHIGHEST",
    -2147481551: "SDK_C_OP_EXLOWEST",
    -2147481228: "SDK_C_OP_GREATER",
    -2147481227: "SDK_C_OP_GREATER_EQUAL",
    -2147481555: "SDK_C_OP_HIGHEST",
    -2147481558: "SDK_C_OP_IN",
    -2147481510: "SDK_C_OP_INTERSECT",
    -2147481509: "SDK_C_OP_INTERSECTIN",
    -2147481218: "SDK_C_OP_IN_LIST",
    -2147481215: "SDK_C_OP_IS_NOT_NULL",
    -2147481216: "SDK_C_OP_IS_NULL",
    -2147481226: "SDK_C_OP_LESS",
    -2147481225: "SDK_C_OP_LESS_EQUAL",
    -2147481557: "SDK_C_OP_LIKE",
    -2147481554: "SDK_C_OP_LOWEST",
    -2147481545: "SDK_C_OP_NOT",
    -2147481556: "SDK_C_OP_NOTLIKE",
    -2147481223: "SDK_C_OP_NOT_BEGINS_WITH",
    -2147481559: "SDK_C_OP_NOT_BETWEEN",
    -2147481219: "SDK_C_OP_NOT_CONTAINS",
    -2147481221: "SDK_C_OP_NOT_ENDS_WITH",
    -2147481229: "SDK_C_OP_NOT_EQUAL",
    -2147481511: "SDK_C_OP_NOT_IN",
    -2147481217: "SDK_C_OP_NOT_IN_LIST",
    -2147481546: "SDK_C_OP_OR",
    -2147481553: "SDK_C_OP_RANK_BETWEEN",
    -2147480989: "SDK_C_OP_RANK_BETWEEN_DSC",
    -2147481549: "SDK_C_OP_RANK_EQUAL",
    -2147480987: "SDK_C_OP_RANK_EQUAL_DSC",
    -2147480985: "SDK_C_OP_RANK_GREATER_ASC",
    -2147480984: "SDK_C_OP_RANK_GREATER_DSC",
    -2147480981: "SDK_C_OP_RANK_IN_ASC",
    -2147480980: "SDK_C_OP_RANK_IN_DSC",
    -2147480983: "SDK_C_OP_RANK_LESS_ASC",
    -2147480982: "SDK_C_OP_RANK_LESS_DSC",
    -2147481550: "SDK_C_OP_RANK_NOTBETWEEN",
    -2147480988: "SDK_C_OP_RANK_NOTBETWEEN_DSC",
    -2147481548: "SDK_C_OP_RANK_NOTEQUAL",
    -2147480986: "SDK_C_OP_RANK_NOTEQUAL_DSC",
    -2147480979: "SDK_C_OP_RANK_NOTIN_ASC",
    -2147480978: "SDK_C_OP_RANK_NOTIN_DSC",
    -2147480974: "SDK_C_ORIGINAL_VIEW",
    -2147481529: "SDK_C_OWNEROBJECT",
    -2147481104: "SDK_C_PANEL",
    -2147481105: "SDK_C_PANEL_STACK",
    -2147481528: "SDK_C_PARENTFOLDER",
    -2147480976: "SDK_C_PASSWORD",
    -2147481581: "SDK_C_PAXML",
    -2147481480: "SDK_C_PLUS",
    -2147481449: "SDK_C_PLUS_N_DAYS",
    -2147481116: "SDK_C_PLUS_N_HOURS",
    -2147481114: "SDK_C_PLUS_N_MINUTES",
    -2147481118: "SDK_C_PLUS_N_MONTHS",
    -2147481575: "SDK_C_PREVIOUS",
    -2147480999: "SDK_C_PRIV_CAT_ADMINISTRATION",
    -2147481000: "SDK_C_PRIV_CAT_ARCHITECT",
    -2147481003: "SDK_C_PRIV_CAT_COMMONPRIVILEGES",
    -2147480972: "SDK_C_PRIV_CAT_DESKTOP",
    -2147481001: "SDK_C_PRIV_CAT_DESKTOPANALYST",
    -2147481002: "SDK_C_PRIV_CAT_DESKTOPDESIGNER",
    -2147480995: "SDK_C_PRIV_CAT_DISTRIBUTIONSERVICES",
    -2147480994: "SDK_C_PRIV_CAT_MOBILE",
    -2147480997: "SDK_C_PRIV_CAT_MSTR_COMMANDMANAGER",
    -2147480992: "SDK_C_PRIV_CAT_MSTR_INTEGRITYMANAGER",
    -2147480996: "SDK_C_PRIV_CAT_MSTR_OBJECTMANAGER",
    -2147480991: "SDK_C_PRIV_CAT_MULTISOURCEOPTION",
    -2147480998: "SDK_C_PRIV_CAT_OFFICE",
    -2147480973: "SDK_C_PRIV_CAT_OPERATIONSMANAGER",
    -2147481005: "SDK_C_PRIV_CAT_WEBANALYST",
    -2147480993: "SDK_C_PRIV_CAT_WEBMMTOPTION",
    -2147481004: "SDK_C_PRIV_CAT_WEBPROFESSIONAL",
    -2147481006: "SDK_C_PRIV_CAT_WEBREPORTER",
    -2147481580: "SDK_C_PROMPT",
    -2147481593: "SDK_C_PROMPTOBJECT",
    -2147481594: "SDK_C_PROMPTQXML",
    -2147481098: "SDK_C_QUALIFICATION_ON",
    -2147481099: "SDK_C_QUALIFY_ON",
    -2147481090: "SDK_C_QUALIFY_ON_ATTR_OF_HIER",
    -2147481107: "SDK_C_RECTANGLE",
    -2147481519: "SDK_C_RELATEBY",
    -2147481518: "SDK_C_RELATEBYFACT",
    -2147481517: "SDK_C_RELATEBYTABLE",
    -2147481566: "SDK_C_RELATIONSHIP",
    -2147481506: "SDK_C_REPORT",
    -2147481524: "SDK_C_REPORTDEF",
    -2147481592: "SDK_C_REPORTS",
    -2147481022: "SDK_C_REPORTS1",
    -2147481596: "SDK_C_REPORTXML",
    -2147481505: "SDK_C_REPORT_SERVICES",
    -2147481534: "SDK_C_ROLE",
    -2147481573: "SDK_C_ROOTNODE",
    -2147481508: "SDK_C_RW_DEFAULT_FONT_NAME",
    -2147481507: "SDK_C_RW_DEFAULT_FONT_SIZE",
    -2147481481: "SDK_C_SATURDAY",
    -2147481538: "SDK_C_SCHEDULES",
    -2147481537: "SDK_C_SCHEDULEXML",
    -2147481540: "SDK_C_SEARCH",
    -2147481023: "SDK_C_SEARCH_FOR_ALL_FILTERS",
    -2147481024: "SDK_C_SEARCH_FOR_ALL_REPORTS",
    -2147481491: "SDK_C_SECOND",
    -2147481103: "SDK_C_SELECTOR",
    -2147481244: "SDK_C_SELECTOR_FONT_NAME",
    -2147481242: "SDK_C_SELECTOR_FONT_SIZE",
    -2147481496: "SDK_C_SEPTEMBER",
    -2147481523: "SDK_C_SESSIONID",
    -2147481522: "SDK_C_SETOF",
    -2147481587: "SDK_C_SHORTCUT",
    -2147481007: "SDK_C_SHORTCUT_TO",
    -2147481532: "SDK_C_SOURCE_OBJECT",
    -2147481589: "SDK_C_SPECOBJINREP",
    -2147481020: "SDK_C_SUBSCRIPTION_FILE_DISPLAY_NAME1",
    -2147481019: "SDK_C_SUBSCRIPTION_FILE_DISPLAY_NAME2",
    -2147481018: "SDK_C_SUBSCRIPTION_PRINTER_DISPLAY_NAME1",
    -2147481017: "SDK_C_SUBSCRIPTION_PRINTER_DISPLAY_NAME2",
    -2147481487: "SDK_C_SUNDAY",
    -2147481516: "SDK_C_SYSTEM_DEFAULT",
    -2147481574: "SDK_C_TABLE",
    -2147481525: "SDK_C_TEMPLATE",
    -2147481526: "SDK_C_TEMPLATEXML",
    -2147481110: "SDK_C_TEXT",
    -2147481490: "SDK_C_THIRD",
    -2147481477: "SDK_C_THIS_FRIDAY",
    -2147481476: "SDK_C_THIS_MONDAY",
    -2147481469: "SDK_C_THIS_MONTH",
    -2147481471: "SDK_C_THIS_SATURDAY",
    -2147481475: "SDK_C_THIS_SUNDAY",
    -2147481472: "SDK_C_THIS_THURSDAY",
    -2147481474: "SDK_C_THIS_TUESDAY",
    -2147481473: "SDK_C_THIS_WEDNESDAY",
    -2147481470: "SDK_C_THIS_WEEK",
    -2147481468: "SDK_C_THIS_YEAR",
    -2147481483: "SDK_C_THURSDAY",
    -2147481463: "SDK_C_TIME_OF_YEAR",
    -2147481464: "SDK_C_TIME_OF_YEAR_WITH_DOW",
    -2147481466: "SDK_C_TIME_OF_YEAR_WITH_OFFSET",
    -2147481465: "SDK_C_TIME_WITH_OFFSET",
    -2147481245: "SDK_C_TITLE_FONT_NAME",
    -2147481243: "SDK_C_TITLE_FONT_SIZE",
    -2147481467: "SDK_C_TODAY",
    -2147481485: "SDK_C_TUESDAY",
    -2147481533: "SDK_C_TUTYPE",
    -2147481527: "SDK_C_TYPE",
    -2147481599: "SDK_C_UNITTYPE",
    -2147481590: "SDK_C_VSXML",
    -2147481484: "SDK_C_WEDNESDAY",
    -2147481457: "SDK_C_WEEKS",
    -2147481521: "SDK_C_WHERE",
    -2147481577: "SDK_C_WPXML",
    -2147481578: "SDK_C_WSXML",
    -2147481455: "SDK_C_YEARS",
    -2147205006: "SDK_E_ADDRESS_NOT_UNC",
    -2147205091: "SDK_E_ANSWER_UNSPECIFIED",
    -2147205112: "SDK_E_ATTRIBUTE_UNINIT",
    -2147205057: "SDK_E_ATTR_NOT_IN_SYS_DIM",
    -2147205098: "SDK_E_AXIS_INCORRECT",
    -2147205092: "SDK_E_AXIS_NOTFOUND",
    -2147205110: "SDK_E_BEFORE_DISPID_NOTFOUND",
    -2147205028: "SDK_E_BRIDGE_ERROR",
    -2147205011: "SDK_E_BULK_EXPORT_NOT_CONFIGURED_IN_NCS",
    -2147205039: "SDK_E_CACHE_SCHEDULE_ELEM_PURGE_VIOLATION",
    -2147205038: "SDK_E_CACHE_SCHEDULE_INVALID_CACHE_OPTION",
    -2147204986: "SDK_E_CANNOT_DELETE_MULTIPLE_RECIPIENT_SUBSCRIPTION",
    -2147204987: "SDK_E_CANNOT_EDIT_MULTIPLE_RECIPIENT_SUBSCRIPTION",
    -2147204983: "SDK_E_CANNOT_FIND_SUBSCRIPTION_MAY_BE_DELETED",
    -2147205014: "SDK_E_CANNOT_REMOVE_ID_FORM",
    -2147205015: "SDK_E_CANNOT_REMOVE_LAST_VIEW_FORM",
    -2147204996: "SDK_E_CANNOT_REMOVE_USED_IN_FILTER",
    -2147205012: "SDK_E_CANNOT_RESOLVE_NAME",
    -2147205049: "SDK_E_CHILDREN_NO_SAME_PARENT",
    -2147205104: "SDK_E_CHILD_INDEX_INVALID",
    -2147205106: "SDK_E_CHILD_NULL",
    -2147204968: "SDK_E_CLOUD_ACCOUNT_STATUS_INVALID",
    -2147204969: "SDK_E_CLOUD_PASSWORD_INCORRECT",
    -2147204965: "SDK_E_CLOUD_UNKNOWN_ERROR",
    -2147204966: "SDK_E_CLOUD_USER_HAS_NOT_ACCEPTED_TERMS",
    -2147204970: "SDK_E_CLOUD_USER_NOT_FOUND",
    -2147204967: "SDK_E_CLOUD_WRONG_SHARD",
    -2147204991: "SDK_E_COOKIE_MISMATCH",
    -2147205120: "SDK_E_DISPID_NOTFOUND",
    -2147205109: "SDK_E_DISP_NEGATIVE",
    -2147205026: "SDK_E_DOCUMENT_EXECUTION_FAILURE",
    -2147205085: "SDK_E_DOM_SERIALIZATION",
    -2147205119: "SDK_E_DSSID_REQUIRED",
    -2147205025: "SDK_E_DUPLICATE_DATA_SET",
    -2147205111: "SDK_E_ELEMENTID_INVALID",
    -2147205010: "SDK_E_ELEMENT_FETCH_FAILURE",
    -2147205021: "SDK_E_EMPTY_ANSWER",
    -2147205043: "SDK_E_EMPTY_ATTR_FORMS_DRILLING",
    -2147205020: "SDK_E_EMPTY_LIST",
    -2147204975: "SDK_E_EMPTY_NUM_STR",
    -2147205042: "SDK_E_EMPTY_OBJECTID_RETURNED_SAVEAS",
    -2147205059: "SDK_E_EMPTY_RESULT_XML",
    -2147205068: "SDK_E_ERROR_POPULATING_OBJ",
    -2147205031: "SDK_E_ERROR_REMOVING_OLDEST_MESSAGE",
    -2147205008: "SDK_E_ERROR_STATUS",
    -2147205017: "SDK_E_EXPRESSION_GENERIC",
    -2147205108: "SDK_E_EXPRESSION_NULL",
    -2147204977: "SDK_E_FILE_NAME_INVALID",
    -2147205036: "SDK_E_FILE_READ_ERROR",
    -2147205035: "SDK_E_FILE_SIZE_TOO_LARGE",
    -2147205005: "SDK_E_FILTER_CIRCULAR_REFERENCE",
    -2147205067: "SDK_E_FORMAT_PROP_NOT_LOADED",
    -2147205093: "SDK_E_FORMAT_UNEXPECTED",
    -2147205016: "SDK_E_ILLEGAL_ARGUMENT",
    -2147205023: "SDK_E_INCORRECT_BETWEEN_SYNTAX",
    -2147205033: "SDK_E_INCORRECT_DERIVED_METRIC_FORMULA",
    -2147205022: "SDK_E_INCORRECT_NOT_BETWEEN_SYNTAX",
    -2147205094: "SDK_E_INDEX_NOTFOUND",
    -2147205086: "SDK_E_INDEX_ONEBASED",
    -2147205107: "SDK_E_INPUT_INVALID",
    -2147205041: "SDK_E_INPUT_IS_ROOT",
    -2147205055: "SDK_E_INPUT_NULL",
    -2147205054: "SDK_E_INPUT_ROOT",
    -2147205045: "SDK_E_INPUT_ROOT_CHILD",
    -2147205069: "SDK_E_INVALID",
    -2147204992: "SDK_E_INVALID_ADDRESS_GENERIC",
    -2147205019: "SDK_E_INVALID_DATE_FORMAT",
    -2147204995: "SDK_E_INVALID_EMAIL_ADDRESS",
    -2147204999: "SDK_E_INVALID_EXP_DATE",
    -2147204994: "SDK_E_INVALID_FILE_PATH",
    -2147204960: "SDK_E_INVALID_FTP_PATH",
    -2147205018: "SDK_E_INVALID_NUMBER_FORMAT",
    -2147205013: "SDK_E_INVALID_NUMBER_OR_DATE_FORMAT",
    -2147205009: "SDK_E_INVALID_OBJECT_NAME",
    -2147204993: "SDK_E_INVALID_PRINTER_NAME",
    -2147205007: "SDK_E_INVALID_STYLEID",
    -2147205089: "SDK_E_ITEM_ADD",
    -2147205088: "SDK_E_ITEM_GET",
    -2147205061: "SDK_E_JAVA_EXCEPTION",
    -2147205062: "SDK_E_JNI_ERROR",
    -2147205058: "SDK_E_LOCKED_ATTRIBUTE",
    -2147205077: "SDK_E_MISSING_DEST_FOLDER",
    -2147205078: "SDK_E_MISSING_DEST_OBJECT",
    -2147205079: "SDK_E_MISSING_SOURCE_OBJECT",
    -2147205044: "SDK_E_MISSING_TEMPLATE_UNIT_DRILLING",
    -2147204981: "SDK_E_MOBILE_CONFIGURATION_NAME_ALREADY_EXISTS",
    -2147204982: "SDK_E_MOBILE_CONFIGURATION_NOT_FOUND",
    -2147204980: "SDK_E_MOBILE_LOGIN_DISABLED",
    -2147205000: "SDK_E_MOBILE_RESULTS_TOO_LARGE",
    -2147205001: "SDK_E_MOBILE_SCHEDULE_NOT_FOUND",
    -2147204990: "SDK_E_MOBILE_SUBSCRIPTION_EXECUTING",
    -2147205003: "SDK_E_MONITOR_MANIPULATION_FAILURE",
    -2147205087: "SDK_E_NONTIDENTITY",
    -2147205046: "SDK_E_NOT_NODE_HAS_MORE_CHILDREN",
    -2147204979: "SDK_E_NO_CRED",
    -2147205083: "SDK_E_NO_DEST_PROJ",
    -2147204988: "SDK_E_NO_DEVICE_FOUND",
    -2147205052: "SDK_E_NO_NEXT_SIB",
    -2147205051: "SDK_E_NO_PRE_SIB",
    -2147204984: "SDK_E_NO_REQUIRED_PRIVILEGE_DELETE_SUBSCRIPTION",
    -2147204985: "SDK_E_NO_REQUIRED_PRIVILEGE_EDIT_SUBSCRIPTION",
    -2147205082: "SDK_E_NO_SOURCE_PROJ",
    -2147204978: "SDK_E_NO_TRUST_TOKEN",
    -2147204964: "SDK_E_NO_VALID_CONTENT",
    -2147204962: "SDK_E_NO_VALID_RECIPIENT",
    -2147204963: "SDK_E_NO_VALID_SCHEDULE",
    -2147205076: "SDK_E_OBJECT_READONLY",
    -2147205071: "SDK_E_OBJECT_XML_MISMATCH",
    -2147205090: "SDK_E_OBJMEMBER_UNSPECIFIED",
    -2147205072: "SDK_E_OBJ_NOTFOUND_XML",
    -2147205084: "SDK_E_OBJ_NULL",
    -2147205105: "SDK_E_PARENT_INVALID",
    -2147205050: "SDK_E_PARENT_NOT_BRANCH_QUA",
    -2147204974: "SDK_E_PARSE_DATE_FAILED",
    -2147204972: "SDK_E_PARSE_INT_FAILED",
    -2147204973: "SDK_E_PARSE_NUM_FAILED",
    -2147204971: "SDK_E_PARSE_TIME_FAILED",
    -2147205037: "SDK_E_PDF_SUPPORT_LIB_NOT_LOADED",
    -2147205064: "SDK_E_POPULATE_NON_INDEP_PROP",
    -2147205002: "SDK_E_PRIVILEGE_MISSING",
    -2147205102: "SDK_E_PROMPTTYPE_INCORRECT",
    -2147205027: "SDK_E_PROMPT_DATE_TIME",
    -2147205030: "SDK_E_PROMPT_EMPTY_VALUES",
    -2147205029: "SDK_E_PROMPT_NEED_TWO_VALUES",
    -2147205034: "SDK_E_PROMPT_NUMERICAL_VALUES",
    -2147205101: "SDK_E_PROMPT_REQUIRED",
    -2147205100: "SDK_E_PROMPT_TOOFEW",
    -2147205099: "SDK_E_PROMPT_TOOMANY",
    -2147205073: "SDK_E_RANK_CHILD_NOTFOUND",
    -2147205032: "SDK_E_REMOVING_REPORT_OBJECT_HAVING_DEPN",
    -2147205097: "SDK_E_RESULTDATA_UNINIT",
    -2147205074: "SDK_E_RETRIEVE_TYPE_INCORRECT",
    -2147205116: "SDK_E_RFD_NOTFOUND",
    -2147205048: "SDK_E_ROOT_IS_NOT",
    -2147204997: "SDK_E_SAME_FILTER",
    -2147205004: "SDK_E_SAP_VARIABLE_INCORRECT_ANSWER",
    -2147205063: "SDK_E_SAVE_PROP_NOT_IN_METADATA",
    -2147205095: "SDK_E_SEARCHID_INVALID",
    -2147204961: "SDK_E_SSL_HANDSHAKE_EXCEPTION",
    -2147205075: "SDK_E_STATEMENT_USAGE_WRONG",
    -2147205114: "SDK_E_STATUS_UNEXPECTED",
    -2147204989: "SDK_E_SUBTOTALFMT_NOTSUPPORTEDBY_METRICTEMPLATE",
    -2147205056: "SDK_E_SYS_DIM_NOTFOUND",
    -2147205047: "SDK_E_TIMEOUT_LOAD_USER_STYLE",
    -2147205053: "SDK_E_TWO_OR_LESS_CHILDREN",
    -2147205103: "SDK_E_TYPE_UNSUPPORTED",
    -2147205065: "SDK_E_UNABLE_SAVE_INDEP_PROP",
    -2147205066: "SDK_E_UNABLE_SAVE_INVALID_PROP",
    -2147204998: "SDK_E_UNANSWERED_PROMPT",
    -2147205040: "SDK_E_UNEXPECTED_STATUS",
    -2147205080: "SDK_E_UNINIT_DATA_SOURCE",
    -2147205081: "SDK_E_UNRELATED_SCHEMAS",
    -2147205024: "SDK_E_UNSUBSCRIBE_NOTHING",
    -2147205096: "SDK_E_USAGE_TYPEINCORRECT",
    -2147205060: "SDK_E_WIN32API_ERROR",
    -2147205113: "SDK_E_XMLATTR_NOTFOUND",
    -2147205115: "SDK_E_XMLNODE_NOTFOUND",
    -2147205118: "SDK_E_XMLROOT_NULL",
    -2147205070: "SDK_E_XML_ERROR",
    -2147205117: "SDK_E_XML_INVALID",
    -2147204976: "SDK_E_ZIP_FILE_NAME_INVALID",
    -2147443425: "SEC_C_ACCESS_RIGHT_DESC_ANNOTATE",
    -2147483118: "SEC_C_ACCESS_RIGHT_DESC_BROWSE",
    -2147483103: "SEC_C_ACCESS_RIGHT_DESC_CONTROL",
    -2147483106: "SEC_C_ACCESS_RIGHT_DESC_DELETE",
    -2147482750: "SEC_C_ACCESS_RIGHT_DESC_EXECUTE",
    -2147483112: "SEC_C_ACCESS_RIGHT_DESC_READ",
    -2147482753: "SEC_C_ACCESS_RIGHT_DESC_USE",
    -2147483115: "SEC_C_ACCESS_RIGHT_DESC_USE_EXECUTE",
    -2147483109: "SEC_C_ACCESS_RIGHT_DESC_WRITE",
    -2147483101: "SEC_C_ACCESS_RIGHT_FULL_ACCESS",
    -2147482723: "SEC_C_ACCESS_RIGHT_LAST_INDEX",
    -2147443427: "SEC_C_ACCESS_RIGHT_LONG_NAME_ANNOTATE",
    -2147483120: "SEC_C_ACCESS_RIGHT_LONG_NAME_BROWSE",
    -2147483105: "SEC_C_ACCESS_RIGHT_LONG_NAME_CONTROL",
    -2147483108: "SEC_C_ACCESS_RIGHT_LONG_NAME_DELETE",
    -2147482752: "SEC_C_ACCESS_RIGHT_LONG_NAME_EXECUTE",
    -2147483114: "SEC_C_ACCESS_RIGHT_LONG_NAME_READ",
    -2147482755: "SEC_C_ACCESS_RIGHT_LONG_NAME_USE",
    -2147483117: "SEC_C_ACCESS_RIGHT_LONG_NAME_USE_EXECUTE",
    -2147483111: "SEC_C_ACCESS_RIGHT_LONG_NAME_WRITE",
    -2147482756: "SEC_C_ACCESS_RIGHT_NEW_STARTING_INDEX",
    -2147483102: "SEC_C_ACCESS_RIGHT_NO_ACCESS",
    -2147443426: "SEC_C_ACCESS_RIGHT_SHORT_NAME_ANNOTATE",
    -2147483119: "SEC_C_ACCESS_RIGHT_SHORT_NAME_BROWSE",
    -2147483104: "SEC_C_ACCESS_RIGHT_SHORT_NAME_CONTROL",
    -2147483107: "SEC_C_ACCESS_RIGHT_SHORT_NAME_DELETE",
    -2147482751: "SEC_C_ACCESS_RIGHT_SHORT_NAME_EXECUTE",
    -2147483113: "SEC_C_ACCESS_RIGHT_SHORT_NAME_READ",
    -2147482754: "SEC_C_ACCESS_RIGHT_SHORT_NAME_USE",
    -2147483116: "SEC_C_ACCESS_RIGHT_SHORT_NAME_USE_EXECUTE",
    -2147483110: "SEC_C_ACCESS_RIGHT_SHORT_NAME_WRITE",
    -2147483121: "SEC_C_ACCESS_RIGHT_STARTING_INDEX",
    -2147443428: "SEC_C_ACCESS_RIGHT_THIRD_STARTING_INDEX",
    -2147483049: "SEC_C_ANONYMOUS_USER_NAME",
    -2147479930: "SEC_C_PRIV_DESC_ACCESSDATAFROMCLOUDAPP",
    -2147480046: "SEC_C_PRIV_DESC_ADDNOTES",
    -2147479926: "SEC_C_PRIV_DESC_ADMINISTEROPERATIONMANAGER",
    -2147482862: "SEC_C_PRIV_DESC_ALIASOBJECTS",
    -2147480136: "SEC_C_PRIV_DESC_ASSIGNSECURITYROLES",
    -2147483016: "SEC_C_PRIV_DESC_BYPASSACCESSCHECKS",
    -2147483141: "SEC_C_PRIV_DESC_BYPASSACCESSCHECKS1",
    -2147481656: "SEC_C_PRIV_DESC_CACHEADMINISTRATION",
    -2147479914: "SEC_C_PRIV_DESC_CANCERTIFY",
    -2147482880: "SEC_C_PRIV_DESC_CHANGEUSERPREFERENCE",
    -2147480120: "SEC_C_PRIV_DESC_CLUSTERADMINISTRATION",
    -2147480134: "SEC_C_PRIV_DESC_CONFIGCONTACTDATAPROFILE",
    -2147480094: "SEC_C_PRIV_DESC_CONFIGURECACHES",
    -2147480090: "SEC_C_PRIV_DESC_CONFIGURECONNECTIONMAP",
    -2147480096: "SEC_C_PRIV_DESC_CONFIGUREGOVERNING",
    -2147480126: "SEC_C_PRIV_DESC_CONFIGUREGROUPMEMBERSHIP",
    -2147480098: "SEC_C_PRIV_DESC_CONFIGUREINBOX",
    -2147480080: "SEC_C_PRIV_DESC_CONFIGURELANGUAGESETTINGS",
    -2147480092: "SEC_C_PRIV_DESC_CONFIGUREPROJECTBASIC",
    -2147480088: "SEC_C_PRIV_DESC_CONFIGUREPROJECTDATASOURCE",
    -2147480100: "SEC_C_PRIV_DESC_CONFIGURESECURITY",
    -2147480104: "SEC_C_PRIV_DESC_CONFIGURESERVERBASIC",
    -2147480102: "SEC_C_PRIV_DESC_CONFIGURESTATISTICS",
    -2147482882: "SEC_C_PRIV_DESC_CONFIGURETOOLBARS",
    -2147480082: "SEC_C_PRIV_DESC_CONFIIGUREAUDITING",
    -2147480084: "SEC_C_PRIV_DESC_CONFIIGURESUBSCRIPTIONSETTINGS",
    -2147483046: "SEC_C_PRIV_DESC_CREATEAPPOBJ",
    -2147483171: "SEC_C_PRIV_DESC_CREATEAPPOBJ1",
    -2147483044: "SEC_C_PRIV_DESC_CREATECONFIGOBJ",
    -2147483169: "SEC_C_PRIV_DESC_CREATECONFIGOBJ1",
    -2147482982: "SEC_C_PRIV_DESC_CREATEDATAMART",
    -2147479910: "SEC_C_PRIV_DESC_CREATEDATASETINWORKSTATION",
    -2147482912: "SEC_C_PRIV_DESC_CREATEDERIVEDMETRICS",
    -2147480032: "SEC_C_PRIV_DESC_CREATEHTMLCONTAINER",
    -2147482868: "SEC_C_PRIV_DESC_CREATENEWFOLDER",
    -2147483042: "SEC_C_PRIV_DESC_CREATESCHEMAOBJ",
    -2147483167: "SEC_C_PRIV_DESC_CREATESCHEMAOBJ1",
    -2147481672: "SEC_C_PRIV_DESC_CREATESHORTCUT",
    -2147480146: "SEC_C_PRIV_DESC_CUBEADMINISTRATION",
    -2147480010: "SEC_C_PRIV_DESC_DASHBOARDDESIGN",
    -2147480068: "SEC_C_PRIV_DESC_DATABASECONNECTIONADMIN",
    -2147481692: "SEC_C_PRIV_DESC_DEFINECUSTOMSQLREPORT",
    -2147480012: "SEC_C_PRIV_DESC_DEFINEDERIVEDELEMENTS",
    -2147481690: "SEC_C_PRIV_DESC_DEFINEOLAPCUBEREPORT",
    -2147480122: "SEC_C_PRIV_DESC_DEFINESECURITYFILTER",
    -2147479984: "SEC_C_PRIV_DESC_DEFINETRANSACTIONREPORT",
    -2147480114: "SEC_C_PRIV_DESC_DEFINEVIEWREPORT",
    -2147481666: "SEC_C_PRIV_DESC_DEFQUERYBUILDERREPORT",
    -2147480002: "SEC_C_PRIV_DESC_DRILLANDLINK",
    -2147481668: "SEC_C_PRIV_DESC_DRILLWITHINTELLIGENTCUBE",
    -2147480066: "SEC_C_PRIV_DESC_DUPLICATEPROJECT",
    -2147480044: "SEC_C_PRIV_DESC_EDITNOTES",
    -2147480006: "SEC_C_PRIV_DESC_EDITREPORTLINKS",
    -2147479962: "SEC_C_PRIV_DESC_EMAILSCREENFROMDEVICE",
    -2147480038: "SEC_C_PRIV_DESC_ENABLEADMINISTRATIONFROMWEB",
    -2147480086: "SEC_C_PRIV_DESC_ENABLEUSER",
    -2147480110: "SEC_C_PRIV_DESC_EXECUTECUBEREPORT",
    -2147480028: "SEC_C_PRIV_DESC_EXECUTEMULTIPLESOURCEREPORT",
    -2147481714: "SEC_C_PRIV_DESC_EXECUTERWDOCUMENT",
    -2147479980: "SEC_C_PRIV_DESC_EXECUTETRANSACTION",
    -2147480054: "SEC_C_PRIV_DESC_EXPORTTOEXCEL",
    -2147480050: "SEC_C_PRIV_DESC_EXPORTTOFLASH",
    -2147480056: "SEC_C_PRIV_DESC_EXPORTTOHTML",
    -2147479924: "SEC_C_PRIV_DESC_EXPORTTOMSTRFILE",
    -2147480058: "SEC_C_PRIV_DESC_EXPORTTOPDF",
    -2147480052: "SEC_C_PRIV_DESC_EXPORTTOTEXT",
    -2147480144: "SEC_C_PRIV_DESC_FIREEVENT",
    -2147482874: "SEC_C_PRIV_DESC_FORMATGRAPH",
    -2147480128: "SEC_C_PRIV_DESC_GRANT_PRIVILEGE",
    -2147480116: "SEC_C_PRIV_DESC_IDLEPROJECT",
    -2147479922: "SEC_C_PRIV_DESC_IMPORTMSTRFILE",
    -2147481688: "SEC_C_PRIV_DESC_IMPORTOLAPCUBE",
    -2147480030: "SEC_C_PRIV_DESC_IMPORTTABLEFROMMULTIPLESOURCES",
    -2147481652: "SEC_C_PRIV_DESC_INBOXADMINISTRATION",
    -2147480072: "SEC_C_PRIV_DESC_JOBADMINISTRATION",
    -2147480130: "SEC_C_PRIV_DESC_LINKTOEXTERNALACCOUNTS",
    -2147480118: "SEC_C_PRIV_DESC_LOADPROJECT",
    -2147479942: "SEC_C_PRIV_DESC_MOBILECREATEANALYSIS",
    -2147479944: "SEC_C_PRIV_DESC_MOBILECREATEDOCUMENT",
    -2147479936: "SEC_C_PRIV_DESC_MOBILEEDITANALYSIS",
    -2147479938: "SEC_C_PRIV_DESC_MOBILEPUBLISH",
    -2147479946: "SEC_C_PRIV_DESC_MOBILESAVEANALYSIS",
    -2147479948: "SEC_C_PRIV_DESC_MOBILESAVEDOCUMENT",
    -2147479940: "SEC_C_PRIV_DESC_MOBILESAVEREPORT",
    -2147479950: "SEC_C_PRIV_DESC_MOBILEVIEWANALYSIS",
    -2147481660: "SEC_C_PRIV_DESC_MOBILEVIEWDOCUMENT",
    -2147482908: "SEC_C_PRIV_DESC_MODIFYREPORTOBJECTLIST",
    -2147482926: "SEC_C_PRIV_DESC_MODIFYSCHEMAOBJECT",
    -2147482872: "SEC_C_PRIV_DESC_MODIFYSORTING",
    -2147482910: "SEC_C_PRIV_DESC_MODIFYSUBTOTALS",
    -2147480078: "SEC_C_PRIV_DESC_MONITORCHANGEJOURNAL",
    -2147479928: "SEC_C_PRIV_DESC_MONITOROPERATIONMANAGER",
    -2147482866: "SEC_C_PRIV_DESC_PIVOTREPORT",
    -2147479964: "SEC_C_PRIV_DESC_PRINTFROMDEVICE",
    -2147479912: "SEC_C_PRIV_DESC_PUBLISHDOSSIER",
    -2147481744: "SEC_C_PRIV_DESC_REEXECUTEREPORTAGAINSTWH",
    -2147482984: "SEC_C_PRIV_DESC_RESERVED2",
    -2147480132: "SEC_C_PRIV_DESC_RESETUSERPASSWORD",
    -2147482916: "SEC_C_PRIV_DESC_SAVECUSTOMAUTOSTYLE",
    -2147480008: "SEC_C_PRIV_DESC_SAVEDERIVEDELEMENTS",
    -2147480026: "SEC_C_PRIV_DESC_SAVEPERSONALPROMPTANWSER",
    -2147482952: "SEC_C_PRIV_DESC_SCHEDULEADMINISTRATION",
    -2147482757: "SEC_C_PRIV_DESC_SCHEDULEADMINISTRATION_UNUSED",
    -2147483040: "SEC_C_PRIV_DESC_SCHEDULEREQUEST",
    -2147483165: "SEC_C_PRIV_DESC_SCHEDULEREQUEST1",
    -2147480060: "SEC_C_PRIV_DESC_SENDLINKINEMAIL",
    -2147481740: "SEC_C_PRIV_DESC_SENDTOEMAIL",
    -2147481694: "SEC_C_PRIV_DESC_SERVERMONITORING",
    -2147482886: "SEC_C_PRIV_DESC_SETATTRIBUTEDISPLAY",
    -2147479920: "SEC_C_PRIV_DESC_SETOAUTHPARAMETERSFORCLOUD",
    -2147480064: "SEC_C_PRIV_DESC_SUBSCRIBEOTHERS",
    -2147480062: "SEC_C_PRIV_DESC_SUBSCRIBETOEMAILALERT",
    -2147483038: "SEC_C_PRIV_DESC_USEARCHITECT",
    -2147483163: "SEC_C_PRIV_DESC_USEARCHITECT1",
    -2147480074: "SEC_C_PRIV_DESC_USEBULKEXPORTEDITOR",
    -2147480076: "SEC_C_PRIV_DESC_USEBULKTRANSLATIONTOOL",
    -2147482938: "SEC_C_PRIV_DESC_USECACHEMONITOR",
    -2147482936: "SEC_C_PRIV_DESC_USECLUSTERMONITOR",
    -2147479908: "SEC_C_PRIV_DESC_USECOLLABORATIONSERVICES",
    -2147481718: "SEC_C_PRIV_DESC_USECOMMANDMANAGER",
    -2147483024: "SEC_C_PRIV_DESC_USECONSOLIDATIONEDITOR",
    -2147483149: "SEC_C_PRIV_DESC_USECONSOLIDATIONEDITOR1",
    -2147480140: "SEC_C_PRIV_DESC_USECONTACTMANAGER",
    -2147481650: "SEC_C_PRIV_DESC_USECUBEMONITOR",
    -2147480112: "SEC_C_PRIV_DESC_USECUBEREPORTEDITOR",
    -2147483022: "SEC_C_PRIV_DESC_USECUSTOMGROUPEDITOR",
    -2147483147: "SEC_C_PRIV_DESC_USECUSTOMGROUPEDITOR1",
    -2147482942: "SEC_C_PRIV_DESC_USEDATABASECONNECTIONMONITOR",
    -2147482934: "SEC_C_PRIV_DESC_USEDATABASEINSTANCEMANAGER",
    -2147480124: "SEC_C_PRIV_DESC_USEDATABASELOGINMANAGER",
    -2147482876: "SEC_C_PRIV_DESC_USEDATAEXPLORER",
    -2147482980: "SEC_C_PRIV_DESC_USEDATAMARTEDITOR",
    -2147482864: "SEC_C_PRIV_DESC_USEDESIGNMODE",
    -2147481674: "SEC_C_PRIV_DESC_USEDESKTOP",
    -2147480042: "SEC_C_PRIV_DESC_USEDISTRIBUTIONSERVICES",
    -2147483020: "SEC_C_PRIV_DESC_USEDOCUMENTEDITOR",
    -2147483145: "SEC_C_PRIV_DESC_USEDOCUMENTEDITOR1",
    -2147481742: "SEC_C_PRIV_DESC_USEDRILLMAPEDITOR",
    -2147479994: "SEC_C_PRIV_DESC_USEDYNAMICSOURCING",
    -2147483030: "SEC_C_PRIV_DESC_USEFILTEREDITOR",
    -2147483155: "SEC_C_PRIV_DESC_USEFILTEREDITOR1",
    -2147481720: "SEC_C_PRIV_DESC_USEFINDANDREPLACEDIALOG",
    -2147482918: "SEC_C_PRIV_DESC_USEFORMATTINGEDITOR",
    -2147481738: "SEC_C_PRIV_DESC_USEFUNCTIONPLUGINEDITOR",
    -2147482860: "SEC_C_PRIV_DESC_USEGRIDOPTIONS",
    -2147482884: "SEC_C_PRIV_DESC_USEHISTORYLIST",
    -2147480040: "SEC_C_PRIV_DESC_USEIMMEDIATEDELIVERY",
    -2147479956: "SEC_C_PRIV_DESC_USEIMMEDIATEPREVIEW",
    -2147481654: "SEC_C_PRIV_DESC_USEINBOXMONITOR",
    -2147481658: "SEC_C_PRIV_DESC_USEINTEGRITYMANAGER",
    -2147482946: "SEC_C_PRIV_DESC_USEJOBMONITOR",
    -2147483032: "SEC_C_PRIV_DESC_USEMETRICEDITOR",
    -2147483157: "SEC_C_PRIV_DESC_USEMETRICEDITOR1",
    -2147479918: "SEC_C_PRIV_DESC_USEMICROSTRATEGYDESKTOP",
    -2147481662: "SEC_C_PRIV_DESC_USEMSTRMOBILE",
    -2147482978: "SEC_C_PRIV_DESC_USEOBJECTMANAGER",
    -2147479974: "SEC_C_PRIV_DESC_USEOBJECTMANAGERIMPORTONLY",
    -2147479976: "SEC_C_PRIV_DESC_USEOBJECTMANAGERREADONLY",
    -2147481710: "SEC_C_PRIV_DESC_USEOFFICEINTELLIGENCE",
    -2147479996: "SEC_C_PRIV_DESC_USEOLAPSERVICES",
    -2147481726: "SEC_C_PRIV_DESC_USEPROJECTDOCUMENTATION",
    -2147482930: "SEC_C_PRIV_DESC_USEPROJECTMONITOR",
    -2147481728: "SEC_C_PRIV_DESC_USEPROJECTSTATUSEDITOR",
    -2147483018: "SEC_C_PRIV_DESC_USEPROMPTEDITOR",
    -2147483143: "SEC_C_PRIV_DESC_USEPROMPTEDITOR1",
    -2147479916: "SEC_C_PRIV_DESC_USEQUICKSEARCHINDICES",
    -2147480070: "SEC_C_PRIV_DESC_USERCONNECTIONADMIN",
    -2147482878: "SEC_C_PRIV_DESC_USEREPORTDATAOPTIONS",
    -2147483026: "SEC_C_PRIV_DESC_USEREPORTEDITOR",
    -2147483151: "SEC_C_PRIV_DESC_USEREPORTEDITOR1",
    -2147482914: "SEC_C_PRIV_DESC_USEREPORTFILTEREDITOR",
    -2147482922: "SEC_C_PRIV_DESC_USEREPORTOBJECTSWINDOW",
    -2147481716: "SEC_C_PRIV_DESC_USERWDOCUMENTEDITOR",
    -2147482932: "SEC_C_PRIV_DESC_USESCHEDULEMANAGER",
    -2147482940: "SEC_C_PRIV_DESC_USESCHEDULEMONITOR",
    -2147481746: "SEC_C_PRIV_DESC_USESEACHEDITOR",
    -2147481730: "SEC_C_PRIV_DESC_USESECURITYFILTERMANAGER",
    -2147480138: "SEC_C_PRIV_DESC_USESECURITYROLEMANAGER",
    -2147483034: "SEC_C_PRIV_DESC_USESERVERADMIN",
    -2147483159: "SEC_C_PRIV_DESC_USESERVERADMIN1",
    -2147482988: "SEC_C_PRIV_DESC_USESERVERCACHE",
    -2147479992: "SEC_C_PRIV_DESC_USESQLTABINEXPORTEDITORS",
    -2147481722: "SEC_C_PRIV_DESC_USESUBTOTALEDITOR",
    -2147483028: "SEC_C_PRIV_DESC_USETEMPLATEEDITOR",
    -2147483153: "SEC_C_PRIV_DESC_USETEMPLATEEDITOR1",
    -2147482920: "SEC_C_PRIV_DESC_USETHRESHOLDSEDITOR",
    -2147479972: "SEC_C_PRIV_DESC_USETRANSACTIONEDITORBYPASS",
    -2147480036: "SEC_C_PRIV_DESC_USETRANSLATIONEDITOR",
    -2147480142: "SEC_C_PRIV_DESC_USETRANSMITTERDEVICEMANAGER",
    -2147482944: "SEC_C_PRIV_DESC_USEUSERCONNECTIONMONITOR",
    -2147482948: "SEC_C_PRIV_DESC_USEUSERMANAGER",
    -2147482958: "SEC_C_PRIV_DESC_USEVLDBPROPEDITOR",
    -2147483161: "SEC_C_PRIV_DESC_USEWEBADMIN1",
    -2147482924: "SEC_C_PRIV_DESC_VIEWETLINFORMATION",
    -2147480048: "SEC_C_PRIV_DESC_VIEWNOTES",
    -2147482870: "SEC_C_PRIV_DESC_VIEWSQL",
    -2147482976: "SEC_C_PRIV_DESC_WEBADDHISTORYLIST",
    -2147483014: "SEC_C_PRIV_DESC_WEBADMINISTRATOR",
    -2147482894: "SEC_C_PRIV_DESC_WEBALIASOBJECTS",
    -2147483002: "SEC_C_PRIV_DESC_WEBCHANGEUSEROPTIONS",
    -2147482974: "SEC_C_PRIV_DESC_WEBCHANGEVIEWMODE",
    -2147482892: "SEC_C_PRIV_DESC_WEBCONFIGURETOOLBARS",
    -2147479982: "SEC_C_PRIV_DESC_WEBCONFIGURETRANSACTION",
    -2147479968: "SEC_C_PRIV_DESC_WEBCREATEANALYSIS",
    -2147482906: "SEC_C_PRIV_DESC_WEBCREATEDERIVEDMETRICS",
    -2147479960: "SEC_C_PRIV_DESC_WEBCREATEDYNAMICADDRESSLIST",
    -2147481708: "SEC_C_PRIV_DESC_WEBCREATEEMAILADDRESS",
    -2147481696: "SEC_C_PRIV_DESC_WEBCREATEFILELOCATION",
    -2147479932: "SEC_C_PRIV_DESC_WEBCREATEFTPLOCATION2",
    -2147479998: "SEC_C_PRIV_DESC_WEBCREATEHTMLCONTAINER",
    -2147483006: "SEC_C_PRIV_DESC_WEBCREATENEWREPORT",
    -2147481702: "SEC_C_PRIV_DESC_WEBCREATEPRINTLOCATION",
    -2147480020: "SEC_C_PRIV_DESC_WEBDASHBOARDDESIGN",
    -2147480000: "SEC_C_PRIV_DESC_WEBDEFINEADVANCEDREPORTOPTION",
    -2147480024: "SEC_C_PRIV_DESC_WEBDEFINEDERIVEDELEMENTS",
    -2147480108: "SEC_C_PRIV_DESC_WEBDEFINEVIEWREPORT",
    -2147481664: "SEC_C_PRIV_DESC_WEBDEFQUERYBUILDERREPORT",
    -2147482992: "SEC_C_PRIV_DESC_WEBDELETEOBJECT",
    -2147481686: "SEC_C_PRIV_DESC_WEBDOCUMENTDESIGN",
    -2147482998: "SEC_C_PRIV_DESC_WEBDRILLING",
    -2147482970: "SEC_C_PRIV_DESC_WEBDRILLMETRICS",
    -2147480004: "SEC_C_PRIV_DESC_WEBEDITNOTES",
    -2147480014: "SEC_C_PRIV_DESC_WEBEDITREPORTLINKS",
    -2147481670: "SEC_C_PRIV_DESC_WEBENABLEMMTACCESS",
    -2147479952: "SEC_C_PRIV_DESC_WEBEXECUTEANALYSIS",
    -2147481678: "SEC_C_PRIV_DESC_WEBEXECUTEBULKEXPORTREPORT",
    -2147480106: "SEC_C_PRIV_DESC_WEBEXECUTECUBEREPORT",
    -2147481724: "SEC_C_PRIV_DESC_WEBEXECUTEDATAMARTREPORT",
    -2147481712: "SEC_C_PRIV_DESC_WEBEXECUTERWDOCUMENT",
    -2147482996: "SEC_C_PRIV_DESC_WEBEXPORT",
    -2147481700: "SEC_C_PRIV_DESC_WEBEXPORTTOFILENOW",
    -2147482954: "SEC_C_PRIV_DESC_WEBFILTERONSELECTIONS",
    -2147482968: "SEC_C_PRIV_DESC_WEBFORMATGRIDGRAPH",
    -2147479988: "SEC_C_PRIV_DESC_WEBIMPORTDATA",
    -2147479986: "SEC_C_PRIV_DESC_WEBIMPORTDATABASE",
    -2147481684: "SEC_C_PRIV_DESC_WEBMANAGEDOCUMENTDATASETS",
    -2147481682: "SEC_C_PRIV_DESC_WEBMODIFYGRIDLEVELINDOCUMENT",
    -2147482902: "SEC_C_PRIV_DESC_WEBMODIFYREPORTLIST",
    -2147482904: "SEC_C_PRIV_DESC_WEBMODIFYSUBTOTALS",
    -2147482972: "SEC_C_PRIV_DESC_WEBNORMALLDRILL",
    -2147481676: "SEC_C_PRIV_DESC_WEBNUMBERFORMATTING",
    -2147483004: "SEC_C_PRIV_DESC_WEBOBJECTSEARCH",
    -2147482994: "SEC_C_PRIV_DESC_WEBPRINTMODE",
    -2147481706: "SEC_C_PRIV_DESC_WEBPRINTNOW",
    -2147482888: "SEC_C_PRIV_DESC_WEBREEXECUTEREPORTAGAINSTWH",
    -2147483036: "SEC_C_PRIV_DESC_WEBREPORTDETAILS",
    -2147483008: "SEC_C_PRIV_DESC_WEBREPORTMANIPULATIONS",
    -2147482986: "SEC_C_PRIV_DESC_WEBREPORTSQL",
    -2147479966: "SEC_C_PRIV_DESC_WEBSAVEANALYSIS",
    -2147480018: "SEC_C_PRIV_DESC_WEBSAVEDERIVEDELEMENTS",
    -2147482956: "SEC_C_PRIV_DESC_WEBSAVETEMPLATESANDFILTERS",
    -2147483000: "SEC_C_PRIV_DESC_WEBSAVETOMYREPORTS",
    -2147482990: "SEC_C_PRIV_DESC_WEBSAVETOSHAREDREPORTS",
    -2147481698: "SEC_C_PRIV_DESC_WEBSCHEDULEDEXPORTTOFILE",
    -2147481704: "SEC_C_PRIV_DESC_WEBSCHEDULEDPRINTING",
    -2147482950: "SEC_C_PRIV_DESC_WEBSCHEDULEEMAIL",
    -2147479934: "SEC_C_PRIV_DESC_WEBSCHEDULEFTP2",
    -2147482966: "SEC_C_PRIV_DESC_WEBSCHEDULEREPORT",
    -2147482928: "SEC_C_PRIV_DESC_WEBSENDNOW",
    -2147481680: "SEC_C_PRIV_DESC_WEBSETATTRIBUTEFORMDISPLAY",
    -2147481732: "SEC_C_PRIV_DESC_WEBSETCOLUMNWIDTHS",
    -2147481736: "SEC_C_PRIV_DESC_WEBSIMPLEGRAPHFORMATTING",
    -2147482964: "SEC_C_PRIV_DESC_WEBSIMUEXECUTION",
    -2147482960: "SEC_C_PRIV_DESC_WEBSORT",
    -2147479958: "SEC_C_PRIV_DESC_WEBSUBSCRIBEDYNAMICADDRESSLIST",
    -2147482962: "SEC_C_PRIV_DESC_WEBSWITCHPAGEBYELE",
    -2147480016: "SEC_C_PRIV_DESC_WEBUSEADVANCEDTHRESHOLDEDITOR",
    -2147480022: "SEC_C_PRIV_DESC_WEBUSEBASICTHRESHOLDEDITOR",
    -2147479990: "SEC_C_PRIV_DESC_WEBUSECUSTOMGROUPEDITOR",
    -2147482896: "SEC_C_PRIV_DESC_WEBUSEDESIGNMODE",
    -2147481734: "SEC_C_PRIV_DESC_WEBUSELOCKEDHEADERS",
    -2147479954: "SEC_C_PRIV_DESC_WEBUSEMETRICEDITOR",
    -2147479970: "SEC_C_PRIV_DESC_WEBUSEOBJECTSHARINGEDITOR",
    -2147480034: "SEC_C_PRIV_DESC_WEBUSEPROMPTEDITOR",
    -2147482890: "SEC_C_PRIV_DESC_WEBUSEQUERYFILTEREDITOR",
    -2147483012: "SEC_C_PRIV_DESC_WEBUSER",
    -2147482898: "SEC_C_PRIV_DESC_WEBUSEREPORTFILTEREDITOR",
    -2147482900: "SEC_C_PRIV_DESC_WEBUSEREPORTOBJECTSWINDOW",
    -2147483010: "SEC_C_PRIV_DESC_WEBVIEWHISTORYLIST",
    -2147479978: "SEC_C_PRIV_DESC_WEBVISUALEXPLORATION",
    -2147479906: "SEC_C_PRIV_DES_ADMINISTERENVIRONMENT",
    -2147479896: "SEC_C_PRIV_DES_MONITORENVIRONMENT",
    -2147479902: "SEC_C_PRIV_DES_USEAPI",
    -2147479900: "SEC_C_PRIV_DES_USELIBRARYWEB",
    -2147479898: "SEC_C_PRIV_DES_USEREPORTER",
    -2147479904: "SEC_C_PRIV_DES_USEWORKSTATION",
    -2147479445: "SEC_C_PRIV_LACK",
    -2147479849: "SEC_C_PRIV_LAST3",
    -2147482859: "SEC_C_PRIV_LAST_ONE",
    -2147481649: "SEC_C_PRIV_LAST_ONE2",
    -2147479931: "SEC_C_PRIV_NAME_ACCESSDATAFROMCLOUDAPP",
    -2147480047: "SEC_C_PRIV_NAME_ADDNOTES",
    -2147479907: "SEC_C_PRIV_NAME_ADMINISTERENVIRONMENT",
    -2147479927: "SEC_C_PRIV_NAME_ADMINISTEROPERATIONMANAGER",
    -2147482863: "SEC_C_PRIV_NAME_ALIASOBJECTS",
    -2147480137: "SEC_C_PRIV_NAME_ASSIGNSECURITYROLES",
    -2147483017: "SEC_C_PRIV_NAME_BYPASSACCESSCHECKS",
    -2147483142: "SEC_C_PRIV_NAME_BYPASSACCESSCHECKS1",
    -2147481657: "SEC_C_PRIV_NAME_CACHEADMINISTRATION",
    -2147479915: "SEC_C_PRIV_NAME_CANCERTIFY",
    -2147482881: "SEC_C_PRIV_NAME_CHANGEUSERPREFERENCE",
    -2147480121: "SEC_C_PRIV_NAME_CLUSTERADMINISTRATION",
    -2147480135: "SEC_C_PRIV_NAME_CONFIGCONTACTDATAPROFILE",
    -2147480095: "SEC_C_PRIV_NAME_CONFIGURECACHES",
    -2147480091: "SEC_C_PRIV_NAME_CONFIGURECONNECTIONMAP",
    -2147480097: "SEC_C_PRIV_NAME_CONFIGUREGOVERNING",
    -2147480127: "SEC_C_PRIV_NAME_CONFIGUREGROUPMEMBERSHIP",
    -2147480099: "SEC_C_PRIV_NAME_CONFIGUREINBOX",
    -2147480081: "SEC_C_PRIV_NAME_CONFIGURELANGUAGESETTINGS",
    -2147480093: "SEC_C_PRIV_NAME_CONFIGUREPROJECTBASIC",
    -2147480089: "SEC_C_PRIV_NAME_CONFIGUREPROJECTDATASOURCE",
    -2147480101: "SEC_C_PRIV_NAME_CONFIGURESECURITY",
    -2147480105: "SEC_C_PRIV_NAME_CONFIGURESERVERBASIC",
    -2147480103: "SEC_C_PRIV_NAME_CONFIGURESTATISTICS",
    -2147482883: "SEC_C_PRIV_NAME_CONFIGURETOOLBARS",
    -2147480083: "SEC_C_PRIV_NAME_CONFIIGUREAUDITING",
    -2147480085: "SEC_C_PRIV_NAME_CONFIIGURESUBSCRIPTIONSETTINGS",
    -2147483047: "SEC_C_PRIV_NAME_CREATEAPPOBJ",
    -2147483172: "SEC_C_PRIV_NAME_CREATEAPPOBJ1",
    -2147483045: "SEC_C_PRIV_NAME_CREATECONFIGOBJ",
    -2147483170: "SEC_C_PRIV_NAME_CREATECONFIGOBJ1",
    -2147482983: "SEC_C_PRIV_NAME_CREATEDATAMART",
    -2147479911: "SEC_C_PRIV_NAME_CREATEDATASETINWORKSTATION",
    -2147482913: "SEC_C_PRIV_NAME_CREATEDERIVEDMETRICS",
    -2147480033: "SEC_C_PRIV_NAME_CREATEHTMLCONTAINER",
    -2147482869: "SEC_C_PRIV_NAME_CREATENEWFOLDER",
    -2147483043: "SEC_C_PRIV_NAME_CREATESCHEMAOBJ",
    -2147483168: "SEC_C_PRIV_NAME_CREATESCHEMAOBJ1",
    -2147481673: "SEC_C_PRIV_NAME_CREATESHORTCUT",
    -2147480147: "SEC_C_PRIV_NAME_CUBEADMINISTRATION",
    -2147480011: "SEC_C_PRIV_NAME_DASHBOARDDESIGN",
    -2147480069: "SEC_C_PRIV_NAME_DATABASECONNECTIONADMIN",
    -2147481693: "SEC_C_PRIV_NAME_DEFINECUSTOMSQLREPORT",
    -2147480013: "SEC_C_PRIV_NAME_DEFINEDERIVEDELEMENTS",
    -2147481691: "SEC_C_PRIV_NAME_DEFINEOLAPCUBEREPORT",
    -2147480123: "SEC_C_PRIV_NAME_DEFINESECURITYFILTER",
    -2147479985: "SEC_C_PRIV_NAME_DEFINETRANSACTIONREPORT",
    -2147480115: "SEC_C_PRIV_NAME_DEFINEVIEWREPORT",
    -2147481667: "SEC_C_PRIV_NAME_DEFQUERYBUILDERREPORT",
    -2147480003: "SEC_C_PRIV_NAME_DRILLANDLINK",
    -2147481669: "SEC_C_PRIV_NAME_DRILLWITHINTELLIGENTCUBE",
    -2147480067: "SEC_C_PRIV_NAME_DUPLICATEPROJECT",
    -2147480045: "SEC_C_PRIV_NAME_EDITNOTES",
    -2147480007: "SEC_C_PRIV_NAME_EDITREPORTLINKS",
    -2147479963: "SEC_C_PRIV_NAME_EMAILSCREENFROMDEVICE",
    -2147480039: "SEC_C_PRIV_NAME_ENABLEADMINISTRATIONFROMWEB",
    -2147480087: "SEC_C_PRIV_NAME_ENABLEUSER",
    -2147480111: "SEC_C_PRIV_NAME_EXECUTECUBEREPORT",
    -2147480029: "SEC_C_PRIV_NAME_EXECUTEMULTIPLESOURCEREPORT",
    -2147481715: "SEC_C_PRIV_NAME_EXECUTERWDOCUMENT",
    -2147479981: "SEC_C_PRIV_NAME_EXECUTETRANSACTION",
    -2147480055: "SEC_C_PRIV_NAME_EXPORTTOEXCEL",
    -2147480051: "SEC_C_PRIV_NAME_EXPORTTOFLASH",
    -2147480057: "SEC_C_PRIV_NAME_EXPORTTOHTML",
    -2147479925: "SEC_C_PRIV_NAME_EXPORTTOMSTRFILE",
    -2147480059: "SEC_C_PRIV_NAME_EXPORTTOPDF",
    -2147480053: "SEC_C_PRIV_NAME_EXPORTTOTEXT",
    -2147480145: "SEC_C_PRIV_NAME_FIREEVENT",
    -2147482875: "SEC_C_PRIV_NAME_FORMATGRAPH",
    -2147480129: "SEC_C_PRIV_NAME_GRANTPRIVILEGE",
    -2147480117: "SEC_C_PRIV_NAME_IDLEPROJECT",
    -2147479923: "SEC_C_PRIV_NAME_IMPORTMSTRFILE",
    -2147481689: "SEC_C_PRIV_NAME_IMPORTOLAPCUBE",
    -2147480031: "SEC_C_PRIV_NAME_IMPORTTABLEFROMMULTIPLESOURCES",
    -2147481653: "SEC_C_PRIV_NAME_INBOXADMINISTRATION",
    -2147480073: "SEC_C_PRIV_NAME_JOBADMINISTRATION",
    -2147480131: "SEC_C_PRIV_NAME_LINKTOEXTERNALACCOUNTS",
    -2147480119: "SEC_C_PRIV_NAME_LOADPROJECT",
    -2147479943: "SEC_C_PRIV_NAME_MOBILECREATEANALYSIS",
    -2147479945: "SEC_C_PRIV_NAME_MOBILECREATEDOCUMENT",
    -2147479937: "SEC_C_PRIV_NAME_MOBILEEDITANALYSIS",
    -2147479939: "SEC_C_PRIV_NAME_MOBILEPUBLISH",
    -2147479947: "SEC_C_PRIV_NAME_MOBILESAVEANALYSIS",
    -2147479949: "SEC_C_PRIV_NAME_MOBILESAVEDOCUMENT",
    -2147479941: "SEC_C_PRIV_NAME_MOBILESAVEREPORT",
    -2147479951: "SEC_C_PRIV_NAME_MOBILEVIEWANALYSIS",
    -2147481661: "SEC_C_PRIV_NAME_MOBILEVIEWDOCUMENT",
    -2147482909: "SEC_C_PRIV_NAME_MODIFYREPORTOBJECTLIST",
    -2147482927: "SEC_C_PRIV_NAME_MODIFYSCHEMAOBJECT",
    -2147482873: "SEC_C_PRIV_NAME_MODIFYSORTING",
    -2147482911: "SEC_C_PRIV_NAME_MODIFYSUBTOTALS",
    -2147480079: "SEC_C_PRIV_NAME_MONITORCHANGEJOURNAL",
    -2147479897: "SEC_C_PRIV_NAME_MONITORENVIRONMENT",
    -2147479929: "SEC_C_PRIV_NAME_MONITOROPERATIONMANAGER",
    -2147482867: "SEC_C_PRIV_NAME_PIVOTREPORT",
    -2147479965: "SEC_C_PRIV_NAME_PRINTFROMDEVICE",
    -2147479913: "SEC_C_PRIV_NAME_PUBLISHDOSSIER",
    -2147481745: "SEC_C_PRIV_NAME_REEXECUTEREPORTAGAINSTWH",
    -2147482985: "SEC_C_PRIV_NAME_RESERVED2",
    -2147480133: "SEC_C_PRIV_NAME_RESETUSERPASSWORD",
    -2147482917: "SEC_C_PRIV_NAME_SAVECUSTOMAUTOSTYLE",
    -2147480009: "SEC_C_PRIV_NAME_SAVEDERIVEDELEMENTS",
    -2147480027: "SEC_C_PRIV_NAME_SAVEPERSONALPROMPTANWSER",
    -2147482953: "SEC_C_PRIV_NAME_SCHEDULEADMINISTRATION",
    -2147482758: "SEC_C_PRIV_NAME_SCHEDULEADMINISTRATION_UNUSED",
    -2147483041: "SEC_C_PRIV_NAME_SCHEDULEREQUEST",
    -2147483166: "SEC_C_PRIV_NAME_SCHEDULEREQUEST1",
    -2147480061: "SEC_C_PRIV_NAME_SENDLINKINEMAIL",
    -2147481741: "SEC_C_PRIV_NAME_SENDTOEMAIL",
    -2147481695: "SEC_C_PRIV_NAME_SERVERMONITORING",
    -2147482887: "SEC_C_PRIV_NAME_SETATTRIBUTEDISPLAY",
    -2147479921: "SEC_C_PRIV_NAME_SETOAUTHPARAMETERSFORCLOUD",
    -2147480065: "SEC_C_PRIV_NAME_SUBSCRIBEOTHERS",
    -2147480063: "SEC_C_PRIV_NAME_SUBSCRIBETOEMAILALERT",
    -2147479903: "SEC_C_PRIV_NAME_USEAPI",
    -2147483039: "SEC_C_PRIV_NAME_USEARCHITECT",
    -2147483164: "SEC_C_PRIV_NAME_USEARCHITECT1",
    -2147480075: "SEC_C_PRIV_NAME_USEBULKEXPORTEDITOR",
    -2147480077: "SEC_C_PRIV_NAME_USEBULKTRANSLATIONTOOL",
    -2147482939: "SEC_C_PRIV_NAME_USECACHEMONITOR",
    -2147482937: "SEC_C_PRIV_NAME_USECLUSTERMONITOR",
    -2147479909: "SEC_C_PRIV_NAME_USECOLLABORATIONSERVICES",
    -2147481719: "SEC_C_PRIV_NAME_USECOMMANDMANAGER",
    -2147483025: "SEC_C_PRIV_NAME_USECONSOLIDATIONEDITOR",
    -2147483150: "SEC_C_PRIV_NAME_USECONSOLIDATIONEDITOR1",
    -2147480141: "SEC_C_PRIV_NAME_USECONTACTMANAGER",
    -2147481651: "SEC_C_PRIV_NAME_USECUBEMONITOR",
    -2147480113: "SEC_C_PRIV_NAME_USECUBEREPORTEDITOR",
    -2147483023: "SEC_C_PRIV_NAME_USECUSTOMGROUPEDITOR",
    -2147483148: "SEC_C_PRIV_NAME_USECUSTOMGROUPEDITOR1",
    -2147482943: "SEC_C_PRIV_NAME_USEDATABASECONNECTIONMONITOR",
    -2147482935: "SEC_C_PRIV_NAME_USEDATABASEINSTANCEMANAGER",
    -2147480125: "SEC_C_PRIV_NAME_USEDATABASELOGINMANAGER",
    -2147482877: "SEC_C_PRIV_NAME_USEDATAEXPLORER",
    -2147482981: "SEC_C_PRIV_NAME_USEDATAMARTEDITOR",
    -2147482865: "SEC_C_PRIV_NAME_USEDESIGNMODE",
    -2147481675: "SEC_C_PRIV_NAME_USEDESKTOP",
    -2147480043: "SEC_C_PRIV_NAME_USEDISTRIBUTIONSERVICES",
    -2147483021: "SEC_C_PRIV_NAME_USEDOCUMENTEDITOR",
    -2147483146: "SEC_C_PRIV_NAME_USEDOCUMENTEDITOR1",
    -2147481743: "SEC_C_PRIV_NAME_USEDRILLMAPEDITOR",
    -2147479995: "SEC_C_PRIV_NAME_USEDYNAMICSOURCING",
    -2147483031: "SEC_C_PRIV_NAME_USEFILTEREDITOR",
    -2147483156: "SEC_C_PRIV_NAME_USEFILTEREDITOR1",
    -2147481721: "SEC_C_PRIV_NAME_USEFINDANDREPLACEDIALOG",
    -2147482919: "SEC_C_PRIV_NAME_USEFORMATTINGEDITOR",
    -2147481739: "SEC_C_PRIV_NAME_USEFUNCTIONPLUGINEDITOR",
    -2147482861: "SEC_C_PRIV_NAME_USEGRIDOPTIONS",
    -2147482885: "SEC_C_PRIV_NAME_USEHISTORYLIST",
    -2147480041: "SEC_C_PRIV_NAME_USEIMMEDIATEDELIVERY",
    -2147479957: "SEC_C_PRIV_NAME_USEIMMEDIATEPREVIEW",
    -2147481655: "SEC_C_PRIV_NAME_USEINBOXMONITOR",
    -2147481659: "SEC_C_PRIV_NAME_USEINTEGRITYMANAGER",
    -2147482947: "SEC_C_PRIV_NAME_USEJOBMONITOR",
    -2147479901: "SEC_C_PRIV_NAME_USELIBRARYWEB",
    -2147483033: "SEC_C_PRIV_NAME_USEMETRICEDITOR",
    -2147483158: "SEC_C_PRIV_NAME_USEMETRICEDITOR1",
    -2147479919: "SEC_C_PRIV_NAME_USEMICROSTRATEGYDESKTOP",
    -2147481663: "SEC_C_PRIV_NAME_USEMSTRMOBILE",
    -2147482979: "SEC_C_PRIV_NAME_USEOBJECTMANAGER",
    -2147479975: "SEC_C_PRIV_NAME_USEOBJECTMANAGERIMPORTONLY",
    -2147479977: "SEC_C_PRIV_NAME_USEOBJECTMANAGERREADONLY",
    -2147481711: "SEC_C_PRIV_NAME_USEOFFICEINTELLIGENCE",
    -2147479997: "SEC_C_PRIV_NAME_USEOLAPSERVICES",
    -2147481727: "SEC_C_PRIV_NAME_USEPROJECTDOCUMENTATION",
    -2147482931: "SEC_C_PRIV_NAME_USEPROJECTMONITOR",
    -2147481729: "SEC_C_PRIV_NAME_USEPROJECTSTATUSEDITOR",
    -2147483019: "SEC_C_PRIV_NAME_USEPROMPTEDITOR",
    -2147483144: "SEC_C_PRIV_NAME_USEPROMPTEDITOR1",
    -2147479917: "SEC_C_PRIV_NAME_USEQUICKSEARCHINDICES",
    -2147480071: "SEC_C_PRIV_NAME_USERCONNECTIONADMIN",
    -2147482879: "SEC_C_PRIV_NAME_USEREPORTDATAOPTIONS",
    -2147483027: "SEC_C_PRIV_NAME_USEREPORTEDITOR",
    -2147483152: "SEC_C_PRIV_NAME_USEREPORTEDITOR1",
    -2147479899: "SEC_C_PRIV_NAME_USEREPORTER",
    -2147482915: "SEC_C_PRIV_NAME_USEREPORTFILTEREDITOR",
    -2147482923: "SEC_C_PRIV_NAME_USEREPORTOBJECTSWINDOW",
    -2147481717: "SEC_C_PRIV_NAME_USERWDOCUMENTEDITOR",
    -2147482933: "SEC_C_PRIV_NAME_USESCHEDULEMANAGER",
    -2147482941: "SEC_C_PRIV_NAME_USESCHEDULEMONITOR",
    -2147481747: "SEC_C_PRIV_NAME_USESEACHEDITOR",
    -2147481731: "SEC_C_PRIV_NAME_USESECURITYFILTERMANAGER",
    -2147480139: "SEC_C_PRIV_NAME_USESECURITYROLEMANAGER",
    -2147483035: "SEC_C_PRIV_NAME_USESERVERADMIN",
    -2147483160: "SEC_C_PRIV_NAME_USESERVERADMIN1",
    -2147482989: "SEC_C_PRIV_NAME_USESERVERCACHE",
    -2147479993: "SEC_C_PRIV_NAME_USESQLTABINEXPORTEDITORS",
    -2147481723: "SEC_C_PRIV_NAME_USESUBTOTALEDITOR",
    -2147483029: "SEC_C_PRIV_NAME_USETEMPLATEEDITOR",
    -2147483154: "SEC_C_PRIV_NAME_USETEMPLATEEDITOR1",
    -2147482921: "SEC_C_PRIV_NAME_USETHRESHOLDSEDITOR",
    -2147479973: "SEC_C_PRIV_NAME_USETRANSACTIONEDITORBYPASS",
    -2147480037: "SEC_C_PRIV_NAME_USETRANSLATIONEDITOR",
    -2147480143: "SEC_C_PRIV_NAME_USETRANSMITTERDEVICEMANAGER",
    -2147482945: "SEC_C_PRIV_NAME_USEUSERCONNECTIONMONITOR",
    -2147482949: "SEC_C_PRIV_NAME_USEUSERMANAGER",
    -2147482959: "SEC_C_PRIV_NAME_USEVLDBPROPEDITOR",
    -2147483162: "SEC_C_PRIV_NAME_USEWEBADMIN1",
    -2147479905: "SEC_C_PRIV_NAME_USEWORKSTATION",
    -2147482925: "SEC_C_PRIV_NAME_VIEWETLINFORMATION",
    -2147480049: "SEC_C_PRIV_NAME_VIEWNOTES",
    -2147482871: "SEC_C_PRIV_NAME_VIEWSQL",
    -2147482977: "SEC_C_PRIV_NAME_WEBADDHISTORYLIST",
    -2147483015: "SEC_C_PRIV_NAME_WEBADMINISTRATOR",
    -2147482895: "SEC_C_PRIV_NAME_WEBALIASOBJECTS",
    -2147483003: "SEC_C_PRIV_NAME_WEBCHANGEUSEROPTIONS",
    -2147482975: "SEC_C_PRIV_NAME_WEBCHANGEVIEWMODE",
    -2147482893: "SEC_C_PRIV_NAME_WEBCONFIGURETOOLBARS",
    -2147479983: "SEC_C_PRIV_NAME_WEBCONFIGURETRANSACTION",
    -2147479969: "SEC_C_PRIV_NAME_WEBCREATEANALYSIS",
    -2147482907: "SEC_C_PRIV_NAME_WEBCREATEDERIVEDMETRICS",
    -2147479961: "SEC_C_PRIV_NAME_WEBCREATEDYNAMICADDRESSLIST",
    -2147481709: "SEC_C_PRIV_NAME_WEBCREATEEMAILADDRESS",
    -2147481697: "SEC_C_PRIV_NAME_WEBCREATEFILELOCATION",
    -2147443145: "SEC_C_PRIV_NAME_WEBCREATEFTPLOCATION",
    -2147479933: "SEC_C_PRIV_NAME_WEBCREATEFTPLOCATION2",
    -2147479999: "SEC_C_PRIV_NAME_WEBCREATEHTMLCONTAINER",
    -2147483007: "SEC_C_PRIV_NAME_WEBCREATENEWREPORT",
    -2147481703: "SEC_C_PRIV_NAME_WEBCREATEPRINTLOCATION",
    -2147480021: "SEC_C_PRIV_NAME_WEBDASHBOARDDESIGN",
    -2147480001: "SEC_C_PRIV_NAME_WEBDEFINEADVANCEDREPORTOPTION",
    -2147480025: "SEC_C_PRIV_NAME_WEBDEFINEDERIVEDELEMENTS",
    -2147480109: "SEC_C_PRIV_NAME_WEBDEFINEVIEWREPORT",
    -2147481665: "SEC_C_PRIV_NAME_WEBDEFQUERYBUILDERREPORT",
    -2147482993: "SEC_C_PRIV_NAME_WEBDELETEOBJECT",
    -2147481687: "SEC_C_PRIV_NAME_WEBDOCUMENTDESIGN",
    -2147482999: "SEC_C_PRIV_NAME_WEBDRILLING",
    -2147482971: "SEC_C_PRIV_NAME_WEBDRILLMETRICS",
    -2147480005: "SEC_C_PRIV_NAME_WEBEDITNOTES",
    -2147480015: "SEC_C_PRIV_NAME_WEBEDITREPORTLINKS",
    -2147481671: "SEC_C_PRIV_NAME_WEBENABLEMMTACCESS",
    -2147479953: "SEC_C_PRIV_NAME_WEBEXECUTEANALYSIS",
    -2147481679: "SEC_C_PRIV_NAME_WEBEXECUTEBULKEXPORTREPORT",
    -2147480107: "SEC_C_PRIV_NAME_WEBEXECUTECUBEREPORT",
    -2147481725: "SEC_C_PRIV_NAME_WEBEXECUTEDATAMARTREPORT",
    -2147481713: "SEC_C_PRIV_NAME_WEBEXECUTERWDOCUMENT",
    -2147482997: "SEC_C_PRIV_NAME_WEBEXPORT",
    -2147481701: "SEC_C_PRIV_NAME_WEBEXPORTTOFILENOW",
    -2147482955: "SEC_C_PRIV_NAME_WEBFILTERONSELECTIONS",
    -2147482969: "SEC_C_PRIV_NAME_WEBFORMATGRIDGRAPH",
    -2147479989: "SEC_C_PRIV_NAME_WEBIMPORTDATA",
    -2147479987: "SEC_C_PRIV_NAME_WEBIMPORTDATABASE",
    -2147481685: "SEC_C_PRIV_NAME_WEBMANAGEDOCUMENTDATASETS",
    -2147481683: "SEC_C_PRIV_NAME_WEBMODIFYGRIDLEVELINDOCUMENT",
    -2147482903: "SEC_C_PRIV_NAME_WEBMODIFYREPORTLIST",
    -2147482905: "SEC_C_PRIV_NAME_WEBMODIFYSUBTOTALS",
    -2147482973: "SEC_C_PRIV_NAME_WEBNORMALDRILL",
    -2147481677: "SEC_C_PRIV_NAME_WEBNUMBERFORMATTING",
    -2147483005: "SEC_C_PRIV_NAME_WEBOBJECTSEARCH",
    -2147482995: "SEC_C_PRIV_NAME_WEBPRINTMODE",
    -2147481707: "SEC_C_PRIV_NAME_WEBPRINTNOW",
    -2147482889: "SEC_C_PRIV_NAME_WEBREEXECUTEREPORTAGAINSTWH",
    -2147483037: "SEC_C_PRIV_NAME_WEBREPORTDETAILS",
    -2147483009: "SEC_C_PRIV_NAME_WEBREPORTMANIPULATIONS",
    -2147482987: "SEC_C_PRIV_NAME_WEBREPORTSQL",
    -2147479967: "SEC_C_PRIV_NAME_WEBSAVEANALYSIS",
    -2147480019: "SEC_C_PRIV_NAME_WEBSAVEDERIVEDELEMENTS",
    -2147482957: "SEC_C_PRIV_NAME_WEBSAVETEMPLATESANDFILTERS",
    -2147483001: "SEC_C_PRIV_NAME_WEBSAVETOMYREPORTS",
    -2147482991: "SEC_C_PRIV_NAME_WEBSAVETOSHAREDREPORTS",
    -2147481699: "SEC_C_PRIV_NAME_WEBSCHEDULEDEXPORTTOFILE",
    -2147443146: "SEC_C_PRIV_NAME_WEBSCHEDULEDFTP",
    -2147481705: "SEC_C_PRIV_NAME_WEBSCHEDULEDPRINTING",
    -2147482951: "SEC_C_PRIV_NAME_WEBSCHEDULEEMAIL",
    -2147479935: "SEC_C_PRIV_NAME_WEBSCHEDULEFTP2",
    -2147482967: "SEC_C_PRIV_NAME_WEBSCHEDULEREPORT",
    -2147482929: "SEC_C_PRIV_NAME_WEBSENDNOW",
    -2147481681: "SEC_C_PRIV_NAME_WEBSETATTRIBUTEFORMDISPLAY",
    -2147481733: "SEC_C_PRIV_NAME_WEBSETCOLUMNWIDTHS",
    -2147481737: "SEC_C_PRIV_NAME_WEBSIMPLEGRAPHFORMATTING",
    -2147482965: "SEC_C_PRIV_NAME_WEBSIMUEXECUTION",
    -2147482961: "SEC_C_PRIV_NAME_WEBSORT",
    -2147479959: "SEC_C_PRIV_NAME_WEBSUBSCRIBEDYNAMICADDRESSLIST",
    -2147482963: "SEC_C_PRIV_NAME_WEBSWITCHPAGEBYELE",
    -2147480017: "SEC_C_PRIV_NAME_WEBUSEADVANCEDTHRESHOLDEDITOR",
    -2147480023: "SEC_C_PRIV_NAME_WEBUSEBASICTHRESHOLDEDITOR",
    -2147479991: "SEC_C_PRIV_NAME_WEBUSECUSTOMGROUPEDITOR",
    -2147482897: "SEC_C_PRIV_NAME_WEBUSEDESIGNMODE",
    -2147481735: "SEC_C_PRIV_NAME_WEBUSELOCKEDHEADERS",
    -2147479955: "SEC_C_PRIV_NAME_WEBUSEMETRICEDITOR",
    -2147479971: "SEC_C_PRIV_NAME_WEBUSEOBJECTSHARINGEDITOR",
    -2147480035: "SEC_C_PRIV_NAME_WEBUSEPROMPTEDITOR",
    -2147482891: "SEC_C_PRIV_NAME_WEBUSEQUERYFILTEREDITOR",
    -2147483013: "SEC_C_PRIV_NAME_WEBUSER",
    -2147482899: "SEC_C_PRIV_NAME_WEBUSEREPORTFILTEREDITOR",
    -2147482901: "SEC_C_PRIV_NAME_WEBUSEREPORTOBJECTSWINDOW",
    -2147483011: "SEC_C_PRIV_NAME_WEBVIEWHISTORYLIST",
    -2147479979: "SEC_C_PRIV_NAME_WEBVISUALEXPLORATION",
    -2147483048: "SEC_C_PRIV_STARTING_INDEX",
    -2147481748: "SEC_C_PRIV_STARTING_INDEX2",
    -2147480148: "SEC_C_PRIV_STARTING_INDEX3",
    -2147214579: "SEC_E_ACCESS_DENIED",
    -2147214570: "SEC_E_ACCESS_DENIED_NONAME",
    -2147214576: "SEC_E_ACCESS_RIGHT_DESC_NOT_FOUND",
    -2147214577: "SEC_E_ACCESS_RIGHT_NAME_NOT_FOUND",
    -2147217342: "SEC_E_ACL_MODIFY_DSOBJ",
    -2147213396: "SEC_E_ADMINISTRATOR_PRIVS",
    -2147214591: "SEC_E_BAD_TOKEN_STRING",
    -2147214592: "SEC_E_CANT_CONSTRUCT_TOKEN",
    -2147214581: "SEC_E_CANT_CREATE_OBJECT",
    -2147214573: "SEC_E_CANT_GET_NT_IDENTITY",
    -2147214585: "SEC_E_CANT_GET_SID",
    -2147214580: "SEC_E_CANT_USE_APPLICATION",
    -2147214571: "SEC_E_DECRYPT_ACCESS_TOKEN_FAIL",
    -2147214572: "SEC_E_ENCRYPT_ACCESS_TOKEN_FAIL",
    -2147214583: "SEC_E_INCORRECT_TOKEN_TYPE",
    -2147214584: "SEC_E_INVALID_USER_RUNTIME",
    -2147214589: "SEC_E_MAX_LIMIT_ON_TOKEN_ELEMENT",
    -2147214588: "SEC_E_MISMATCHED_PRIV_SIZE",
    -2147214590: "SEC_E_MISSING_TOKEN_ELEMENT",
    -2147214575: "SEC_E_NOT_CONTAINER_OBJECT",
    -2147214574: "SEC_E_NOT_USER_OBJECT",
    -2147214578: "SEC_E_NO_ACCESS_TO_PROJECT",
    -2147202273: "SEC_E_NO_CERTIFY_PRIVILEGE",
    -2147214569: "SEC_E_NO_PUBLISH_DOSSIER_PRIVILEGE",
    -2147216622: "SEC_E_OBSOLETED",
    -2147214587: "SEC_E_TOKEN_ALREADY_CONTAINS_PROJECT",
    -2147214582: "SEC_E_TOKEN_ELEMENT_ALREADY_DEFINED",
    -2147214586: "SEC_E_TOKEN_MISSING_PROJECT",
    -2147214568: "SEC_E_USER_ACCESS_DENIED",
    -2147216998: "SER_E_BLOCK_NOT_FOUND",
    -2147216996: "SER_E_CORRUPT_TEXT_STREAM",
    -2147213383: "SER_E_READ_EXCEPTION",
    -2147213425: "SER_E_READ_EXCEPTION_W_PARAM",
    -2147212294: "SER_E_SIZE_EXCEPTION_W_PARAM",
    -2147216995: "SER_E_UNEXPECTED_END",
    -2147213382: "SER_E_WRITE_EXCEPTION",
    -2147213424: "SER_E_WRITE_EXCEPTION_W_PARAM",
    -2147216993: "SER_E_XML_ERROR",
    -2147216994: "SER_E_XML_FORMAT",
    -2147216992: "SER_E_XML_LOAD",
    -2147212153: "SESVC_E_AUTOCOMPLETE_DATABASE",
    -2147212172: "SESVC_E_BISEARCHER_OPEN_SEARCH_ENGINE_FAILED",
    -2147212188: "SESVC_E_BISEARCHER_SEARCH_ENGINE_EXCEPTION",
    -2147212165: "SESVC_E_BISEARCHER_STATUS_ERROR",
    -2147212164: "SESVC_E_BISEARCHER_TIMEOUT",
    -2147212171: "SESVC_E_BISEARCHER_UNKNOWN_DOCUMENT_TYPE",
    -2147212187: "SESVC_E_BISEARCHER_UNKNOWN_EXCEPTION",
    -2147212190: "SESVC_E_CACHE_CRAWLER_CRAWLING",
    -2147212189: "SESVC_E_CACHE_SESSION_COLLECTION_EMPTY",
    -2147212152: "SESVC_E_COMPONENT_NOT_INITIALIZED",
    -2147212156: "SESVC_E_CORRUPT_INDEX",
    -2147212105: "SESVC_E_EMPTY_QUERY",
    -2147212162: "SESVC_E_EXCEPTION_TYPE_CORRUPT_INDEX",
    -2147212160: "SESVC_E_EXCEPTION_TYPE_FILE_NOT_FOUND",
    -2147212157: "SESVC_E_EXCEPTION_TYPE_ILLEGAL_ARGUMENT",
    -2147212161: "SESVC_E_EXCEPTION_TYPE_IO",
    -2147212159: "SESVC_E_EXCEPTION_TYPE_PARSE_FAIL",
    -2147212158: "SESVC_E_EXCEPTION_TYPE_PARSE_TOOMANYCLAUSES",
    -2147212163: "SESVC_E_EXCEPTION_TYPE_SEARCH_ENGINE",
    -2147212155: "SESVC_E_FAIL_TO_MANIPULATE_INDEX",
    -2147212150: "SESVC_E_GET_INDEX_METADATA_ERROR",
    -2147212151: "SESVC_E_INCORRECT_PROJECT_STATUS",
    -2147212148: "SESVC_E_INDEX_NOT_MATCH_METADATA",
    -2147212184: "SESVC_E_MD_CRAWLER_BUSY",
    -2147212177: "SESVC_E_MD_CRAWLER_DESTROY_CURRENT_PROJECT",
    -2147212176: "SESVC_E_MD_CRAWLER_DESTROY_CURRENT_PROJECT_AND_FAIL",
    -2147212178: "SESVC_E_MD_CRAWLER_DESTROY_PROJECT_FAIL",
    -2147212182: "SESVC_E_MD_CRAWLER_ERROR",
    -2147212179: "SESVC_E_MD_CRAWLER_HAS_DONE_PARTIAL_PROJECT",
    -2147212181: "SESVC_E_MD_CRAWLER_HAS_DONE_PROJECT",
    -2147212180: "SESVC_E_MD_CRAWLER_HAS_PARTIAL_PROJECT",
    -2147212185: "SESVC_E_MD_CRAWLER_LOAD_DONE_PROJECT_FAIL",
    -2147212175: "SESVC_E_MD_CRAWLER_NOT_RIGHT_STATE",
    -2147212186: "SESVC_E_MD_CRAWLER_NO_SEARCH_ENGINE",
    -2147212183: "SESVC_E_MD_CRAWLER_STOPPED",
    -2147212173: "SESVC_E_MD_INDEXER_ADD_DOCUMENT_FAIL",
    -2147212174: "SESVC_E_MD_INDEXER_DELETE_DOCUMENT_FAIL",
    -2147212168: "SESVC_E_MD_INDEXER_GENERATE_DOC_FAIL",
    -2147212106: "SESVC_E_NOT_SUPPORT_TYPE",
    -2147212166: "SESVC_E_NO_EVENT_HANDLER",
    -2147212104: "SESVC_E_PROJECT_ALREADY_CRAWLED",
    -2147212103: "SESVC_E_PROJECT_IS_CRAWLING",
    -2147212102: "SESVC_E_PROJECT_NOT_INITIAL_CRAWLED",
    -2147212154: "SESVC_E_PROJECT_SEARCH_DISABLED",
    -2147212167: "SESVC_E_PROPERTIESMANAGER_INIT_FAIL",
    -2147212170: "SESVC_E_PROPERTIES_INVALID_PROPERTY_TYPE",
    -2147212169: "SESVC_E_PROPERTIES_MISSING_PROPERTYSET",
    -2147211954: "SESVC_E_RECOMMENDATION_TYPE_INVALID",
    -2147212073: "SESVC_E_SEARCH_ENGINE_NOT_STARTED",
    -2147202265: "SESVC_E_SEARCH_INDEX_IS_NOT_READY",
    -2147212147: "SESVC_E_SEARCH_SERVICE_NOT_ENABLED",
    -2147212075: "SESVC_E_STATE_TRANSITION_ERROR",
    -2147212149: "SESVC_E_UPDATE_INDEX_METADATA_ERROR",
    -2147202399: "SE_CMI_ADDITIONAL_CHECKS1",
    -2147202398: "SE_CMI_ADDITIONAL_CHECKS2",
    -2147202397: "SE_CMI_ADDITIONAL_CHECKS3",
    -2147202396: "SE_CMI_ADDITIONAL_CHECKS4",
    -2147202392: "SE_CMI_AGGREGATION_ON_ATTRIBUTES_RELATED_TO_TRANSFORMATION_ATTRIBUTES",
    -2147202464: "SE_CMI_AGG_METRIC_BRANCH_WITH_ZERO_CHECKING",
    -2147202405: "SE_CMI_AGG_METRIC_LEAF_EXPECTED",
    -2147202497: "SE_CMI_ALL_METRICS_REMOVED_FROM_CUBE",
    -2147202452: "SE_CMI_ANDNOT_OR_ORNOT_IN_FILTER",
    -2147202440: "SE_CMI_ATTRIBUTE_UNAVAILABLE",
    -2147202453: "SE_CMI_BAD_OR_IN_FILTER",
    -2147202385: "SE_CMI_CANNOT_PERFROM_NONAGG_BY_FACT_ON_CUBE_METRIC",
    -2147202498: "SE_CMI_CG_OR_CONSOLIDATION",
    -2147202456: "SE_CMI_COMPLEX_METRIC_EXPRESSION_ON_CUBE",
    -2147202489: "SE_CMI_CSI_OR_ELEMENT_BROWSING",
    -2147202490: "SE_CMI_CUBES_FOR_AD_HOC_DISABLED_FOR_REPORT",
    -2147202491: "SE_CMI_CUBES_FOR_AD_HOC_DISABLED_MASTERSWITCH",
    -2147202485: "SE_CMI_CUBE_TEMPLATE_MISSING_FILTER_ATTRIBUTE_FORM",
    -2147202415: "SE_CMI_DB_ONLY_FUNCTION_IN_FILTER",
    -2147202457: "SE_CMI_DB_ONLY_FUNCTION_IN_METRIC_FORMULA",
    -2147202403: "SE_CMI_DIFFERENT_AGG_TABLE_HIT",
    -2147202436: "SE_CMI_DIFFERENT_DB_ROLES",
    -2147202382: "SE_CMI_DIFFERENT_MDX_SOURCE_TABLE_USED",
    -2147202394: "SE_CMI_DIFFERENT_METRIC_FORMULA",
    -2147202360: "SE_CMI_DIFFERENT_METRIC_GROUP_BY_LEVELS",
    -2147202393: "SE_CMI_DIFFERENT_TRANSORMATIONS_USED",
    -2147202473: "SE_CMI_DIMMETRIC_BRANCH_IN_CUBE",
    -2147202407: "SE_CMI_DIM_METRIC_LEAF_EXPECTED",
    -2147202402: "SE_CMI_DISTINCT_FOUND_ON_AGGREGATION_FUNCTION",
    -2147202432: "SE_CMI_DISTINGUISH_DUPLICATED_ROWS_MISMATCH_FOR_CUBE_AND_REPORT",
    -2147202459: "SE_CMI_DUPLICATED_ROWS_OR_NULLCHECKING_SETTINGS_READING_ERROR",
    -2147202479: "SE_CMI_ERROR_READING_AE_NULLCHECKING_PROPERTY",
    -2147202480: "SE_CMI_ERROR_READING_DUPLICATED_ROWS_PROPERTY",
    -2147202469: "SE_CMI_FACT_ENTRY_LVL_ERROR",
    -2147202460: "SE_CMI_FACT_ENTRY_LVL_GREATER_THAN_A_FILTER_LEVEL",
    -2147202482: "SE_CMI_FACT_NOT_SUPPORTED_AT_REQUIRED_CUBE_LEVEL",
    -2147202426: "SE_CMI_FILTERING_KEY_ATTRIBUTE_UNAVAILABLE",
    -2147202408: "SE_CMI_FILTERS_CANNOT_ENSURE_ALL_DATA_NEEDED_IS_IN_CUBE",
    -2147202417: "SE_CMI_FILTER_FACT_NODE_NOT_SUPPORTED",
    -2147202427: "SE_CMI_FILTER_KEY_ATTRIBUTE_UNAVAILABLE",
    -2147202419: "SE_CMI_FILTER_METRIC_EXPR_NODE_NOT_SUPPORTED",
    -2147202420: "SE_CMI_FILTER_METRIC_NODE_NOT_SUPPORTED",
    -2147202424: "SE_CMI_FILTER_NOT_RESTRICTIVE_ENOUGH",
    -2147202422: "SE_CMI_FILTER_PRED_NODE_NOT_SUPPORTED",
    -2147202418: "SE_CMI_FILTER_RELATIONSHIP_NODE_NOT_SUPPORTED",
    -2147202421: "SE_CMI_FILTER_TABLE_NODE_NOT_SUPPORTED",
    -2147202423: "SE_CMI_FILTER_UNIT_ROOT_NODE_NOT_SUPPORTED",
    -2147202400: "SE_CMI_FUNCTION_EXPECTED",
    -2147202441: "SE_CMI_GENERIC_CUBE_MISMATCH_ERROR",
    -2147202455: "SE_CMI_GENERIC_ERROR_IN_FILTER",
    -2147202447: "SE_CMI_GENERIC_FILTER_CONSTRUCTION_ERROR",
    -2147202478: "SE_CMI_GENERIC_METRIC_ERROR",
    -2147202429: "SE_CMI_GENERIC_METRIC_MISMATCH_ERROR",
    -2147202425: "SE_CMI_GENERIC_METRIC_VS_METRIC_MISMATCH_ERROR",
    -2147202428: "SE_CMI_GROUP_BY_ATTRIBUTE_UNAVAILABLE",
    -2147202435: "SE_CMI_IF_NO_METRIC_REPORT_AND_CUBE_LOWEST_LVL_MUST_BE_THE_SAME",
    -2147202412: "SE_CMI_INCOMPATIBLE_DATA_TYPES_IN_FILTER",
    -2147202486: "SE_CMI_INCOMPLETE_HIERARCHY_DANGEROUS_ATTRIBUTE",
    -2147202414: "SE_CMI_INVALID_BETWEEN_IN_FILTER",
    -2147202484: "SE_CMI_JOINT_PARENT_OR_JOINT_CHILD_OR_MANY_TO_MANY_NOT_SUPPORTED",
    -2147202458: "SE_CMI_METRICS_WITH_NESTED_AGGREGATION_NOT_SUPPORTED",
    -2147202470: "SE_CMI_METRIC_AND_TEMPLATE_LVL_NOT_MATCHING_IN_CUBE",
    -2147202483: "SE_CMI_METRIC_BREAK_BY_NOT_ON_CUBE_TEMPLATE",
    -2147202444: "SE_CMI_METRIC_CROSS_JOINED_NO_GROUP_BY",
    -2147202358: "SE_CMI_METRIC_FILTER_KEY_NOT_IN_TEMPLATE",
    -2147202466: "SE_CMI_METRIC_FITLER_KEY_NOT_IN_TEMPLATE",
    -2147202465: "SE_CMI_METRIC_GROUP_BY_KEY_NOT_IN_TEMPLATE",
    -2147202475: "SE_CMI_METRIC_NOT_LEAF_OR_BRANCH",
    -2147202476: "SE_CMI_METRIC_NOT_OJ",
    -2147202463: "SE_CMI_METRIC_NOT_SAFE",
    -2147202474: "SE_CMI_METRIC_WITH_CONDITIONALITY_IN_CUBE",
    -2147202494: "SE_CMI_ML_PROBLEM",
    -2147202380: "SE_CMI_NEED_ATTRIBUTE_OUTER_JOINS_FOR_NON_AGG_BY_LOOK_UP",
    -2147202386: "SE_CMI_NESTED_AGG_METRIC_WITH_TRANSFORMATION",
    -2147202401: "SE_CMI_NONAGGREGATABLE_METRIC",
    -2147202471: "SE_CMI_NONAGGREGATION_IN_METRIC",
    -2147202359: "SE_CMI_NONAGG_BY_LKP_ON_INCR_REFR_CUBE_NOT_SUPPORTED",
    -2147202376: "SE_CMI_NONAGG_ON_ATTR_RELATED_TO_SECURITY_FILTER_BOTTOM_ATTR",
    -2147202388: "SE_CMI_NONAGG_ON_DIFFERENT_HIERARCHIES",
    -2147202374: "SE_CMI_NONAGG_ON_NESTED_AGG_NOT_SUPPORTED",
    -2147202390: "SE_CMI_NONAGG_TYPE_MISMATCH",
    -2147202373: "SE_CMI_NONE_FILTERING_NONAGG_BY_LKP_NOT_SUPPORTED",
    -2147202404: "SE_CMI_NON_AGG_FUNCTION_FOUND",
    -2147202481: "SE_CMI_NON_AGG_NOT_REPORT_LEVEL_METRIC_FOUND",
    -2147202434: "SE_CMI_NON_HDA_USER_CANNOT_USE_HDA_CUBE",
    -2147202468: "SE_CMI_NO_CU_FOUND",
    -2147202504: "SE_CMI_NO_ERROR",
    -2147202445: "SE_CMI_NO_GOOD_CANDIDATE_METRICS_FOUND",
    -2147202487: "SE_CMI_NO_REPORT_LVL_METRIC",
    -2147202361: "SE_CMI_NULLCHECK_UNDER_UNSUPPORTED_FUNC",
    -2147202406: "SE_CMI_NULL_AGG_METRIC",
    -2147202499: "SE_CMI_NULL_ATTRIBUTE_ON_TEMPLATE",
    -2147202395: "SE_CMI_NULL_CHECKING_FOR_ANALYTICAL_ENGINE_MISMATCH",
    -2147202454: "SE_CMI_NULL_IN_FILTER",
    -2147202477: "SE_CMI_NULL_METRIC_FOUND",
    -2147202493: "SE_CMI_NULL_METRIC_ORNULL_METRIC_DSSID",
    -2147202501: "SE_CMI_NULL_TEMPLATE_UNIT",
    -2147202462: "SE_CMI_OLD_OLAP_FUNCTION_IN_METRIC",
    -2147202461: "SE_CMI_OVERFLOW_IN_METRIC_CALCULATION",
    -2147202379: "SE_CMI_PARENT_CHILD_ORDER_PROBLEM",
    -2147202416: "SE_CMI_PERFORM_OR_FAILED",
    -2147202433: "SE_CMI_REPORTS_WITH_ZERO_RL_METRICS_CAN_ONLY_HIT_CUBE_WITH_FOJ_SUPPORT",
    -2147202330: "SE_CMI_REPORT_HAS_SAP_VARIABLE",
    -2147202502: "SE_CMI_REPORT_IS_XDA",
    -2147202500: "SE_CMI_REPORT_LIMIT_ON_CUBE_FOUND",
    -2147202443: "SE_CMI_REPORT_OLAP_METRIC_BREAK_BY_MISSING_FROM_CUBE_TEMPLATE",
    -2147202442: "SE_CMI_REPORT_OLAP_METRIC_SORT_BY_MISSING_FROM_CUBE_TEMPLATE",
    -2147202446: "SE_CMI_REPORT_TEMPLATE_ATTRIBUTE_FORM_MISSING_FROM_CUBE_TEMPLATE",
    -2147202389: "SE_CMI_SAME_LEVEL_METRIC_REQUIRED_FOR_NONAGG_BY_REL",
    -2147202377: "SE_CMI_SAME_NONAGGREGATION_METRIC_WITH_DIFFERENT_GROUP_BYS",
    -2147202438: "SE_CMI_SECURITY_FILTER_KEY_ATTRIBUTE_UNAVAILABLE",
    -2147202437: "SE_CMI_SECURITY_FILTER_LEVEL_ATTRIBUTE_UNAVAILABLE",
    -2147202413: "SE_CMI_STRING_COMPARISON_NOT_ALLOWED",
    -2147202409: "SE_CMI_STRING_COMPARISON_NOT_ALLOWED_IN_SORT_BY",
    -2147202467: "SE_CMI_TABLE_EXPR_GENERATION_ERROR",
    -2147202381: "SE_CMI_UNEXPECTED_COMP_UNIT_STRUCTURE",
    -2147202492: "SE_CMI_UNEXPECTED_REPORT_TYPE",
    -2147202503: "SE_CMI_UNKNOWN_ERROR",
    -2147202410: "SE_CMI_UNSATISFIABLE_CONDITION_IN_FILTER",
    -2147202411: "SE_CMI_UNSUPPORTED_ELEMENT_IN_FILTER",
    -2147202387: "SE_CMI_UNSUPPORTED_ELEMENT_IN_NESTED_AGG_METRIC",
    -2147202449: "SE_CMI_UNSUPPORTED_EXPR_TYPE_IN_FILTER",
    -2147202451: "SE_CMI_UNSUPPORTED_FILTER_NODE",
    -2147202450: "SE_CMI_UNSUPPORTED_FUNCTION_IN_FILTER",
    -2147202378: "SE_CMI_UNSUPPORTED_FUNCTION_IN_METRIC_FORMULA",
    -2147202363: "SE_CMI_UNSUPPORTED_INCREMENTAL_REFRESH",
    -2147202448: "SE_CMI_UNSUPPORTED_MERGE_TYPE_IN_FILTER",
    -2147202472: "SE_CMI_UNSUPPORTED_METRIC_TYPE",
    -2147202384: "SE_CMI_USER_DOESNT_HAVE_DYNAMIC_SOURCING_PRIVILEGE",
    -2147202430: "SE_CMI_USER_LOCALE_NOT_SUPPORTED_IN_CUBE",
    -2147202496: "SE_CMI_VLDB_DOWNWARD_OJ_PROBLEM",
    -2147202488: "SE_CMI_VLDB_INCOMPLETE_LOOKUP_PROBLEM",
    -2147202364: "SE_CMI_VLDB_NESTED_AGG_OUTER_JOIN_UNSUPPORTED_VALUE",
    -2147202375: "SE_CMI_VLDB_NONAGG_OPTIMIZATION_PROBLEM",
    -2147202495: "SE_CMI_VLDB_OUTER_TO_LOOKUP_PROBLEM",
    -2147202431: "SE_CMI_VLDB_SETTING_MISMATCH_FOR_CUBE_AND_REPORT",
    -2147202439: "SE_CMI_ZERO_METRICS_NEEDED",
    -2147050424: "SE_E_DBROLE_SCHEMA_EXCEPTION",
    -2147212800: "SE_E_DFC_EXCEPTION",
    -2147212799: "SE_E_DFC_UNKNOWN_EXCEPTION",
    -2147203467: "SE_E_DIMENSIONALITY_EXCEPTION",
    -2147212794: "SE_E_FREE_SQL_EXCEPTION",
    -2147203481: "SE_E_LOCALE_NOT_SUPPORT",
    -2147212793: "SE_E_MDX_EXCEPTION",
    -2147181017: "SE_E_NULL_CHILDREN_VEC",
    -2147212792: "SE_E_QUERY_WIZARD_EXCEPTION",
    -2147203470: "SE_E_RECURSIVE_ATTR_RELATIONSHIP",
    -2147212797: "SE_E_REPORT_CONVERSION",
    -2147212791: "SE_E_SCHEMA_CHANGED",
    -2147212798: "SE_E_SCHEMA_CONVERSION",
    -2147203468: "SE_E_SCHEMA_EXCEPTION",
    -2147212796: "SE_E_UNRECOVERABLE_ERROR",
    -2147203469: "SE_E_VLDB_EXCEPTION",
    -2147465608: "SE_INFO_STEPS",
    -2147482624: "SE_STR_JOBCOMPLETE",
    -2147213055: "SQL_E_CORRUPT_STREAM",
    -2147213056: "SQL_E_NOT_COMPLETE",
    -2147211255: "SQL_E_SQL_NOT_AVAILABLE",
    -2147215612: "SRCLNT_E_MSG_HEADERCORRUPT",
    -2147215616: "SRCLNT_E_MsgLocalMethodOnly",
    -2147215613: "SRCLNT_E_MsgNoDataReturned",
    -2147215614: "SRCLNT_E_MsgNoFindObject",
    -2147215615: "SRCLNT_E_MsgSourceNetClientUninitialized",
    -2147213453: "SRCLNT_E_NO_EVENT_HANDLER",
    -2147207011: "SYNCH_CLASSES_SUCCESS",
    -2147207075: "THREAD_CLASS_SUCCESS",
    -2147211260: "VLDB_E_BUFFER_OVERFLOW",
    -2147211258: "VLDB_E_CATALOG_UNSUPPORT",
    -2147211262: "VLDB_E_DATA_TYPE_MISMATCH",
    -2147211261: "VLDB_E_MAPPING_TABLE_MISSING",
    -2147211256: "VLDB_E_NO_ASSOC",
    -2147211259: "VLDB_E_NULL_POINTER",
    -2147211263: "VLDB_E_TYPE_MAPPING_FAIL",
    -2147211257: "VLDB_E_UNKNOWN_DATA_TYPE",
    -2147211264: "VLDB_E_UNKNOWN_ERROR",
    -2147204503: "VLDB_E_UNSUPPORTED_DATETIME_INFORMIX",
    -2147213430: "XERCESXMLDOM_DOMSTRING_SIZE_ERROR",
    -2147213429: "XERCESXMLDOM_HIERARCHY_REQUEST_ERR",
    -2147213431: "XERCESXMLDOM_INDEX_SIZE_ERROR",
    -2147213412: "XERCESXMLDOM_INUSE_ATTRIBUTE_ERR",
    -2147213407: "XERCESXMLDOM_INVALID_ACCESS_ERR",
    -2147213427: "XERCESXMLDOM_INVALID_CHARACTER_ERR",
    -2147213409: "XERCESXMLDOM_INVALID_MODIFICATION_ERR",
    -2147213411: "XERCESXMLDOM_INVALID_STATE_ERR",
    -2147213408: "XERCESXMLDOM_NAMESPACE_ERR",
    -2147213414: "XERCESXMLDOM_NOT_FOUND_ERR",
    -2147213413: "XERCESXMLDOM_NOT_SUPPORTED_ERR",
    -2147213416: "XERCESXMLDOM_NO_DATA_ALLOWED_ERR",
    -2147213415: "XERCESXMLDOM_NO_MODIFICATION_ALLOWED_ERR",
    -2147213410: "XERCESXMLDOM_SYNTAX_ERR",
    -2147213432: "XERCESXMLDOM_UNDEFINE_ERR",
    -2147213428: "XERCESXMLDOM_WRONG_DOCUMENT_ERR",
    -2147212451: "XMLSAX_E_DEPTH_BEYOND_LIMIT",
    -2147213384: "XSLSTYLESHEET_NOSUPPORTED_ERR",
}
